Class: Google::Apis::ComputeAlpha::AcceleratorPodController

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Represents a controller for managing out-of-band access to an accelerator domain (e.g., NVLink Domain).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AcceleratorPodController

Returns a new instance of AcceleratorPodController.



175
176
177
# File 'lib/google/apis/compute_alpha/classes.rb', line 175

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


112
113
114
# File 'lib/google/apis/compute_alpha/classes.rb', line 112

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Corresponds to the JSON property description

Returns:

  • (String)


117
118
119
# File 'lib/google/apis/compute_alpha/classes.rb', line 117

def description
  @description
end

#idFixnum

Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


124
125
126
# File 'lib/google/apis/compute_alpha/classes.rb', line 124

def id
  @id
end

#kindString

Corresponds to the JSON property kind

Returns:

  • (String)


129
130
131
# File 'lib/google/apis/compute_alpha/classes.rb', line 129

def kind
  @kind
end

#management_interfacesHash<String,Google::Apis::ComputeAlpha::ManagementInterface>

Map of management interfaces. Keys must be valid RFC1035 names and at most 63 characters long. Corresponds to the JSON property managementInterfaces



135
136
137
# File 'lib/google/apis/compute_alpha/classes.rb', line 135

def management_interfaces
  @management_interfaces
end

#nameString

Required. The name of the resource, provided by the client when initially creating the resource. The resource name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


147
148
149
# File 'lib/google/apis/compute_alpha/classes.rb', line 147

def name
  @name
end

Output only. [Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


152
153
154
# File 'lib/google/apis/compute_alpha/classes.rb', line 152

def self_link
  @self_link
end

Output only. [Output Only] Server-defined URL for the resource with the resource ID. Corresponds to the JSON property selfLinkWithId

Returns:

  • (String)


158
159
160
# File 'lib/google/apis/compute_alpha/classes.rb', line 158

def self_link_with_id
  @self_link_with_id
end

#targetString

Required. The target accelerator domain this controller manages. This must be a resolvable identifier for the specific NVLink Domain or TPU system (e.g., a Reservation Sub-block URI). Example: "projects/my-project/reservations/my-reservation/subBlocks/subblock-1". Corresponds to the JSON property target

Returns:

  • (String)


167
168
169
# File 'lib/google/apis/compute_alpha/classes.rb', line 167

def target
  @target
end

#zoneString

Output only. [Output Only] URL of the zone where the accelerator pod controller resides. Corresponds to the JSON property zone

Returns:

  • (String)


173
174
175
# File 'lib/google/apis/compute_alpha/classes.rb', line 173

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



180
181
182
183
184
185
186
187
188
189
190
191
# File 'lib/google/apis/compute_alpha/classes.rb', line 180

def update!(**args)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @management_interfaces = args[:management_interfaces] if args.key?(:management_interfaces)
  @name = args[:name] if args.key?(:name)
  @self_link = args[:self_link] if args.key?(:self_link)
  @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id)
  @target = args[:target] if args.key?(:target)
  @zone = args[:zone] if args.key?(:zone)
end