Class: Google::Apis::ComputeAlpha::AliasIpRange

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

An alias IP range attached to an instance's network interface.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AliasIpRange

Returns a new instance of AliasIpRange.



1686
1687
1688
# File 'lib/google/apis/compute_alpha/classes.rb', line 1686

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#candidate_subnetwork_range_namesArray<String>

Identifies the candidate subnetwork range names for the alias IPs to be allocated from. When it is set, the IP would be allocated from any subnetwork range defined here if the IPs are available. Only one of subnetwork_range_name or candidate_subnetwork_range_names should be set. Corresponds to the JSON property candidateSubnetworkRangeNames

Returns:

  • (Array<String>)


1663
1664
1665
# File 'lib/google/apis/compute_alpha/classes.rb', line 1663

def candidate_subnetwork_range_names
  @candidate_subnetwork_range_names
end

#effective_subnetwork_range_nameString

Output only. [Output Only] The subnetwork range name where the IP is allocated. It will be set to the subnetwork range where the IP is allocated only. Corresponds to the JSON property effectiveSubnetworkRangeName

Returns:

  • (String)


1669
1670
1671
# File 'lib/google/apis/compute_alpha/classes.rb', line 1669

def effective_subnetwork_range_name
  @effective_subnetwork_range_name
end

#ip_cidr_rangeString

The IP alias ranges to allocate for this interface. This IP CIDR range must belong to the specified subnetwork and cannot contain IP addresses reserved by system or used by other network interfaces. This range may be a single IP address (such as 10.2.3.4), a netmask (such as/24) or a CIDR- formatted string (such as10.1.2.0/24). Corresponds to the JSON property ipCidrRange

Returns:

  • (String)


1678
1679
1680
# File 'lib/google/apis/compute_alpha/classes.rb', line 1678

def ip_cidr_range
  @ip_cidr_range
end

#subnetwork_range_nameString

The name of a subnetwork secondary IP range from which to allocate an IP alias range. If not specified, the primary range of the subnetwork is used. Corresponds to the JSON property subnetworkRangeName

Returns:

  • (String)


1684
1685
1686
# File 'lib/google/apis/compute_alpha/classes.rb', line 1684

def subnetwork_range_name
  @subnetwork_range_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1691
1692
1693
1694
1695
1696
# File 'lib/google/apis/compute_alpha/classes.rb', line 1691

def update!(**args)
  @candidate_subnetwork_range_names = args[:candidate_subnetwork_range_names] if args.key?(:candidate_subnetwork_range_names)
  @effective_subnetwork_range_name = args[:effective_subnetwork_range_name] if args.key?(:effective_subnetwork_range_name)
  @ip_cidr_range = args[:ip_cidr_range] if args.key?(:ip_cidr_range)
  @subnetwork_range_name = args[:subnetwork_range_name] if args.key?(:subnetwork_range_name)
end