Class: Google::Apis::ComputeAlpha::AllocationAggregateReservation

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

This reservation type is specified by total resource amounts (e.g. total count of CPUs) and can account for multiple instance SKUs. In other words, one can create instances of varying shapes against this reservation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AllocationAggregateReservation

Returns a new instance of AllocationAggregateReservation.



1744
1745
1746
# File 'lib/google/apis/compute_alpha/classes.rb', line 1744

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#host_countFixnum

Count of reserved hosts of specified VM family. The host has fixed number of accelerators based on the accelerator/vm-family selected. Corresponds to the JSON property hostCount

Returns:

  • (Fixnum)


1709
1710
1711
# File 'lib/google/apis/compute_alpha/classes.rb', line 1709

def host_count
  @host_count
end

#in_use_host_countFixnum

Output only. Number of hosts currently in use. If there is one or more Instances running on the host, it is considered in use. Corresponds to the JSON property inUseHostCount

Returns:

  • (Fixnum)


1716
1717
1718
# File 'lib/google/apis/compute_alpha/classes.rb', line 1716

def in_use_host_count
  @in_use_host_count
end

#in_use_instance_countFixnum

Output only. Number of instances currently in use in this reservation. Corresponds to the JSON property inUseInstanceCount

Returns:

  • (Fixnum)


1721
1722
1723
# File 'lib/google/apis/compute_alpha/classes.rb', line 1721

def in_use_instance_count
  @in_use_instance_count
end

#in_use_resourcesArray<Google::Apis::ComputeAlpha::AllocationAggregateReservationReservedResourceInfo>

Output only. [Output only] List of resources currently in use. Corresponds to the JSON property inUseResources



1726
1727
1728
# File 'lib/google/apis/compute_alpha/classes.rb', line 1726

def in_use_resources
  @in_use_resources
end

#reserved_resourcesArray<Google::Apis::ComputeAlpha::AllocationAggregateReservationReservedResourceInfo>

List of reserved resources (CPUs, memory, accelerators). Corresponds to the JSON property reservedResources



1731
1732
1733
# File 'lib/google/apis/compute_alpha/classes.rb', line 1731

def reserved_resources
  @reserved_resources
end

#vm_familyString

The VM family that all instances scheduled against this reservation must belong to. Corresponds to the JSON property vmFamily

Returns:

  • (String)


1737
1738
1739
# File 'lib/google/apis/compute_alpha/classes.rb', line 1737

def vm_family
  @vm_family
end

#workload_typeString

The workload type of the instances that will target this reservation. Corresponds to the JSON property workloadType

Returns:

  • (String)


1742
1743
1744
# File 'lib/google/apis/compute_alpha/classes.rb', line 1742

def workload_type
  @workload_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1749
1750
1751
1752
1753
1754
1755
1756
1757
# File 'lib/google/apis/compute_alpha/classes.rb', line 1749

def update!(**args)
  @host_count = args[:host_count] if args.key?(:host_count)
  @in_use_host_count = args[:in_use_host_count] if args.key?(:in_use_host_count)
  @in_use_instance_count = args[:in_use_instance_count] if args.key?(:in_use_instance_count)
  @in_use_resources = args[:in_use_resources] if args.key?(:in_use_resources)
  @reserved_resources = args[:reserved_resources] if args.key?(:reserved_resources)
  @vm_family = args[:vm_family] if args.key?(:vm_family)
  @workload_type = args[:workload_type] if args.key?(:workload_type)
end