Class: Google::Apis::ComputeAlpha::AllocationResourceStatus
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::AllocationResourceStatus
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
[Output Only] Contains output only fields.
Instance Attribute Summary collapse
-
#aggregate_allocation ⇒ Google::Apis::ComputeAlpha::AllocationResourceStatusAggregateAllocation
Contains Properties set for the aggregate reservation.
-
#health_info ⇒ Google::Apis::ComputeAlpha::AllocationResourceStatusHealthInfo
Health information for the reservation.
-
#reservation_block_count ⇒ Fixnum
The number of reservation blocks associated with this reservation.
-
#reservation_maintenance ⇒ Google::Apis::ComputeAlpha::GroupMaintenanceInfo
Maintenance Info for ReservationBlocks.
-
#specific_sku_allocation ⇒ Google::Apis::ComputeAlpha::AllocationResourceStatusSpecificSkuAllocation
Contains Properties set for the reservation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AllocationResourceStatus
constructor
A new instance of AllocationResourceStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AllocationResourceStatus
Returns a new instance of AllocationResourceStatus.
1813 1814 1815 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 1813 def initialize(**args) update!(**args) end |
Instance Attribute Details
#aggregate_allocation ⇒ Google::Apis::ComputeAlpha::AllocationResourceStatusAggregateAllocation
Contains Properties set for the aggregate reservation.
Corresponds to the JSON property aggregateAllocation
1791 1792 1793 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 1791 def aggregate_allocation @aggregate_allocation end |
#health_info ⇒ Google::Apis::ComputeAlpha::AllocationResourceStatusHealthInfo
Health information for the reservation.
Corresponds to the JSON property healthInfo
1796 1797 1798 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 1796 def health_info @health_info end |
#reservation_block_count ⇒ Fixnum
The number of reservation blocks associated with this reservation.
Corresponds to the JSON property reservationBlockCount
1801 1802 1803 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 1801 def reservation_block_count @reservation_block_count end |
#reservation_maintenance ⇒ Google::Apis::ComputeAlpha::GroupMaintenanceInfo
Maintenance Info for ReservationBlocks.
Corresponds to the JSON property reservationMaintenance
1806 1807 1808 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 1806 def reservation_maintenance @reservation_maintenance end |
#specific_sku_allocation ⇒ Google::Apis::ComputeAlpha::AllocationResourceStatusSpecificSkuAllocation
Contains Properties set for the reservation.
Corresponds to the JSON property specificSkuAllocation
1811 1812 1813 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 1811 def specific_sku_allocation @specific_sku_allocation end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1818 1819 1820 1821 1822 1823 1824 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 1818 def update!(**args) @aggregate_allocation = args[:aggregate_allocation] if args.key?(:aggregate_allocation) @health_info = args[:health_info] if args.key?(:health_info) @reservation_block_count = args[:reservation_block_count] if args.key?(:reservation_block_count) @reservation_maintenance = args[:reservation_maintenance] if args.key?(:reservation_maintenance) @specific_sku_allocation = args[:specific_sku_allocation] if args.key?(:specific_sku_allocation) end |