Class: Google::Apis::ComputeAlpha::AutoscalerAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AutoscalerAggregatedList

Returns a new instance of AutoscalerAggregatedList.



3015
3016
3017
# File 'lib/google/apis/compute_alpha/classes.rb', line 3015

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


2975
2976
2977
# File 'lib/google/apis/compute_alpha/classes.rb', line 2975

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::AutoscalersScopedList>

A list of AutoscalersScopedList resources. Corresponds to the JSON property items



2980
2981
2982
# File 'lib/google/apis/compute_alpha/classes.rb', line 2980

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# autoscalerAggregatedList for aggregated lists of autoscalers. Corresponds to the JSON property kind

Returns:

  • (String)


2987
2988
2989
# File 'lib/google/apis/compute_alpha/classes.rb', line 2987

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


2997
2998
2999
# File 'lib/google/apis/compute_alpha/classes.rb', line 2997

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


3002
3003
3004
# File 'lib/google/apis/compute_alpha/classes.rb', line 3002

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


3008
3009
3010
# File 'lib/google/apis/compute_alpha/classes.rb', line 3008

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::AutoscalerAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



3013
3014
3015
# File 'lib/google/apis/compute_alpha/classes.rb', line 3013

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3020
3021
3022
3023
3024
3025
3026
3027
3028
# File 'lib/google/apis/compute_alpha/classes.rb', line 3020

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end