Class: Google::Apis::ComputeAlpha::BackendBucketCdnPolicyCacheKeyPolicy

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Message containing what to include in the cache key for a request for Cloud CDN.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BackendBucketCdnPolicyCacheKeyPolicy

Returns a new instance of BackendBucketCdnPolicyCacheKeyPolicy.



4202
4203
4204
# File 'lib/google/apis/compute_alpha/classes.rb', line 4202

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#include_http_headersArray<String>

Allows HTTP request headers (by name) to be used in the cache key. Corresponds to the JSON property includeHttpHeaders

Returns:

  • (Array<String>)


4193
4194
4195
# File 'lib/google/apis/compute_alpha/classes.rb', line 4193

def include_http_headers
  @include_http_headers
end

#query_string_whitelistArray<String>

Names of query string parameters to include in cache keys. Default parameters are always included. '&' and '=' will be percent encoded and not treated as delimiters. Corresponds to the JSON property queryStringWhitelist

Returns:

  • (Array<String>)


4200
4201
4202
# File 'lib/google/apis/compute_alpha/classes.rb', line 4200

def query_string_whitelist
  @query_string_whitelist
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4207
4208
4209
4210
# File 'lib/google/apis/compute_alpha/classes.rb', line 4207

def update!(**args)
  @include_http_headers = args[:include_http_headers] if args.key?(:include_http_headers)
  @query_string_whitelist = args[:query_string_whitelist] if args.key?(:query_string_whitelist)
end