Class: Google::Apis::ComputeAlpha::BackendBucketList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of BackendBucket resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BackendBucketList

Returns a new instance of BackendBucketList.



4604
4605
4606
# File 'lib/google/apis/compute_alpha/classes.rb', line 4604

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


4572
4573
4574
# File 'lib/google/apis/compute_alpha/classes.rb', line 4572

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::BackendBucket>

A list of BackendBucket resources. Corresponds to the JSON property items



4577
4578
4579
# File 'lib/google/apis/compute_alpha/classes.rb', line 4577

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


4582
4583
4584
# File 'lib/google/apis/compute_alpha/classes.rb', line 4582

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


4592
4593
4594
# File 'lib/google/apis/compute_alpha/classes.rb', line 4592

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


4597
4598
4599
# File 'lib/google/apis/compute_alpha/classes.rb', line 4597

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::BackendBucketList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



4602
4603
4604
# File 'lib/google/apis/compute_alpha/classes.rb', line 4602

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4609
4610
4611
4612
4613
4614
4615
4616
# File 'lib/google/apis/compute_alpha/classes.rb', line 4609

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end