Class: Google::Apis::ComputeAlpha::BackendService

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Represents a Backend Service resource. A backend service defines how Google Cloud load balancers distribute traffic. The backend service configuration contains a set of values, such as the protocol used to connect to backends, various distribution and session settings, health checks, and timeouts. These settings provide fine-grained control over how your load balancer behaves. Most of the settings have default values that allow for easy configuration if you need to get started quickly. Backend services in Google Compute Engine can be either regionally or globally scoped.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BackendService

Returns a new instance of BackendService.



5532
5533
5534
# File 'lib/google/apis/compute_alpha/classes.rb', line 5532

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

Lifetime of cookies in seconds. This setting is applicable to Application Load Balancers and Traffic Director and requires GENERATED_COOKIE or HTTP_COOKIE session affinity. If set to 0, the cookie is non-persistent and lasts only until the end of the browser session (or equivalent). The maximum allowed value is two weeks (1,209,600). Not supported when the backend service is referenced by a URL map that is bound to target gRPC proxy that has validateForProxyless field set to true. Corresponds to the JSON property affinityCookieTtlSec

Returns:

  • (Fixnum)


5011
5012
5013
# File 'lib/google/apis/compute_alpha/classes.rb', line 5011

def affinity_cookie_ttl_sec
  @affinity_cookie_ttl_sec
end

#allow_multinetworkBoolean Also known as: allow_multinetwork?

A boolean flag enabling multi-network mesh. This field is only allowed with load balancing scheme set to INTERNAL_SELF_MANAGED. Corresponds to the JSON property allowMultinetwork

Returns:

  • (Boolean)


5017
5018
5019
# File 'lib/google/apis/compute_alpha/classes.rb', line 5017

def allow_multinetwork
  @allow_multinetwork
end

#backendsArray<Google::Apis::ComputeAlpha::Backend>

The list of backends that serve this BackendService. Corresponds to the JSON property backends



5023
5024
5025
# File 'lib/google/apis/compute_alpha/classes.rb', line 5023

def backends
  @backends
end

#cdn_policyGoogle::Apis::ComputeAlpha::BackendServiceCdnPolicy

Message containing Cloud CDN configuration for a backend service. Corresponds to the JSON property cdnPolicy



5028
5029
5030
# File 'lib/google/apis/compute_alpha/classes.rb', line 5028

def cdn_policy
  @cdn_policy
end

#circuit_breakersGoogle::Apis::ComputeAlpha::CircuitBreakers

Settings controlling the volume of requests, connections and retries to this backend service. Corresponds to the JSON property circuitBreakers



5034
5035
5036
# File 'lib/google/apis/compute_alpha/classes.rb', line 5034

def circuit_breakers
  @circuit_breakers
end

#compression_modeString

Compress text responses using Brotli or gzip compression, based on the client's Accept-Encoding header. Corresponds to the JSON property compressionMode

Returns:

  • (String)


5040
5041
5042
# File 'lib/google/apis/compute_alpha/classes.rb', line 5040

def compression_mode
  @compression_mode
end

#connection_drainingGoogle::Apis::ComputeAlpha::ConnectionDraining

Message containing connection draining configuration. Corresponds to the JSON property connectionDraining



5045
5046
5047
# File 'lib/google/apis/compute_alpha/classes.rb', line 5045

def connection_draining
  @connection_draining
end

#connection_tracking_policyGoogle::Apis::ComputeAlpha::BackendServiceConnectionTrackingPolicy

Connection Tracking configuration for this BackendService. Corresponds to the JSON property connectionTrackingPolicy



5050
5051
5052
# File 'lib/google/apis/compute_alpha/classes.rb', line 5050

def connection_tracking_policy
  @connection_tracking_policy
end

#consistent_hashGoogle::Apis::ComputeAlpha::ConsistentHashLoadBalancerSettings

This message defines settings for a consistent hash style load balancer. Corresponds to the JSON property consistentHash



5055
5056
5057
# File 'lib/google/apis/compute_alpha/classes.rb', line 5055

def consistent_hash
  @consistent_hash
end

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


5061
5062
5063
# File 'lib/google/apis/compute_alpha/classes.rb', line 5061

def creation_timestamp
  @creation_timestamp
end

#custom_metricsArray<Google::Apis::ComputeAlpha::BackendServiceCustomMetric>

List of custom metrics that are used for theWEIGHTED_ROUND_ROBIN locality_lb_policy. Corresponds to the JSON property customMetrics



5067
5068
5069
# File 'lib/google/apis/compute_alpha/classes.rb', line 5067

def custom_metrics
  @custom_metrics
end

#custom_request_headersArray<String>

Headers that the load balancer adds to proxied requests. See Creating custom headers. Corresponds to the JSON property customRequestHeaders

Returns:

  • (Array<String>)


5074
5075
5076
# File 'lib/google/apis/compute_alpha/classes.rb', line 5074

def custom_request_headers
  @custom_request_headers
end

#custom_response_headersArray<String>

Headers that the load balancer adds to proxied responses. See Creating custom headers. Corresponds to the JSON property customResponseHeaders

Returns:

  • (Array<String>)


5081
5082
5083
# File 'lib/google/apis/compute_alpha/classes.rb', line 5081

def custom_response_headers
  @custom_response_headers
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


5087
5088
5089
# File 'lib/google/apis/compute_alpha/classes.rb', line 5087

def description
  @description
end

#dynamic_forwardingGoogle::Apis::ComputeAlpha::BackendServiceDynamicForwarding

Defines a dynamic forwarding configuration for the backend service. Corresponds to the JSON property dynamicForwarding



5092
5093
5094
# File 'lib/google/apis/compute_alpha/classes.rb', line 5092

def dynamic_forwarding
  @dynamic_forwarding
end

#edge_security_policyString

[Output Only] The resource URL for the edge security policy associated with this backend service. Corresponds to the JSON property edgeSecurityPolicy

Returns:

  • (String)


5098
5099
5100
# File 'lib/google/apis/compute_alpha/classes.rb', line 5098

def edge_security_policy
  @edge_security_policy
end

#enable_cdnBoolean Also known as: enable_cdn?

If true, enables Cloud CDN for the backend service of a global external Application Load Balancer. Corresponds to the JSON property enableCDN

Returns:

  • (Boolean)


5104
5105
5106
# File 'lib/google/apis/compute_alpha/classes.rb', line 5104

def enable_cdn
  @enable_cdn
end

#external_managed_migration_stateString

Specifies the canary migration state. Possible values are PREPARE, TEST_BY_PERCENTAGE, and TEST_ALL_TRAFFIC. To begin the migration from EXTERNAL to EXTERNAL_MANAGED, the state must be changed to PREPARE. The state must be changed to TEST_ALL_TRAFFIC before the loadBalancingScheme can be changed to EXTERNAL_MANAGED. Optionally, the TEST_BY_PERCENTAGE state can be used to migrate traffic by percentage using externalManagedMigrationTestingPercentage. Rolling back a migration requires the states to be set in reverse order. So changing the scheme from EXTERNAL_MANAGED to EXTERNAL requires the state to be set to TEST_ALL_TRAFFIC at the same time. Optionally, the TEST_BY_PERCENTAGE state can be used to migrate some traffic back to EXTERNAL or PREPARE can be used to migrate all traffic back to EXTERNAL. Corresponds to the JSON property externalManagedMigrationState

Returns:

  • (String)


5121
5122
5123
# File 'lib/google/apis/compute_alpha/classes.rb', line 5121

def external_managed_migration_state
  @external_managed_migration_state
end

#external_managed_migration_testing_percentageFloat

Determines the fraction of requests that should be processed by the Global external Application Load Balancer. The value of this field must be in the range [0, 100]. Session affinity options will slightly affect this routing behavior, for more details, see:Session Affinity. This value can only be set if the loadBalancingScheme in the BackendService is set to EXTERNAL (when using the classic Application Load Balancer) and the migration state is TEST_BY_PERCENTAGE. Corresponds to the JSON property externalManagedMigrationTestingPercentage

Returns:

  • (Float)


5134
5135
5136
# File 'lib/google/apis/compute_alpha/classes.rb', line 5134

def external_managed_migration_testing_percentage
  @external_managed_migration_testing_percentage
end

#failover_policyGoogle::Apis::ComputeAlpha::BackendServiceFailoverPolicy

For load balancers that have configurable failover: Internal passthrough Network Load Balancers and external passthrough Network Load Balancers. On failover or failback, this field indicates whether connection draining will be honored. Google Cloud has a fixed connection draining timeout of 10 minutes. A setting of true terminates existing TCP connections to the active pool during failover and failback, immediately draining traffic. A setting of false allows existing TCP connections to persist, even on VMs no longer in the active pool, for up to the duration of the connection draining timeout (10 minutes). Corresponds to the JSON property failoverPolicy



5154
5155
5156
# File 'lib/google/apis/compute_alpha/classes.rb', line 5154

def failover_policy
  @failover_policy
end

#fingerprintString

Fingerprint of this resource. A hash of the contents stored in this object. This field is used in optimistic locking. This field will be ignored when inserting a BackendService. An up-to-date fingerprint must be provided in order to update the BackendService, otherwise the request will fail with error 412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve a BackendService. Corresponds to the JSON property fingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


5166
5167
5168
# File 'lib/google/apis/compute_alpha/classes.rb', line 5166

def fingerprint
  @fingerprint
end

#ha_policyGoogle::Apis::ComputeAlpha::BackendServiceHaPolicy

Configures self-managed High Availability (HA) for External and Internal Protocol Forwarding. The backends of this regional backend service must only specify zonal network endpoint groups (NEGs) of type GCE_VM_IP. When haPolicy is set for an Internal Passthrough Network Load Balancer, the regional backend service must set the network field. All zonal NEGs must belong to the same network. However, individual NEGs can belong to different subnetworks of that network. When haPolicy is specified, the set of attached network endpoints across all backends comprise an High Availability domain from which one endpoint is selected as the active endpoint (the leader) that receives all traffic. haPolicy can be added only at backend service creation time. Once set up, it cannot be deleted. Note that haPolicy is not for load balancing, and therefore cannot be specified with sessionAffinity, connectionTrackingPolicy, and failoverPolicy. haPolicy requires customers to be responsible for tracking backend endpoint health and electing a leader among the healthy endpoints. Therefore, haPolicy cannot be specified with healthChecks. haPolicy can only be specified for External Passthrough Network Load Balancers and Internal Passthrough Network Load Balancers. Corresponds to the JSON property haPolicy



5192
5193
5194
# File 'lib/google/apis/compute_alpha/classes.rb', line 5192

def ha_policy
  @ha_policy
end

#health_checksArray<String>

The list of URLs to the healthChecks, httpHealthChecks (legacy), or httpsHealthChecks (legacy) resource for health checking this backend service. Not all backend services support legacy health checks. See Load balancer guide. Currently, at most one health check can be specified for each backend service. Backend services with instance group or zonal NEG backends must have a health check unless haPolicy is specified. Backend services with internet or serverless NEG backends must not have a health check. healthChecks[] cannot be specified with haPolicy. Corresponds to the JSON property healthChecks

Returns:

  • (Array<String>)


5205
5206
5207
# File 'lib/google/apis/compute_alpha/classes.rb', line 5205

def health_checks
  @health_checks
end

#iapGoogle::Apis::ComputeAlpha::BackendServiceIap

Identity-Aware Proxy Corresponds to the JSON property iap



5210
5211
5212
# File 'lib/google/apis/compute_alpha/classes.rb', line 5210

def iap
  @iap
end

#idFixnum

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


5216
5217
5218
# File 'lib/google/apis/compute_alpha/classes.rb', line 5216

def id
  @id
end

#ip_address_selection_policyString

Specifies a preference for traffic sent from the proxy to the backend (or from the client to the backend for proxyless gRPC). The possible values are:

  • IPV4_ONLY: Only send IPv4 traffic to the backends of the backend service (Instance Group, Managed Instance Group, Network Endpoint Group), regardless of traffic from the client to the proxy. Only IPv4 health checks are used to check the health of the backends. This is the default setting.
  • PREFER_IPV6: Prioritize the connection to the endpoint's IPv6 address over its IPv4 address (provided there is a healthy IPv6 address).
  • IPV6_ONLY: Only send IPv6 traffic to the backends of the backend service (Instance Group, Managed Instance Group, Network Endpoint Group), regardless of traffic from the client to the proxy. Only IPv6 health checks are used to check the health of the backends. This field is applicable to either:

  • Advanced global external Application Load Balancer (load balancing scheme EXTERNAL_MANAGED),

  • Regional external Application Load Balancer,

  • Internal proxy Network Load Balancer (load balancing scheme INTERNAL_MANAGED),

  • Regional internal Application Load Balancer (load balancing scheme INTERNAL_MANAGED),

  • Traffic Director with Envoy proxies and proxyless gRPC (load balancing scheme INTERNAL_SELF_MANAGED). Corresponds to the JSON property ipAddressSelectionPolicy

Returns:

  • (String)


5249
5250
5251
# File 'lib/google/apis/compute_alpha/classes.rb', line 5249

def ip_address_selection_policy
  @ip_address_selection_policy
end

#kindString

Output only. [Output Only] Type of resource. Always compute#backendService for backend services. Corresponds to the JSON property kind

Returns:

  • (String)


5255
5256
5257
# File 'lib/google/apis/compute_alpha/classes.rb', line 5255

def kind
  @kind
end

#load_balancing_schemeString

Specifies the load balancer type. A backend service created for one type of load balancer cannot be used with another. For more information, refer toChoosing a load balancer. Corresponds to the JSON property loadBalancingScheme

Returns:

  • (String)


5263
5264
5265
# File 'lib/google/apis/compute_alpha/classes.rb', line 5263

def load_balancing_scheme
  @load_balancing_scheme
end

#locality_lb_policiesArray<Google::Apis::ComputeAlpha::BackendServiceLocalityLoadBalancingPolicyConfig>

A list of locality load-balancing policies to be used in order of preference. When you use localityLbPolicies, you must set at least one value for either the localityLbPolicies[].policy or the localityLbPolicies[].customPolicy field. localityLbPolicies overrides any value set in the localityLbPolicy field. For an example of how to use this field, seeDefine a list of preferred policies. Caution: This field and its children are intended for use in a service mesh that includes gRPC clients only. Envoy proxies can't use backend services that have this configuration. Corresponds to the JSON property localityLbPolicies



5277
5278
5279
# File 'lib/google/apis/compute_alpha/classes.rb', line 5277

def locality_lb_policies
  @locality_lb_policies
end

#locality_lb_policyString

The load balancing algorithm used within the scope of the locality. The possible values are:

  • ROUND_ROBIN: This is a simple policy in which each healthy backend is selected in round robin order. This is the default.
  • LEAST_REQUEST: An O(1) algorithm which selects two random healthy hosts and picks the host which has fewer active requests.
  • RING_HASH: The ring/modulo hash load balancer implements consistent hashing to backends. The algorithm has the property that the addition/removal of a host from a set of N hosts only affects 1/N of the requests.
  • RANDOM: The load balancer selects a random healthy host.
  • ORIGINAL_DESTINATION: Backend host is selected based on the client connection metadata, i.e., connections are opened to the same address as the destination address of the incoming connection before the connection was redirected to the load balancer.
  • MAGLEV: used as a drop in replacement for the ring hash load balancer. Maglev is not as stable as ring hash but has faster table lookup build times and host selection times. For more information about Maglev, see Maglev: A Fast and Reliable Software Network Load Balancer.
  • WEIGHTED_ROUND_ROBIN: Per-endpoint Weighted Round Robin Load Balancing using weights computed from Backend reported Custom Metrics. If set, the Backend Service responses are expected to contain non-standard HTTP response header field Endpoint-Load-Metrics. The reported metrics to use for computing the weights are specified via thecustomMetrics field.

This field is applicable to either:

  • A regional backend service with the service protocol set to HTTP, HTTPS, HTTP2 or H2C, and load_balancing_scheme set to INTERNAL_MANAGED.
  • A global backend service with the load_balancing_scheme set to INTERNAL_SELF_MANAGED, INTERNAL_MANAGED, or EXTERNAL_MANAGED.

If sessionAffinity is not configured—that is, if session affinity remains at the default value of NONE—then the default value for localityLbPolicy is ROUND_ROBIN. If session affinity is set to a value other than NONE, then the default value for localityLbPolicy isMAGLEV.

Only ROUND_ROBIN and RING_HASH are supported when the backend service is referenced by a URL map that is bound to target gRPC proxy that has validateForProxyless field set to true.

localityLbPolicy cannot be specified with haPolicy. Corresponds to the JSON property localityLbPolicy

Returns:

  • (String)


5332
5333
5334
# File 'lib/google/apis/compute_alpha/classes.rb', line 5332

def locality_lb_policy
  @locality_lb_policy
end

#log_configGoogle::Apis::ComputeAlpha::BackendServiceLogConfig

The available logging options for the load balancer traffic served by this backend service. Corresponds to the JSON property logConfig



5338
5339
5340
# File 'lib/google/apis/compute_alpha/classes.rb', line 5338

def log_config
  @log_config
end

#max_stream_durationGoogle::Apis::ComputeAlpha::Duration

A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution. It is independent of any calendar and concepts like "day" or "month". Range is approximately 10,000 years. Corresponds to the JSON property maxStreamDuration



5346
5347
5348
# File 'lib/google/apis/compute_alpha/classes.rb', line 5346

def max_stream_duration
  @max_stream_duration
end

#metadatasHash<String,String>

Deployment metadata associated with the resource to be set by a GKE hub controller and read by the backend RCTH Corresponds to the JSON property metadatas

Returns:

  • (Hash<String,String>)


5352
5353
5354
# File 'lib/google/apis/compute_alpha/classes.rb', line 5352

def metadatas
  @metadatas
end

#nameString

Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


5363
5364
5365
# File 'lib/google/apis/compute_alpha/classes.rb', line 5363

def name
  @name
end

#networkString

The URL of the network to which this backend service belongs. This field must be set for Internal Passthrough Network Load Balancers when the haPolicy is enabled, and for External Passthrough Network Load Balancers when the haPolicy fastIpMove is enabled. This field can only be specified when the load balancing scheme is set toINTERNAL, or when the load balancing scheme is set toEXTERNAL and haPolicy fastIpMove is enabled. Corresponds to the JSON property network

Returns:

  • (String)


5374
5375
5376
# File 'lib/google/apis/compute_alpha/classes.rb', line 5374

def network
  @network
end

#network_pass_through_lb_traffic_policyGoogle::Apis::ComputeAlpha::BackendServiceNetworkPassThroughLbTrafficPolicy

Configures traffic steering properties of internal passthrough Network Load Balancers. networkPassThroughLbTrafficPolicy cannot be specified with haPolicy. Corresponds to the JSON property networkPassThroughLbTrafficPolicy



5381
5382
5383
# File 'lib/google/apis/compute_alpha/classes.rb', line 5381

def network_pass_through_lb_traffic_policy
  @network_pass_through_lb_traffic_policy
end

#orchestration_infoGoogle::Apis::ComputeAlpha::BackendServiceOrchestrationInfo

A message containing information about the resource or system that manages the backend service. Corresponds to the JSON property orchestrationInfo



5387
5388
5389
# File 'lib/google/apis/compute_alpha/classes.rb', line 5387

def orchestration_info
  @orchestration_info
end

#outlier_detectionGoogle::Apis::ComputeAlpha::OutlierDetection

Settings controlling the eviction of unhealthy hosts from the load balancing pool for the backend service. Corresponds to the JSON property outlierDetection



5393
5394
5395
# File 'lib/google/apis/compute_alpha/classes.rb', line 5393

def outlier_detection
  @outlier_detection
end

#paramsGoogle::Apis::ComputeAlpha::BackendServiceParams

Additional Backend Service parameters. Corresponds to the JSON property params



5398
5399
5400
# File 'lib/google/apis/compute_alpha/classes.rb', line 5398

def params
  @params
end

#portFixnum

Deprecated in favor of portName. The TCP port to connect on the backend. The default value is 80. For internal passthrough Network Load Balancers and external passthrough Network Load Balancers, omit port. Corresponds to the JSON property port

Returns:

  • (Fixnum)


5406
5407
5408
# File 'lib/google/apis/compute_alpha/classes.rb', line 5406

def port
  @port
end

#port_nameString

A named port on a backend instance group representing the port for communication to the backend VMs in that group. The named port must be defined on each backend instance group. This parameter has no meaning if the backends are NEGs. For internal passthrough Network Load Balancers and external passthrough Network Load Balancers, omit port_name. Corresponds to the JSON property portName

Returns:

  • (String)


5418
5419
5420
# File 'lib/google/apis/compute_alpha/classes.rb', line 5418

def port_name
  @port_name
end

#protocolString

The protocol this BackendService uses to communicate with backends. Possible values are HTTP, HTTPS, HTTP2, H2C, TCP, SSL, UDP or GRPC. depending on the chosen load balancer or Traffic Director configuration. Refer to the documentation for the load balancers or for Traffic Director for more information. Must be set to GRPC when the backend service is referenced by a URL map that is bound to target gRPC proxy. Corresponds to the JSON property protocol

Returns:

  • (String)


5430
5431
5432
# File 'lib/google/apis/compute_alpha/classes.rb', line 5430

def protocol
  @protocol
end

#regionString

Output only. [Output Only] URL of the region where the regional backend service resides. This field is not applicable to global backend services. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body. Corresponds to the JSON property region

Returns:

  • (String)


5439
5440
5441
# File 'lib/google/apis/compute_alpha/classes.rb', line 5439

def region
  @region
end

#security_policyString

[Output Only] The resource URL for the security policy associated with this backend service. Corresponds to the JSON property securityPolicy

Returns:

  • (String)


5445
5446
5447
# File 'lib/google/apis/compute_alpha/classes.rb', line 5445

def security_policy
  @security_policy
end

#security_settingsGoogle::Apis::ComputeAlpha::SecuritySettings

The authentication and authorization settings for a BackendService. Corresponds to the JSON property securitySettings



5450
5451
5452
# File 'lib/google/apis/compute_alpha/classes.rb', line 5450

def security_settings
  @security_settings
end

[Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


5455
5456
5457
# File 'lib/google/apis/compute_alpha/classes.rb', line 5455

def self_link
  @self_link
end

Output only. [Output Only] Server-defined URL for this resource with the resource id. Corresponds to the JSON property selfLinkWithId

Returns:

  • (String)


5461
5462
5463
# File 'lib/google/apis/compute_alpha/classes.rb', line 5461

def self_link_with_id
  @self_link_with_id
end

#service_bindingsArray<String>

URLs of networkservices.ServiceBinding resources. Can only be set if load balancing scheme is INTERNAL_SELF_MANAGED. If set, lists of backends and health checks must be both empty. Corresponds to the JSON property serviceBindings

Returns:

  • (Array<String>)


5468
5469
5470
# File 'lib/google/apis/compute_alpha/classes.rb', line 5468

def service_bindings
  @service_bindings
end

#service_lb_policyString

URL to networkservices.ServiceLbPolicy resource. Can only be set if load balancing scheme is EXTERNAL_MANAGED, INTERNAL_MANAGED or INTERNAL_SELF_MANAGED for a global backend service, and EXTERNAL_MANAGED or INTERNAL_MANAGED for a regional backend service. For a global backend service, the service lb policy must be global. For a regional backend service, the service lb policy must be regional and in the same region. Corresponds to the JSON property serviceLbPolicy

Returns:

  • (String)


5479
5480
5481
# File 'lib/google/apis/compute_alpha/classes.rb', line 5479

def service_lb_policy
  @service_lb_policy
end

#session_affinityString

Type of session affinity to use. The default is NONE. Only NONE and HEADER_FIELD are supported when the backend service is referenced by a URL map that is bound to target gRPC proxy that has validateForProxyless field set to true. For more details, see: Session Affinity. sessionAffinity cannot be specified with haPolicy. Corresponds to the JSON property sessionAffinity

Returns:

  • (String)


5492
5493
5494
# File 'lib/google/apis/compute_alpha/classes.rb', line 5492

def session_affinity
  @session_affinity
end

The HTTP cookie used for stateful session affinity. Corresponds to the JSON property strongSessionAffinityCookie



5497
5498
5499
# File 'lib/google/apis/compute_alpha/classes.rb', line 5497

def strong_session_affinity_cookie
  @strong_session_affinity_cookie
end

#subsettingGoogle::Apis::ComputeAlpha::Subsetting

Subsetting configuration for this BackendService. Currently this is applicable only for Internal TCP/UDP load balancing, Internal HTTP(S) load balancing and Traffic Director. Corresponds to the JSON property subsetting



5504
5505
5506
# File 'lib/google/apis/compute_alpha/classes.rb', line 5504

def subsetting
  @subsetting
end

#timeout_secFixnum

The backend service timeout has a different meaning depending on the type of load balancer. For more information see, Backend service settings. The default is 30 seconds. The full range of timeout values allowed goes from 1 through 2,147,483,647 seconds. This value can be overridden in the PathMatcher configuration of the UrlMap that references this backend service. Not supported when the backend service is referenced by a URL map that is bound to target gRPC proxy that has validateForProxyless field set to true. Instead, use maxStreamDuration. Corresponds to the JSON property timeoutSec

Returns:

  • (Fixnum)


5519
5520
5521
# File 'lib/google/apis/compute_alpha/classes.rb', line 5519

def timeout_sec
  @timeout_sec
end

#tls_settingsGoogle::Apis::ComputeAlpha::BackendServiceTlsSettings

Configuration for Backend Authenticated TLS and mTLS. May only be specified when the backend protocol is SSL, HTTPS or HTTP2. Corresponds to the JSON property tlsSettings



5525
5526
5527
# File 'lib/google/apis/compute_alpha/classes.rb', line 5525

def tls_settings
  @tls_settings
end

#used_byArray<Google::Apis::ComputeAlpha::BackendServiceUsedBy>

Output only. [Output Only] List of resources referencing given backend service. Corresponds to the JSON property usedBy



5530
5531
5532
# File 'lib/google/apis/compute_alpha/classes.rb', line 5530

def used_by
  @used_by
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5537
5538
5539
5540
5541
5542
5543
5544
5545
5546
5547
5548
5549
5550
5551
5552
5553
5554
5555
5556
5557
5558
5559
5560
5561
5562
5563
5564
5565
5566
5567
5568
5569
5570
5571
5572
5573
5574
5575
5576
5577
5578
5579
5580
5581
5582
5583
5584
5585
5586
5587
5588
5589
5590
5591
5592
5593
# File 'lib/google/apis/compute_alpha/classes.rb', line 5537

def update!(**args)
  @affinity_cookie_ttl_sec = args[:affinity_cookie_ttl_sec] if args.key?(:affinity_cookie_ttl_sec)
  @allow_multinetwork = args[:allow_multinetwork] if args.key?(:allow_multinetwork)
  @backends = args[:backends] if args.key?(:backends)
  @cdn_policy = args[:cdn_policy] if args.key?(:cdn_policy)
  @circuit_breakers = args[:circuit_breakers] if args.key?(:circuit_breakers)
  @compression_mode = args[:compression_mode] if args.key?(:compression_mode)
  @connection_draining = args[:connection_draining] if args.key?(:connection_draining)
  @connection_tracking_policy = args[:connection_tracking_policy] if args.key?(:connection_tracking_policy)
  @consistent_hash = args[:consistent_hash] if args.key?(:consistent_hash)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @custom_metrics = args[:custom_metrics] if args.key?(:custom_metrics)
  @custom_request_headers = args[:custom_request_headers] if args.key?(:custom_request_headers)
  @custom_response_headers = args[:custom_response_headers] if args.key?(:custom_response_headers)
  @description = args[:description] if args.key?(:description)
  @dynamic_forwarding = args[:dynamic_forwarding] if args.key?(:dynamic_forwarding)
  @edge_security_policy = args[:edge_security_policy] if args.key?(:edge_security_policy)
  @enable_cdn = args[:enable_cdn] if args.key?(:enable_cdn)
  @external_managed_migration_state = args[:external_managed_migration_state] if args.key?(:external_managed_migration_state)
  @external_managed_migration_testing_percentage = args[:external_managed_migration_testing_percentage] if args.key?(:external_managed_migration_testing_percentage)
  @failover_policy = args[:failover_policy] if args.key?(:failover_policy)
  @fingerprint = args[:fingerprint] if args.key?(:fingerprint)
  @ha_policy = args[:ha_policy] if args.key?(:ha_policy)
  @health_checks = args[:health_checks] if args.key?(:health_checks)
  @iap = args[:iap] if args.key?(:iap)
  @id = args[:id] if args.key?(:id)
  @ip_address_selection_policy = args[:ip_address_selection_policy] if args.key?(:ip_address_selection_policy)
  @kind = args[:kind] if args.key?(:kind)
  @load_balancing_scheme = args[:load_balancing_scheme] if args.key?(:load_balancing_scheme)
  @locality_lb_policies = args[:locality_lb_policies] if args.key?(:locality_lb_policies)
  @locality_lb_policy = args[:locality_lb_policy] if args.key?(:locality_lb_policy)
  @log_config = args[:log_config] if args.key?(:log_config)
  @max_stream_duration = args[:max_stream_duration] if args.key?(:max_stream_duration)
  @metadatas = args[:metadatas] if args.key?(:metadatas)
  @name = args[:name] if args.key?(:name)
  @network = args[:network] if args.key?(:network)
  @network_pass_through_lb_traffic_policy = args[:network_pass_through_lb_traffic_policy] if args.key?(:network_pass_through_lb_traffic_policy)
  @orchestration_info = args[:orchestration_info] if args.key?(:orchestration_info)
  @outlier_detection = args[:outlier_detection] if args.key?(:outlier_detection)
  @params = args[:params] if args.key?(:params)
  @port = args[:port] if args.key?(:port)
  @port_name = args[:port_name] if args.key?(:port_name)
  @protocol = args[:protocol] if args.key?(:protocol)
  @region = args[:region] if args.key?(:region)
  @security_policy = args[:security_policy] if args.key?(:security_policy)
  @security_settings = args[:security_settings] if args.key?(:security_settings)
  @self_link = args[:self_link] if args.key?(:self_link)
  @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id)
  @service_bindings = args[:service_bindings] if args.key?(:service_bindings)
  @service_lb_policy = args[:service_lb_policy] if args.key?(:service_lb_policy)
  @session_affinity = args[:session_affinity] if args.key?(:session_affinity)
  @strong_session_affinity_cookie = args[:strong_session_affinity_cookie] if args.key?(:strong_session_affinity_cookie)
  @subsetting = args[:subsetting] if args.key?(:subsetting)
  @timeout_sec = args[:timeout_sec] if args.key?(:timeout_sec)
  @tls_settings = args[:tls_settings] if args.key?(:tls_settings)
  @used_by = args[:used_by] if args.key?(:used_by)
end