Class: Google::Apis::ComputeAlpha::BackendServiceAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::BackendServiceAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Contains a list of BackendServicesScopedList.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::BackendServicesScopedList>
A list of BackendServicesScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::BackendServiceAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BackendServiceAggregatedList
constructor
A new instance of BackendServiceAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BackendServiceAggregatedList
Returns a new instance of BackendServiceAggregatedList.
5670 5671 5672 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 5670 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
5633 5634 5635 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 5633 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::BackendServicesScopedList>
A list of BackendServicesScopedList resources.
Corresponds to the JSON property items
5638 5639 5640 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 5638 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
5643 5644 5645 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 5643 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
5653 5654 5655 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 5653 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
5658 5659 5660 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 5658 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
5663 5664 5665 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 5663 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::BackendServiceAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
5668 5669 5670 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 5668 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5675 5676 5677 5678 5679 5680 5681 5682 5683 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 5675 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |