Class: Google::Apis::ComputeAlpha::BackendServiceIap

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Identity-Aware Proxy

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BackendServiceIap

Returns a new instance of BackendServiceIap.



6184
6185
6186
# File 'lib/google/apis/compute_alpha/classes.rb', line 6184

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enabledBoolean Also known as: enabled?

Whether the serving infrastructure will authenticate and authorize all incoming requests. Corresponds to the JSON property enabled

Returns:

  • (Boolean)


6155
6156
6157
# File 'lib/google/apis/compute_alpha/classes.rb', line 6155

def enabled
  @enabled
end

#oauth2_client_idString

OAuth2 client ID to use for the authentication flow. Corresponds to the JSON property oauth2ClientId

Returns:

  • (String)


6161
6162
6163
# File 'lib/google/apis/compute_alpha/classes.rb', line 6161

def oauth2_client_id
  @oauth2_client_id
end

#oauth2_client_infoGoogle::Apis::ComputeAlpha::BackendServiceIapoAuth2ClientInfo

[Input Only] OAuth client info required to generate client id to be used for IAP. Corresponds to the JSON property oauth2ClientInfo



6167
6168
6169
# File 'lib/google/apis/compute_alpha/classes.rb', line 6167

def oauth2_client_info
  @oauth2_client_info
end

#oauth2_client_secretString

OAuth2 client secret to use for the authentication flow. For security reasons, this value cannot be retrieved via the API. Instead, the SHA-256 hash of the value is returned in the oauth2ClientSecretSha256 field. Corresponds to the JSON property oauth2ClientSecret

Returns:

  • (String)


6176
6177
6178
# File 'lib/google/apis/compute_alpha/classes.rb', line 6176

def oauth2_client_secret
  @oauth2_client_secret
end

#oauth2_client_secret_sha256String

Output only. [Output Only] SHA256 hash value for the field oauth2_client_secret above. Corresponds to the JSON property oauth2ClientSecretSha256

Returns:

  • (String)


6182
6183
6184
# File 'lib/google/apis/compute_alpha/classes.rb', line 6182

def oauth2_client_secret_sha256
  @oauth2_client_secret_sha256
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6189
6190
6191
6192
6193
6194
6195
# File 'lib/google/apis/compute_alpha/classes.rb', line 6189

def update!(**args)
  @enabled = args[:enabled] if args.key?(:enabled)
  @oauth2_client_id = args[:oauth2_client_id] if args.key?(:oauth2_client_id)
  @oauth2_client_info = args[:oauth2_client_info] if args.key?(:oauth2_client_info)
  @oauth2_client_secret = args[:oauth2_client_secret] if args.key?(:oauth2_client_secret)
  @oauth2_client_secret_sha256 = args[:oauth2_client_secret_sha256] if args.key?(:oauth2_client_secret_sha256)
end