Class: Google::Apis::ComputeAlpha::BackendServiceList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of BackendService resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BackendServiceList

Returns a new instance of BackendServiceList.



6602
6603
6604
# File 'lib/google/apis/compute_alpha/classes.rb', line 6602

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


6569
6570
6571
# File 'lib/google/apis/compute_alpha/classes.rb', line 6569

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::BackendService>

A list of BackendService resources. Corresponds to the JSON property items



6574
6575
6576
# File 'lib/google/apis/compute_alpha/classes.rb', line 6574

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute#backendServiceList for lists of backend services. Corresponds to the JSON property kind

Returns:

  • (String)


6580
6581
6582
# File 'lib/google/apis/compute_alpha/classes.rb', line 6580

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


6590
6591
6592
# File 'lib/google/apis/compute_alpha/classes.rb', line 6590

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


6595
6596
6597
# File 'lib/google/apis/compute_alpha/classes.rb', line 6595

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::BackendServiceList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



6600
6601
6602
# File 'lib/google/apis/compute_alpha/classes.rb', line 6600

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6607
6608
6609
6610
6611
6612
6613
6614
# File 'lib/google/apis/compute_alpha/classes.rb', line 6607

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end