Class: Google::Apis::ComputeAlpha::BackendServiceLocalityLoadBalancingPolicyConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Container for either a built-in LB policy supported by gRPC or Envoy or a custom one implemented by the end user.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BackendServiceLocalityLoadBalancingPolicyConfig

Returns a new instance of BackendServiceLocalityLoadBalancingPolicyConfig.



6829
6830
6831
# File 'lib/google/apis/compute_alpha/classes.rb', line 6829

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#custom_policyGoogle::Apis::ComputeAlpha::BackendServiceLocalityLoadBalancingPolicyConfigCustomPolicy

The configuration for a custom policy implemented by the user and deployed with the client. Corresponds to the JSON property customPolicy



6822
6823
6824
# File 'lib/google/apis/compute_alpha/classes.rb', line 6822

def custom_policy
  @custom_policy
end

#policyGoogle::Apis::ComputeAlpha::BackendServiceLocalityLoadBalancingPolicyConfigPolicy

The configuration for a built-in load balancing policy. Corresponds to the JSON property policy



6827
6828
6829
# File 'lib/google/apis/compute_alpha/classes.rb', line 6827

def policy
  @policy
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6834
6835
6836
6837
# File 'lib/google/apis/compute_alpha/classes.rb', line 6834

def update!(**args)
  @custom_policy = args[:custom_policy] if args.key?(:custom_policy)
  @policy = args[:policy] if args.key?(:policy)
end