Class: Google::Apis::ComputeAlpha::BackendServiceLocalityLoadBalancingPolicyConfigCustomPolicy

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

The configuration for a custom policy implemented by the user and deployed with the client.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BackendServiceLocalityLoadBalancingPolicyConfigCustomPolicy

Returns a new instance of BackendServiceLocalityLoadBalancingPolicyConfigCustomPolicy.



6833
6834
6835
# File 'lib/google/apis/compute_alpha/classes.rb', line 6833

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dataString

An optional, arbitrary JSON object with configuration data, understood by a locally installed custom policy implementation. Corresponds to the JSON property data

Returns:

  • (String)


6818
6819
6820
# File 'lib/google/apis/compute_alpha/classes.rb', line 6818

def data
  @data
end

#nameString

Identifies the custom policy. The value should match the name of a custom implementation registered on the gRPC clients. It should follow protocol buffer message naming conventions and include the full path (for example, myorg.CustomLbPolicy). The maximum length is 256 characters. Do not specify the same custom policy more than once for a backend. If you do, the configuration is rejected. For an example of how to use this field, seeUse a custom policy. Corresponds to the JSON property name

Returns:

  • (String)


6831
6832
6833
# File 'lib/google/apis/compute_alpha/classes.rb', line 6831

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6838
6839
6840
6841
# File 'lib/google/apis/compute_alpha/classes.rb', line 6838

def update!(**args)
  @data = args[:data] if args.key?(:data)
  @name = args[:name] if args.key?(:name)
end