Class: Google::Apis::ComputeAlpha::BackendServiceNetworkPassThroughLbTrafficPolicyZonalAffinity
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::BackendServiceNetworkPassThroughLbTrafficPolicyZonalAffinity
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#spillover ⇒ String
This field indicates whether zonal affinity is enabled or not.
-
#spillover_ratio ⇒ Float
The value of the field must be in [0, 1].
Instance Method Summary collapse
-
#initialize(**args) ⇒ BackendServiceNetworkPassThroughLbTrafficPolicyZonalAffinity
constructor
A new instance of BackendServiceNetworkPassThroughLbTrafficPolicyZonalAffinity.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BackendServiceNetworkPassThroughLbTrafficPolicyZonalAffinity
Returns a new instance of BackendServiceNetworkPassThroughLbTrafficPolicyZonalAffinity.
7016 7017 7018 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 7016 def initialize(**args) update!(**args) end |
Instance Attribute Details
#spillover ⇒ String
This field indicates whether zonal affinity is enabled or not. The possible values are:
- ZONAL_AFFINITY_DISABLED: Default Value. Zonal Affinity is disabled. The load balancer distributes new connections to all healthy backend endpoints across all zones.
- ZONAL_AFFINITY_STAY_WITHIN_ZONE: Zonal Affinity is enabled. The load balancer distributes new connections to all healthy backend endpoints in the local zone only. If there are no healthy backend endpoints in the local zone, the load balancer distributes new connections to all backend endpoints in the local zone.
- ZONAL_AFFINITY_SPILL_CROSS_ZONE: Zonal Affinity is
enabled. The load balancer distributes new connections to all healthy
backend endpoints in the local zone only. If there aren't enough
healthy backend endpoints in the local zone, the load balancer
distributes new connections to all healthy backend endpoints across all
zones.
Corresponds to the JSON property
spillover
7002 7003 7004 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 7002 def spillover @spillover end |
#spillover_ratio ⇒ Float
The value of the field must be in [0, 1]. When the ratio of the count
of healthy backend endpoints in a zone to the count of backend
endpoints in that same zone is equal to or above this threshold, the
load balancer distributes new connections to all healthy endpoints in
the local zone only. When the ratio of the count of healthy backend
endpoints in a zone to the count of backend endpoints in that same
zone is below this threshold, the load balancer distributes all new
connections to all healthy endpoints across all zones.
Corresponds to the JSON property spilloverRatio
7014 7015 7016 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 7014 def spillover_ratio @spillover_ratio end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7021 7022 7023 7024 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 7021 def update!(**args) @spillover = args[:spillover] if args.key?(:spillover) @spillover_ratio = args[:spillover_ratio] if args.key?(:spillover_ratio) end |