Class: Google::Apis::ComputeAlpha::BackendServiceOrchestrationInfo

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

A message containing information about the resource or system that manages the backend service.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BackendServiceOrchestrationInfo

Returns a new instance of BackendServiceOrchestrationInfo.



6972
6973
6974
# File 'lib/google/apis/compute_alpha/classes.rb', line 6972

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#resource_uriString

The resource URI of the resource or system that manages the backend service. Corresponds to the JSON property resourceUri

Returns:

  • (String)


6970
6971
6972
# File 'lib/google/apis/compute_alpha/classes.rb', line 6970

def resource_uri
  @resource_uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6977
6978
6979
# File 'lib/google/apis/compute_alpha/classes.rb', line 6977

def update!(**args)
  @resource_uri = args[:resource_uri] if args.key?(:resource_uri)
end