Class: Google::Apis::ComputeAlpha::BfdStatusPacketCounts

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BfdStatusPacketCounts

Returns a new instance of BfdStatusPacketCounts.



7606
7607
7608
# File 'lib/google/apis/compute_alpha/classes.rb', line 7606

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#num_rxFixnum

Number of packets received since the beginning of the current BFD session. Corresponds to the JSON property numRx

Returns:

  • (Fixnum)


7586
7587
7588
# File 'lib/google/apis/compute_alpha/classes.rb', line 7586

def num_rx
  @num_rx
end

#num_rx_rejectedFixnum

Number of packets received that were rejected because of errors since the beginning of the current BFD session. Corresponds to the JSON property numRxRejected

Returns:

  • (Fixnum)


7592
7593
7594
# File 'lib/google/apis/compute_alpha/classes.rb', line 7592

def num_rx_rejected
  @num_rx_rejected
end

#num_rx_successfulFixnum

Number of packets received that were successfully processed since the beginning of the current BFD session. Corresponds to the JSON property numRxSuccessful

Returns:

  • (Fixnum)


7598
7599
7600
# File 'lib/google/apis/compute_alpha/classes.rb', line 7598

def num_rx_successful
  @num_rx_successful
end

#num_txFixnum

Number of packets transmitted since the beginning of the current BFD session. Corresponds to the JSON property numTx

Returns:

  • (Fixnum)


7604
7605
7606
# File 'lib/google/apis/compute_alpha/classes.rb', line 7604

def num_tx
  @num_tx
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7611
7612
7613
7614
7615
7616
# File 'lib/google/apis/compute_alpha/classes.rb', line 7611

def update!(**args)
  @num_rx = args[:num_rx] if args.key?(:num_rx)
  @num_rx_rejected = args[:num_rx_rejected] if args.key?(:num_rx_rejected)
  @num_rx_successful = args[:num_rx_successful] if args.key?(:num_rx_successful)
  @num_tx = args[:num_tx] if args.key?(:num_tx)
end