Class: Google::Apis::ComputeAlpha::CalendarModeAdviceRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

A request to recommend the best way to consume the specified resources in the future.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CalendarModeAdviceRequest

Returns a new instance of CalendarModeAdviceRequest.



8461
8462
8463
# File 'lib/google/apis/compute_alpha/classes.rb', line 8461

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#future_resources_specsHash<String,Google::Apis::ComputeAlpha::FutureResourcesSpec>

Specification of resources to create in the future. The key of the map is an arbitrary string specified by the caller. Value of the map is a specification of required resources and their constraints. Currently only one value is allowed in this map. Corresponds to the JSON property futureResourcesSpecs



8459
8460
8461
# File 'lib/google/apis/compute_alpha/classes.rb', line 8459

def future_resources_specs
  @future_resources_specs
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8466
8467
8468
# File 'lib/google/apis/compute_alpha/classes.rb', line 8466

def update!(**args)
  @future_resources_specs = args[:future_resources_specs] if args.key?(:future_resources_specs)
end