Class: Google::Apis::ComputeAlpha::CalendarModeExtensionAdviceRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

A request to recommend the best duration for extending an existing Future Reservation in CALENDAR mode, that is equal or less than the specified extension duration.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CalendarModeExtensionAdviceRequest

Returns a new instance of CalendarModeExtensionAdviceRequest.



8609
8610
8611
# File 'lib/google/apis/compute_alpha/classes.rb', line 8609

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#end_time_not_later_thanString

Required. The desired end time after the Future Reservation is extended. Corresponds to the JSON property endTimeNotLaterThan

Returns:

  • (String)


8599
8600
8601
# File 'lib/google/apis/compute_alpha/classes.rb', line 8599

def end_time_not_later_than
  @end_time_not_later_than
end

#future_reservationString

Required. Reference to the Future Reservation, in the format: projects/project/zones/zone/futureReservations/name Full URIs that include hostnames (like compute.googleapis.com or www.googleapis.com) are also supported. Corresponds to the JSON property futureReservation

Returns:

  • (String)


8607
8608
8609
# File 'lib/google/apis/compute_alpha/classes.rb', line 8607

def future_reservation
  @future_reservation
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8614
8615
8616
8617
# File 'lib/google/apis/compute_alpha/classes.rb', line 8614

def update!(**args)
  @end_time_not_later_than = args[:end_time_not_later_than] if args.key?(:end_time_not_later_than)
  @future_reservation = args[:future_reservation] if args.key?(:future_reservation)
end