Class: Google::Apis::ComputeAlpha::CalendarModeExtensionAdviceResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

A response containing the recommended duration to extend a Future Reservation in CALENDAR mode based on the available capacity during the extension period.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CalendarModeExtensionAdviceResponse

Returns a new instance of CalendarModeExtensionAdviceResponse.



8644
8645
8646
# File 'lib/google/apis/compute_alpha/classes.rb', line 8644

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#end_timeString

The recommended end time for the extension, which will either be the end time requested by the caller or the longest alternative for which there is sufficient capacity. If extension is not possible, this field will be empty, and not_recommended_reason will be populated instead. Corresponds to the JSON property endTime

Returns:

  • (String)


8632
8633
8634
# File 'lib/google/apis/compute_alpha/classes.rb', line 8632

def end_time
  @end_time
end

Information about why no recommendation was provided. Corresponds to the JSON property notRecommendedReason



8637
8638
8639
# File 'lib/google/apis/compute_alpha/classes.rb', line 8637

def not_recommended_reason
  @not_recommended_reason
end

#recommendation_idString

Unique id of the recommendation, a UUID string generated by the API. Corresponds to the JSON property recommendationId

Returns:

  • (String)


8642
8643
8644
# File 'lib/google/apis/compute_alpha/classes.rb', line 8642

def recommendation_id
  @recommendation_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8649
8650
8651
8652
8653
# File 'lib/google/apis/compute_alpha/classes.rb', line 8649

def update!(**args)
  @end_time = args[:end_time] if args.key?(:end_time)
  @not_recommended_reason = args[:not_recommended_reason] if args.key?(:not_recommended_reason)
  @recommendation_id = args[:recommendation_id] if args.key?(:recommendation_id)
end