Class: Google::Apis::ComputeAlpha::CalendarModeRecommendation
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::CalendarModeRecommendation
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
A single recommendation to create requested resources. Contains detailed recommendations for every future resources specification specified in CalendarModeAdviceRequest.
Instance Attribute Summary collapse
-
#recommendations_per_spec ⇒ Hash<String,Google::Apis::ComputeAlpha::FutureResourcesRecommendation>
Recommendations for every future resource specification passed in CalendarModeAdviceRequest.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CalendarModeRecommendation
constructor
A new instance of CalendarModeRecommendation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CalendarModeRecommendation
Returns a new instance of CalendarModeRecommendation.
8241 8242 8243 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 8241 def initialize(**args) update!(**args) end |
Instance Attribute Details
#recommendations_per_spec ⇒ Hash<String,Google::Apis::ComputeAlpha::FutureResourcesRecommendation>
Recommendations for every future resource specification passed in
CalendarModeAdviceRequest. Keys of the map correspond to keys
specified in the request.
Corresponds to the JSON property recommendationsPerSpec
8239 8240 8241 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 8239 def recommendations_per_spec @recommendations_per_spec end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8246 8247 8248 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 8246 def update!(**args) @recommendations_per_spec = args[:recommendations_per_spec] if args.key?(:recommendations_per_spec) end |