Class: Google::Apis::ComputeAlpha::CallCredentials

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

[Deprecated] gRPC call credentials to access the SDS server. gRPC call credentials to access the SDS server.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CallCredentials

Returns a new instance of CallCredentials.



8273
8274
8275
# File 'lib/google/apis/compute_alpha/classes.rb', line 8273

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#call_credential_typeString

The type of call credentials to use for GRPC requests to the SDS server. This field can be set to one of the following:

  • GCE_VM: The local GCE VM service account credentials are used to access the SDS server.
  • FROM_PLUGIN: Custom authenticator credentials are used to access the SDS server. Corresponds to the JSON property callCredentialType

Returns:

  • (String)


8265
8266
8267
# File 'lib/google/apis/compute_alpha/classes.rb', line 8265

def call_credential_type
  @call_credential_type
end

#from_pluginGoogle::Apis::ComputeAlpha::MetadataCredentialsFromPlugin

[Deprecated] Custom authenticator credentials. Custom authenticator credentials. Corresponds to the JSON property fromPlugin



8271
8272
8273
# File 'lib/google/apis/compute_alpha/classes.rb', line 8271

def from_plugin
  @from_plugin
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8278
8279
8280
8281
# File 'lib/google/apis/compute_alpha/classes.rb', line 8278

def update!(**args)
  @call_credential_type = args[:call_credential_type] if args.key?(:call_credential_type)
  @from_plugin = args[:from_plugin] if args.key?(:from_plugin)
end