Class: Google::Apis::ComputeAlpha::CapacityAdviceRequestInstancePropertiesScheduling
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::CapacityAdviceRequestInstancePropertiesScheduling
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Defines the instance scheduling options.
Instance Attribute Summary collapse
-
#max_run_duration ⇒ String
The maximum time that instances can run before Compute Engine terminates them.
-
#provisioning_model ⇒ String
Specifies the provisioning model of the instance.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CapacityAdviceRequestInstancePropertiesScheduling
constructor
A new instance of CapacityAdviceRequestInstancePropertiesScheduling.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CapacityAdviceRequestInstancePropertiesScheduling
Returns a new instance of CapacityAdviceRequestInstancePropertiesScheduling.
8448 8449 8450 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 8448 def initialize(**args) update!(**args) end |
Instance Attribute Details
#max_run_duration ⇒ String
The maximum time that instances can run before Compute Engine
terminates them.
Corresponds to the JSON property maxRunDuration
8441 8442 8443 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 8441 def max_run_duration @max_run_duration end |
#provisioning_model ⇒ String
Specifies the provisioning model of the instance.
Corresponds to the JSON property provisioningModel
8446 8447 8448 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 8446 def provisioning_model @provisioning_model end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8453 8454 8455 8456 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 8453 def update!(**args) @max_run_duration = args[:max_run_duration] if args.key?(:max_run_duration) @provisioning_model = args[:provisioning_model] if args.key?(:provisioning_model) end |