Class: Google::Apis::ComputeAlpha::CapacityAdviceResponseRecommendationShard
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::CapacityAdviceResponseRecommendationShard
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Shards represent blocks of uniform capacity in recommendations. Each shard is for a single zone and a single machine shape. Each shard defines a size expressed as the number of VMs.
Instance Attribute Summary collapse
-
#instance_count ⇒ Fixnum
The number of instances.
-
#machine_type ⇒ String
The machine type corresponds to the instance selection in the request.
-
#provisioning_model ⇒ String
The provisioning model that you want to view recommendations for.
-
#zone ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CapacityAdviceResponseRecommendationShard
constructor
A new instance of CapacityAdviceResponseRecommendationShard.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CapacityAdviceResponseRecommendationShard
Returns a new instance of CapacityAdviceResponseRecommendationShard.
9070 9071 9072 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 9070 def initialize(**args) update!(**args) end |
Instance Attribute Details
#instance_count ⇒ Fixnum
The number of instances.
Corresponds to the JSON property instanceCount
9053 9054 9055 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 9053 def instance_count @instance_count end |
#machine_type ⇒ String
The machine type corresponds to the instance selection in the request.
Corresponds to the JSON property machineType
9058 9059 9060 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 9058 def machine_type @machine_type end |
#provisioning_model ⇒ String
The provisioning model that you want to view recommendations for.
Corresponds to the JSON property provisioningModel
9063 9064 9065 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 9063 def provisioning_model @provisioning_model end |
#zone ⇒ String
Output only. The zone name for this shard.
Corresponds to the JSON property zone
9068 9069 9070 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 9068 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9075 9076 9077 9078 9079 9080 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 9075 def update!(**args) @instance_count = args[:instance_count] if args.key?(:instance_count) @machine_type = args[:machine_type] if args.key?(:machine_type) @provisioning_model = args[:provisioning_model] if args.key?(:provisioning_model) @zone = args[:zone] if args.key?(:zone) end |