Class: Google::Apis::ComputeAlpha::CapacityHistoryRequest
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::CapacityHistoryRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
A request to get the capacity history.
Instance Attribute Summary collapse
-
#instance_properties ⇒ Google::Apis::ComputeAlpha::CapacityHistoryRequestInstanceProperties
Instance properties for this request.
-
#location_policy ⇒ Google::Apis::ComputeAlpha::CapacityHistoryRequestLocationPolicy
Location policy for this request.
-
#types ⇒ Array<String>
List of history types to get capacity history for.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CapacityHistoryRequest
constructor
A new instance of CapacityHistoryRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CapacityHistoryRequest
Returns a new instance of CapacityHistoryRequest.
9102 9103 9104 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 9102 def initialize(**args) update!(**args) end |
Instance Attribute Details
#instance_properties ⇒ Google::Apis::ComputeAlpha::CapacityHistoryRequestInstanceProperties
Instance properties for this request.
Corresponds to the JSON property instanceProperties
9090 9091 9092 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 9090 def instance_properties @instance_properties end |
#location_policy ⇒ Google::Apis::ComputeAlpha::CapacityHistoryRequestLocationPolicy
Location policy for this request.
Corresponds to the JSON property locationPolicy
9095 9096 9097 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 9095 def location_policy @location_policy end |
#types ⇒ Array<String>
List of history types to get capacity history for.
Corresponds to the JSON property types
9100 9101 9102 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 9100 def types @types end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9107 9108 9109 9110 9111 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 9107 def update!(**args) @instance_properties = args[:instance_properties] if args.key?(:instance_properties) @location_policy = args[:location_policy] if args.key?(:location_policy) @types = args[:types] if args.key?(:types) end |