Class: Google::Apis::ComputeAlpha::CapacityHistoryRequestLocationPolicy
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::CapacityHistoryRequestLocationPolicy
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Location policy for this request.
Instance Attribute Summary collapse
-
#location ⇒ String
The region or zone to get capacity history for.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CapacityHistoryRequestLocationPolicy
constructor
A new instance of CapacityHistoryRequestLocationPolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CapacityHistoryRequestLocationPolicy
Returns a new instance of CapacityHistoryRequestLocationPolicy.
8722 8723 8724 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 8722 def initialize(**args) update!(**args) end |
Instance Attribute Details
#location ⇒ String
The region or zone to get capacity history for. It can be a partial or full URL. For example, the following are valid values:
- https://www.googleapis.com/compute/v1/projects/project/zones/zone
- projects/project/zones/zone
- zones/zone
This field is optional.
Corresponds to the JSON property
location
8720 8721 8722 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 8720 def location @location end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8727 8728 8729 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 8727 def update!(**args) @location = args[:location] if args.key?(:location) end |