Class: Google::Apis::ComputeAlpha::CircuitBreakers

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Settings controlling the volume of requests, connections and retries to this backend service.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CircuitBreakers

Returns a new instance of CircuitBreakers.



9372
9373
9374
# File 'lib/google/apis/compute_alpha/classes.rb', line 9372

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#connect_timeoutGoogle::Apis::ComputeAlpha::Duration

A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution. It is independent of any calendar and concepts like "day" or "month". Range is approximately 10,000 years. Corresponds to the JSON property connectTimeout



9330
9331
9332
# File 'lib/google/apis/compute_alpha/classes.rb', line 9330

def connect_timeout
  @connect_timeout
end

#max_connectionsFixnum

The maximum number of connections to the backend service. If not specified, there is no limit. Not supported when the backend service is referenced by a URL map that is bound to target gRPC proxy that has validateForProxyless field set to true. Corresponds to the JSON property maxConnections

Returns:

  • (Fixnum)


9338
9339
9340
# File 'lib/google/apis/compute_alpha/classes.rb', line 9338

def max_connections
  @max_connections
end

#max_pending_requestsFixnum

The maximum number of pending requests allowed to the backend service. If not specified, there is no limit. Not supported when the backend service is referenced by a URL map that is bound to target gRPC proxy that has validateForProxyless field set to true. Corresponds to the JSON property maxPendingRequests

Returns:

  • (Fixnum)


9346
9347
9348
# File 'lib/google/apis/compute_alpha/classes.rb', line 9346

def max_pending_requests
  @max_pending_requests
end

#max_requestsFixnum

The maximum number of parallel requests that allowed to the backend service. If not specified, there is no limit. Corresponds to the JSON property maxRequests

Returns:

  • (Fixnum)


9352
9353
9354
# File 'lib/google/apis/compute_alpha/classes.rb', line 9352

def max_requests
  @max_requests
end

#max_requests_per_connectionFixnum

Maximum requests for a single connection to the backend service. This parameter is respected by both the HTTP/1.1 and HTTP/2 implementations. If not specified, there is no limit. Setting this parameter to 1 will effectively disable keep alive. Not supported when the backend service is referenced by a URL map that is bound to target gRPC proxy that has validateForProxyless field set to true. Corresponds to the JSON property maxRequestsPerConnection

Returns:

  • (Fixnum)


9362
9363
9364
# File 'lib/google/apis/compute_alpha/classes.rb', line 9362

def max_requests_per_connection
  @max_requests_per_connection
end

#max_retriesFixnum

The maximum number of parallel retries allowed to the backend cluster. If not specified, the default is 1. Not supported when the backend service is referenced by a URL map that is bound to target gRPC proxy that has validateForProxyless field set to true. Corresponds to the JSON property maxRetries

Returns:

  • (Fixnum)


9370
9371
9372
# File 'lib/google/apis/compute_alpha/classes.rb', line 9370

def max_retries
  @max_retries
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9377
9378
9379
9380
9381
9382
9383
9384
# File 'lib/google/apis/compute_alpha/classes.rb', line 9377

def update!(**args)
  @connect_timeout = args[:connect_timeout] if args.key?(:connect_timeout)
  @max_connections = args[:max_connections] if args.key?(:max_connections)
  @max_pending_requests = args[:max_pending_requests] if args.key?(:max_pending_requests)
  @max_requests = args[:max_requests] if args.key?(:max_requests)
  @max_requests_per_connection = args[:max_requests_per_connection] if args.key?(:max_requests_per_connection)
  @max_retries = args[:max_retries] if args.key?(:max_retries)
end