Class: Google::Apis::ComputeAlpha::CommitmentResourceStatus

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

[Output Only] Contains output only fields.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CommitmentResourceStatus

Returns a new instance of CommitmentResourceStatus.



9536
9537
9538
# File 'lib/google/apis/compute_alpha/classes.rb', line 9536

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cancellation_informationGoogle::Apis::ComputeAlpha::CommitmentResourceStatusCancellationInformation

Output only. [Output Only] An optional, contains all the needed information of cancellation. Corresponds to the JSON property cancellationInformation



9526
9527
9528
# File 'lib/google/apis/compute_alpha/classes.rb', line 9526

def cancellation_information
  @cancellation_information
end

#custom_term_eligibility_end_timestampString

Output only. [Output Only] Indicates the end time of customer's eligibility to send custom term requests in RFC3339 text format. Term extension requests that (not the end time in the request) after this time will be rejected. Corresponds to the JSON property customTermEligibilityEndTimestamp

Returns:

  • (String)


9534
9535
9536
# File 'lib/google/apis/compute_alpha/classes.rb', line 9534

def custom_term_eligibility_end_timestamp
  @custom_term_eligibility_end_timestamp
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9541
9542
9543
9544
# File 'lib/google/apis/compute_alpha/classes.rb', line 9541

def update!(**args)
  @cancellation_information = args[:cancellation_information] if args.key?(:cancellation_information)
  @custom_term_eligibility_end_timestamp = args[:custom_term_eligibility_end_timestamp] if args.key?(:custom_term_eligibility_end_timestamp)
end