Class: Google::Apis::ComputeAlpha::CommitmentResourceStatusCancellationInformation

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CommitmentResourceStatusCancellationInformation

Returns a new instance of CommitmentResourceStatusCancellationInformation.



9996
9997
9998
# File 'lib/google/apis/compute_alpha/classes.rb', line 9996

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#canceled_commitmentGoogle::Apis::ComputeAlpha::Money

Represents an amount of money with its currency type. Corresponds to the JSON property canceledCommitment



9972
9973
9974
# File 'lib/google/apis/compute_alpha/classes.rb', line 9972

def canceled_commitment
  @canceled_commitment
end

#canceled_commitment_last_updated_timestampString

Output only. [Output Only] An optional last update time of canceled_commitment. RFC3339 text format. Corresponds to the JSON property canceledCommitmentLastUpdatedTimestamp

Returns:

  • (String)


9978
9979
9980
# File 'lib/google/apis/compute_alpha/classes.rb', line 9978

def canceled_commitment_last_updated_timestamp
  @canceled_commitment_last_updated_timestamp
end

#cancellation_capGoogle::Apis::ComputeAlpha::Money

Represents an amount of money with its currency type. Corresponds to the JSON property cancellationCap



9983
9984
9985
# File 'lib/google/apis/compute_alpha/classes.rb', line 9983

def cancellation_cap
  @cancellation_cap
end

#cancellation_feeGoogle::Apis::ComputeAlpha::Money

Represents an amount of money with its currency type. Corresponds to the JSON property cancellationFee



9988
9989
9990
# File 'lib/google/apis/compute_alpha/classes.rb', line 9988

def cancellation_fee
  @cancellation_fee
end

#cancellation_fee_expiration_timestampString

Output only. [Output Only] An optional, cancellation fee expiration time. RFC3339 text format. Corresponds to the JSON property cancellationFeeExpirationTimestamp

Returns:

  • (String)


9994
9995
9996
# File 'lib/google/apis/compute_alpha/classes.rb', line 9994

def cancellation_fee_expiration_timestamp
  @cancellation_fee_expiration_timestamp
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10001
10002
10003
10004
10005
10006
10007
# File 'lib/google/apis/compute_alpha/classes.rb', line 10001

def update!(**args)
  @canceled_commitment = args[:canceled_commitment] if args.key?(:canceled_commitment)
  @canceled_commitment_last_updated_timestamp = args[:canceled_commitment_last_updated_timestamp] if args.key?(:canceled_commitment_last_updated_timestamp)
  @cancellation_cap = args[:cancellation_cap] if args.key?(:cancellation_cap)
  @cancellation_fee = args[:cancellation_fee] if args.key?(:cancellation_fee)
  @cancellation_fee_expiration_timestamp = args[:cancellation_fee_expiration_timestamp] if args.key?(:cancellation_fee_expiration_timestamp)
end