Class: Google::Apis::ComputeAlpha::CompositeHealthCheckAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of CompositeHealthChecksScopedList.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CompositeHealthCheckAggregatedList

Returns a new instance of CompositeHealthCheckAggregatedList.



10294
10295
10296
# File 'lib/google/apis/compute_alpha/classes.rb', line 10294

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


10257
10258
10259
# File 'lib/google/apis/compute_alpha/classes.rb', line 10257

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::CompositeHealthChecksScopedList>

A list of CompositeHealthChecksScopedList resources. Corresponds to the JSON property items



10262
10263
10264
# File 'lib/google/apis/compute_alpha/classes.rb', line 10262

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


10267
10268
10269
# File 'lib/google/apis/compute_alpha/classes.rb', line 10267

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


10277
10278
10279
# File 'lib/google/apis/compute_alpha/classes.rb', line 10277

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


10282
10283
10284
# File 'lib/google/apis/compute_alpha/classes.rb', line 10282

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


10287
10288
10289
# File 'lib/google/apis/compute_alpha/classes.rb', line 10287

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::CompositeHealthCheckAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



10292
10293
10294
# File 'lib/google/apis/compute_alpha/classes.rb', line 10292

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10299
10300
10301
10302
10303
10304
10305
10306
10307
# File 'lib/google/apis/compute_alpha/classes.rb', line 10299

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end