Class: Google::Apis::ComputeAlpha::CompositeHealthCheckList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CompositeHealthCheckList

Returns a new instance of CompositeHealthCheckList.



10453
10454
10455
# File 'lib/google/apis/compute_alpha/classes.rb', line 10453

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


10420
10421
10422
# File 'lib/google/apis/compute_alpha/classes.rb', line 10420

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::CompositeHealthCheck>

A list of CompositeHealthCheck resources. Corresponds to the JSON property items



10425
10426
10427
# File 'lib/google/apis/compute_alpha/classes.rb', line 10425

def items
  @items
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# compositeHealthCheck for composite health checks. Corresponds to the JSON property kind

Returns:

  • (String)


10431
10432
10433
# File 'lib/google/apis/compute_alpha/classes.rb', line 10431

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


10441
10442
10443
# File 'lib/google/apis/compute_alpha/classes.rb', line 10441

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


10446
10447
10448
# File 'lib/google/apis/compute_alpha/classes.rb', line 10446

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::CompositeHealthCheckList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



10451
10452
10453
# File 'lib/google/apis/compute_alpha/classes.rb', line 10451

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10458
10459
10460
10461
10462
10463
10464
10465
# File 'lib/google/apis/compute_alpha/classes.rb', line 10458

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end