Class: Google::Apis::ComputeAlpha::CompositeHealthChecksScopedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::CompositeHealthChecksScopedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#composite_health_checks ⇒ Array<Google::Apis::ComputeAlpha::CompositeHealthCheck>
A list of CompositeHealthChecks contained in this scope.
-
#warning ⇒ Google::Apis::ComputeAlpha::CompositeHealthChecksScopedList::Warning
Informational warning which replaces the list of composite health checks when the list is empty.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CompositeHealthChecksScopedList
constructor
A new instance of CompositeHealthChecksScopedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CompositeHealthChecksScopedList
Returns a new instance of CompositeHealthChecksScopedList.
10113 10114 10115 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 10113 def initialize(**args) update!(**args) end |
Instance Attribute Details
#composite_health_checks ⇒ Array<Google::Apis::ComputeAlpha::CompositeHealthCheck>
A list of CompositeHealthChecks contained in this scope.
Corresponds to the JSON property compositeHealthChecks
10105 10106 10107 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 10105 def composite_health_checks @composite_health_checks end |
#warning ⇒ Google::Apis::ComputeAlpha::CompositeHealthChecksScopedList::Warning
Informational warning which replaces the list of composite health checks
when the list is empty.
Corresponds to the JSON property warning
10111 10112 10113 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 10111 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10118 10119 10120 10121 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 10118 def update!(**args) @composite_health_checks = args[:composite_health_checks] if args.key?(:composite_health_checks) @warning = args[:warning] if args.key?(:warning) end |