Class: Google::Apis::ComputeAlpha::CrossSiteNetwork
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::CrossSiteNetwork
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
A resource that represents a cross-site network. You can use cross-site networks to connect your on-premises networks to each other through Interconnect connections.
Instance Attribute Summary collapse
-
#creation_timestamp ⇒ String
Output only.
-
#description ⇒ String
An optional description of the cross-site network.
-
#id ⇒ Fixnum
Output only.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
Name of the resource.
-
#self_link ⇒ String
Output only.
-
#self_link_with_id ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CrossSiteNetwork
constructor
A new instance of CrossSiteNetwork.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CrossSiteNetwork
Returns a new instance of CrossSiteNetwork.
10945 10946 10947 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 10945 def initialize(**args) update!(**args) end |
Instance Attribute Details
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
10903 10904 10905 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 10903 def @creation_timestamp end |
#description ⇒ String
An optional description of the cross-site network.
Corresponds to the JSON property description
10908 10909 10910 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 10908 def description @description end |
#id ⇒ Fixnum
Output only. [Output Only] The unique identifier for the resource type. The
server
generates this identifier.
Corresponds to the JSON property id
10915 10916 10917 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 10915 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#
crossSiteNetwork for cross-site networks.
Corresponds to the JSON property kind
10921 10922 10923 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 10921 def kind @kind end |
#name ⇒ String
Name of the resource. Provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must
be a dash, lowercase letter, or digit, except the last character, which
cannot be a dash.
Corresponds to the JSON property name
10932 10933 10934 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 10932 def name @name end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
10937 10938 10939 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 10937 def self_link @self_link end |
#self_link_with_id ⇒ String
Output only. [Output Only] Server-defined URL for this resource with the
resource id.
Corresponds to the JSON property selfLinkWithId
10943 10944 10945 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 10943 def self_link_with_id @self_link_with_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10950 10951 10952 10953 10954 10955 10956 10957 10958 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 10950 def update!(**args) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @self_link = args[:self_link] if args.key?(:self_link) @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id) end |