Class: Google::Apis::ComputeAlpha::DhcpOptionsConfigList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DhcpOptionsConfigList

Returns a new instance of DhcpOptionsConfigList.



11792
11793
11794
# File 'lib/google/apis/compute_alpha/classes.rb', line 11792

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Server-defined ETag for optimistic concurrency control. Corresponds to the JSON property etag

Returns:

  • (String)


11747
11748
11749
# File 'lib/google/apis/compute_alpha/classes.rb', line 11747

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


11752
11753
11754
# File 'lib/google/apis/compute_alpha/classes.rb', line 11752

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::DhcpOptionsConfig>

A list of DhcpOptionsConfig resources. Corresponds to the JSON property items



11757
11758
11759
# File 'lib/google/apis/compute_alpha/classes.rb', line 11757

def items
  @items
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# dhcpOptionsConfigList for a list of dhcp options configs. Corresponds to the JSON property kind

Returns:

  • (String)


11764
11765
11766
# File 'lib/google/apis/compute_alpha/classes.rb', line 11764

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


11774
11775
11776
# File 'lib/google/apis/compute_alpha/classes.rb', line 11774

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


11779
11780
11781
# File 'lib/google/apis/compute_alpha/classes.rb', line 11779

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


11785
11786
11787
# File 'lib/google/apis/compute_alpha/classes.rb', line 11785

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::DhcpOptionsConfigList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



11790
11791
11792
# File 'lib/google/apis/compute_alpha/classes.rb', line 11790

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11797
11798
11799
11800
11801
11802
11803
11804
11805
11806
# File 'lib/google/apis/compute_alpha/classes.rb', line 11797

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end