Class: Google::Apis::ComputeAlpha::DiskInstantiationConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

A specification of the desired way to instantiate a disk in the instance template when its created from a source instance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DiskInstantiationConfig

Returns a new instance of DiskInstantiationConfig.



11711
11712
11713
# File 'lib/google/apis/compute_alpha/classes.rb', line 11711

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#auto_deleteBoolean Also known as: auto_delete?

Specifies whether the disk will be auto-deleted when the instance is deleted (but not when the disk is detached from the instance). Corresponds to the JSON property autoDelete

Returns:

  • (Boolean)


11675
11676
11677
# File 'lib/google/apis/compute_alpha/classes.rb', line 11675

def auto_delete
  @auto_delete
end

#custom_imageString

The custom source image to be used to restore this disk when instantiating this instance template. Corresponds to the JSON property customImage

Returns:

  • (String)


11682
11683
11684
# File 'lib/google/apis/compute_alpha/classes.rb', line 11682

def custom_image
  @custom_image
end

#device_nameString

Specifies the device name of the disk to which the configurations apply to. Corresponds to the JSON property deviceName

Returns:

  • (String)


11687
11688
11689
# File 'lib/google/apis/compute_alpha/classes.rb', line 11687

def device_name
  @device_name
end

#instantiate_fromString

Specifies whether to include the disk and what image to use. Possible values are:

  • source-image: to use the same image that was used to create the source instance's corresponding disk. Applicable to the boot disk and additional read-write disks.
  • source-image-family: to use the same image family that was used to create the source instance's corresponding disk. Applicable to the boot disk and additional read-write disks.
  • custom-image: to use a user-provided image url for disk creation. Applicable to the boot disk and additional read-write disks.
  • attach-read-only: to attach a read-only disk. Applicable to read-only disks.
  • do-not-include: to exclude a disk from the template. Applicable to additional read-write disks, local SSDs, and read-only disks. Corresponds to the JSON property instantiateFrom

Returns:

  • (String)


11709
11710
11711
# File 'lib/google/apis/compute_alpha/classes.rb', line 11709

def instantiate_from
  @instantiate_from
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11716
11717
11718
11719
11720
11721
# File 'lib/google/apis/compute_alpha/classes.rb', line 11716

def update!(**args)
  @auto_delete = args[:auto_delete] if args.key?(:auto_delete)
  @custom_image = args[:custom_image] if args.key?(:custom_image)
  @device_name = args[:device_name] if args.key?(:device_name)
  @instantiate_from = args[:instantiate_from] if args.key?(:instantiate_from)
end