Class: Google::Apis::ComputeAlpha::DiskSettings
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::DiskSettings
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#access_location ⇒ Google::Apis::ComputeAlpha::DiskSettingsAccessLocation
AccessLocation is only used for regional snapshot.
-
#default_resource_policies ⇒ Hash<String,Google::Apis::ComputeAlpha::DiskSettingsResourcePolicyDetails>
An optional parameter for storing the default resource policies that will be used for the Disks created in the given scope.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DiskSettings
constructor
A new instance of DiskSettings.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DiskSettings
Returns a new instance of DiskSettings.
12050 12051 12052 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 12050 def initialize(**args) update!(**args) end |
Instance Attribute Details
#access_location ⇒ Google::Apis::ComputeAlpha::DiskSettingsAccessLocation
AccessLocation is only used for regional snapshot. It contains which
regions are allowed to create a regional snapshot from disks located in the
given region/zone.
It includes key-value pairs designed to store the following structure. The
keys should match their corresponding values, which must be provided:
access_location:
locations
us-central1
region: "us-central1"
,
asia-west2
region: "asia-west2"
Corresponds to the JSON property accessLocation
12038 12039 12040 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 12038 def access_location @access_location end |
#default_resource_policies ⇒ Hash<String,Google::Apis::ComputeAlpha::DiskSettingsResourcePolicyDetails>
An optional parameter for storing the default resource policies that
will be used for the Disks created in the given scope.
The Key is a string type, provided by customers to uniquely identify the
default Resource Policy entry.
The Value is a Default ResourcePolicyDetails Object used to represent the
detailed information of the Resource Policy entry.
Corresponds to the JSON property defaultResourcePolicies
12048 12049 12050 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 12048 def default_resource_policies @default_resource_policies end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12055 12056 12057 12058 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 12055 def update!(**args) @access_location = args[:access_location] if args.key?(:access_location) @default_resource_policies = args[:default_resource_policies] if args.key?(:default_resource_policies) end |