Class: Google::Apis::ComputeAlpha::DisksResizeRequest
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::DisksResizeRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#size_gb ⇒ Fixnum
The new size of the persistent disk, which is specified in GB.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DisksResizeRequest
constructor
A new instance of DisksResizeRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DisksResizeRequest
Returns a new instance of DisksResizeRequest.
12980 12981 12982 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 12980 def initialize(**args) update!(**args) end |
Instance Attribute Details
#size_gb ⇒ Fixnum
The new size of the persistent disk, which is specified in GB.
Corresponds to the JSON property sizeGb
12978 12979 12980 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 12978 def size_gb @size_gb end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12985 12986 12987 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 12985 def update!(**args) @size_gb = args[:size_gb] if args.key?(:size_gb) end |