Class: Google::Apis::ComputeAlpha::ExchangedPeeringRoute

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ExchangedPeeringRoute

Returns a new instance of ExchangedPeeringRoute.



13995
13996
13997
# File 'lib/google/apis/compute_alpha/classes.rb', line 13995

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dest_rangeString

The destination range of the route. Corresponds to the JSON property destRange

Returns:

  • (String)


13968
13969
13970
# File 'lib/google/apis/compute_alpha/classes.rb', line 13968

def dest_range
  @dest_range
end

#importedBoolean Also known as: imported?

True if the peering route has been imported from a peer. The actual import happens if the field networkPeering.importCustomRoutes is true for this network, and networkPeering.exportCustomRoutes is true for the peer network, and the import does not result in a route conflict. Corresponds to the JSON property imported

Returns:

  • (Boolean)


13977
13978
13979
# File 'lib/google/apis/compute_alpha/classes.rb', line 13977

def imported
  @imported
end

#next_hop_regionString

The region of peering route next hop, only applies to dynamic routes. Corresponds to the JSON property nextHopRegion

Returns:

  • (String)


13983
13984
13985
# File 'lib/google/apis/compute_alpha/classes.rb', line 13983

def next_hop_region
  @next_hop_region
end

#priorityFixnum

The priority of the peering route. Corresponds to the JSON property priority

Returns:

  • (Fixnum)


13988
13989
13990
# File 'lib/google/apis/compute_alpha/classes.rb', line 13988

def priority
  @priority
end

#typeString

The type of the peering route. Corresponds to the JSON property type

Returns:

  • (String)


13993
13994
13995
# File 'lib/google/apis/compute_alpha/classes.rb', line 13993

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



14000
14001
14002
14003
14004
14005
14006
# File 'lib/google/apis/compute_alpha/classes.rb', line 14000

def update!(**args)
  @dest_range = args[:dest_range] if args.key?(:dest_range)
  @imported = args[:imported] if args.key?(:imported)
  @next_hop_region = args[:next_hop_region] if args.key?(:next_hop_region)
  @priority = args[:priority] if args.key?(:priority)
  @type = args[:type] if args.key?(:type)
end