Class: Google::Apis::ComputeAlpha::ExchangedPeeringRoutesList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::ExchangedPeeringRoutesList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::ExchangedPeeringRoute>
A list of ExchangedPeeringRoute resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::ExchangedPeeringRoutesList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ExchangedPeeringRoutesList
constructor
A new instance of ExchangedPeeringRoutesList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ExchangedPeeringRoutesList
Returns a new instance of ExchangedPeeringRoutesList.
14243 14244 14245 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 14243 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
14209 14210 14211 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 14209 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::ExchangedPeeringRoute>
A list of ExchangedPeeringRoute resources.
Corresponds to the JSON property items
14214 14215 14216 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 14214 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
exchangedPeeringRoutesList for exchanged peering
routes lists.
Corresponds to the JSON property kind
14221 14222 14223 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 14221 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
14231 14232 14233 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 14231 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
14236 14237 14238 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 14236 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::ExchangedPeeringRoutesList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
14241 14242 14243 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 14241 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
14248 14249 14250 14251 14252 14253 14254 14255 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 14248 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |