Class: Google::Apis::ComputeAlpha::Firewall

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Represents a Firewall Rule resource. Firewall rules allow or deny ingress traffic to, and egress traffic from your instances. For more information, readFirewall rules.

Defined Under Namespace

Classes: Allowed, Denied

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Firewall

Returns a new instance of Firewall.



14910
14911
14912
# File 'lib/google/apis/compute_alpha/classes.rb', line 14910

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allowedArray<Google::Apis::ComputeAlpha::Firewall::Allowed>

The list of ALLOW rules specified by this firewall. Each rule specifies a protocol and port-range tuple that describes a permitted connection. Corresponds to the JSON property allowed



14718
14719
14720
# File 'lib/google/apis/compute_alpha/classes.rb', line 14718

def allowed
  @allowed
end

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


14724
14725
14726
# File 'lib/google/apis/compute_alpha/classes.rb', line 14724

def creation_timestamp
  @creation_timestamp
end

#deniedArray<Google::Apis::ComputeAlpha::Firewall::Denied>

The list of DENY rules specified by this firewall. Each rule specifies a protocol and port-range tuple that describes a denied connection. Corresponds to the JSON property denied



14730
14731
14732
# File 'lib/google/apis/compute_alpha/classes.rb', line 14730

def denied
  @denied
end

#descriptionString

An optional description of this resource. Provide this field when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


14736
14737
14738
# File 'lib/google/apis/compute_alpha/classes.rb', line 14736

def description
  @description
end

#destination_rangesArray<String>

If destination ranges are specified, the firewall rule applies only to traffic that has destination IP address in these ranges. These ranges must be expressed inCIDR format. Both IPv4 and IPv6 are supported. Corresponds to the JSON property destinationRanges

Returns:

  • (Array<String>)


14743
14744
14745
# File 'lib/google/apis/compute_alpha/classes.rb', line 14743

def destination_ranges
  @destination_ranges
end

#directionString

Direction of traffic to which this firewall applies, either INGRESS or EGRESS. The default is INGRESS. For EGRESS traffic, you cannot specify the sourceTags fields. Corresponds to the JSON property direction

Returns:

  • (String)


14750
14751
14752
# File 'lib/google/apis/compute_alpha/classes.rb', line 14750

def direction
  @direction
end

#disabledBoolean Also known as: disabled?

Denotes whether the firewall rule is disabled. When set to true, the firewall rule is not enforced and the network behaves as if it did not exist. If this is unspecified, the firewall rule will be enabled. Corresponds to the JSON property disabled

Returns:

  • (Boolean)


14757
14758
14759
# File 'lib/google/apis/compute_alpha/classes.rb', line 14757

def disabled
  @disabled
end

#enable_loggingBoolean Also known as: enable_logging?

Deprecated in favor of enable in LogConfig. This field denotes whether to enable logging for a particular firewall rule. If logging is enabled, logs will be exported t Cloud Logging. Corresponds to the JSON property enableLogging

Returns:

  • (Boolean)


14766
14767
14768
# File 'lib/google/apis/compute_alpha/classes.rb', line 14766

def enable_logging
  @enable_logging
end

#idFixnum

Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


14774
14775
14776
# File 'lib/google/apis/compute_alpha/classes.rb', line 14774

def id
  @id
end

#kindString

Output only. [Output Only] Type of the resource. Always compute#firewall for firewall rules. Corresponds to the JSON property kind

Returns:

  • (String)


14780
14781
14782
# File 'lib/google/apis/compute_alpha/classes.rb', line 14780

def kind
  @kind
end

#log_configGoogle::Apis::ComputeAlpha::FirewallLogConfig

The available logging options for a firewall rule. Corresponds to the JSON property logConfig



14785
14786
14787
# File 'lib/google/apis/compute_alpha/classes.rb', line 14785

def log_config
  @log_config
end

#nameString

Name of the resource; provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])?. The first character must be a lowercase letter, and all following characters (except for the last character) must be a dash, lowercase letter, or digit. The last character must be a lowercase letter or digit. Corresponds to the JSON property name

Returns:

  • (String)


14796
14797
14798
# File 'lib/google/apis/compute_alpha/classes.rb', line 14796

def name
  @name
end

#networkString

URL of the network resource for this firewall rule. If not specified when creating a firewall rule, the default network is used: global/networks/default If you choose to specify this field, you can specify the network as a full or partial URL. For example, the following are all valid URLs:

- https://www.googleapis.com/compute/v1/projects/myproject/global/networks/my- network

  • projects/myproject/global/networks/my-network
  • global/networks/default Corresponds to the JSON property network

Returns:

  • (String)


14812
14813
14814
# File 'lib/google/apis/compute_alpha/classes.rb', line 14812

def network
  @network
end

#paramsGoogle::Apis::ComputeAlpha::FirewallParams

Additional firewall parameters. Corresponds to the JSON property params



14817
14818
14819
# File 'lib/google/apis/compute_alpha/classes.rb', line 14817

def params
  @params
end

#priorityFixnum

Priority for this rule. This is an integer between 0 and 65535, both inclusive. The default value is 1000. Relative priorities determine which rule takes effect if multiple rules apply. Lower values indicate higher priority. For example, a rule with priority 0 has higher precedence than a rule with priority 1. DENY rules take precedence over ALLOW rules if they have equal priority. Note that VPC networks have implied rules with a priority of 65535. To avoid conflicts with the implied rules, use a priority number less than 65535. Corresponds to the JSON property priority

Returns:

  • (Fixnum)


14831
14832
14833
# File 'lib/google/apis/compute_alpha/classes.rb', line 14831

def priority
  @priority
end

[Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


14836
14837
14838
# File 'lib/google/apis/compute_alpha/classes.rb', line 14836

def self_link
  @self_link
end

Output only. [Output Only] Server-defined URL for this resource with the resource id. Corresponds to the JSON property selfLinkWithId

Returns:

  • (String)


14842
14843
14844
# File 'lib/google/apis/compute_alpha/classes.rb', line 14842

def self_link_with_id
  @self_link_with_id
end

#source_rangesArray<String>

If source ranges are specified, the firewall rule applies only to traffic that has a source IP address in these ranges. These ranges must be expressed inCIDR format. One or both of sourceRanges and sourceTags may be set. If both fields are set, the rule applies to traffic that has a source IP address within sourceRanges OR a source IP from a resource with a matching tag listed in thesourceTags field. The connection does not need to match both fields for the rule to apply. Both IPv4 and IPv6 are supported. Corresponds to the JSON property sourceRanges

Returns:

  • (Array<String>)


14856
14857
14858
# File 'lib/google/apis/compute_alpha/classes.rb', line 14856

def source_ranges
  @source_ranges
end

#source_service_accountsArray<String>

If source service accounts are specified, the firewall rules apply only to traffic originating from an instance with a service account in this list. Source service accounts cannot be used to control traffic to an instance's external IP address because service accounts are associated with an instance, not an IP address.sourceRanges can be set at the same time assourceServiceAccounts. If both are set, the firewall applies to traffic that has a source IP address within the sourceRanges OR a source IP that belongs to an instance with service account listed insourceServiceAccount. The connection does not need to match both fields for the firewall to apply.sourceServiceAccounts cannot be used at the same time assourceTags or targetTags. Corresponds to the JSON property sourceServiceAccounts

Returns:

  • (Array<String>)


14872
14873
14874
# File 'lib/google/apis/compute_alpha/classes.rb', line 14872

def source_service_accounts
  @source_service_accounts
end

#source_tagsArray<String>

If source tags are specified, the firewall rule applies only to traffic with source IPs that match the primary network interfaces of VM instances that have the tag and are in the same VPC network. Source tags cannot be used to control traffic to an instance's external IP address, it only applies to traffic between instances in the same virtual network. Because tags are associated with instances, not IP addresses. One or both of sourceRanges and sourceTags may be set. If both fields are set, the firewall applies to traffic that has a source IP address within sourceRanges OR a source IP from a resource with a matching tag listed in the sourceTags field. The connection does not need to match both fields for the firewall to apply. Corresponds to the JSON property sourceTags

Returns:

  • (Array<String>)


14888
14889
14890
# File 'lib/google/apis/compute_alpha/classes.rb', line 14888

def source_tags
  @source_tags
end

#target_service_accountsArray<String>

A list of service accounts indicating sets of instances located in the network that may make network connections as specified inallowed[]. targetServiceAccounts cannot be used at the same time astargetTags or sourceTags. If neither targetServiceAccounts nor targetTags are specified, the firewall rule applies to all instances on the specified network. Corresponds to the JSON property targetServiceAccounts

Returns:

  • (Array<String>)


14899
14900
14901
# File 'lib/google/apis/compute_alpha/classes.rb', line 14899

def target_service_accounts
  @target_service_accounts
end

#target_tagsArray<String>

A list of tags that controls which instances the firewall rule applies to. If targetTags are specified, then the firewall rule applies only to instances in the VPC network that have one of those tags. If no targetTags are specified, the firewall rule applies to all instances on the specified network. Corresponds to the JSON property targetTags

Returns:

  • (Array<String>)


14908
14909
14910
# File 'lib/google/apis/compute_alpha/classes.rb', line 14908

def target_tags
  @target_tags
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



14915
14916
14917
14918
14919
14920
14921
14922
14923
14924
14925
14926
14927
14928
14929
14930
14931
14932
14933
14934
14935
14936
14937
14938
# File 'lib/google/apis/compute_alpha/classes.rb', line 14915

def update!(**args)
  @allowed = args[:allowed] if args.key?(:allowed)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @denied = args[:denied] if args.key?(:denied)
  @description = args[:description] if args.key?(:description)
  @destination_ranges = args[:destination_ranges] if args.key?(:destination_ranges)
  @direction = args[:direction] if args.key?(:direction)
  @disabled = args[:disabled] if args.key?(:disabled)
  @enable_logging = args[:enable_logging] if args.key?(:enable_logging)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @log_config = args[:log_config] if args.key?(:log_config)
  @name = args[:name] if args.key?(:name)
  @network = args[:network] if args.key?(:network)
  @params = args[:params] if args.key?(:params)
  @priority = args[:priority] if args.key?(:priority)
  @self_link = args[:self_link] if args.key?(:self_link)
  @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id)
  @source_ranges = args[:source_ranges] if args.key?(:source_ranges)
  @source_service_accounts = args[:source_service_accounts] if args.key?(:source_service_accounts)
  @source_tags = args[:source_tags] if args.key?(:source_tags)
  @target_service_accounts = args[:target_service_accounts] if args.key?(:target_service_accounts)
  @target_tags = args[:target_tags] if args.key?(:target_tags)
end