Class: Google::Apis::ComputeAlpha::Firewall::Allowed

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Allowed

Returns a new instance of Allowed.



14992
14993
14994
# File 'lib/google/apis/compute_alpha/classes.rb', line 14992

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ip_protocolString

The IP protocol to which this rule applies. The protocol type is required when creating a firewall rule. This value can either be one of the following well known protocol strings (tcp, udp,icmp, esp, ah, ipip,sctp) or the IP protocol number. Corresponds to the JSON property IPProtocol

Returns:

  • (String)


14980
14981
14982
# File 'lib/google/apis/compute_alpha/classes.rb', line 14980

def ip_protocol
  @ip_protocol
end

#portsArray<String>

An optional list of ports to which this rule applies. This field is only applicable for the UDP or TCP protocol. Each entry must be either an integer or a range. If not specified, this rule applies to connections through any port. Example inputs include: ["22"], ["80","443"], and ["12345-12349"]. Corresponds to the JSON property ports

Returns:

  • (Array<String>)


14990
14991
14992
# File 'lib/google/apis/compute_alpha/classes.rb', line 14990

def ports
  @ports
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



14997
14998
14999
15000
# File 'lib/google/apis/compute_alpha/classes.rb', line 14997

def update!(**args)
  @ip_protocol = args[:ip_protocol] if args.key?(:ip_protocol)
  @ports = args[:ports] if args.key?(:ports)
end