Class: Google::Apis::ComputeAlpha::FirewallList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of firewalls.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FirewallList

Returns a new instance of FirewallList.



15077
15078
15079
# File 'lib/google/apis/compute_alpha/classes.rb', line 15077

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


15044
15045
15046
# File 'lib/google/apis/compute_alpha/classes.rb', line 15044

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::Firewall>

A list of Firewall resources. Corresponds to the JSON property items



15049
15050
15051
# File 'lib/google/apis/compute_alpha/classes.rb', line 15049

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#firewallList for lists of firewalls. Corresponds to the JSON property kind

Returns:

  • (String)


15055
15056
15057
# File 'lib/google/apis/compute_alpha/classes.rb', line 15055

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


15065
15066
15067
# File 'lib/google/apis/compute_alpha/classes.rb', line 15065

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


15070
15071
15072
# File 'lib/google/apis/compute_alpha/classes.rb', line 15070

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::FirewallList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



15075
15076
15077
# File 'lib/google/apis/compute_alpha/classes.rb', line 15075

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



15082
15083
15084
15085
15086
15087
15088
15089
# File 'lib/google/apis/compute_alpha/classes.rb', line 15082

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end