Class: Google::Apis::ComputeAlpha::FirewallPoliciesScopedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FirewallPoliciesScopedList

Returns a new instance of FirewallPoliciesScopedList.



15070
15071
15072
# File 'lib/google/apis/compute_alpha/classes.rb', line 15070

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#firewall_policiesArray<Google::Apis::ComputeAlpha::FirewallPolicy>

A list of firewall policies contained in this scope. Corresponds to the JSON property firewallPolicies



15062
15063
15064
# File 'lib/google/apis/compute_alpha/classes.rb', line 15062

def firewall_policies
  @firewall_policies
end

#warningGoogle::Apis::ComputeAlpha::FirewallPoliciesScopedList::Warning

Informational warning which replaces the list of firewall policies when the list is empty. Corresponds to the JSON property warning



15068
15069
15070
# File 'lib/google/apis/compute_alpha/classes.rb', line 15068

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



15075
15076
15077
15078
# File 'lib/google/apis/compute_alpha/classes.rb', line 15075

def update!(**args)
  @firewall_policies = args[:firewall_policies] if args.key?(:firewall_policies)
  @warning = args[:warning] if args.key?(:warning)
end