Class: Google::Apis::ComputeAlpha::FirewallPolicyAssociation

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FirewallPolicyAssociation

Returns a new instance of FirewallPolicyAssociation.



15579
15580
15581
# File 'lib/google/apis/compute_alpha/classes.rb', line 15579

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#attachment_targetString

The target that the firewall policy is attached to. Corresponds to the JSON property attachmentTarget

Returns:

  • (String)


15545
15546
15547
# File 'lib/google/apis/compute_alpha/classes.rb', line 15545

def attachment_target
  @attachment_target
end

#display_nameString

[Output Only] Deprecated, please use short name instead. The display name of the firewall policy of the association. Corresponds to the JSON property displayName

Returns:

  • (String)


15551
15552
15553
# File 'lib/google/apis/compute_alpha/classes.rb', line 15551

def display_name
  @display_name
end

#firewall_policy_idString

Output only. [Output Only] The firewall policy ID of the association. Corresponds to the JSON property firewallPolicyId

Returns:

  • (String)


15556
15557
15558
# File 'lib/google/apis/compute_alpha/classes.rb', line 15556

def firewall_policy_id
  @firewall_policy_id
end

#nameString

The name for an association. Corresponds to the JSON property name

Returns:

  • (String)


15561
15562
15563
# File 'lib/google/apis/compute_alpha/classes.rb', line 15561

def name
  @name
end

#priorityFixnum

An integer indicating the priority of an association. The priority must be a positive value between 1 and 2147483647. Firewall Policies are evaluated from highest to lowest priority where 1 is the highest priority and 2147483647 is the lowest priority. The default value is 1000. If two associations have the same priority then lexicographical order on association names is applied. Corresponds to the JSON property priority

Returns:

  • (Fixnum)


15571
15572
15573
# File 'lib/google/apis/compute_alpha/classes.rb', line 15571

def priority
  @priority
end

#short_nameString

Output only. [Output Only] The short name of the firewall policy of the association. Corresponds to the JSON property shortName

Returns:

  • (String)


15577
15578
15579
# File 'lib/google/apis/compute_alpha/classes.rb', line 15577

def short_name
  @short_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



15584
15585
15586
15587
15588
15589
15590
15591
# File 'lib/google/apis/compute_alpha/classes.rb', line 15584

def update!(**args)
  @attachment_target = args[:attachment_target] if args.key?(:attachment_target)
  @display_name = args[:display_name] if args.key?(:display_name)
  @firewall_policy_id = args[:firewall_policy_id] if args.key?(:firewall_policy_id)
  @name = args[:name] if args.key?(:name)
  @priority = args[:priority] if args.key?(:priority)
  @short_name = args[:short_name] if args.key?(:short_name)
end