Class: Google::Apis::ComputeAlpha::FirewallPolicyRolloutOperationRolloutStatus
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::FirewallPolicyRolloutOperationRolloutStatus
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Represents progressive rollout current status.
Instance Attribute Summary collapse
-
#next_rollout ⇒ Google::Apis::ComputeAlpha::FirewallPolicyRolloutOperationRolloutStatusNextRollout
[Output only] The next rollout.
-
#ongoing_rollouts ⇒ Array<Google::Apis::ComputeAlpha::FirewallPolicyRolloutOperationRolloutStatusRolloutMetadata>
[Output only] The ongoing rollout.
-
#previous_rollout ⇒ Google::Apis::ComputeAlpha::FirewallPolicyRolloutOperationRolloutStatusRolloutMetadata
Represents the status of the progressive rollout instance, either completed or ongoing.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FirewallPolicyRolloutOperationRolloutStatus
constructor
A new instance of FirewallPolicyRolloutOperationRolloutStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FirewallPolicyRolloutOperationRolloutStatus
Returns a new instance of FirewallPolicyRolloutOperationRolloutStatus.
15792 15793 15794 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 15792 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_rollout ⇒ Google::Apis::ComputeAlpha::FirewallPolicyRolloutOperationRolloutStatusNextRollout
[Output only] The next rollout.
Corresponds to the JSON property nextRollout
15779 15780 15781 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 15779 def next_rollout @next_rollout end |
#ongoing_rollouts ⇒ Array<Google::Apis::ComputeAlpha::FirewallPolicyRolloutOperationRolloutStatusRolloutMetadata>
[Output only] The ongoing rollout.
Corresponds to the JSON property ongoingRollouts
15784 15785 15786 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 15784 def ongoing_rollouts @ongoing_rollouts end |
#previous_rollout ⇒ Google::Apis::ComputeAlpha::FirewallPolicyRolloutOperationRolloutStatusRolloutMetadata
Represents the status of the progressive rollout instance, either
completed or ongoing.
Corresponds to the JSON property previousRollout
15790 15791 15792 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 15790 def previous_rollout @previous_rollout end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
15797 15798 15799 15800 15801 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 15797 def update!(**args) @next_rollout = args[:next_rollout] if args.key?(:next_rollout) @ongoing_rollouts = args[:ongoing_rollouts] if args.key?(:ongoing_rollouts) @previous_rollout = args[:previous_rollout] if args.key?(:previous_rollout) end |