Class: Google::Apis::ComputeAlpha::ForwardingRuleAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::ForwardingRuleAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::ForwardingRulesScopedList>
A list of ForwardingRulesScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::ForwardingRuleAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ForwardingRuleAggregatedList
constructor
A new instance of ForwardingRuleAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ForwardingRuleAggregatedList
Returns a new instance of ForwardingRuleAggregatedList.
17227 17228 17229 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 17227 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
17189 17190 17191 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 17189 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::ForwardingRulesScopedList>
A list of ForwardingRulesScopedList resources.
Corresponds to the JSON property items
17194 17195 17196 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 17194 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
forwardingRuleAggregatedList for lists of forwarding rules.
Corresponds to the JSON property kind
17200 17201 17202 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 17200 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
17210 17211 17212 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 17210 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
17215 17216 17217 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 17215 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
17220 17221 17222 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 17220 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::ForwardingRuleAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
17225 17226 17227 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 17225 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
17232 17233 17234 17235 17236 17237 17238 17239 17240 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 17232 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |