Class: Google::Apis::ComputeAlpha::FutureReservationSpecificSkuProperties

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FutureReservationSpecificSkuProperties

Returns a new instance of FutureReservationSpecificSkuProperties.



17946
17947
17948
# File 'lib/google/apis/compute_alpha/classes.rb', line 17946

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#instance_propertiesGoogle::Apis::ComputeAlpha::AllocationSpecificSkuAllocationReservedInstanceProperties

Properties of the SKU instances being reserved. Next ID: 10 Corresponds to the JSON property instanceProperties



17932
17933
17934
# File 'lib/google/apis/compute_alpha/classes.rb', line 17932

def instance_properties
  @instance_properties
end

#source_instance_templateString

The instance template that will be used to populate the ReservedInstanceProperties of the future reservation Corresponds to the JSON property sourceInstanceTemplate

Returns:

  • (String)


17938
17939
17940
# File 'lib/google/apis/compute_alpha/classes.rb', line 17938

def source_instance_template
  @source_instance_template
end

#total_countFixnum

Total number of instances for which capacity assurance is requested at a future time period. Corresponds to the JSON property totalCount

Returns:

  • (Fixnum)


17944
17945
17946
# File 'lib/google/apis/compute_alpha/classes.rb', line 17944

def total_count
  @total_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



17951
17952
17953
17954
17955
# File 'lib/google/apis/compute_alpha/classes.rb', line 17951

def update!(**args)
  @instance_properties = args[:instance_properties] if args.key?(:instance_properties)
  @source_instance_template = args[:source_instance_template] if args.key?(:source_instance_template)
  @total_count = args[:total_count] if args.key?(:total_count)
end