Class: Google::Apis::ComputeAlpha::FutureReservationStatusExistingMatchingUsageInfo

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

[Output Only] Represents the existing matching usage for the future reservation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FutureReservationStatusExistingMatchingUsageInfo

Returns a new instance of FutureReservationStatusExistingMatchingUsageInfo.



16918
16919
16920
# File 'lib/google/apis/compute_alpha/classes.rb', line 16918

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#countFixnum

Output only. Count to represent min(FR total_count, matching_reserved_capacity+matching_unreserved_instances) Corresponds to the JSON property count

Returns:

  • (Fixnum)


16911
16912
16913
# File 'lib/google/apis/compute_alpha/classes.rb', line 16911

def count
  @count
end

#timestampString

Output only. Timestamp when the matching usage was calculated Corresponds to the JSON property timestamp

Returns:

  • (String)


16916
16917
16918
# File 'lib/google/apis/compute_alpha/classes.rb', line 16916

def timestamp
  @timestamp
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



16923
16924
16925
16926
# File 'lib/google/apis/compute_alpha/classes.rb', line 16923

def update!(**args)
  @count = args[:count] if args.key?(:count)
  @timestamp = args[:timestamp] if args.key?(:timestamp)
end