Class: Google::Apis::ComputeAlpha::FutureReservationStatusLastKnownGoodStateFutureReservationSpecs
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::FutureReservationStatusLastKnownGoodStateFutureReservationSpecs
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
The properties of the last known good state for the Future Reservation.
Instance Attribute Summary collapse
-
#share_settings ⇒ Google::Apis::ComputeAlpha::ShareSettings
The share setting for reservations and sole tenancy node groups.
-
#specific_sku_properties ⇒ Google::Apis::ComputeAlpha::FutureReservationSpecificSkuProperties
Output only.
-
#time_window ⇒ Google::Apis::ComputeAlpha::FutureReservationTimeWindow
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FutureReservationStatusLastKnownGoodStateFutureReservationSpecs
constructor
A new instance of FutureReservationStatusLastKnownGoodStateFutureReservationSpecs.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FutureReservationStatusLastKnownGoodStateFutureReservationSpecs
Returns a new instance of FutureReservationStatusLastKnownGoodStateFutureReservationSpecs.
18144 18145 18146 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 18144 def initialize(**args) update!(**args) end |
Instance Attribute Details
#share_settings ⇒ Google::Apis::ComputeAlpha::ShareSettings
The share setting for reservations and sole tenancy node groups.
Corresponds to the JSON property shareSettings
18131 18132 18133 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 18131 def share_settings @share_settings end |
#specific_sku_properties ⇒ Google::Apis::ComputeAlpha::FutureReservationSpecificSkuProperties
Output only. [Output Only] The previous instance related properties of the
Future Reservation.
Corresponds to the JSON property specificSkuProperties
18137 18138 18139 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 18137 def specific_sku_properties @specific_sku_properties end |
#time_window ⇒ Google::Apis::ComputeAlpha::FutureReservationTimeWindow
Output only. [Output Only] The previous time window of the Future Reservation.
Corresponds to the JSON property timeWindow
18142 18143 18144 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 18142 def time_window @time_window end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
18149 18150 18151 18152 18153 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 18149 def update!(**args) @share_settings = args[:share_settings] if args.key?(:share_settings) @specific_sku_properties = args[:specific_sku_properties] if args.key?(:specific_sku_properties) @time_window = args[:time_window] if args.key?(:time_window) end |