Class: Google::Apis::ComputeAlpha::FutureReservationStoragePoolProvisionedCapacity

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Storage pool provisioned capacities for each SKU type.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FutureReservationStoragePoolProvisionedCapacity

Returns a new instance of FutureReservationStoragePoolProvisionedCapacity.



18228
18229
18230
# File 'lib/google/apis/compute_alpha/classes.rb', line 18228

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#pool_provisioned_capacity_gbFixnum

Size of the storage pool in GiB. Corresponds to the JSON property poolProvisionedCapacityGb

Returns:

  • (Fixnum)


18214
18215
18216
# File 'lib/google/apis/compute_alpha/classes.rb', line 18214

def pool_provisioned_capacity_gb
  @pool_provisioned_capacity_gb
end

#pool_provisioned_iopsFixnum

Provisioned IOPS of the storage pool. Only relevant if the storage pool type is hyperdisk-balanced. Corresponds to the JSON property poolProvisionedIops

Returns:

  • (Fixnum)


18220
18221
18222
# File 'lib/google/apis/compute_alpha/classes.rb', line 18220

def pool_provisioned_iops
  @pool_provisioned_iops
end

#pool_provisioned_throughputFixnum

Provisioned throughput of the storage pool in MiB/s. Only relevant if the storage pool type is hyperdisk-balanced or hyperdisk-throughput. Corresponds to the JSON property poolProvisionedThroughput

Returns:

  • (Fixnum)


18226
18227
18228
# File 'lib/google/apis/compute_alpha/classes.rb', line 18226

def pool_provisioned_throughput
  @pool_provisioned_throughput
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



18233
18234
18235
18236
18237
# File 'lib/google/apis/compute_alpha/classes.rb', line 18233

def update!(**args)
  @pool_provisioned_capacity_gb = args[:pool_provisioned_capacity_gb] if args.key?(:pool_provisioned_capacity_gb)
  @pool_provisioned_iops = args[:pool_provisioned_iops] if args.key?(:pool_provisioned_iops)
  @pool_provisioned_throughput = args[:pool_provisioned_throughput] if args.key?(:pool_provisioned_throughput)
end