Class: Google::Apis::ComputeAlpha::FutureReservationsAggregatedListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of future reservations.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FutureReservationsAggregatedListResponse

Returns a new instance of FutureReservationsAggregatedListResponse.



18326
18327
18328
# File 'lib/google/apis/compute_alpha/classes.rb', line 18326

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


18282
18283
18284
# File 'lib/google/apis/compute_alpha/classes.rb', line 18282

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


18287
18288
18289
# File 'lib/google/apis/compute_alpha/classes.rb', line 18287

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::FutureReservationsScopedList>

A list of Future reservation resources. Corresponds to the JSON property items



18292
18293
18294
# File 'lib/google/apis/compute_alpha/classes.rb', line 18292

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# futureReservationsAggregatedListResponse for future resevation aggregated list response. Corresponds to the JSON property kind

Returns:

  • (String)


18299
18300
18301
# File 'lib/google/apis/compute_alpha/classes.rb', line 18299

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


18309
18310
18311
# File 'lib/google/apis/compute_alpha/classes.rb', line 18309

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


18314
18315
18316
# File 'lib/google/apis/compute_alpha/classes.rb', line 18314

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


18319
18320
18321
# File 'lib/google/apis/compute_alpha/classes.rb', line 18319

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::FutureReservationsAggregatedListResponse::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



18324
18325
18326
# File 'lib/google/apis/compute_alpha/classes.rb', line 18324

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



18331
18332
18333
18334
18335
18336
18337
18338
18339
18340
# File 'lib/google/apis/compute_alpha/classes.rb', line 18331

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end