Class: Google::Apis::ComputeAlpha::FutureReservationsListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FutureReservationsListResponse

Returns a new instance of FutureReservationsListResponse.



18465
18466
18467
# File 'lib/google/apis/compute_alpha/classes.rb', line 18465

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


18420
18421
18422
# File 'lib/google/apis/compute_alpha/classes.rb', line 18420

def etag
  @etag
end

#idString

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


18426
18427
18428
# File 'lib/google/apis/compute_alpha/classes.rb', line 18426

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::FutureReservation>

[Output Only] A list of future reservation resources. Corresponds to the JSON property items



18431
18432
18433
# File 'lib/google/apis/compute_alpha/classes.rb', line 18431

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource.Alwayscompute# FutureReservationsListResponse for lists of reservations Corresponds to the JSON property kind

Returns:

  • (String)


18438
18439
18440
# File 'lib/google/apis/compute_alpha/classes.rb', line 18438

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


18448
18449
18450
# File 'lib/google/apis/compute_alpha/classes.rb', line 18448

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


18453
18454
18455
# File 'lib/google/apis/compute_alpha/classes.rb', line 18453

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


18458
18459
18460
# File 'lib/google/apis/compute_alpha/classes.rb', line 18458

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::FutureReservationsListResponse::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



18463
18464
18465
# File 'lib/google/apis/compute_alpha/classes.rb', line 18463

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



18470
18471
18472
18473
18474
18475
18476
18477
18478
18479
# File 'lib/google/apis/compute_alpha/classes.rb', line 18470

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end