Class: Google::Apis::ComputeAlpha::FutureReservationsScopedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FutureReservationsScopedList

Returns a new instance of FutureReservationsScopedList.



17052
17053
17054
# File 'lib/google/apis/compute_alpha/classes.rb', line 17052

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#future_reservationsArray<Google::Apis::ComputeAlpha::FutureReservation>

A list of future reservations contained in this scope. Corresponds to the JSON property futureReservations



17044
17045
17046
# File 'lib/google/apis/compute_alpha/classes.rb', line 17044

def future_reservations
  @future_reservations
end

#warningGoogle::Apis::ComputeAlpha::FutureReservationsScopedList::Warning

Informational warning which replaces the list of future reservations when the list is empty. Corresponds to the JSON property warning



17050
17051
17052
# File 'lib/google/apis/compute_alpha/classes.rb', line 17050

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



17057
17058
17059
17060
# File 'lib/google/apis/compute_alpha/classes.rb', line 17057

def update!(**args)
  @future_reservations = args[:future_reservations] if args.key?(:future_reservations)
  @warning = args[:warning] if args.key?(:warning)
end