Class: Google::Apis::ComputeAlpha::FutureResourcesRecommendation
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::FutureResourcesRecommendation
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Recommendation for single resources specification, to be created in the future.
Instance Attribute Summary collapse
-
#end_time ⇒ String
Corresponds to the JSON property
endTime. -
#location ⇒ String
The advised location for resource usage.
-
#other_locations ⇒ Hash<String,Google::Apis::ComputeAlpha::FutureResourcesRecommendationOtherLocation>
List of locations in the request scope that were not recommended.
-
#recommendation_id ⇒ String
Unique id of the recommendation, a UUID string generated by the API.
-
#recommendation_type ⇒ String
Type of recommendation.
-
#start_time ⇒ String
Corresponds to the JSON property
startTime.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FutureResourcesRecommendation
constructor
A new instance of FutureResourcesRecommendation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FutureResourcesRecommendation
Returns a new instance of FutureResourcesRecommendation.
18689 18690 18691 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 18689 def initialize(**args) update!(**args) end |
Instance Attribute Details
#end_time ⇒ String
Corresponds to the JSON property endTime
18657 18658 18659 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 18657 def end_time @end_time end |
#location ⇒ String
The advised location for resource usage. When a zone, in format
'zones/'.
If not set, it means that no location is recommended - see
other_locations for details.
Corresponds to the JSON property location
18665 18666 18667 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 18665 def location @location end |
#other_locations ⇒ Hash<String,Google::Apis::ComputeAlpha::FutureResourcesRecommendationOtherLocation>
List of locations in the request scope that were not
recommended. Keys of the map are zones, in format 'zones/'.
The values are status information indicating the recommendation status.
Corresponds to the JSON property otherLocations
18672 18673 18674 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 18672 def other_locations @other_locations end |
#recommendation_id ⇒ String
Unique id of the recommendation, a UUID string generated by the API.
Corresponds to the JSON property recommendationId
18677 18678 18679 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 18677 def recommendation_id @recommendation_id end |
#recommendation_type ⇒ String
Type of recommendation. Currently only FUTURE_RESERVATION is supported.
Corresponds to the JSON property recommendationType
18682 18683 18684 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 18682 def recommendation_type @recommendation_type end |
#start_time ⇒ String
Corresponds to the JSON property startTime
18687 18688 18689 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 18687 def start_time @start_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
18694 18695 18696 18697 18698 18699 18700 18701 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 18694 def update!(**args) @end_time = args[:end_time] if args.key?(:end_time) @location = args[:location] if args.key?(:location) @other_locations = args[:other_locations] if args.key?(:other_locations) @recommendation_id = args[:recommendation_id] if args.key?(:recommendation_id) @recommendation_type = args[:recommendation_type] if args.key?(:recommendation_type) @start_time = args[:start_time] if args.key?(:start_time) end |