Class: Google::Apis::ComputeAlpha::FutureResourcesRecommendationOtherLocation
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::FutureResourcesRecommendationOtherLocation
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Information about recommendation status for locations that were allowed but not used by the response.
Instance Attribute Summary collapse
-
#details ⇒ String
Details (human readable) describing the situation.
-
#status ⇒ String
Status of recommendation in this location.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FutureResourcesRecommendationOtherLocation
constructor
A new instance of FutureResourcesRecommendationOtherLocation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FutureResourcesRecommendationOtherLocation
Returns a new instance of FutureResourcesRecommendationOtherLocation.
18591 18592 18593 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 18591 def initialize(**args) update!(**args) end |
Instance Attribute Details
#details ⇒ String
Details (human readable) describing the situation.
For example, if status is CONDITION_NOT_MET, then
details contain information about the parameters of the time window
that did not meet the required conditions.
Corresponds to the JSON property details
18584 18585 18586 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 18584 def details @details end |
#status ⇒ String
Status of recommendation in this location.
Corresponds to the JSON property status
18589 18590 18591 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 18589 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
18596 18597 18598 18599 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 18596 def update!(**args) @details = args[:details] if args.key?(:details) @status = args[:status] if args.key?(:status) end |