Class: Google::Apis::ComputeAlpha::FutureResourcesSpecAggregateResources
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::FutureResourcesSpecAggregateResources
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#accelerator_count ⇒ Fixnum
Size of the request, in accelerator (chip) count.
-
#vm_family ⇒ String
The VM family that all instances scheduled against this reservation must belong to.
-
#workload_type ⇒ String
Workload type.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FutureResourcesSpecAggregateResources
constructor
A new instance of FutureResourcesSpecAggregateResources.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FutureResourcesSpecAggregateResources
Returns a new instance of FutureResourcesSpecAggregateResources.
18663 18664 18665 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 18663 def initialize(**args) update!(**args) end |
Instance Attribute Details
#accelerator_count ⇒ Fixnum
Size of the request, in accelerator (chip) count.
Corresponds to the JSON property acceleratorCount
18650 18651 18652 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 18650 def accelerator_count @accelerator_count end |
#vm_family ⇒ String
The VM family that all instances scheduled against this reservation
must belong to. Use for TPU reservations.
Corresponds to the JSON property vmFamily
18656 18657 18658 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 18656 def vm_family @vm_family end |
#workload_type ⇒ String
Workload type. Use for TPU reservations.
Corresponds to the JSON property workloadType
18661 18662 18663 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 18661 def workload_type @workload_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
18668 18669 18670 18671 18672 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 18668 def update!(**args) @accelerator_count = args[:accelerator_count] if args.key?(:accelerator_count) @vm_family = args[:vm_family] if args.key?(:vm_family) @workload_type = args[:workload_type] if args.key?(:workload_type) end |