Class: Google::Apis::ComputeAlpha::GetVersionOperationMetadataSbomInfo
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::GetVersionOperationMetadataSbomInfo
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#current_component_versions ⇒ Hash<String,String>
A mapping of components to their currently-applied versions or other appropriate identifiers.
-
#target_component_versions ⇒ Hash<String,String>
A mapping of components to their target versions or other appropriate identifiers.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GetVersionOperationMetadataSbomInfo
constructor
A new instance of GetVersionOperationMetadataSbomInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GetVersionOperationMetadataSbomInfo
Returns a new instance of GetVersionOperationMetadataSbomInfo.
19200 19201 19202 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 19200 def initialize(**args) update!(**args) end |
Instance Attribute Details
#current_component_versions ⇒ Hash<String,String>
A mapping of components to their currently-applied versions or other
appropriate identifiers.
Corresponds to the JSON property currentComponentVersions
19192 19193 19194 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 19192 def current_component_versions @current_component_versions end |
#target_component_versions ⇒ Hash<String,String>
A mapping of components to their target versions or other appropriate
identifiers.
Corresponds to the JSON property targetComponentVersions
19198 19199 19200 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 19198 def target_component_versions @target_component_versions end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
19205 19206 19207 19208 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 19205 def update!(**args) @current_component_versions = args[:current_component_versions] if args.key?(:current_component_versions) @target_component_versions = args[:target_component_versions] if args.key?(:target_component_versions) end |