Class: Google::Apis::ComputeAlpha::GuestOsFeature

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Guest OS features.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GuestOsFeature

Returns a new instance of GuestOsFeature.



20488
20489
20490
# File 'lib/google/apis/compute_alpha/classes.rb', line 20488

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#typeString

The ID of a supported feature. To add multiple values, use commas to separate values. Set to one or more of the following values:

  • VIRTIO_SCSI_MULTIQUEUE
  • WINDOWS
  • MULTI_IP_SUBNET
  • UEFI_COMPATIBLE
  • GVNIC
  • SEV_CAPABLE
  • SUSPEND_RESUME_COMPATIBLE
  • SEV_LIVE_MIGRATABLE_V2
  • SEV_SNP_CAPABLE
  • TDX_CAPABLE
  • IDPF
  • SNP_SVSM_CAPABLE
  • CCA_CAPABLE For more information, see Enabling guest operating system features. Corresponds to the JSON property type

Returns:

  • (String)


20486
20487
20488
# File 'lib/google/apis/compute_alpha/classes.rb', line 20486

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20493
20494
20495
# File 'lib/google/apis/compute_alpha/classes.rb', line 20493

def update!(**args)
  @type = args[:type] if args.key?(:type)
end