Class: Google::Apis::ComputeAlpha::HaController

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

HaController handles failover for a VM Instance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HaController

Returns a new instance of HaController.



20896
20897
20898
# File 'lib/google/apis/compute_alpha/classes.rb', line 20896

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backend_servicesArray<String>

Advanced configuration option. If specified, these Backend Services need to be pre-created. Currently, only one backend service can be specified, and it must be L4 Internal Load Balancer (ILB). Corresponds to the JSON property backendServices

Returns:

  • (Array<String>)


20799
20800
20801
# File 'lib/google/apis/compute_alpha/classes.rb', line 20799

def backend_services
  @backend_services
end

#creation_timestampString

Output only. [Output Only] Creation timestamp in RFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


20805
20806
20807
# File 'lib/google/apis/compute_alpha/classes.rb', line 20805

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


20811
20812
20813
# File 'lib/google/apis/compute_alpha/classes.rb', line 20811

def description
  @description
end

#failover_initiationString

Indicates how failover should be initiated. Corresponds to the JSON property failoverInitiation

Returns:

  • (String)


20816
20817
20818
# File 'lib/google/apis/compute_alpha/classes.rb', line 20816

def failover_initiation
  @failover_initiation
end

#idFixnum

Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


20823
20824
20825
# File 'lib/google/apis/compute_alpha/classes.rb', line 20823

def id
  @id
end

#instance_nameString

Name of the instance that HaController is in charge of. If not specified the HaController's resource name will be used instead. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property instanceName

Returns:

  • (String)


20835
20836
20837
# File 'lib/google/apis/compute_alpha/classes.rb', line 20835

def instance_name
  @instance_name
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute#haController for HaControllers. Corresponds to the JSON property kind

Returns:

  • (String)


20841
20842
20843
# File 'lib/google/apis/compute_alpha/classes.rb', line 20841

def kind
  @kind
end

#nameString

Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


20853
20854
20855
# File 'lib/google/apis/compute_alpha/classes.rb', line 20853

def name
  @name
end

#networking_auto_configurationGoogle::Apis::ComputeAlpha::HaControllerNetworkingAutoConfiguration

Basic networking configuration. Required backend services and forwarding rules will be automatically created with default parameters. Corresponds to the JSON property networkingAutoConfiguration



20859
20860
20861
# File 'lib/google/apis/compute_alpha/classes.rb', line 20859

def networking_auto_configuration
  @networking_auto_configuration
end

#regionString

Output only. [Output Only] URL of the region where the resource resides. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body. Corresponds to the JSON property region

Returns:

  • (String)


20866
20867
20868
# File 'lib/google/apis/compute_alpha/classes.rb', line 20866

def region
  @region
end

Output only. [Output only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


20871
20872
20873
# File 'lib/google/apis/compute_alpha/classes.rb', line 20871

def self_link
  @self_link
end

Output only. [Output Only] Server-defined URL for this resource with the resource id. Corresponds to the JSON property selfLinkWithId

Returns:

  • (String)


20877
20878
20879
# File 'lib/google/apis/compute_alpha/classes.rb', line 20877

def self_link_with_id
  @self_link_with_id
end

#stateString

Output only. The current state of the HA Controller. Corresponds to the JSON property state

Returns:

  • (String)


20882
20883
20884
# File 'lib/google/apis/compute_alpha/classes.rb', line 20882

def state
  @state
end

#statusGoogle::Apis::ComputeAlpha::HaControllerStatus

Contains information about current status of the HaController. Corresponds to the JSON property status



20887
20888
20889
# File 'lib/google/apis/compute_alpha/classes.rb', line 20887

def status
  @status
end

#zone_configurationsHash<String,Google::Apis::ComputeAlpha::HaControllerZoneConfiguration>

Map of zone configurations Key: name of the zone Value: ZoneConfiguration Corresponds to the JSON property zoneConfigurations



20894
20895
20896
# File 'lib/google/apis/compute_alpha/classes.rb', line 20894

def zone_configurations
  @zone_configurations
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20901
20902
20903
20904
20905
20906
20907
20908
20909
20910
20911
20912
20913
20914
20915
20916
20917
# File 'lib/google/apis/compute_alpha/classes.rb', line 20901

def update!(**args)
  @backend_services = args[:backend_services] if args.key?(:backend_services)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @failover_initiation = args[:failover_initiation] if args.key?(:failover_initiation)
  @id = args[:id] if args.key?(:id)
  @instance_name = args[:instance_name] if args.key?(:instance_name)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @networking_auto_configuration = args[:networking_auto_configuration] if args.key?(:networking_auto_configuration)
  @region = args[:region] if args.key?(:region)
  @self_link = args[:self_link] if args.key?(:self_link)
  @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id)
  @state = args[:state] if args.key?(:state)
  @status = args[:status] if args.key?(:status)
  @zone_configurations = args[:zone_configurations] if args.key?(:zone_configurations)
end