Class: Google::Apis::ComputeAlpha::HaControllerStatusFailoverProgress

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains information about the current failover operation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HaControllerStatusFailoverProgress

Returns a new instance of HaControllerStatusFailoverProgress.



21074
21075
21076
# File 'lib/google/apis/compute_alpha/classes.rb', line 21074

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#failover_complete_timestampString

Output only. [Output Only] Timestamp of the failover completion. Filled only if the failover is completed, in lastFailoverInfo. Corresponds to the JSON property failoverCompleteTimestamp

Returns:

  • (String)


21048
21049
21050
# File 'lib/google/apis/compute_alpha/classes.rb', line 21048

def failover_complete_timestamp
  @failover_complete_timestamp
end

#failover_durationString

Output only. The duration of the last failover. Corresponds to the JSON property failoverDuration

Returns:

  • (String)


21053
21054
21055
# File 'lib/google/apis/compute_alpha/classes.rb', line 21053

def failover_duration
  @failover_duration
end

#failover_triggerString

Output only. [Output Only] Indicates if failover has been triggered automatically or manually. Corresponds to the JSON property failoverTrigger

Returns:

  • (String)


21060
21061
21062
# File 'lib/google/apis/compute_alpha/classes.rb', line 21060

def failover_trigger
  @failover_trigger
end

#failover_trigger_timestampString

Output only. [Output Only] Timestamp of the last failover trigger. Corresponds to the JSON property failoverTriggerTimestamp

Returns:

  • (String)


21065
21066
21067
# File 'lib/google/apis/compute_alpha/classes.rb', line 21065

def failover_trigger_timestamp
  @failover_trigger_timestamp
end

#last_failover_attemptGoogle::Apis::ComputeAlpha::HaControllerStatusFailoverProgressLastFailoverAttempt

Output only. [Output Only] Contains details of the last failed failover. This field is filled only if the current failover is failing Corresponds to the JSON property lastFailoverAttempt



21072
21073
21074
# File 'lib/google/apis/compute_alpha/classes.rb', line 21072

def last_failover_attempt
  @last_failover_attempt
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



21079
21080
21081
21082
21083
21084
21085
# File 'lib/google/apis/compute_alpha/classes.rb', line 21079

def update!(**args)
  @failover_complete_timestamp = args[:failover_complete_timestamp] if args.key?(:failover_complete_timestamp)
  @failover_duration = args[:failover_duration] if args.key?(:failover_duration)
  @failover_trigger = args[:failover_trigger] if args.key?(:failover_trigger)
  @failover_trigger_timestamp = args[:failover_trigger_timestamp] if args.key?(:failover_trigger_timestamp)
  @last_failover_attempt = args[:last_failover_attempt] if args.key?(:last_failover_attempt)
end