Class: Google::Apis::ComputeAlpha::HealthAggregationPoliciesScopedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::HealthAggregationPoliciesScopedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#health_aggregation_policies ⇒ Array<Google::Apis::ComputeAlpha::HealthAggregationPolicy>
A list of HealthAggregationPolicys contained in this scope.
-
#warning ⇒ Google::Apis::ComputeAlpha::HealthAggregationPoliciesScopedList::Warning
Informational warning which replaces the list of health aggregation policies when the list is empty.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HealthAggregationPoliciesScopedList
constructor
A new instance of HealthAggregationPoliciesScopedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HealthAggregationPoliciesScopedList
Returns a new instance of HealthAggregationPoliciesScopedList.
20249 20250 20251 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 20249 def initialize(**args) update!(**args) end |
Instance Attribute Details
#health_aggregation_policies ⇒ Array<Google::Apis::ComputeAlpha::HealthAggregationPolicy>
A list of HealthAggregationPolicys contained in this scope.
Corresponds to the JSON property healthAggregationPolicies
20241 20242 20243 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 20241 def health_aggregation_policies @health_aggregation_policies end |
#warning ⇒ Google::Apis::ComputeAlpha::HealthAggregationPoliciesScopedList::Warning
Informational warning which replaces the list of health aggregation
policies when the list is empty.
Corresponds to the JSON property warning
20247 20248 20249 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 20247 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
20254 20255 20256 20257 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 20254 def update!(**args) @health_aggregation_policies = args[:health_aggregation_policies] if args.key?(:health_aggregation_policies) @warning = args[:warning] if args.key?(:warning) end |