Class: Google::Apis::ComputeAlpha::HealthCheckServiceAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of HealthCheckServicesScopedList.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HealthCheckServiceAggregatedList

Returns a new instance of HealthCheckServiceAggregatedList.



22984
22985
22986
# File 'lib/google/apis/compute_alpha/classes.rb', line 22984

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


22947
22948
22949
# File 'lib/google/apis/compute_alpha/classes.rb', line 22947

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::HealthCheckServicesScopedList>

A list of HealthCheckServicesScopedList resources. Corresponds to the JSON property items



22952
22953
22954
# File 'lib/google/apis/compute_alpha/classes.rb', line 22952

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


22957
22958
22959
# File 'lib/google/apis/compute_alpha/classes.rb', line 22957

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


22967
22968
22969
# File 'lib/google/apis/compute_alpha/classes.rb', line 22967

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


22972
22973
22974
# File 'lib/google/apis/compute_alpha/classes.rb', line 22972

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


22977
22978
22979
# File 'lib/google/apis/compute_alpha/classes.rb', line 22977

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::HealthCheckServiceAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



22982
22983
22984
# File 'lib/google/apis/compute_alpha/classes.rb', line 22982

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



22989
22990
22991
22992
22993
22994
22995
22996
22997
# File 'lib/google/apis/compute_alpha/classes.rb', line 22989

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end