Class: Google::Apis::ComputeAlpha::HealthSourceAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of HealthSourcesScopedList.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HealthSourceAggregatedList

Returns a new instance of HealthSourceAggregatedList.



23712
23713
23714
# File 'lib/google/apis/compute_alpha/classes.rb', line 23712

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


23675
23676
23677
# File 'lib/google/apis/compute_alpha/classes.rb', line 23675

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::HealthSourcesScopedList>

A list of HealthSourcesScopedList resources. Corresponds to the JSON property items



23680
23681
23682
# File 'lib/google/apis/compute_alpha/classes.rb', line 23680

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


23685
23686
23687
# File 'lib/google/apis/compute_alpha/classes.rb', line 23685

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


23695
23696
23697
# File 'lib/google/apis/compute_alpha/classes.rb', line 23695

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


23700
23701
23702
# File 'lib/google/apis/compute_alpha/classes.rb', line 23700

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


23705
23706
23707
# File 'lib/google/apis/compute_alpha/classes.rb', line 23705

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::HealthSourceAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



23710
23711
23712
# File 'lib/google/apis/compute_alpha/classes.rb', line 23710

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



23717
23718
23719
23720
23721
23722
23723
23724
23725
# File 'lib/google/apis/compute_alpha/classes.rb', line 23717

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end