Class: Google::Apis::ComputeAlpha::HealthSourcesGetHealthResponseSourceInfoBackendInfo

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HealthSourcesGetHealthResponseSourceInfoBackendInfo

Returns a new instance of HealthSourcesGetHealthResponseSourceInfoBackendInfo.



24012
24013
24014
# File 'lib/google/apis/compute_alpha/classes.rb', line 24012

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#endpoint_countFixnum

Total number of endpoints when determining the health of the regionHealthSource. Corresponds to the JSON property endpointCount

Returns:

  • (Fixnum)


23998
23999
24000
# File 'lib/google/apis/compute_alpha/classes.rb', line 23998

def endpoint_count
  @endpoint_count
end

#groupString

Fully qualified URL of an instance group or network endpoint group behind the source backend service. Corresponds to the JSON property group

Returns:

  • (String)


24004
24005
24006
# File 'lib/google/apis/compute_alpha/classes.rb', line 24004

def group
  @group
end

#healthy_endpoint_countFixnum

Number of endpoints considered healthy when determining health of the regionHealthSource. Corresponds to the JSON property healthyEndpointCount

Returns:

  • (Fixnum)


24010
24011
24012
# File 'lib/google/apis/compute_alpha/classes.rb', line 24010

def healthy_endpoint_count
  @healthy_endpoint_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



24017
24018
24019
24020
24021
# File 'lib/google/apis/compute_alpha/classes.rb', line 24017

def update!(**args)
  @endpoint_count = args[:endpoint_count] if args.key?(:endpoint_count)
  @group = args[:group] if args.key?(:group)
  @healthy_endpoint_count = args[:healthy_endpoint_count] if args.key?(:healthy_endpoint_count)
end