Class: Google::Apis::ComputeAlpha::HealthStatus

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HealthStatus

Returns a new instance of HealthStatus.



24184
24185
24186
# File 'lib/google/apis/compute_alpha/classes.rb', line 24184

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#annotationsHash<String,String>

Metadata defined as annotations for network endpoint. Corresponds to the JSON property annotations

Returns:

  • (Hash<String,String>)


24128
24129
24130
# File 'lib/google/apis/compute_alpha/classes.rb', line 24128

def annotations
  @annotations
end

#forwarding_ruleString

URL of the forwarding rule associated with the health status of the instance. Corresponds to the JSON property forwardingRule

Returns:

  • (String)


24134
24135
24136
# File 'lib/google/apis/compute_alpha/classes.rb', line 24134

def forwarding_rule
  @forwarding_rule
end

#forwarding_rule_ipString

A forwarding rule IP address assigned to this instance. Corresponds to the JSON property forwardingRuleIp

Returns:

  • (String)


24139
24140
24141
# File 'lib/google/apis/compute_alpha/classes.rb', line 24139

def forwarding_rule_ip
  @forwarding_rule_ip
end

#health_stateString

Health state of the IPv4 address of the instance. Corresponds to the JSON property healthState

Returns:

  • (String)


24144
24145
24146
# File 'lib/google/apis/compute_alpha/classes.rb', line 24144

def health_state
  @health_state
end

#instanceString

URL of the instance resource. Corresponds to the JSON property instance

Returns:

  • (String)


24149
24150
24151
# File 'lib/google/apis/compute_alpha/classes.rb', line 24149

def instance
  @instance
end

#ip_addressString

For target pool based Network Load Balancing, it indicates the forwarding rule's IP address assigned to this instance. For other types of load balancing, the field indicates VM internal ip. Corresponds to the JSON property ipAddress

Returns:

  • (String)


24156
24157
24158
# File 'lib/google/apis/compute_alpha/classes.rb', line 24156

def ip_address
  @ip_address
end

#ipv6_addressString

Corresponds to the JSON property ipv6Address

Returns:

  • (String)


24161
24162
24163
# File 'lib/google/apis/compute_alpha/classes.rb', line 24161

def ipv6_address
  @ipv6_address
end

#ipv6_health_stateString

Health state of the IPv6 address of the instance. Corresponds to the JSON property ipv6HealthState

Returns:

  • (String)


24166
24167
24168
# File 'lib/google/apis/compute_alpha/classes.rb', line 24166

def ipv6_health_state
  @ipv6_health_state
end

#portFixnum

The named port of the instance group, not necessarily the port that is health-checked. Corresponds to the JSON property port

Returns:

  • (Fixnum)


24172
24173
24174
# File 'lib/google/apis/compute_alpha/classes.rb', line 24172

def port
  @port
end

#weightString

Corresponds to the JSON property weight

Returns:

  • (String)


24177
24178
24179
# File 'lib/google/apis/compute_alpha/classes.rb', line 24177

def weight
  @weight
end

#weight_errorString

Corresponds to the JSON property weightError

Returns:

  • (String)


24182
24183
24184
# File 'lib/google/apis/compute_alpha/classes.rb', line 24182

def weight_error
  @weight_error
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



24189
24190
24191
24192
24193
24194
24195
24196
24197
24198
24199
24200
24201
# File 'lib/google/apis/compute_alpha/classes.rb', line 24189

def update!(**args)
  @annotations = args[:annotations] if args.key?(:annotations)
  @forwarding_rule = args[:forwarding_rule] if args.key?(:forwarding_rule)
  @forwarding_rule_ip = args[:forwarding_rule_ip] if args.key?(:forwarding_rule_ip)
  @health_state = args[:health_state] if args.key?(:health_state)
  @instance = args[:instance] if args.key?(:instance)
  @ip_address = args[:ip_address] if args.key?(:ip_address)
  @ipv6_address = args[:ipv6_address] if args.key?(:ipv6_address)
  @ipv6_health_state = args[:ipv6_health_state] if args.key?(:ipv6_health_state)
  @port = args[:port] if args.key?(:port)
  @weight = args[:weight] if args.key?(:weight)
  @weight_error = args[:weight_error] if args.key?(:weight_error)
end