Class: Google::Apis::ComputeAlpha::Help

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Provides links to documentation or for performing an out of band action. For example, if a quota check failed with an error indicating the calling project hasn't enabled the accessed service, this can contain a URL pointing directly to the right place in the developer console to flip the bit.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Help

Returns a new instance of Help.



22601
22602
22603
# File 'lib/google/apis/compute_alpha/classes.rb', line 22601

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

URL(s) pointing to additional information on handling the current error. Corresponds to the JSON property links



22599
22600
22601
# File 'lib/google/apis/compute_alpha/classes.rb', line 22599

def links
  @links
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



22606
22607
22608
# File 'lib/google/apis/compute_alpha/classes.rb', line 22606

def update!(**args)
  @links = args[:links] if args.key?(:links)
end