Class: Google::Apis::ComputeAlpha::HostPhysicalTopology

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HostPhysicalTopology

Returns a new instance of HostPhysicalTopology.



24296
24297
24298
# File 'lib/google/apis/compute_alpha/classes.rb', line 24296

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#blockString

The unique identifier of the capacity block within the cluster. Corresponds to the JSON property block

Returns:

  • (String)


24278
24279
24280
# File 'lib/google/apis/compute_alpha/classes.rb', line 24278

def block
  @block
end

#clusterString

The cluster name of the reservation sub-block. Corresponds to the JSON property cluster

Returns:

  • (String)


24283
24284
24285
# File 'lib/google/apis/compute_alpha/classes.rb', line 24283

def cluster
  @cluster
end

#hostString

The unique identifier of the capacity host within the capacity sub-block. Corresponds to the JSON property host

Returns:

  • (String)


24288
24289
24290
# File 'lib/google/apis/compute_alpha/classes.rb', line 24288

def host
  @host
end

#sub_blockString

The unique identifier of the capacity sub-block within the capacity block. Corresponds to the JSON property subBlock

Returns:

  • (String)


24294
24295
24296
# File 'lib/google/apis/compute_alpha/classes.rb', line 24294

def sub_block
  @sub_block
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



24301
24302
24303
24304
24305
24306
# File 'lib/google/apis/compute_alpha/classes.rb', line 24301

def update!(**args)
  @block = args[:block] if args.key?(:block)
  @cluster = args[:cluster] if args.key?(:cluster)
  @host = args[:host] if args.key?(:host)
  @sub_block = args[:sub_block] if args.key?(:sub_block)
end