Class: Google::Apis::ComputeAlpha::HostsListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HostsListResponse

Returns a new instance of HostsListResponse.



24575
24576
24577
# File 'lib/google/apis/compute_alpha/classes.rb', line 24575

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


24532
24533
24534
# File 'lib/google/apis/compute_alpha/classes.rb', line 24532

def etag
  @etag
end

#idString

The unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


24537
24538
24539
# File 'lib/google/apis/compute_alpha/classes.rb', line 24537

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::Host>

A list of host resources. Corresponds to the JSON property items



24542
24543
24544
# File 'lib/google/apis/compute_alpha/classes.rb', line 24542

def items
  @items
end

#kindString

The type of resource. Always compute#host for a list of hosts. Corresponds to the JSON property kind

Returns:

  • (String)


24547
24548
24549
# File 'lib/google/apis/compute_alpha/classes.rb', line 24547

def kind
  @kind
end

#next_page_tokenString

This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


24557
24558
24559
# File 'lib/google/apis/compute_alpha/classes.rb', line 24557

def next_page_token
  @next_page_token
end

The server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


24562
24563
24564
# File 'lib/google/apis/compute_alpha/classes.rb', line 24562

def self_link
  @self_link
end

#unreachablesArray<String>

Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


24568
24569
24570
# File 'lib/google/apis/compute_alpha/classes.rb', line 24568

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::HostsListResponse::Warning

An informational warning message. Corresponds to the JSON property warning



24573
24574
24575
# File 'lib/google/apis/compute_alpha/classes.rb', line 24573

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



24580
24581
24582
24583
24584
24585
24586
24587
24588
24589
# File 'lib/google/apis/compute_alpha/classes.rb', line 24580

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end