Class: Google::Apis::ComputeAlpha::HttpHeaderOption
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::HttpHeaderOption
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Specification determining how headers are added to requests or responses.
Instance Attribute Summary collapse
-
#header_name ⇒ String
The name of the header.
-
#header_value ⇒ String
The value of the header to add.
-
#replace ⇒ Boolean
(also: #replace?)
If false, headerValue is appended to any values that already exist for the header.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HttpHeaderOption
constructor
A new instance of HttpHeaderOption.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HttpHeaderOption
Returns a new instance of HttpHeaderOption.
24966 24967 24968 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24966 def initialize(**args) update!(**args) end |
Instance Attribute Details
#header_name ⇒ String
The name of the header.
Corresponds to the JSON property headerName
24946 24947 24948 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24946 def header_name @header_name end |
#header_value ⇒ String
The value of the header to add.
Corresponds to the JSON property headerValue
24951 24952 24953 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24951 def header_value @header_value end |
#replace ⇒ Boolean Also known as: replace?
If false, headerValue is appended to any values
that already
exist for the header. If true, headerValue is set for the
header, discarding any values that were set for that header.
The default value is true,
unless a variable is present in headerValue,
in which case the default value is false.
.
Corresponds to the JSON property replace
24963 24964 24965 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24963 def replace @replace end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
24971 24972 24973 24974 24975 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24971 def update!(**args) @header_name = args[:header_name] if args.key?(:header_name) @header_value = args[:header_value] if args.key?(:header_value) @replace = args[:replace] if args.key?(:replace) end |