Class: Google::Apis::ComputeAlpha::HttpHealthCheck

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Represents a legacy HTTP Health Check resource. Legacy HTTP health checks are now only required by target pool-based network load balancers. For all other load balancers, including backend service-based network load balancers, and for managed instance group auto-healing, you must use modern (non-legacy) health checks. For more information, seeHealth checks overview.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HttpHealthCheck

Returns a new instance of HttpHealthCheck.



20675
20676
20677
# File 'lib/google/apis/compute_alpha/classes.rb', line 20675

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#check_interval_secFixnum

How often (in seconds) to send a health check. The default value is5 seconds. Corresponds to the JSON property checkIntervalSec

Returns:

  • (Fixnum)


24991
24992
24993
# File 'lib/google/apis/compute_alpha/classes.rb', line 24991

def check_interval_sec
  @check_interval_sec
end

#creation_timestampString

[Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


24997
24998
24999
# File 'lib/google/apis/compute_alpha/classes.rb', line 24997

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


25003
25004
25005
# File 'lib/google/apis/compute_alpha/classes.rb', line 25003

def description
  @description
end

#healthy_thresholdFixnum

A so-far unhealthy instance will be marked healthy after this many consecutive successes. The default value is 2. Corresponds to the JSON property healthyThreshold

Returns:

  • (Fixnum)


25009
25010
25011
# File 'lib/google/apis/compute_alpha/classes.rb', line 25009

def healthy_threshold
  @healthy_threshold
end

#hostString

The value of the host header in the HTTP health check request. If left empty (default value), the public IP on behalf of which this health check is performed will be used. Corresponds to the JSON property host

Returns:

  • (String)


20607
20608
20609
# File 'lib/google/apis/compute_alpha/classes.rb', line 20607

def host
  @host
end

#idFixnum

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


25022
25023
25024
# File 'lib/google/apis/compute_alpha/classes.rb', line 25022

def id
  @id
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute#httpHealthCheck for HTTP health checks. Corresponds to the JSON property kind

Returns:

  • (String)


25028
25029
25030
# File 'lib/google/apis/compute_alpha/classes.rb', line 25028

def kind
  @kind
end

#nameString

Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


25039
25040
25041
# File 'lib/google/apis/compute_alpha/classes.rb', line 25039

def name
  @name
end

#portFixnum

The TCP port number for the HTTP health check request. The default value is80. Corresponds to the JSON property port

Returns:

  • (Fixnum)


20613
20614
20615
# File 'lib/google/apis/compute_alpha/classes.rb', line 20613

def port
  @port
end

#port_nameString

Not supported. Corresponds to the JSON property portName

Returns:

  • (String)


20618
20619
20620
# File 'lib/google/apis/compute_alpha/classes.rb', line 20618

def port_name
  @port_name
end

#port_specificationString

Specifies how a port is selected for health checking. Can be one of the following values: USE_FIXED_PORT: Specifies a port number explicitly using theport field in the health check. Supported by backend services for passthrough load balancers and backend services for proxy load balancers. Also supported in legacy HTTP health checks for target pools. The health check supports all backends supported by the backend service provided the backend can be health checked. For example,GCE_VM_IP network endpoint groups, GCE_VM_IP_PORT network endpoint groups, and instance group backends. USE_NAMED_PORT: Not supported. USE_SERVING_PORT: Provides an indirect method of specifying the health check port by referring to the backend service. Only supported by backend services for proxy load balancers. Not supported by target pools. Not supported by backend services for pass-through load balancers. Supports all backends that can be health checked; for example,GCE_VM_IP_PORT network endpoint groups and instance group backends. For GCE_VM_IP_PORT network endpoint group backends, the health check uses the port number specified for each endpoint in the network endpoint group. For instance group backends, the health check uses the port number determined by looking up the backend service's named port in the instance group's list of named ports. Corresponds to the JSON property portSpecification

Returns:

  • (String)


20645
20646
20647
# File 'lib/google/apis/compute_alpha/classes.rb', line 20645

def port_specification
  @port_specification
end

#proxy_headerString

Specifies the type of proxy header to append before sending data to the backend, either NONE or PROXY_V1. The default is NONE. Corresponds to the JSON property proxyHeader

Returns:

  • (String)


20652
20653
20654
# File 'lib/google/apis/compute_alpha/classes.rb', line 20652

def proxy_header
  @proxy_header
end

#request_pathString

The request path of the HTTP health check request. The default value is/. This field does not support query parameters. Must comply withRFC3986. Corresponds to the JSON property requestPath

Returns:

  • (String)


20658
20659
20660
# File 'lib/google/apis/compute_alpha/classes.rb', line 20658

def request_path
  @request_path
end

#responseString

Creates a content-based HTTP health check. In addition to the required HTTP 200 (OK) status code, you can configure the health check to pass only when the backend sends this specific ASCII response string within the first 1024 bytes of the HTTP response body. For details, see: https://cloud.google.com/load-balancing/docs/health-check-concepts#criteria- protocol-http Corresponds to the JSON property response

Returns:

  • (String)


20668
20669
20670
# File 'lib/google/apis/compute_alpha/classes.rb', line 20668

def response
  @response
end

[Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


25056
25057
25058
# File 'lib/google/apis/compute_alpha/classes.rb', line 25056

def self_link
  @self_link
end

Output only. [Output Only] Server-defined URL for this resource with the resource id. Corresponds to the JSON property selfLinkWithId

Returns:

  • (String)


25062
25063
25064
# File 'lib/google/apis/compute_alpha/classes.rb', line 25062

def self_link_with_id
  @self_link_with_id
end

#timeout_secFixnum

How long (in seconds) to wait before claiming failure. The default value is5 seconds. It is invalid for timeoutSec to have greater value than checkIntervalSec. Corresponds to the JSON property timeoutSec

Returns:

  • (Fixnum)


25069
25070
25071
# File 'lib/google/apis/compute_alpha/classes.rb', line 25069

def timeout_sec
  @timeout_sec
end

#unhealthy_thresholdFixnum

A so-far healthy instance will be marked unhealthy after this many consecutive failures. The default value is 2. Corresponds to the JSON property unhealthyThreshold

Returns:

  • (Fixnum)


25075
25076
25077
# File 'lib/google/apis/compute_alpha/classes.rb', line 25075

def unhealthy_threshold
  @unhealthy_threshold
end

#weight_report_modeString

Weight report mode. used for weighted Load Balancing. Corresponds to the JSON property weightReportMode

Returns:

  • (String)


20673
20674
20675
# File 'lib/google/apis/compute_alpha/classes.rb', line 20673

def weight_report_mode
  @weight_report_mode
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20680
20681
20682
20683
20684
20685
20686
20687
20688
20689
# File 'lib/google/apis/compute_alpha/classes.rb', line 20680

def update!(**args)
  @host = args[:host] if args.key?(:host)
  @port = args[:port] if args.key?(:port)
  @port_name = args[:port_name] if args.key?(:port_name)
  @port_specification = args[:port_specification] if args.key?(:port_specification)
  @proxy_header = args[:proxy_header] if args.key?(:proxy_header)
  @request_path = args[:request_path] if args.key?(:request_path)
  @response = args[:response] if args.key?(:response)
  @weight_report_mode = args[:weight_report_mode] if args.key?(:weight_report_mode)
end