Class: Google::Apis::ComputeAlpha::HttpsHealthCheckList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of HttpsHealthCheck resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HttpsHealthCheckList

Returns a new instance of HttpsHealthCheckList.



25945
25946
25947
# File 'lib/google/apis/compute_alpha/classes.rb', line 25945

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


25913
25914
25915
# File 'lib/google/apis/compute_alpha/classes.rb', line 25913

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::HttpsHealthCheck>

A list of HttpsHealthCheck resources. Corresponds to the JSON property items



25918
25919
25920
# File 'lib/google/apis/compute_alpha/classes.rb', line 25918

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


25923
25924
25925
# File 'lib/google/apis/compute_alpha/classes.rb', line 25923

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


25933
25934
25935
# File 'lib/google/apis/compute_alpha/classes.rb', line 25933

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


25938
25939
25940
# File 'lib/google/apis/compute_alpha/classes.rb', line 25938

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::HttpsHealthCheckList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



25943
25944
25945
# File 'lib/google/apis/compute_alpha/classes.rb', line 25943

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



25950
25951
25952
25953
25954
25955
25956
25957
# File 'lib/google/apis/compute_alpha/classes.rb', line 25950

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end