Class: Google::Apis::ComputeAlpha::Image

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Represents an Image resource. You can use images to create boot disks for your VM instances. For more information, read Images.

Defined Under Namespace

Classes: RawDisk

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Image

Returns a new instance of Image.



26354
26355
26356
# File 'lib/google/apis/compute_alpha/classes.rb', line 26354

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#architectureString

The architecture of the image. Valid values are ARM64 or X86_64. Corresponds to the JSON property architecture

Returns:

  • (String)


26040
26041
26042
# File 'lib/google/apis/compute_alpha/classes.rb', line 26040

def architecture
  @architecture
end

#archive_size_bytesFixnum

Size of the image tar.gz archive stored in Google Cloud Storage (in bytes). Corresponds to the JSON property archiveSizeBytes

Returns:

  • (Fixnum)


26046
26047
26048
# File 'lib/google/apis/compute_alpha/classes.rb', line 26046

def archive_size_bytes
  @archive_size_bytes
end

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


26052
26053
26054
# File 'lib/google/apis/compute_alpha/classes.rb', line 26052

def creation_timestamp
  @creation_timestamp
end

#deprecatedGoogle::Apis::ComputeAlpha::DeprecationStatus

Deprecation status for a public resource. Corresponds to the JSON property deprecated



26057
26058
26059
# File 'lib/google/apis/compute_alpha/classes.rb', line 26057

def deprecated
  @deprecated
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


26063
26064
26065
# File 'lib/google/apis/compute_alpha/classes.rb', line 26063

def description
  @description
end

#disk_size_gbFixnum

Size of the image when restored onto a persistent disk (in GB). Corresponds to the JSON property diskSizeGb

Returns:

  • (Fixnum)


26068
26069
26070
# File 'lib/google/apis/compute_alpha/classes.rb', line 26068

def disk_size_gb
  @disk_size_gb
end

#enable_confidential_computeBoolean Also known as: enable_confidential_compute?

Output only. Whether this image is created from a confidential compute mode disk. [Output Only]: This field is not set by user, but from source disk. Corresponds to the JSON property enableConfidentialCompute

Returns:

  • (Boolean)


26075
26076
26077
# File 'lib/google/apis/compute_alpha/classes.rb', line 26075

def enable_confidential_compute
  @enable_confidential_compute
end

#familyString

The name of the image family to which this image belongs. The image family name can be from a publicly managed image family provided by Compute Engine, or from a custom image family you create. For example,centos- stream-9 is a publicly available image family. For more information, see Image family best practices. When creating disks, you can specify an image family instead of a specific image name. The image family always returns its latest image that is not deprecated. The name of the image family must comply with RFC1035. Corresponds to the JSON property family

Returns:

  • (String)


26089
26090
26091
# File 'lib/google/apis/compute_alpha/classes.rb', line 26089

def family
  @family
end

#guest_os_featuresArray<Google::Apis::ComputeAlpha::GuestOsFeature>

A list of features to enable on the guest operating system. Applicable only for bootable images. To see a list of available options, see theguestOSfeatures[].type parameter. Corresponds to the JSON property guestOsFeatures



26096
26097
26098
# File 'lib/google/apis/compute_alpha/classes.rb', line 26096

def guest_os_features
  @guest_os_features
end

#idFixnum

Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


26103
26104
26105
# File 'lib/google/apis/compute_alpha/classes.rb', line 26103

def id
  @id
end

#image_encryption_keyGoogle::Apis::ComputeAlpha::CustomerEncryptionKey

Encrypts the image using acustomer-supplied encryption key. After you encrypt an image with a customer-supplied key, you must provide the same key if you use the image later (e.g. to create a disk from the image). Customer-supplied encryption keys do not protect access to metadata of the disk. If you do not provide an encryption key when creating the image, then the disk will be encrypted using an automatically generated key and you do not need to provide a key to use the image later. Corresponds to the JSON property imageEncryptionKey



26117
26118
26119
# File 'lib/google/apis/compute_alpha/classes.rb', line 26117

def image_encryption_key
  @image_encryption_key
end

#kindString

Output only. [Output Only] Type of the resource. Always compute#image for images. Corresponds to the JSON property kind

Returns:

  • (String)


26123
26124
26125
# File 'lib/google/apis/compute_alpha/classes.rb', line 26123

def kind
  @kind
end

#label_fingerprintString

A fingerprint for the labels being applied to this image, which is essentially a hash of the labels used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update labels. You must always provide an up-to-date fingerprint hash in order to update or change labels, otherwise the request will fail with error412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve an image. Corresponds to the JSON property labelFingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


26136
26137
26138
# File 'lib/google/apis/compute_alpha/classes.rb', line 26136

def label_fingerprint
  @label_fingerprint
end

#labelsHash<String,String>

Labels to apply to this image. These can be later modified by the setLabels method. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


26142
26143
26144
# File 'lib/google/apis/compute_alpha/classes.rb', line 26142

def labels
  @labels
end

#license_codesArray<Fixnum>

Integer license codes indicating which licenses are attached to this image. Corresponds to the JSON property licenseCodes

Returns:

  • (Array<Fixnum>)


26147
26148
26149
# File 'lib/google/apis/compute_alpha/classes.rb', line 26147

def license_codes
  @license_codes
end

#licensesArray<String>

Any applicable license URI. Corresponds to the JSON property licenses

Returns:

  • (Array<String>)


26152
26153
26154
# File 'lib/google/apis/compute_alpha/classes.rb', line 26152

def licenses
  @licenses
end

#lockedBoolean Also known as: locked?

A flag for marketplace VM disk created from the image, which is designed for marketplace VM disk to prevent the proprietary data on the disk from being accessed unwantedly. The flag will be inherited by the disk created from the image. The disk with locked flag set to true will be prohibited from performing the operations below:

  • R/W or R/O disk attach
  • Disk detach, if disk is created via create-on-create
  • Create images
  • Create snapshots
  • Create disk clone (create disk from the current disk) The image with the locked field set to true will be prohibited from performing the operations below:

  • Create images from the current image

  • Update the locked field for the current image The instance with at least one disk with locked flag set to true will be prohibited from performing the operations below:

  • Secondary disk attach

  • Create instant snapshot

  • Create machine images

  • Create instance template

  • Delete the instance with --keep-disk parameter set to true Corresponds to the JSON property locked

Returns:

  • (Boolean)


26181
26182
26183
# File 'lib/google/apis/compute_alpha/classes.rb', line 26181

def locked
  @locked
end

#nameString

Name of the resource; provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


26193
26194
26195
# File 'lib/google/apis/compute_alpha/classes.rb', line 26193

def name
  @name
end

#paramsGoogle::Apis::ComputeAlpha::ImageParams

Additional image params. Corresponds to the JSON property params



26198
26199
26200
# File 'lib/google/apis/compute_alpha/classes.rb', line 26198

def params
  @params
end

#raw_diskGoogle::Apis::ComputeAlpha::Image::RawDisk

The parameters of the raw disk image. Corresponds to the JSON property rawDisk



26203
26204
26205
# File 'lib/google/apis/compute_alpha/classes.rb', line 26203

def raw_disk
  @raw_disk
end

#rollout_overrideGoogle::Apis::ComputeAlpha::RolloutPolicy

A rollout policy configuration. Corresponds to the JSON property rolloutOverride



26208
26209
26210
# File 'lib/google/apis/compute_alpha/classes.rb', line 26208

def rollout_override
  @rollout_override
end

#satisfies_pziBoolean Also known as: satisfies_pzi?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzi

Returns:

  • (Boolean)


26213
26214
26215
# File 'lib/google/apis/compute_alpha/classes.rb', line 26213

def satisfies_pzi
  @satisfies_pzi
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

Output only. [Output Only] Reserved for future use. Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


26219
26220
26221
# File 'lib/google/apis/compute_alpha/classes.rb', line 26219

def satisfies_pzs
  @satisfies_pzs
end

Output only. [Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


26225
26226
26227
# File 'lib/google/apis/compute_alpha/classes.rb', line 26225

def self_link
  @self_link
end

Output only. [Output Only] Server-defined URL for this resource's resource id. Corresponds to the JSON property selfLinkWithId

Returns:

  • (String)


26230
26231
26232
# File 'lib/google/apis/compute_alpha/classes.rb', line 26230

def self_link_with_id
  @self_link_with_id
end

#shielded_instance_initial_stateGoogle::Apis::ComputeAlpha::InitialStateConfig

Initial State for shielded instance, these are public keys which are safe to store in public Corresponds to the JSON property shieldedInstanceInitialState



26236
26237
26238
# File 'lib/google/apis/compute_alpha/classes.rb', line 26236

def shielded_instance_initial_state
  @shielded_instance_initial_state
end

#source_diskString

URL of the source disk used to create this image. For example, the following are valid values:

  • https://www.googleapis.com/compute/v1/projects/project/zones/zone/disks/ disk
  • projects/project/zones/zone/disks/disk
  • zones/zone/disks/disk In order to create an image, you must provide the full or partial URL of one of the following:

  • The rawDisk.source URL

  • The sourceDisk URL

  • The sourceImage URL

  • The sourceSnapshot URL Corresponds to the JSON property sourceDisk

Returns:

  • (String)


26254
26255
26256
# File 'lib/google/apis/compute_alpha/classes.rb', line 26254

def source_disk
  @source_disk
end

#source_disk_encryption_keyGoogle::Apis::ComputeAlpha::CustomerEncryptionKey

Thecustomer-supplied encryption key of the source disk. Required if the source disk is protected by a customer-supplied encryption key. Corresponds to the JSON property sourceDiskEncryptionKey



26261
26262
26263
# File 'lib/google/apis/compute_alpha/classes.rb', line 26261

def source_disk_encryption_key
  @source_disk_encryption_key
end

#source_disk_idString

Output only. [Output Only] The ID value of the disk used to create this image. This value may be used to determine whether the image was taken from the current or a previous instance of a given disk name. Corresponds to the JSON property sourceDiskId

Returns:

  • (String)


26269
26270
26271
# File 'lib/google/apis/compute_alpha/classes.rb', line 26269

def source_disk_id
  @source_disk_id
end

#source_imageString

URL of the source image used to create this image. The following are valid formats for the URL:

  • https://www.googleapis.com/compute/v1/projects/project_id/global/ images/image_name
  • projects/project_id/global/images/image_name In order to create an image, you must provide the full or partial URL of one of the following:

  • The rawDisk.source URL

  • The sourceDisk URL

  • The sourceImage URL

  • The sourceSnapshot URL Corresponds to the JSON property sourceImage

Returns:

  • (String)


26286
26287
26288
# File 'lib/google/apis/compute_alpha/classes.rb', line 26286

def source_image
  @source_image
end

#source_image_encryption_keyGoogle::Apis::ComputeAlpha::CustomerEncryptionKey

The customer-supplied encryption key of the source image. Required if the source image is protected by a customer-supplied encryption key. Corresponds to the JSON property sourceImageEncryptionKey



26292
26293
26294
# File 'lib/google/apis/compute_alpha/classes.rb', line 26292

def source_image_encryption_key
  @source_image_encryption_key
end

#source_image_idString

Output only. [Output Only] The ID value of the image used to create this image. This value may be used to determine whether the image was taken from the current or a previous instance of a given image name. Corresponds to the JSON property sourceImageId

Returns:

  • (String)


26300
26301
26302
# File 'lib/google/apis/compute_alpha/classes.rb', line 26300

def source_image_id
  @source_image_id
end

#source_snapshotString

URL of the source snapshot used to create this image. The following are valid formats for the URL:

  • https://www.googleapis.com/compute/v1/projects/project_id/global/ snapshots/snapshot_name
  • projects/project_id/global/snapshots/snapshot_name In order to create an image, you must provide the full or partial URL of one of the following:

  • The rawDisk.source URL

  • The sourceDisk URL

  • The sourceImage URL

  • The sourceSnapshot URL Corresponds to the JSON property sourceSnapshot

Returns:

  • (String)


26317
26318
26319
# File 'lib/google/apis/compute_alpha/classes.rb', line 26317

def source_snapshot
  @source_snapshot
end

#source_snapshot_encryption_keyGoogle::Apis::ComputeAlpha::CustomerEncryptionKey

The customer-supplied encryption key of the source snapshot. Required if the source snapshot is protected by a customer-supplied encryption key. Corresponds to the JSON property sourceSnapshotEncryptionKey



26323
26324
26325
# File 'lib/google/apis/compute_alpha/classes.rb', line 26323

def source_snapshot_encryption_key
  @source_snapshot_encryption_key
end

#source_snapshot_idString

Output only. [Output Only] The ID value of the snapshot used to create this image. This value may be used to determine whether the snapshot was taken from the current or a previous instance of a given snapshot name. Corresponds to the JSON property sourceSnapshotId

Returns:

  • (String)


26331
26332
26333
# File 'lib/google/apis/compute_alpha/classes.rb', line 26331

def source_snapshot_id
  @source_snapshot_id
end

#source_typeString

The type of the image used to create this disk. The default and only valid value is RAW. Corresponds to the JSON property sourceType

Returns:

  • (String)


26337
26338
26339
# File 'lib/google/apis/compute_alpha/classes.rb', line 26337

def source_type
  @source_type
end

#statusString

Output only. [Output Only] The status of the image. An image can be used to create other resources, such as instances, only after the image has been successfully created and the status is set to READY. Possible values are FAILED, PENDING, orREADY. Corresponds to the JSON property status

Returns:

  • (String)


26346
26347
26348
# File 'lib/google/apis/compute_alpha/classes.rb', line 26346

def status
  @status
end

#storage_locationsArray<String>

Cloud Storage bucket storage location of the image (regional or multi-regional). Corresponds to the JSON property storageLocations

Returns:

  • (Array<String>)


26352
26353
26354
# File 'lib/google/apis/compute_alpha/classes.rb', line 26352

def storage_locations
  @storage_locations
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



26359
26360
26361
26362
26363
26364
26365
26366
26367
26368
26369
26370
26371
26372
26373
26374
26375
26376
26377
26378
26379
26380
26381
26382
26383
26384
26385
26386
26387
26388
26389
26390
26391
26392
26393
26394
26395
26396
26397
26398
# File 'lib/google/apis/compute_alpha/classes.rb', line 26359

def update!(**args)
  @architecture = args[:architecture] if args.key?(:architecture)
  @archive_size_bytes = args[:archive_size_bytes] if args.key?(:archive_size_bytes)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @deprecated = args[:deprecated] if args.key?(:deprecated)
  @description = args[:description] if args.key?(:description)
  @disk_size_gb = args[:disk_size_gb] if args.key?(:disk_size_gb)
  @enable_confidential_compute = args[:enable_confidential_compute] if args.key?(:enable_confidential_compute)
  @family = args[:family] if args.key?(:family)
  @guest_os_features = args[:guest_os_features] if args.key?(:guest_os_features)
  @id = args[:id] if args.key?(:id)
  @image_encryption_key = args[:image_encryption_key] if args.key?(:image_encryption_key)
  @kind = args[:kind] if args.key?(:kind)
  @label_fingerprint = args[:label_fingerprint] if args.key?(:label_fingerprint)
  @labels = args[:labels] if args.key?(:labels)
  @license_codes = args[:license_codes] if args.key?(:license_codes)
  @licenses = args[:licenses] if args.key?(:licenses)
  @locked = args[:locked] if args.key?(:locked)
  @name = args[:name] if args.key?(:name)
  @params = args[:params] if args.key?(:params)
  @raw_disk = args[:raw_disk] if args.key?(:raw_disk)
  @rollout_override = args[:rollout_override] if args.key?(:rollout_override)
  @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @self_link = args[:self_link] if args.key?(:self_link)
  @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id)
  @shielded_instance_initial_state = args[:shielded_instance_initial_state] if args.key?(:shielded_instance_initial_state)
  @source_disk = args[:source_disk] if args.key?(:source_disk)
  @source_disk_encryption_key = args[:source_disk_encryption_key] if args.key?(:source_disk_encryption_key)
  @source_disk_id = args[:source_disk_id] if args.key?(:source_disk_id)
  @source_image = args[:source_image] if args.key?(:source_image)
  @source_image_encryption_key = args[:source_image_encryption_key] if args.key?(:source_image_encryption_key)
  @source_image_id = args[:source_image_id] if args.key?(:source_image_id)
  @source_snapshot = args[:source_snapshot] if args.key?(:source_snapshot)
  @source_snapshot_encryption_key = args[:source_snapshot_encryption_key] if args.key?(:source_snapshot_encryption_key)
  @source_snapshot_id = args[:source_snapshot_id] if args.key?(:source_snapshot_id)
  @source_type = args[:source_type] if args.key?(:source_type)
  @status = args[:status] if args.key?(:status)
  @storage_locations = args[:storage_locations] if args.key?(:storage_locations)
end