Class: Google::Apis::ComputeAlpha::ImageList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of images.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ImageList

Returns a new instance of ImageList.



26512
26513
26514
# File 'lib/google/apis/compute_alpha/classes.rb', line 26512

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


26480
26481
26482
# File 'lib/google/apis/compute_alpha/classes.rb', line 26480

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::Image>

A list of Image resources. Corresponds to the JSON property items



26485
26486
26487
# File 'lib/google/apis/compute_alpha/classes.rb', line 26485

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


26490
26491
26492
# File 'lib/google/apis/compute_alpha/classes.rb', line 26490

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


26500
26501
26502
# File 'lib/google/apis/compute_alpha/classes.rb', line 26500

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


26505
26506
26507
# File 'lib/google/apis/compute_alpha/classes.rb', line 26505

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::ImageList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



26510
26511
26512
# File 'lib/google/apis/compute_alpha/classes.rb', line 26510

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



26517
26518
26519
26520
26521
26522
26523
26524
# File 'lib/google/apis/compute_alpha/classes.rb', line 26517

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end