Class: Google::Apis::ComputeAlpha::InstanceAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceAggregatedList

Returns a new instance of InstanceAggregatedList.



27368
27369
27370
# File 'lib/google/apis/compute_alpha/classes.rb', line 27368

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


27329
27330
27331
# File 'lib/google/apis/compute_alpha/classes.rb', line 27329

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::InstancesScopedList>

An object that contains a list of instances scoped by zone. Corresponds to the JSON property items



27334
27335
27336
# File 'lib/google/apis/compute_alpha/classes.rb', line 27334

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# instanceAggregatedList for aggregated lists of Instance resources. Corresponds to the JSON property kind

Returns:

  • (String)


27341
27342
27343
# File 'lib/google/apis/compute_alpha/classes.rb', line 27341

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


27351
27352
27353
# File 'lib/google/apis/compute_alpha/classes.rb', line 27351

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


27356
27357
27358
# File 'lib/google/apis/compute_alpha/classes.rb', line 27356

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


27361
27362
27363
# File 'lib/google/apis/compute_alpha/classes.rb', line 27361

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::InstanceAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



27366
27367
27368
# File 'lib/google/apis/compute_alpha/classes.rb', line 27366

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



27373
27374
27375
27376
27377
27378
27379
27380
27381
# File 'lib/google/apis/compute_alpha/classes.rb', line 27373

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end