Class: Google::Apis::ComputeAlpha::InstanceGroupManager

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Represents a Managed Instance Group resource. An instance group is a collection of VM instances that you can manage as a single entity. For more information, readInstance groups. For zonal Managed Instance Group, use the instanceGroupManagers resource. For regional Managed Instance Group, use theregionInstanceGroupManagers resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupManager

Returns a new instance of InstanceGroupManager.



28271
28272
28273
# File 'lib/google/apis/compute_alpha/classes.rb', line 28271

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#all_instances_configGoogle::Apis::ComputeAlpha::InstanceGroupManagerAllInstancesConfig

Specifies configuration that overrides the instance template configuration for the group. Corresponds to the JSON property allInstancesConfig



28007
28008
28009
# File 'lib/google/apis/compute_alpha/classes.rb', line 28007

def all_instances_config
  @all_instances_config
end

#auto_healing_policiesArray<Google::Apis::ComputeAlpha::InstanceGroupManagerAutoHealingPolicy>

The autohealing policy for this managed instance group. You can specify only one value. Corresponds to the JSON property autoHealingPolicies



28013
28014
28015
# File 'lib/google/apis/compute_alpha/classes.rb', line 28013

def auto_healing_policies
  @auto_healing_policies
end

#base_instance_nameString

The base instance name is a prefix that you want to attach to the names of all VMs in a MIG. The maximum character length is 58 and the name must comply with RFC1035 format. When a VM is created in the group, the MIG appends a hyphen and a random four-character string to the base instance name. If you want the MIG to assign sequential numbers instead of a random string, then end the base instance name with a hyphen followed by one or more hash symbols. The hash symbols indicate the number of digits. For example, a base instance name of "vm-###" results in "vm-001" as a VM name. a-z Corresponds to the JSON property baseInstanceName

Returns:

  • (String)


28028
28029
28030
# File 'lib/google/apis/compute_alpha/classes.rb', line 28028

def base_instance_name
  @base_instance_name
end

#creation_timestampString

Output only. The creation timestamp for this managed instance group inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


28034
28035
28036
# File 'lib/google/apis/compute_alpha/classes.rb', line 28034

def creation_timestamp
  @creation_timestamp
end

#current_actionsGoogle::Apis::ComputeAlpha::InstanceGroupManagerActionsSummary

Output only. The list of instance actions and the number of instances in this managed instance group that are scheduled for each of those actions. Corresponds to the JSON property currentActions



28041
28042
28043
# File 'lib/google/apis/compute_alpha/classes.rb', line 28041

def current_actions
  @current_actions
end

#descriptionString

An optional description of this resource. Corresponds to the JSON property description

Returns:

  • (String)


28046
28047
28048
# File 'lib/google/apis/compute_alpha/classes.rb', line 28046

def description
  @description
end

#distribution_policyGoogle::Apis::ComputeAlpha::DistributionPolicy

Policy specifying the intended distribution of managed instances across zones in a regional managed instance group. Corresponds to the JSON property distributionPolicy



28052
28053
28054
# File 'lib/google/apis/compute_alpha/classes.rb', line 28052

def distribution_policy
  @distribution_policy
end

#failover_actionString

The action to perform in case of zone failure. Only one value is supported, NO_FAILOVER. The default is NO_FAILOVER. Corresponds to the JSON property failoverAction

Returns:

  • (String)


28058
28059
28060
# File 'lib/google/apis/compute_alpha/classes.rb', line 28058

def failover_action
  @failover_action
end

#fingerprintString

Fingerprint of this resource. This field may be used in optimistic locking. It will be ignored when inserting an InstanceGroupManager. An up-to-date fingerprint must be provided in order to update the InstanceGroupManager, otherwise the request will fail with error412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve an InstanceGroupManager. Corresponds to the JSON property fingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


28069
28070
28071
# File 'lib/google/apis/compute_alpha/classes.rb', line 28069

def fingerprint
  @fingerprint
end

#idFixnum

Output only. A unique identifier for this resource type. The server generates this identifier. Corresponds to the JSON property id

Returns:

  • (Fixnum)


28075
28076
28077
# File 'lib/google/apis/compute_alpha/classes.rb', line 28075

def id
  @id
end

#instance_flexibility_policyGoogle::Apis::ComputeAlpha::InstanceGroupManagerInstanceFlexibilityPolicy

Instance flexibility allowing MIG to create VMs from multiple types of machines. Instance flexibility configuration on MIG overrides instance template configuration. Corresponds to the JSON property instanceFlexibilityPolicy



28083
28084
28085
# File 'lib/google/apis/compute_alpha/classes.rb', line 28083

def instance_flexibility_policy
  @instance_flexibility_policy
end

#instance_groupString

Output only. The URL of the Instance Group resource. Corresponds to the JSON property instanceGroup

Returns:

  • (String)


28088
28089
28090
# File 'lib/google/apis/compute_alpha/classes.rb', line 28088

def instance_group
  @instance_group
end

#instance_lifecycle_policyGoogle::Apis::ComputeAlpha::InstanceGroupManagerInstanceLifecyclePolicy

The repair policy for this managed instance group. Corresponds to the JSON property instanceLifecyclePolicy



28093
28094
28095
# File 'lib/google/apis/compute_alpha/classes.rb', line 28093

def instance_lifecycle_policy
  @instance_lifecycle_policy
end

#instance_templateString

The URL of the instance template that is specified for this managed instance group. The group uses this template to create all new instances in the managed instance group. The templates for existing instances in the group do not change unless you run recreateInstances, runapplyUpdatesToInstances, or set the group'supdatePolicy.type to PROACTIVE. Corresponds to the JSON property instanceTemplate

Returns:

  • (String)


28102
28103
28104
# File 'lib/google/apis/compute_alpha/classes.rb', line 28102

def instance_template
  @instance_template
end

#kindString

Output only. The resource type, which is alwayscompute#instanceGroupManager for managed instance groups. Corresponds to the JSON property kind

Returns:

  • (String)


28108
28109
28110
# File 'lib/google/apis/compute_alpha/classes.rb', line 28108

def kind
  @kind
end

#list_managed_instances_resultsString

Pagination behavior of the listManagedInstances API method for this managed instance group. Corresponds to the JSON property listManagedInstancesResults

Returns:

  • (String)


28114
28115
28116
# File 'lib/google/apis/compute_alpha/classes.rb', line 28114

def list_managed_instances_results
  @list_managed_instances_results
end

#multi_migString

URL to the multi-MIG that this Managed Instance Group belongs to. Corresponds to the JSON property multiMig

Returns:

  • (String)


28119
28120
28121
# File 'lib/google/apis/compute_alpha/classes.rb', line 28119

def multi_mig
  @multi_mig
end

#nameString

The name of the managed instance group. The name must be 1-63 characters long, and comply withRFC1035. Corresponds to the JSON property name

Returns:

  • (String)


28125
28126
28127
# File 'lib/google/apis/compute_alpha/classes.rb', line 28125

def name
  @name
end

#named_portsArray<Google::Apis::ComputeAlpha::NamedPort>

[Output Only] Named ports configured on the Instance Groups complementary to this Instance Group Manager. Corresponds to the JSON property namedPorts



28131
28132
28133
# File 'lib/google/apis/compute_alpha/classes.rb', line 28131

def named_ports
  @named_ports
end

#paramsGoogle::Apis::ComputeAlpha::InstanceGroupManagerParams

Input only additional params for instance group manager creation. Corresponds to the JSON property params



28136
28137
28138
# File 'lib/google/apis/compute_alpha/classes.rb', line 28136

def params
  @params
end

#regionString

Output only. [Output Only] The URL of theregion where the managed instance group resides (for regional resources). Corresponds to the JSON property region

Returns:

  • (String)


28142
28143
28144
# File 'lib/google/apis/compute_alpha/classes.rb', line 28142

def region
  @region
end

#resource_policiesGoogle::Apis::ComputeAlpha::InstanceGroupManagerResourcePolicies

Resource policies for this managed instance group. Corresponds to the JSON property resourcePolicies



28147
28148
28149
# File 'lib/google/apis/compute_alpha/classes.rb', line 28147

def resource_policies
  @resource_policies
end

#satisfies_pziBoolean Also known as: satisfies_pzi?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzi

Returns:

  • (Boolean)


28152
28153
28154
# File 'lib/google/apis/compute_alpha/classes.rb', line 28152

def satisfies_pzi
  @satisfies_pzi
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


28158
28159
28160
# File 'lib/google/apis/compute_alpha/classes.rb', line 28158

def satisfies_pzs
  @satisfies_pzs
end

Output only. The URL for this managed instance group. The server defines this URL. Corresponds to the JSON property selfLink

Returns:

  • (String)


28165
28166
28167
# File 'lib/google/apis/compute_alpha/classes.rb', line 28165

def self_link
  @self_link
end

Output only. Server-defined URL for this resource with the resource id. Corresponds to the JSON property selfLinkWithId

Returns:

  • (String)


28170
28171
28172
# File 'lib/google/apis/compute_alpha/classes.rb', line 28170

def self_link_with_id
  @self_link_with_id
end

#service_accountString

The service account to be used as credentials for all operations performed by the managed instance group on instances. The service accounts needs all permissions required to create and delete instances. By default, the service account projectNumber@cloudservices.gserviceaccount.com is used. Corresponds to the JSON property serviceAccount

Returns:

  • (String)


28179
28180
28181
# File 'lib/google/apis/compute_alpha/classes.rb', line 28179

def 
  @service_account
end

#standby_policyGoogle::Apis::ComputeAlpha::InstanceGroupManagerStandbyPolicy

Standby policy for stopped and suspended instances. Corresponds to the JSON property standbyPolicy



28184
28185
28186
# File 'lib/google/apis/compute_alpha/classes.rb', line 28184

def standby_policy
  @standby_policy
end

#stateful_policyGoogle::Apis::ComputeAlpha::StatefulPolicy

Stateful configuration for this Instanced Group Manager Corresponds to the JSON property statefulPolicy



28189
28190
28191
# File 'lib/google/apis/compute_alpha/classes.rb', line 28189

def stateful_policy
  @stateful_policy
end

#statusGoogle::Apis::ComputeAlpha::InstanceGroupManagerStatus

Output only. The status of this managed instance group. Corresponds to the JSON property status



28194
28195
28196
# File 'lib/google/apis/compute_alpha/classes.rb', line 28194

def status
  @status
end

#target_poolsArray<String>

The URLs for all TargetPool resources to which instances in theinstanceGroup field are added. The target pools automatically apply to all of the instances in the managed instance group. Corresponds to the JSON property targetPools

Returns:

  • (Array<String>)


28201
28202
28203
# File 'lib/google/apis/compute_alpha/classes.rb', line 28201

def target_pools
  @target_pools
end

#target_sizeFixnum

The target number of running instances for this managed instance group. You can reduce this number by using the instanceGroupManager deleteInstances or abandonInstances methods. Resizing the group also changes this number. Corresponds to the JSON property targetSize

Returns:

  • (Fixnum)


28209
28210
28211
# File 'lib/google/apis/compute_alpha/classes.rb', line 28209

def target_size
  @target_size
end

#target_size_policyGoogle::Apis::ComputeAlpha::InstanceGroupManagerTargetSizePolicy

The policy that specifies how the MIG creates its VMs to achieve the target size. Corresponds to the JSON property targetSizePolicy



28215
28216
28217
# File 'lib/google/apis/compute_alpha/classes.rb', line 28215

def target_size_policy
  @target_size_policy
end

#target_size_unitString

The unit of measure for the target size. Corresponds to the JSON property targetSizeUnit

Returns:

  • (String)


28220
28221
28222
# File 'lib/google/apis/compute_alpha/classes.rb', line 28220

def target_size_unit
  @target_size_unit
end

#target_stopped_sizeFixnum

The target number of stopped instances for this managed instance group. This number changes when you:

  • Stop instance using the stopInstances method or start instances using the startInstances method.
  • Manually change the targetStoppedSize using the update method. Corresponds to the JSON property targetStoppedSize

Returns:

  • (Fixnum)


28232
28233
28234
# File 'lib/google/apis/compute_alpha/classes.rb', line 28232

def target_stopped_size
  @target_stopped_size
end

#target_suspended_sizeFixnum

The target number of suspended instances for this managed instance group. This number changes when you:

  • Suspend instance using the suspendInstances method or resume instances using the resumeInstances method.
  • Manually change the targetSuspendedSize using the update method. Corresponds to the JSON property targetSuspendedSize

Returns:

  • (Fixnum)


28244
28245
28246
# File 'lib/google/apis/compute_alpha/classes.rb', line 28244

def target_suspended_size
  @target_suspended_size
end

#update_policyGoogle::Apis::ComputeAlpha::InstanceGroupManagerUpdatePolicy

The update policy for this managed instance group. Corresponds to the JSON property updatePolicy



28249
28250
28251
# File 'lib/google/apis/compute_alpha/classes.rb', line 28249

def update_policy
  @update_policy
end

#versionsArray<Google::Apis::ComputeAlpha::InstanceGroupManagerVersion>

Specifies the instance templates used by this managed instance group to create instances. Each version is defined by an instanceTemplate and aname. Every version can appear at most once per instance group. This field overrides the top-level instanceTemplate field. Read more about therelationships between these fields. Exactly one version must leave thetargetSize field unset. That version will be applied to all remaining instances. For more information, read aboutcanary updates. Corresponds to the JSON property versions



28263
28264
28265
# File 'lib/google/apis/compute_alpha/classes.rb', line 28263

def versions
  @versions
end

#zoneString

Output only. The URL of azone where the managed instance group is located (for zonal resources). Corresponds to the JSON property zone

Returns:

  • (String)


28269
28270
28271
# File 'lib/google/apis/compute_alpha/classes.rb', line 28269

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



28276
28277
28278
28279
28280
28281
28282
28283
28284
28285
28286
28287
28288
28289
28290
28291
28292
28293
28294
28295
28296
28297
28298
28299
28300
28301
28302
28303
28304
28305
28306
28307
28308
28309
28310
28311
28312
28313
28314
28315
28316
# File 'lib/google/apis/compute_alpha/classes.rb', line 28276

def update!(**args)
  @all_instances_config = args[:all_instances_config] if args.key?(:all_instances_config)
  @auto_healing_policies = args[:auto_healing_policies] if args.key?(:auto_healing_policies)
  @base_instance_name = args[:base_instance_name] if args.key?(:base_instance_name)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @current_actions = args[:current_actions] if args.key?(:current_actions)
  @description = args[:description] if args.key?(:description)
  @distribution_policy = args[:distribution_policy] if args.key?(:distribution_policy)
  @failover_action = args[:failover_action] if args.key?(:failover_action)
  @fingerprint = args[:fingerprint] if args.key?(:fingerprint)
  @id = args[:id] if args.key?(:id)
  @instance_flexibility_policy = args[:instance_flexibility_policy] if args.key?(:instance_flexibility_policy)
  @instance_group = args[:instance_group] if args.key?(:instance_group)
  @instance_lifecycle_policy = args[:instance_lifecycle_policy] if args.key?(:instance_lifecycle_policy)
  @instance_template = args[:instance_template] if args.key?(:instance_template)
  @kind = args[:kind] if args.key?(:kind)
  @list_managed_instances_results = args[:list_managed_instances_results] if args.key?(:list_managed_instances_results)
  @multi_mig = args[:multi_mig] if args.key?(:multi_mig)
  @name = args[:name] if args.key?(:name)
  @named_ports = args[:named_ports] if args.key?(:named_ports)
  @params = args[:params] if args.key?(:params)
  @region = args[:region] if args.key?(:region)
  @resource_policies = args[:resource_policies] if args.key?(:resource_policies)
  @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @self_link = args[:self_link] if args.key?(:self_link)
  @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id)
  @service_account = args[:service_account] if args.key?(:service_account)
  @standby_policy = args[:standby_policy] if args.key?(:standby_policy)
  @stateful_policy = args[:stateful_policy] if args.key?(:stateful_policy)
  @status = args[:status] if args.key?(:status)
  @target_pools = args[:target_pools] if args.key?(:target_pools)
  @target_size = args[:target_size] if args.key?(:target_size)
  @target_size_policy = args[:target_size_policy] if args.key?(:target_size_policy)
  @target_size_unit = args[:target_size_unit] if args.key?(:target_size_unit)
  @target_stopped_size = args[:target_stopped_size] if args.key?(:target_stopped_size)
  @target_suspended_size = args[:target_suspended_size] if args.key?(:target_suspended_size)
  @update_policy = args[:update_policy] if args.key?(:update_policy)
  @versions = args[:versions] if args.key?(:versions)
  @zone = args[:zone] if args.key?(:zone)
end