Class: Google::Apis::ComputeAlpha::InstanceGroupManagerAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupManagerAggregatedList

Returns a new instance of InstanceGroupManagerAggregatedList.



28512
28513
28514
# File 'lib/google/apis/compute_alpha/classes.rb', line 28512

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Output only. Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


28473
28474
28475
# File 'lib/google/apis/compute_alpha/classes.rb', line 28473

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::InstanceGroupManagersScopedList>

A list of InstanceGroupManagersScopedList resources. Corresponds to the JSON property items



28478
28479
28480
# File 'lib/google/apis/compute_alpha/classes.rb', line 28478

def items
  @items
end

#kindString

Output only. The resource type, which is alwayscompute# instanceGroupManagerAggregatedList for an aggregated list of managed instance groups. Corresponds to the JSON property kind

Returns:

  • (String)


28485
28486
28487
# File 'lib/google/apis/compute_alpha/classes.rb', line 28485

def kind
  @kind
end

#next_page_tokenString

Output only. This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


28495
28496
28497
# File 'lib/google/apis/compute_alpha/classes.rb', line 28495

def next_page_token
  @next_page_token
end

Output only. Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


28500
28501
28502
# File 'lib/google/apis/compute_alpha/classes.rb', line 28500

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


28505
28506
28507
# File 'lib/google/apis/compute_alpha/classes.rb', line 28505

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::InstanceGroupManagerAggregatedList::Warning

Output only. Informational warning message. Corresponds to the JSON property warning



28510
28511
28512
# File 'lib/google/apis/compute_alpha/classes.rb', line 28510

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



28517
28518
28519
28520
28521
28522
28523
28524
28525
# File 'lib/google/apis/compute_alpha/classes.rb', line 28517

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end