Class: Google::Apis::ComputeAlpha::InstanceGroupManagerAutoHealingPolicy
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::InstanceGroupManagerAutoHealingPolicy
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#auto_healing_triggers ⇒ Google::Apis::ComputeAlpha::InstanceGroupManagerAutoHealingPolicyAutoHealingTriggers
Restricts what triggers autohealing.
-
#health_check ⇒ String
The URL for the health check that signals autohealing.
-
#initial_delay_sec ⇒ Fixnum
The initial delay is the number of seconds that a new VM takes to initialize and run its startup script.
-
#max_unavailable ⇒ Google::Apis::ComputeAlpha::FixedOrPercent
Encapsulates numeric value that can be either absolute or relative.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceGroupManagerAutoHealingPolicy
constructor
A new instance of InstanceGroupManagerAutoHealingPolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceGroupManagerAutoHealingPolicy
Returns a new instance of InstanceGroupManagerAutoHealingPolicy.
27162 27163 27164 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27162 def initialize(**args) update!(**args) end |
Instance Attribute Details
#auto_healing_triggers ⇒ Google::Apis::ComputeAlpha::InstanceGroupManagerAutoHealingPolicyAutoHealingTriggers
Restricts what triggers autohealing.
Corresponds to the JSON property autoHealingTriggers
27138 27139 27140 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27138 def auto_healing_triggers @auto_healing_triggers end |
#health_check ⇒ String
The URL for the health check that signals autohealing.
Corresponds to the JSON property healthCheck
27143 27144 27145 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27143 def health_check @health_check end |
#initial_delay_sec ⇒ Fixnum
The initial delay is the number of seconds that a new VM takes to
initialize and run its startup script. During a VM's initial delay
period, the MIG ignores unsuccessful health checks because the VM might
be in the startup process. This prevents the MIG from prematurely
recreating a VM. If the health check receives a healthy response during
the initial delay, it indicates that the startup process is complete and
the VM is ready. The value of initial delay must be between 0 and 3600
seconds. The default value is 0.
Corresponds to the JSON property initialDelaySec
27155 27156 27157 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27155 def initial_delay_sec @initial_delay_sec end |
#max_unavailable ⇒ Google::Apis::ComputeAlpha::FixedOrPercent
Encapsulates numeric value that can be either absolute or relative.
Corresponds to the JSON property maxUnavailable
27160 27161 27162 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27160 def max_unavailable @max_unavailable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
27167 27168 27169 27170 27171 27172 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27167 def update!(**args) @auto_healing_triggers = args[:auto_healing_triggers] if args.key?(:auto_healing_triggers) @health_check = args[:health_check] if args.key?(:health_check) @initial_delay_sec = args[:initial_delay_sec] if args.key?(:initial_delay_sec) @max_unavailable = args[:max_unavailable] if args.key?(:max_unavailable) end |