Class: Google::Apis::ComputeAlpha::InstanceGroupManagerParams

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Input only additional params for instance group manager creation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupManagerParams

Returns a new instance of InstanceGroupManagerParams.



28929
28930
28931
# File 'lib/google/apis/compute_alpha/classes.rb', line 28929

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#resource_manager_tagsHash<String,String>

Input only. Resource manager tags to bind to the managed instance group. The tags are key-value pairs. Keys and values can be either in numeric format, such as tagKeys/tag_key_idand `tagValues/456` or in namespaced format such asorg_id|project_id/tag_key_short_nameand tag_value_short_name`. For more information, seeManage tags for resources. Corresponds to the JSON propertyresourceManagerTags`

Returns:

  • (Hash<String,String>)


28927
28928
28929
# File 'lib/google/apis/compute_alpha/classes.rb', line 28927

def resource_manager_tags
  @resource_manager_tags
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



28934
28935
28936
# File 'lib/google/apis/compute_alpha/classes.rb', line 28934

def update!(**args)
  @resource_manager_tags = args[:resource_manager_tags] if args.key?(:resource_manager_tags)
end