Class: Google::Apis::ComputeAlpha::InstanceGroupManagerResizeRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

InstanceGroupManagerResizeRequest represents a request to create a number of VMs: either immediately or by queuing the request for the specified time. This resize request is nested under InstanceGroupManager and the VMs created by this request are added to the owning InstanceGroupManager.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupManagerResizeRequest

Returns a new instance of InstanceGroupManagerResizeRequest.



29180
29181
29182
# File 'lib/google/apis/compute_alpha/classes.rb', line 29180

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#countFixnum

This field is deprecated, please use resize_by instead. The count of instances to create as part of this resize request. Corresponds to the JSON property count

Returns:

  • (Fixnum)


29086
29087
29088
# File 'lib/google/apis/compute_alpha/classes.rb', line 29086

def count
  @count
end

#creation_timestampString

Output only. The creation timestamp for this resize request inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


29092
29093
29094
# File 'lib/google/apis/compute_alpha/classes.rb', line 29092

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Corresponds to the JSON property description

Returns:

  • (String)


29097
29098
29099
# File 'lib/google/apis/compute_alpha/classes.rb', line 29097

def description
  @description
end

#idFixnum

Output only. A unique identifier for this resource type. The server generates this identifier. Corresponds to the JSON property id

Returns:

  • (Fixnum)


29104
29105
29106
# File 'lib/google/apis/compute_alpha/classes.rb', line 29104

def id
  @id
end

#instancesArray<Google::Apis::ComputeAlpha::PerInstanceConfig>

The names of instances to be created by this resize request. The number of names specified determines the number of instances to create. The group's target size will be increased by this number. This field cannot be used together with 'resize_by'. Corresponds to the JSON property instances



29112
29113
29114
# File 'lib/google/apis/compute_alpha/classes.rb', line 29112

def instances
  @instances
end

#kindString

Output only. The resource type, which is alwayscompute# instanceGroupManagerResizeRequest for resize requests. Corresponds to the JSON property kind

Returns:

  • (String)


29118
29119
29120
# File 'lib/google/apis/compute_alpha/classes.rb', line 29118

def kind
  @kind
end

#nameString

The name of this resize request. The name must be 1-63 characters long, and comply withRFC1035. Corresponds to the JSON property name

Returns:

  • (String)


29124
29125
29126
# File 'lib/google/apis/compute_alpha/classes.rb', line 29124

def name
  @name
end

#queuing_policyGoogle::Apis::ComputeAlpha::QueuingPolicy

Queuing parameters for the requested deferred capacity. Corresponds to the JSON property queuingPolicy



29129
29130
29131
# File 'lib/google/apis/compute_alpha/classes.rb', line 29129

def queuing_policy
  @queuing_policy
end

#regionString

Output only. The URL of a region where the resize request is located. Populated only for regional resize requests. Corresponds to the JSON property region

Returns:

  • (String)


29136
29137
29138
# File 'lib/google/apis/compute_alpha/classes.rb', line 29136

def region
  @region
end

#requested_run_durationGoogle::Apis::ComputeAlpha::Duration

A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution. It is independent of any calendar and concepts like "day" or "month". Range is approximately 10,000 years. Corresponds to the JSON property requestedRunDuration



29144
29145
29146
# File 'lib/google/apis/compute_alpha/classes.rb', line 29144

def requested_run_duration
  @requested_run_duration
end

#resize_byFixnum

The number of instances to be created by this resize request. The group's target size will be increased by this number. This field cannot be used together with 'instances'. Corresponds to the JSON property resizeBy

Returns:

  • (Fixnum)


29151
29152
29153
# File 'lib/google/apis/compute_alpha/classes.rb', line 29151

def resize_by
  @resize_by
end

Output only. The URL for this resize request. The server defines this URL. Corresponds to the JSON property selfLink

Returns:

  • (String)


29156
29157
29158
# File 'lib/google/apis/compute_alpha/classes.rb', line 29156

def self_link
  @self_link
end

Output only. Server-defined URL for this resource with the resource id. Corresponds to the JSON property selfLinkWithId

Returns:

  • (String)


29161
29162
29163
# File 'lib/google/apis/compute_alpha/classes.rb', line 29161

def self_link_with_id
  @self_link_with_id
end

#stateString

Output only. Current state of the request. Corresponds to the JSON property state

Returns:

  • (String)


29166
29167
29168
# File 'lib/google/apis/compute_alpha/classes.rb', line 29166

def state
  @state
end

#statusGoogle::Apis::ComputeAlpha::InstanceGroupManagerResizeRequestStatus

Output only. Status of the request. Corresponds to the JSON property status



29171
29172
29173
# File 'lib/google/apis/compute_alpha/classes.rb', line 29171

def status
  @status
end

#zoneString

Output only. The URL of a zone where the resize request is located. Populated only for zonal resize requests. Corresponds to the JSON property zone

Returns:

  • (String)


29178
29179
29180
# File 'lib/google/apis/compute_alpha/classes.rb', line 29178

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



29185
29186
29187
29188
29189
29190
29191
29192
29193
29194
29195
29196
29197
29198
29199
29200
29201
29202
# File 'lib/google/apis/compute_alpha/classes.rb', line 29185

def update!(**args)
  @count = args[:count] if args.key?(:count)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @id = args[:id] if args.key?(:id)
  @instances = args[:instances] if args.key?(:instances)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @queuing_policy = args[:queuing_policy] if args.key?(:queuing_policy)
  @region = args[:region] if args.key?(:region)
  @requested_run_duration = args[:requested_run_duration] if args.key?(:requested_run_duration)
  @resize_by = args[:resize_by] if args.key?(:resize_by)
  @self_link = args[:self_link] if args.key?(:self_link)
  @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id)
  @state = args[:state] if args.key?(:state)
  @status = args[:status] if args.key?(:status)
  @zone = args[:zone] if args.key?(:zone)
end