Class: Google::Apis::ComputeAlpha::InstanceGroupManagerResizeRequestStatus::Error
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::InstanceGroupManagerResizeRequestStatus::Error
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Output only. Fatal errors encountered during the queueing or provisioning phases of the ResizeRequest that caused the transition to the FAILED state. Contrary to the last_attempt errors, this field is final and errors are never removed from here, as the ResizeRequest is not going to retry.
Defined Under Namespace
Classes: Error
Instance Attribute Summary collapse
-
#errors ⇒ Array<Google::Apis::ComputeAlpha::InstanceGroupManagerResizeRequestStatus::Error::Error>
[Output Only] The array of errors encountered while processing this operation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Error
constructor
A new instance of Error.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Error
Returns a new instance of Error.
28854 28855 28856 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 28854 def initialize(**args) update!(**args) end |
Instance Attribute Details
#errors ⇒ Array<Google::Apis::ComputeAlpha::InstanceGroupManagerResizeRequestStatus::Error::Error>
[Output Only] The array of errors encountered while processing this
operation.
Corresponds to the JSON property errors
28852 28853 28854 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 28852 def errors @errors end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
28859 28860 28861 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 28859 def update!(**args) @errors = args[:errors] if args.key?(:errors) end |