Class: Google::Apis::ComputeAlpha::InstanceGroupManagerResizeRequestStatusLastAttempt::Error::Error
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::InstanceGroupManagerResizeRequestStatusLastAttempt::Error::Error
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Represents a single error encountered during the processing of an operation.
Defined Under Namespace
Classes: ErrorDetail
Instance Attribute Summary collapse
-
#code ⇒ String
[Output Only] The error type identifier for this error.
-
#error_details ⇒ Array<Google::Apis::ComputeAlpha::InstanceGroupManagerResizeRequestStatusLastAttempt::Error::Error::ErrorDetail>
[Output Only] An optional list of messages that contain the error details.
-
#location ⇒ String
[Output Only] Indicates the field in the request that caused the error.
-
#message ⇒ String
[Output Only] An optional, human-readable error message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Error
constructor
A new instance of Error.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Error
Returns a new instance of Error.
29035 29036 29037 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 29035 def initialize(**args) update!(**args) end |
Instance Attribute Details
#code ⇒ String
[Output Only] The error type identifier for this error.
Corresponds to the JSON property code
29013 29014 29015 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 29013 def code @code end |
#error_details ⇒ Array<Google::Apis::ComputeAlpha::InstanceGroupManagerResizeRequestStatusLastAttempt::Error::Error::ErrorDetail>
[Output Only] An optional list of messages that contain the error
details. There is a set of defined message types to use for providing
details.The syntax depends on the error code. For example,
QuotaExceededInfo will have details when the error code is
QUOTA_EXCEEDED.
Corresponds to the JSON property errorDetails
29022 29023 29024 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 29022 def error_details @error_details end |
#location ⇒ String
[Output Only] Indicates the field in the request that caused the error.
This property is optional.
Corresponds to the JSON property location
29028 29029 29030 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 29028 def location @location end |
#message ⇒ String
[Output Only] An optional, human-readable error message.
Corresponds to the JSON property message
29033 29034 29035 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 29033 def @message end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
29040 29041 29042 29043 29044 29045 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 29040 def update!(**args) @code = args[:code] if args.key?(:code) @error_details = args[:error_details] if args.key?(:error_details) @location = args[:location] if args.key?(:location) @message = args[:message] if args.key?(:message) end |