Class: Google::Apis::ComputeAlpha::InstanceGroupManagerResizeRequestsListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

[Output Only] A list of resize requests.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupManagerResizeRequestsListResponse

Returns a new instance of InstanceGroupManagerResizeRequestsListResponse.



29558
29559
29560
# File 'lib/google/apis/compute_alpha/classes.rb', line 29558

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Output only. Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


29524
29525
29526
# File 'lib/google/apis/compute_alpha/classes.rb', line 29524

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::InstanceGroupManagerResizeRequest>

A list of resize request resources. Corresponds to the JSON property items



29529
29530
29531
# File 'lib/google/apis/compute_alpha/classes.rb', line 29529

def items
  @items
end

#kindString

Output only. Type of the resource. Alwayscompute# instanceGroupManagerResizeRequestList for a list of resize requests. Corresponds to the JSON property kind

Returns:

  • (String)


29536
29537
29538
# File 'lib/google/apis/compute_alpha/classes.rb', line 29536

def kind
  @kind
end

#next_page_tokenString

Output only. This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use thenextPageToken as a value for the query parameterpageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


29546
29547
29548
# File 'lib/google/apis/compute_alpha/classes.rb', line 29546

def next_page_token
  @next_page_token
end

Output only. Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


29551
29552
29553
# File 'lib/google/apis/compute_alpha/classes.rb', line 29551

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::InstanceGroupManagerResizeRequestsListResponse::Warning

Output only. Informational warning message. Corresponds to the JSON property warning



29556
29557
29558
# File 'lib/google/apis/compute_alpha/classes.rb', line 29556

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



29563
29564
29565
29566
29567
29568
29569
29570
# File 'lib/google/apis/compute_alpha/classes.rb', line 29563

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end