Class: Google::Apis::ComputeAlpha::InstanceGroupManagerStatusAcceleratorTopologyAcceleratorTopologyStateDetails::Error::Error

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: ErrorDetail

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Error

Returns a new instance of Error.



27717
27718
27719
# File 'lib/google/apis/compute_alpha/classes.rb', line 27717

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#codeString

[Output Only] The error type identifier for this error. Corresponds to the JSON property code

Returns:

  • (String)


27695
27696
27697
# File 'lib/google/apis/compute_alpha/classes.rb', line 27695

def code
  @code
end

#error_detailsArray<Google::Apis::ComputeAlpha::InstanceGroupManagerStatusAcceleratorTopologyAcceleratorTopologyStateDetails::Error::Error::ErrorDetail>

[Output Only] An optional list of messages that contain the error details. There is a set of defined message types to use for providing details.The syntax depends on the error code. For example, QuotaExceededInfo will have details when the error code is QUOTA_EXCEEDED. Corresponds to the JSON property errorDetails



27704
27705
27706
# File 'lib/google/apis/compute_alpha/classes.rb', line 27704

def error_details
  @error_details
end

#locationString

[Output Only] Indicates the field in the request that caused the error. This property is optional. Corresponds to the JSON property location

Returns:

  • (String)


27710
27711
27712
# File 'lib/google/apis/compute_alpha/classes.rb', line 27710

def location
  @location
end

#messageString

[Output Only] An optional, human-readable error message. Corresponds to the JSON property message

Returns:

  • (String)


27715
27716
27717
# File 'lib/google/apis/compute_alpha/classes.rb', line 27715

def message
  @message
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



27722
27723
27724
27725
27726
27727
# File 'lib/google/apis/compute_alpha/classes.rb', line 27722

def update!(**args)
  @code = args[:code] if args.key?(:code)
  @error_details = args[:error_details] if args.key?(:error_details)
  @location = args[:location] if args.key?(:location)
  @message = args[:message] if args.key?(:message)
end