Class: Google::Apis::ComputeAlpha::InstanceGroupManagerStatusBulkInstanceOperationLastProgressCheck::Error::Error
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::InstanceGroupManagerStatusBulkInstanceOperationLastProgressCheck::Error::Error
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: ErrorDetail
Instance Attribute Summary collapse
-
#code ⇒ String
[Output Only] The error type identifier for this error.
-
#error_details ⇒ Array<Google::Apis::ComputeAlpha::InstanceGroupManagerStatusBulkInstanceOperationLastProgressCheck::Error::Error::ErrorDetail>
[Output Only] An optional list of messages that contain the error details.
-
#location ⇒ String
[Output Only] Indicates the field in the request that caused the error.
-
#message ⇒ String
[Output Only] An optional, human-readable error message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Error
constructor
A new instance of Error.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Error
Returns a new instance of Error.
28940 28941 28942 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 28940 def initialize(**args) update!(**args) end |
Instance Attribute Details
#code ⇒ String
[Output Only] The error type identifier for this error.
Corresponds to the JSON property code
28918 28919 28920 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 28918 def code @code end |
#error_details ⇒ Array<Google::Apis::ComputeAlpha::InstanceGroupManagerStatusBulkInstanceOperationLastProgressCheck::Error::Error::ErrorDetail>
[Output Only] An optional list of messages that contain the error
details. There is a set of defined message types to use for providing
details.The syntax depends on the error code. For example,
QuotaExceededInfo will have details when the error code is
QUOTA_EXCEEDED.
Corresponds to the JSON property errorDetails
28927 28928 28929 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 28927 def error_details @error_details end |
#location ⇒ String
[Output Only] Indicates the field in the request that caused the error.
This property is optional.
Corresponds to the JSON property location
28933 28934 28935 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 28933 def location @location end |
#message ⇒ String
[Output Only] An optional, human-readable error message.
Corresponds to the JSON property message
28938 28939 28940 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 28938 def @message end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
28945 28946 28947 28948 28949 28950 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 28945 def update!(**args) @code = args[:code] if args.key?(:code) @error_details = args[:error_details] if args.key?(:error_details) @location = args[:location] if args.key?(:location) @message = args[:message] if args.key?(:message) end |