Class: Google::Apis::ComputeAlpha::InstanceGroupManagerStatusStateful

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupManagerStatusStateful

Returns a new instance of InstanceGroupManagerStatusStateful.



28818
28819
28820
# File 'lib/google/apis/compute_alpha/classes.rb', line 28818

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#has_stateful_configBoolean Also known as: has_stateful_config?

Output only. A bit indicating whether the managed instance group has stateful configuration, that is, if you have configured any items in a stateful policy or in per-instance configs. The group might report that it has no stateful configuration even when there is still some preserved state on a managed instance, for example, if you have deleted all PICs but not yet applied those deletions. Corresponds to the JSON property hasStatefulConfig

Returns:

  • (Boolean)


28798
28799
28800
# File 'lib/google/apis/compute_alpha/classes.rb', line 28798

def has_stateful_config
  @has_stateful_config
end

#is_statefulBoolean Also known as: is_stateful?

Output only. A bit indicating whether the managed instance group has stateful configuration, that is, if you have configured any items in a stateful policy or in per-instance configs. The group might report that it has no stateful configuration even when there is still some preserved state on a managed instance, for example, if you have deleted all PICs but not yet applied those deletions. This field is deprecated in favor of has_stateful_config. Corresponds to the JSON property isStateful

Returns:

  • (Boolean)


28810
28811
28812
# File 'lib/google/apis/compute_alpha/classes.rb', line 28810

def is_stateful
  @is_stateful
end

#per_instance_configsGoogle::Apis::ComputeAlpha::InstanceGroupManagerStatusStatefulPerInstanceConfigs

Output only. Status of per-instance configurations on the instances. Corresponds to the JSON property perInstanceConfigs



28816
28817
28818
# File 'lib/google/apis/compute_alpha/classes.rb', line 28816

def per_instance_configs
  @per_instance_configs
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



28823
28824
28825
28826
28827
# File 'lib/google/apis/compute_alpha/classes.rb', line 28823

def update!(**args)
  @has_stateful_config = args[:has_stateful_config] if args.key?(:has_stateful_config)
  @is_stateful = args[:is_stateful] if args.key?(:is_stateful)
  @per_instance_configs = args[:per_instance_configs] if args.key?(:per_instance_configs)
end