Class: Google::Apis::ComputeAlpha::InstanceGroupManagerStatusVersionTarget

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupManagerStatusVersionTarget

Returns a new instance of InstanceGroupManagerStatusVersionTarget.



30222
30223
30224
# File 'lib/google/apis/compute_alpha/classes.rb', line 30222

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#is_reachedBoolean Also known as: is_reached?

Output only. A bit indicating whether version target has been reached in this managed instance group, i.e. all instances are in their target version. Instances' target version are specified byversion field on Instance Group Manager. Corresponds to the JSON property isReached

Returns:

  • (Boolean)


30219
30220
30221
# File 'lib/google/apis/compute_alpha/classes.rb', line 30219

def is_reached
  @is_reached
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



30227
30228
30229
# File 'lib/google/apis/compute_alpha/classes.rb', line 30227

def update!(**args)
  @is_reached = args[:is_reached] if args.key?(:is_reached)
end