Class: Google::Apis::ComputeAlpha::InstanceGroupManagerTargetSizePolicy
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::InstanceGroupManagerTargetSizePolicy
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#mode ⇒ String
The mode of target size policy based on which the MIG creates its VMs individually or all at once.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceGroupManagerTargetSizePolicy
constructor
A new instance of InstanceGroupManagerTargetSizePolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceGroupManagerTargetSizePolicy
Returns a new instance of InstanceGroupManagerTargetSizePolicy.
29024 29025 29026 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 29024 def initialize(**args) update!(**args) end |
Instance Attribute Details
#mode ⇒ String
The mode of target size policy based on which the MIG creates its VMs
individually or all at once.
Corresponds to the JSON property mode
29022 29023 29024 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 29022 def mode @mode end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
29029 29030 29031 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 29029 def update!(**args) @mode = args[:mode] if args.key?(:mode) end |