Class: Google::Apis::ComputeAlpha::InstanceGroupManagersGetAvailableAcceleratorTopologiesResponse
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::InstanceGroupManagersGetAvailableAcceleratorTopologiesResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#accelerator_topologies_info ⇒ Hash<String,Google::Apis::ComputeAlpha::InstanceGroupManagersGetAvailableAcceleratorTopologiesResponseAcceleratorTopologyInfo>
The accelerator topology information returned per id of the topology location.
-
#multi_mig ⇒ String
URL to MMIG this MIG belongs to.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceGroupManagersGetAvailableAcceleratorTopologiesResponse
constructor
A new instance of InstanceGroupManagersGetAvailableAcceleratorTopologiesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceGroupManagersGetAvailableAcceleratorTopologiesResponse
Returns a new instance of InstanceGroupManagersGetAvailableAcceleratorTopologiesResponse.
29428 29429 29430 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 29428 def initialize(**args) update!(**args) end |
Instance Attribute Details
#accelerator_topologies_info ⇒ Hash<String,Google::Apis::ComputeAlpha::InstanceGroupManagersGetAvailableAcceleratorTopologiesResponseAcceleratorTopologyInfo>
The accelerator topology information returned per id of the topology
location.
Corresponds to the JSON property acceleratorTopologiesInfo
29421 29422 29423 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 29421 def accelerator_topologies_info @accelerator_topologies_info end |
#multi_mig ⇒ String
URL to MMIG this MIG belongs to.
Corresponds to the JSON property multiMig
29426 29427 29428 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 29426 def multi_mig @multi_mig end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
29433 29434 29435 29436 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 29433 def update!(**args) @accelerator_topologies_info = args[:accelerator_topologies_info] if args.key?(:accelerator_topologies_info) @multi_mig = args[:multi_mig] if args.key?(:multi_mig) end |