Class: Google::Apis::ComputeAlpha::InstanceGroupManagersGetAvailableAcceleratorTopologiesResponseAcceleratorTopologyState

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Specifies the topology state

Defined Under Namespace

Classes: Error

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupManagersGetAvailableAcceleratorTopologiesResponseAcceleratorTopologyState

Returns a new instance of InstanceGroupManagersGetAvailableAcceleratorTopologiesResponseAcceleratorTopologyState.



29521
29522
29523
# File 'lib/google/apis/compute_alpha/classes.rb', line 29521

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#current_stateString

Corresponds to the JSON property currentState

Returns:

  • (String)


29500
29501
29502
# File 'lib/google/apis/compute_alpha/classes.rb', line 29500

def current_state
  @current_state
end

#errorGoogle::Apis::ComputeAlpha::InstanceGroupManagersGetAvailableAcceleratorTopologiesResponseAcceleratorTopologyState::Error

Reason why the topology state change failed Corresponds to the JSON property error



29505
29506
29507
# File 'lib/google/apis/compute_alpha/classes.rb', line 29505

def error
  @error
end

#error_timestampString

Timestamp when the last error happened Corresponds to the JSON property errorTimestamp

Returns:

  • (String)


29510
29511
29512
# File 'lib/google/apis/compute_alpha/classes.rb', line 29510

def error_timestamp
  @error_timestamp
end

#external_idString

Identifier of the accelerator topology assigned externally to differentiate who is the owner of the topology. This is set in ConfigureAcceleratorTopologies. If it is provided on activating the sub-slice it will have to be provided on deactivating as well. This identifier is cleared on successful deform of a sub-slice. Corresponds to the JSON property externalId

Returns:

  • (String)


29519
29520
29521
# File 'lib/google/apis/compute_alpha/classes.rb', line 29519

def external_id
  @external_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



29526
29527
29528
29529
29530
29531
# File 'lib/google/apis/compute_alpha/classes.rb', line 29526

def update!(**args)
  @current_state = args[:current_state] if args.key?(:current_state)
  @error = args[:error] if args.key?(:error)
  @error_timestamp = args[:error_timestamp] if args.key?(:error_timestamp)
  @external_id = args[:external_id] if args.key?(:external_id)
end