Class: Google::Apis::ComputeAlpha::InstanceGroupManagersGetAvailableAcceleratorTopologiesResponseAcceleratorTopologyState::Error::Error
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::InstanceGroupManagersGetAvailableAcceleratorTopologiesResponseAcceleratorTopologyState::Error::Error
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: ErrorDetail
Instance Attribute Summary collapse
-
#code ⇒ String
[Output Only] The error type identifier for this error.
-
#error_details ⇒ Array<Google::Apis::ComputeAlpha::InstanceGroupManagersGetAvailableAcceleratorTopologiesResponseAcceleratorTopologyState::Error::Error::ErrorDetail>
[Output Only] An optional list of messages that contain the error details.
-
#location ⇒ String
[Output Only] Indicates the field in the request that caused the error.
-
#message ⇒ String
[Output Only] An optional, human-readable error message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Error
constructor
A new instance of Error.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Error
Returns a new instance of Error.
28734 28735 28736 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 28734 def initialize(**args) update!(**args) end |
Instance Attribute Details
#code ⇒ String
[Output Only] The error type identifier for this error.
Corresponds to the JSON property code
28712 28713 28714 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 28712 def code @code end |
#error_details ⇒ Array<Google::Apis::ComputeAlpha::InstanceGroupManagersGetAvailableAcceleratorTopologiesResponseAcceleratorTopologyState::Error::Error::ErrorDetail>
[Output Only] An optional list of messages that contain the error
details. There is a set of defined message types to use for providing
details.The syntax depends on the error code. For example,
QuotaExceededInfo will have details when the error code is
QUOTA_EXCEEDED.
Corresponds to the JSON property errorDetails
28721 28722 28723 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 28721 def error_details @error_details end |
#location ⇒ String
[Output Only] Indicates the field in the request that caused the error.
This property is optional.
Corresponds to the JSON property location
28727 28728 28729 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 28727 def location @location end |
#message ⇒ String
[Output Only] An optional, human-readable error message.
Corresponds to the JSON property message
28732 28733 28734 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 28732 def @message end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
28739 28740 28741 28742 28743 28744 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 28739 def update!(**args) @code = args[:code] if args.key?(:code) @error_details = args[:error_details] if args.key?(:error_details) @location = args[:location] if args.key?(:location) @message = args[:message] if args.key?(:message) end |