Class: Google::Apis::ComputeAlpha::InstanceGroupManagersScopedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupManagersScopedList

Returns a new instance of InstanceGroupManagersScopedList.



31185
31186
31187
# File 'lib/google/apis/compute_alpha/classes.rb', line 31185

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#instance_group_managersArray<Google::Apis::ComputeAlpha::InstanceGroupManager>

Output only. The list of managed instance groups that are contained in the specified project and zone. Corresponds to the JSON property instanceGroupManagers



31176
31177
31178
# File 'lib/google/apis/compute_alpha/classes.rb', line 31176

def instance_group_managers
  @instance_group_managers
end

#warningGoogle::Apis::ComputeAlpha::InstanceGroupManagersScopedList::Warning

Output only. The warning that replaces the list of managed instance groups when the list is empty. Corresponds to the JSON property warning



31183
31184
31185
# File 'lib/google/apis/compute_alpha/classes.rb', line 31183

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



31190
31191
31192
31193
# File 'lib/google/apis/compute_alpha/classes.rb', line 31190

def update!(**args)
  @instance_group_managers = args[:instance_group_managers] if args.key?(:instance_group_managers)
  @warning = args[:warning] if args.key?(:warning)
end