Class: Google::Apis::ComputeAlpha::InstanceManagementInterface

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Represents Out-of-Band (OOB) Host Management Interface configuration details for direct host control.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceManagementInterface

Returns a new instance of InstanceManagementInterface.



32292
32293
32294
# File 'lib/google/apis/compute_alpha/classes.rb', line 32292

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#authentication_configGoogle::Apis::ComputeAlpha::InstanceManagementInterfaceAuthenticationConfig

Authentication configuration for the management interface, typically using mTLS. Corresponds to the JSON property authenticationConfig



32250
32251
32252
# File 'lib/google/apis/compute_alpha/classes.rb', line 32250

def authentication_config
  @authentication_config
end

#ipv4_addressString

The IPv4 internal IP address assigned to this management interface endpoint. This address will be used by the customer to route traffic to the management interface. Corresponds to the JSON property ipv4Address

Returns:

  • (String)


32257
32258
32259
# File 'lib/google/apis/compute_alpha/classes.rb', line 32257

def ipv4_address
  @ipv4_address
end

#ipv6_addressString

The IPv6 internal IP address assigned to this management interface endpoint. This address will be used by the customer to route traffic to the management interface if IPv6 is supported and configured. Corresponds to the JSON property ipv6Address

Returns:

  • (String)


32264
32265
32266
# File 'lib/google/apis/compute_alpha/classes.rb', line 32264

def ipv6_address
  @ipv6_address
end

#networkString

The URL of the VPC network to which the management interface endpoint is attached. The customer must ensure that this network is correctly configured for routing to the instance. Corresponds to the JSON property network

Returns:

  • (String)


32271
32272
32273
# File 'lib/google/apis/compute_alpha/classes.rb', line 32271

def network
  @network
end

#stateString

Output only. [Output Only] The current state of the management interface endpoint. Corresponds to the JSON property state

Returns:

  • (String)


32277
32278
32279
# File 'lib/google/apis/compute_alpha/classes.rb', line 32277

def state
  @state
end

#subnetworkString

The URL of the subnetwork from which to assign the IP address for the endpoint. The subnetwork must belong to the specified network and have available IP addresses. Corresponds to the JSON property subnetwork

Returns:

  • (String)


32284
32285
32286
# File 'lib/google/apis/compute_alpha/classes.rb', line 32284

def subnetwork
  @subnetwork
end

#typeString

Required. The type of management service this interface provides. Supported types include HOST_MANAGEMENT for direct host control. Corresponds to the JSON property type

Returns:

  • (String)


32290
32291
32292
# File 'lib/google/apis/compute_alpha/classes.rb', line 32290

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



32297
32298
32299
32300
32301
32302
32303
32304
32305
# File 'lib/google/apis/compute_alpha/classes.rb', line 32297

def update!(**args)
  @authentication_config = args[:authentication_config] if args.key?(:authentication_config)
  @ipv4_address = args[:ipv4_address] if args.key?(:ipv4_address)
  @ipv6_address = args[:ipv6_address] if args.key?(:ipv6_address)
  @network = args[:network] if args.key?(:network)
  @state = args[:state] if args.key?(:state)
  @subnetwork = args[:subnetwork] if args.key?(:subnetwork)
  @type = args[:type] if args.key?(:type)
end