Class: Google::Apis::ComputeAlpha::InstancePropertiesPatch

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Represents the change that you want to make to the instance properties.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstancePropertiesPatch

Returns a new instance of InstancePropertiesPatch.



32667
32668
32669
# File 'lib/google/apis/compute_alpha/classes.rb', line 32667

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#expose_host_topologyBoolean Also known as: expose_host_topology?

This optional flag exposes the hashed physical host ID. Corresponds to the JSON property exposeHostTopology

Returns:

  • (Boolean)


32652
32653
32654
# File 'lib/google/apis/compute_alpha/classes.rb', line 32652

def expose_host_topology
  @expose_host_topology
end

#labelsHash<String,String>

The label key-value pairs that you want to patch onto the instance. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


32658
32659
32660
# File 'lib/google/apis/compute_alpha/classes.rb', line 32658

def labels
  @labels
end

#metadataHash<String,String>

The metadata key-value pairs that you want to patch onto the instance. For more information, see Project and instance metadata. Corresponds to the JSON property metadata

Returns:

  • (Hash<String,String>)


32665
32666
32667
# File 'lib/google/apis/compute_alpha/classes.rb', line 32665

def 
  @metadata
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



32672
32673
32674
32675
32676
# File 'lib/google/apis/compute_alpha/classes.rb', line 32672

def update!(**args)
  @expose_host_topology = args[:expose_host_topology] if args.key?(:expose_host_topology)
  @labels = args[:labels] if args.key?(:labels)
  @metadata = args[:metadata] if args.key?(:metadata)
end