Class: Google::Apis::ComputeAlpha::InstanceSettings

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Represents a Instance Settings resource. You can use instance settings to configure default settings for Compute Engine VM instances. For example, you can use it to configure default machine type of Compute Engine VM instances.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceSettings

Returns a new instance of InstanceSettings.



32743
32744
32745
# File 'lib/google/apis/compute_alpha/classes.rb', line 32743

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#emailString

Email address of the service account. Corresponds to the JSON property email

Returns:

  • (String)


32708
32709
32710
# File 'lib/google/apis/compute_alpha/classes.rb', line 32708

def email
  @email
end

#fingerprintString

Specifies a fingerprint for instance settings, which is essentially a hash of the instance settings resource's contents and used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update the instance settings resource. You must always provide an up-to-date fingerprint hash in order to update or change the resource, otherwise the request will fail with error 412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve the resource. Corresponds to the JSON property fingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


32722
32723
32724
# File 'lib/google/apis/compute_alpha/classes.rb', line 32722

def fingerprint
  @fingerprint
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# instance_settings for instance settings. Corresponds to the JSON property kind

Returns:

  • (String)


32728
32729
32730
# File 'lib/google/apis/compute_alpha/classes.rb', line 32728

def kind
  @kind
end

#metadataGoogle::Apis::ComputeAlpha::InstanceSettingsMetadata

The metadata key/value pairs assigned to all the instances in the corresponding scope. Corresponds to the JSON property metadata



32734
32735
32736
# File 'lib/google/apis/compute_alpha/classes.rb', line 32734

def 
  @metadata
end

#zoneString

Output only. [Output Only] URL of the zone where the resource resides You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body. Corresponds to the JSON property zone

Returns:

  • (String)


32741
32742
32743
# File 'lib/google/apis/compute_alpha/classes.rb', line 32741

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



32748
32749
32750
32751
32752
32753
32754
# File 'lib/google/apis/compute_alpha/classes.rb', line 32748

def update!(**args)
  @email = args[:email] if args.key?(:email)
  @fingerprint = args[:fingerprint] if args.key?(:fingerprint)
  @kind = args[:kind] if args.key?(:kind)
  @metadata = args[:metadata] if args.key?(:metadata)
  @zone = args[:zone] if args.key?(:zone)
end