Class: Google::Apis::ComputeAlpha::InstanceTemplateList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

A list of instance templates.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceTemplateList

Returns a new instance of InstanceTemplateList.



33063
33064
33065
# File 'lib/google/apis/compute_alpha/classes.rb', line 33063

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


33029
33030
33031
# File 'lib/google/apis/compute_alpha/classes.rb', line 33029

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::InstanceTemplate>

A list of InstanceTemplate resources. Corresponds to the JSON property items



33034
33035
33036
# File 'lib/google/apis/compute_alpha/classes.rb', line 33034

def items
  @items
end

#kindString

Output only. [Output Only] The resource type, which is alwayscompute# instanceTemplatesListResponse for instance template lists. Corresponds to the JSON property kind

Returns:

  • (String)


33041
33042
33043
# File 'lib/google/apis/compute_alpha/classes.rb', line 33041

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


33051
33052
33053
# File 'lib/google/apis/compute_alpha/classes.rb', line 33051

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


33056
33057
33058
# File 'lib/google/apis/compute_alpha/classes.rb', line 33056

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::InstanceTemplateList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



33061
33062
33063
# File 'lib/google/apis/compute_alpha/classes.rb', line 33061

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



33068
33069
33070
33071
33072
33073
33074
33075
# File 'lib/google/apis/compute_alpha/classes.rb', line 33068

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end