Class: Google::Apis::ComputeAlpha::InstancesReportHostAsFaultyRequest
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::InstancesReportHostAsFaultyRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#action_hint ⇒ String
The action hint to report the host as faulty.
-
#disruption_schedule ⇒ String
The disruption schedule for the VM.
-
#fault_reasons ⇒ Array<Google::Apis::ComputeAlpha::InstancesReportHostAsFaultyRequestFaultReason>
Corresponds to the JSON property
faultReasons.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstancesReportHostAsFaultyRequest
constructor
A new instance of InstancesReportHostAsFaultyRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstancesReportHostAsFaultyRequest
Returns a new instance of InstancesReportHostAsFaultyRequest.
31148 31149 31150 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 31148 def initialize(**args) update!(**args) end |
Instance Attribute Details
#action_hint ⇒ String
The action hint to report the host as faulty.
Corresponds to the JSON property actionHint
31136 31137 31138 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 31136 def action_hint @action_hint end |
#disruption_schedule ⇒ String
The disruption schedule for the VM. Required field, only allows IMMEDIATE.
Corresponds to the JSON property disruptionSchedule
31141 31142 31143 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 31141 def disruption_schedule @disruption_schedule end |
#fault_reasons ⇒ Array<Google::Apis::ComputeAlpha::InstancesReportHostAsFaultyRequestFaultReason>
Corresponds to the JSON property faultReasons
31146 31147 31148 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 31146 def fault_reasons @fault_reasons end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
31153 31154 31155 31156 31157 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 31153 def update!(**args) @action_hint = args[:action_hint] if args.key?(:action_hint) @disruption_schedule = args[:disruption_schedule] if args.key?(:disruption_schedule) @fault_reasons = args[:fault_reasons] if args.key?(:fault_reasons) end |