Class: Google::Apis::ComputeAlpha::InstancesSetLabelsRequest
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::InstancesSetLabelsRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#label_fingerprint ⇒ String
Fingerprint of the previous set of labels for this resource, used to prevent conflicts.
-
#labels ⇒ Hash<String,String>
Corresponds to the JSON property
labels.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstancesSetLabelsRequest
constructor
A new instance of InstancesSetLabelsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstancesSetLabelsRequest
Returns a new instance of InstancesSetLabelsRequest.
33159 33160 33161 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 33159 def initialize(**args) update!(**args) end |
Instance Attribute Details
#label_fingerprint ⇒ String
Fingerprint of the previous set of labels for this resource,
used to prevent conflicts. Provide the latest fingerprint value when making
a request to add or change labels.
Corresponds to the JSON property labelFingerprint
NOTE: Values are automatically base64 encoded/decoded in the client library.
33152 33153 33154 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 33152 def label_fingerprint @label_fingerprint end |
#labels ⇒ Hash<String,String>
Corresponds to the JSON property labels
33157 33158 33159 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 33157 def labels @labels end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
33164 33165 33166 33167 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 33164 def update!(**args) @label_fingerprint = args[:label_fingerprint] if args.key?(:label_fingerprint) @labels = args[:labels] if args.key?(:labels) end |