Class: Google::Apis::ComputeAlpha::InstancesSetServiceAccountRequest
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::InstancesSetServiceAccountRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#email ⇒ String
Email address of the service account.
-
#scopes ⇒ Array<String>
The list of scopes to be made available for this service account.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstancesSetServiceAccountRequest
constructor
A new instance of InstancesSetServiceAccountRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstancesSetServiceAccountRequest
Returns a new instance of InstancesSetServiceAccountRequest.
31474 31475 31476 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 31474 def initialize(**args) update!(**args) end |
Instance Attribute Details
#email ⇒ String
Email address of the service account.
Corresponds to the JSON property email
31467 31468 31469 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 31467 def email @email end |
#scopes ⇒ Array<String>
The list of scopes to be made available for this service account.
Corresponds to the JSON property scopes
31472 31473 31474 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 31472 def scopes @scopes end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
31479 31480 31481 31482 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 31479 def update!(**args) @email = args[:email] if args.key?(:email) @scopes = args[:scopes] if args.key?(:scopes) end |