Class: Google::Apis::ComputeAlpha::InstancesStartWithEncryptionKeyRequest
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::InstancesStartWithEncryptionKeyRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#disks ⇒ Array<Google::Apis::ComputeAlpha::CustomerEncryptionKeyProtectedDisk>
Array of disks associated with this instance that are protected with acustomer- supplied encryption key.
-
#instance_encryption_key ⇒ Google::Apis::ComputeAlpha::CustomerEncryptionKey
Decrypts data associated with an instance that is protected with acustomer- supplied encryption key.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstancesStartWithEncryptionKeyRequest
constructor
A new instance of InstancesStartWithEncryptionKeyRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstancesStartWithEncryptionKeyRequest
Returns a new instance of InstancesStartWithEncryptionKeyRequest.
32582 32583 32584 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 32582 def initialize(**args) update!(**args) end |
Instance Attribute Details
#disks ⇒ Array<Google::Apis::ComputeAlpha::CustomerEncryptionKeyProtectedDisk>
Array of disks associated with this instance that are protected with acustomer-
supplied
encryption key.
In order to start the instance, the disk url and its corresponding key must
be provided.
If the disk is not protected with a customer-supplied encryption key it
should not be specified.
Corresponds to the JSON property disks
32570 32571 32572 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 32570 def disks @disks end |
#instance_encryption_key ⇒ Google::Apis::ComputeAlpha::CustomerEncryptionKey
Decrypts data associated with an instance that is protected with acustomer-
supplied
encryption key.
If the instance you are starting is protected with a customer-supplied
encryption key, the correct key must be provided otherwise the
instance start will not succeed.
Corresponds to the JSON property instanceEncryptionKey
32580 32581 32582 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 32580 def instance_encryption_key @instance_encryption_key end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
32587 32588 32589 32590 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 32587 def update!(**args) @disks = args[:disks] if args.key?(:disks) @instance_encryption_key = args[:instance_encryption_key] if args.key?(:instance_encryption_key) end |