Class: Google::Apis::ComputeAlpha::InterconnectAttachmentGroupConfiguredAvailabilitySla

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

[Output Only] Which SLA this group is configured to support, and why this group does or does not meet that SLA's requirements.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectAttachmentGroupConfiguredAvailabilitySla

Returns a new instance of InterconnectAttachmentGroupConfiguredAvailabilitySla.



34545
34546
34547
# File 'lib/google/apis/compute_alpha/classes.rb', line 34545

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#effective_slaString

Corresponds to the JSON property effectiveSla

Returns:

  • (String)


34538
34539
34540
# File 'lib/google/apis/compute_alpha/classes.rb', line 34538

def effective_sla
  @effective_sla
end

#intended_sla_blockersArray<Google::Apis::ComputeAlpha::InterconnectAttachmentGroupConfiguredAvailabilitySlaIntendedSlaBlockers>

Corresponds to the JSON property intendedSlaBlockers



34543
34544
34545
# File 'lib/google/apis/compute_alpha/classes.rb', line 34543

def intended_sla_blockers
  @intended_sla_blockers
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



34550
34551
34552
34553
# File 'lib/google/apis/compute_alpha/classes.rb', line 34550

def update!(**args)
  @effective_sla = args[:effective_sla] if args.key?(:effective_sla)
  @intended_sla_blockers = args[:intended_sla_blockers] if args.key?(:intended_sla_blockers)
end