Class: Google::Apis::ComputeAlpha::InterconnectAttachmentGroupConfiguredAvailabilitySlaIntendedSlaBlockers

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

[Output Only] Reasons why configuration.availabilitySLA.sla differs from intent.availabilitySLA. This list is empty if and only if those are the same.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectAttachmentGroupConfiguredAvailabilitySlaIntendedSlaBlockers

Returns a new instance of InterconnectAttachmentGroupConfiguredAvailabilitySlaIntendedSlaBlockers.



36079
36080
36081
# File 'lib/google/apis/compute_alpha/classes.rb', line 36079

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#attachmentsArray<String>

Output only. [Output Only] URLs of any particular Attachments to explain this blocker in more detail. Corresponds to the JSON property attachments

Returns:

  • (Array<String>)


36035
36036
36037
# File 'lib/google/apis/compute_alpha/classes.rb', line 36035

def attachments
  @attachments
end

#blocker_typeString

Corresponds to the JSON property blockerType

Returns:

  • (String)


36040
36041
36042
# File 'lib/google/apis/compute_alpha/classes.rb', line 36040

def blocker_type
  @blocker_type
end

Output only. [Output Only] The url of Google Cloud public documentation explaining this requirement. This is set for every type of requirement. Corresponds to the JSON property documentationLink

Returns:

  • (String)


36047
36048
36049
# File 'lib/google/apis/compute_alpha/classes.rb', line 36047

def documentation_link
  @documentation_link
end

#explanationString

Output only. [Output Only] A human-readable explanation of this requirement and why it's not met. This is set for every type of requirement. Corresponds to the JSON property explanation

Returns:

  • (String)


36054
36055
36056
# File 'lib/google/apis/compute_alpha/classes.rb', line 36054

def explanation
  @explanation
end

#metrosArray<String>

Output only. [Output Only] Metros used to explain this blocker in more detail. These are three-letter lowercase strings like "iad". This will be set for some blockers (like NO_ATTACHMENTS_IN_METRO_AND_ZONE) but does not apply to others. Corresponds to the JSON property metros

Returns:

  • (Array<String>)


36062
36063
36064
# File 'lib/google/apis/compute_alpha/classes.rb', line 36062

def metros
  @metros
end

#regionsArray<String>

Output only. [Output Only] Regions used to explain this blocker in more detail. These are region names formatted like "us-central1". This will be set for some blockers (like INCOMPATIBLE_REGIONS) but does not apply to others. Corresponds to the JSON property regions

Returns:

  • (Array<String>)


36070
36071
36072
# File 'lib/google/apis/compute_alpha/classes.rb', line 36070

def regions
  @regions
end

#zonesArray<String>

Output only. [Output Only] Zones used to explain this blocker in more detail. Format is "zone1" and/or "zone2". This will be set for some blockers (like MISSING_ZONE) but does not apply to others. Corresponds to the JSON property zones

Returns:

  • (Array<String>)


36077
36078
36079
# File 'lib/google/apis/compute_alpha/classes.rb', line 36077

def zones
  @zones
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



36084
36085
36086
36087
36088
36089
36090
36091
36092
# File 'lib/google/apis/compute_alpha/classes.rb', line 36084

def update!(**args)
  @attachments = args[:attachments] if args.key?(:attachments)
  @blocker_type = args[:blocker_type] if args.key?(:blocker_type)
  @documentation_link = args[:documentation_link] if args.key?(:documentation_link)
  @explanation = args[:explanation] if args.key?(:explanation)
  @metros = args[:metros] if args.key?(:metros)
  @regions = args[:regions] if args.key?(:regions)
  @zones = args[:zones] if args.key?(:zones)
end