Class: Google::Apis::ComputeAlpha::InterconnectAttachmentGroupLogicalStructure

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

[Output Only] An analysis of the logical layout of Attachments in this group. Every Attachment in the group is shown once in this structure.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectAttachmentGroupLogicalStructure

Returns a new instance of InterconnectAttachmentGroupLogicalStructure.



36125
36126
36127
# File 'lib/google/apis/compute_alpha/classes.rb', line 36125

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#regionsArray<Google::Apis::ComputeAlpha::InterconnectAttachmentGroupLogicalStructureRegion>

Corresponds to the JSON property regions



36123
36124
36125
# File 'lib/google/apis/compute_alpha/classes.rb', line 36123

def regions
  @regions
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



36130
36131
36132
# File 'lib/google/apis/compute_alpha/classes.rb', line 36130

def update!(**args)
  @regions = args[:regions] if args.key?(:regions)
end