Class: Google::Apis::ComputeAlpha::InterconnectAttachmentGroupsCreateMembers

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectAttachmentGroupsCreateMembers

Returns a new instance of InterconnectAttachmentGroupsCreateMembers.



36040
36041
36042
# File 'lib/google/apis/compute_alpha/classes.rb', line 36040

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#attachmentsArray<Google::Apis::ComputeAlpha::InterconnectAttachmentGroupsCreateMembersInterconnectAttachmentInput>

Parameters for the specific Attachments to create. Corresponds to the JSON property attachments



36025
36026
36027
# File 'lib/google/apis/compute_alpha/classes.rb', line 36025

def attachments
  @attachments
end

#intent_mismatch_behaviorString

How to behave when configured.availabilitySLA.effectiveSLA would not equal intent.availabilitySLA after this call. Corresponds to the JSON property intentMismatchBehavior

Returns:

  • (String)


36031
36032
36033
# File 'lib/google/apis/compute_alpha/classes.rb', line 36031

def intent_mismatch_behavior
  @intent_mismatch_behavior
end

#template_attachmentGoogle::Apis::ComputeAlpha::InterconnectAttachmentGroupsCreateMembersInterconnectAttachmentInput

Parameters used to create an InterconnectAttachment. This is similar to InterconnectAttachment, but the region field used here is not output only and all other output only fields are excluded. Corresponds to the JSON property templateAttachment



36038
36039
36040
# File 'lib/google/apis/compute_alpha/classes.rb', line 36038

def template_attachment
  @template_attachment
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



36045
36046
36047
36048
36049
# File 'lib/google/apis/compute_alpha/classes.rb', line 36045

def update!(**args)
  @attachments = args[:attachments] if args.key?(:attachments)
  @intent_mismatch_behavior = args[:intent_mismatch_behavior] if args.key?(:intent_mismatch_behavior)
  @template_attachment = args[:template_attachment] if args.key?(:template_attachment)
end