Class: Google::Apis::ComputeAlpha::InterconnectAttachmentGroupsListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectAttachmentGroupsListResponse

Returns a new instance of InterconnectAttachmentGroupsListResponse.



36687
36688
36689
# File 'lib/google/apis/compute_alpha/classes.rb', line 36687

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


36643
36644
36645
# File 'lib/google/apis/compute_alpha/classes.rb', line 36643

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


36648
36649
36650
# File 'lib/google/apis/compute_alpha/classes.rb', line 36648

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::InterconnectAttachmentGroup>

A list of InterconnectAttachmentGroup resources. Corresponds to the JSON property items



36653
36654
36655
# File 'lib/google/apis/compute_alpha/classes.rb', line 36653

def items
  @items
end

#kindString

Corresponds to the JSON property kind

Returns:

  • (String)


36658
36659
36660
# File 'lib/google/apis/compute_alpha/classes.rb', line 36658

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


36668
36669
36670
# File 'lib/google/apis/compute_alpha/classes.rb', line 36668

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


36673
36674
36675
# File 'lib/google/apis/compute_alpha/classes.rb', line 36673

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


36680
36681
36682
# File 'lib/google/apis/compute_alpha/classes.rb', line 36680

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::InterconnectAttachmentGroupsListResponse::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



36685
36686
36687
# File 'lib/google/apis/compute_alpha/classes.rb', line 36685

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



36692
36693
36694
36695
36696
36697
36698
36699
36700
36701
# File 'lib/google/apis/compute_alpha/classes.rb', line 36692

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end