Class: Google::Apis::ComputeAlpha::InterconnectAttachmentGroupsOperationalStatus

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectAttachmentGroupsOperationalStatus

Returns a new instance of InterconnectAttachmentGroupsOperationalStatus.



36808
36809
36810
# File 'lib/google/apis/compute_alpha/classes.rb', line 36808

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#attachment_statusesArray<Google::Apis::ComputeAlpha::InterconnectAttachmentGroupsOperationalStatusAttachmentStatus>

Corresponds to the JSON property attachmentStatuses



36781
36782
36783
# File 'lib/google/apis/compute_alpha/classes.rb', line 36781

def attachment_statuses
  @attachment_statuses
end

#configuredGoogle::Apis::ComputeAlpha::InterconnectAttachmentGroupConfigured

[Output Only] The redundancy this group is configured to support. The way a user queries what SLA their Attachment gets is by looking at this field of the Attachment's AttachmentGroup. Corresponds to the JSON property configured



36788
36789
36790
# File 'lib/google/apis/compute_alpha/classes.rb', line 36788

def configured
  @configured
end

#group_statusString

Output only. Summarizes the status of the group. Corresponds to the JSON property groupStatus

Returns:

  • (String)


36793
36794
36795
# File 'lib/google/apis/compute_alpha/classes.rb', line 36793

def group_status
  @group_status
end

#intentGoogle::Apis::ComputeAlpha::InterconnectAttachmentGroupIntent

The user's intent for this AttachmentGroup. This is the only required field besides the name that must be specified on group creation. Corresponds to the JSON property intent



36799
36800
36801
# File 'lib/google/apis/compute_alpha/classes.rb', line 36799

def intent
  @intent
end

#operationalGoogle::Apis::ComputeAlpha::InterconnectAttachmentGroupConfigured

[Output Only] The redundancy this group is configured to support. The way a user queries what SLA their Attachment gets is by looking at this field of the Attachment's AttachmentGroup. Corresponds to the JSON property operational



36806
36807
36808
# File 'lib/google/apis/compute_alpha/classes.rb', line 36806

def operational
  @operational
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



36813
36814
36815
36816
36817
36818
36819
# File 'lib/google/apis/compute_alpha/classes.rb', line 36813

def update!(**args)
  @attachment_statuses = args[:attachment_statuses] if args.key?(:attachment_statuses)
  @configured = args[:configured] if args.key?(:configured)
  @group_status = args[:group_status] if args.key?(:group_status)
  @intent = args[:intent] if args.key?(:intent)
  @operational = args[:operational] if args.key?(:operational)
end