Class: Google::Apis::ComputeAlpha::InterconnectAttachmentGroupsOperationalStatusAttachmentStatus

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

The status of one Attachment in the group. List order is arbitrary.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectAttachmentGroupsOperationalStatusAttachmentStatus

Returns a new instance of InterconnectAttachmentGroupsOperationalStatusAttachmentStatus.



35246
35247
35248
# File 'lib/google/apis/compute_alpha/classes.rb', line 35246

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#admin_enabledBoolean Also known as: admin_enabled?

Output only. Whether this Attachment is enabled. This becomes false when the customer drains their Attachment. Corresponds to the JSON property adminEnabled

Returns:

  • (Boolean)


35224
35225
35226
# File 'lib/google/apis/compute_alpha/classes.rb', line 35224

def admin_enabled
  @admin_enabled
end

#attachmentString

Output only. The URL of the Attachment being described. Corresponds to the JSON property attachment

Returns:

  • (String)


35230
35231
35232
# File 'lib/google/apis/compute_alpha/classes.rb', line 35230

def attachment
  @attachment
end

#is_activeString

Output only. Whether this Attachment is participating in the redundant configuration. This will be ACTIVE if and only if the status below is CONNECTION_UP. Any INACTIVE Attachments are excluded from the analysis that generates operational.availabilitySLA. Corresponds to the JSON property isActive

Returns:

  • (String)


35239
35240
35241
# File 'lib/google/apis/compute_alpha/classes.rb', line 35239

def is_active
  @is_active
end

#statusString

Output only. Whether this Attachment is active, and if so, whether BGP is up. Corresponds to the JSON property status

Returns:

  • (String)


35244
35245
35246
# File 'lib/google/apis/compute_alpha/classes.rb', line 35244

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



35251
35252
35253
35254
35255
35256
# File 'lib/google/apis/compute_alpha/classes.rb', line 35251

def update!(**args)
  @admin_enabled = args[:admin_enabled] if args.key?(:admin_enabled)
  @attachment = args[:attachment] if args.key?(:attachment)
  @is_active = args[:is_active] if args.key?(:is_active)
  @status = args[:status] if args.key?(:status)
end