Class: Google::Apis::ComputeAlpha::InterconnectAttachmentList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Response to the list request, and contains a list of interconnect attachments.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectAttachmentList

Returns a new instance of InterconnectAttachmentList.



37055
37056
37057
# File 'lib/google/apis/compute_alpha/classes.rb', line 37055

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


37021
37022
37023
# File 'lib/google/apis/compute_alpha/classes.rb', line 37021

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::InterconnectAttachment>

A list of InterconnectAttachment resources. Corresponds to the JSON property items



37026
37027
37028
# File 'lib/google/apis/compute_alpha/classes.rb', line 37026

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# interconnectAttachmentList for lists of interconnect attachments. Corresponds to the JSON property kind

Returns:

  • (String)


37033
37034
37035
# File 'lib/google/apis/compute_alpha/classes.rb', line 37033

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


37043
37044
37045
# File 'lib/google/apis/compute_alpha/classes.rb', line 37043

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


37048
37049
37050
# File 'lib/google/apis/compute_alpha/classes.rb', line 37048

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::InterconnectAttachmentList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



37053
37054
37055
# File 'lib/google/apis/compute_alpha/classes.rb', line 37053

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



37060
37061
37062
37063
37064
37065
37066
37067
# File 'lib/google/apis/compute_alpha/classes.rb', line 37060

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end