Class: Google::Apis::ComputeAlpha::InterconnectAttachmentsScopedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectAttachmentsScopedList

Returns a new instance of InterconnectAttachmentsScopedList.



35983
35984
35985
# File 'lib/google/apis/compute_alpha/classes.rb', line 35983

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#interconnect_attachmentsArray<Google::Apis::ComputeAlpha::InterconnectAttachment>

A list of interconnect attachments contained in this scope. Corresponds to the JSON property interconnectAttachments



35975
35976
35977
# File 'lib/google/apis/compute_alpha/classes.rb', line 35975

def interconnect_attachments
  @interconnect_attachments
end

#warningGoogle::Apis::ComputeAlpha::InterconnectAttachmentsScopedList::Warning

Informational warning which replaces the list of addresses when the list is empty. Corresponds to the JSON property warning



35981
35982
35983
# File 'lib/google/apis/compute_alpha/classes.rb', line 35981

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



35988
35989
35990
35991
# File 'lib/google/apis/compute_alpha/classes.rb', line 35988

def update!(**args)
  @interconnect_attachments = args[:interconnect_attachments] if args.key?(:interconnect_attachments)
  @warning = args[:warning] if args.key?(:warning)
end