Class: Google::Apis::ComputeAlpha::InterconnectCircuitInfo
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::InterconnectCircuitInfo
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Describes a single physical circuit between the Customer and Google. CircuitInfo objects are created by Google, so all fields are output only.
Instance Attribute Summary collapse
-
#customer_demarc_id ⇒ String
Customer-side demarc ID for this circuit.
-
#google_circuit_id ⇒ String
Google-assigned unique ID for this circuit.
-
#google_demarc_id ⇒ String
Google-side demarc ID for this circuit.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InterconnectCircuitInfo
constructor
A new instance of InterconnectCircuitInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InterconnectCircuitInfo
Returns a new instance of InterconnectCircuitInfo.
35870 35871 35872 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 35870 def initialize(**args) update!(**args) end |
Instance Attribute Details
#customer_demarc_id ⇒ String
Customer-side demarc ID for this circuit.
Corresponds to the JSON property customerDemarcId
35857 35858 35859 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 35857 def customer_demarc_id @customer_demarc_id end |
#google_circuit_id ⇒ String
Google-assigned unique ID for this circuit. Assigned at circuit turn-up.
Corresponds to the JSON property googleCircuitId
35862 35863 35864 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 35862 def google_circuit_id @google_circuit_id end |
#google_demarc_id ⇒ String
Google-side demarc ID for this circuit. Assigned at circuit turn-up and
provided by Google to the customer in the LOA.
Corresponds to the JSON property googleDemarcId
35868 35869 35870 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 35868 def google_demarc_id @google_demarc_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
35875 35876 35877 35878 35879 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 35875 def update!(**args) @customer_demarc_id = args[:customer_demarc_id] if args.key?(:customer_demarc_id) @google_circuit_id = args[:google_circuit_id] if args.key?(:google_circuit_id) @google_demarc_id = args[:google_demarc_id] if args.key?(:google_demarc_id) end |