Class: Google::Apis::ComputeAlpha::InterconnectDiagnosticsLinkLacpStatus

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectDiagnosticsLinkLacpStatus

Returns a new instance of InterconnectDiagnosticsLinkLacpStatus.



37234
37235
37236
# File 'lib/google/apis/compute_alpha/classes.rb', line 37234

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#google_system_idString

System ID of the port on Google's side of the LACP exchange. Corresponds to the JSON property googleSystemId

Returns:

  • (String)


37218
37219
37220
# File 'lib/google/apis/compute_alpha/classes.rb', line 37218

def google_system_id
  @google_system_id
end

#neighbor_system_idString

System ID of the port on the neighbor's side of the LACP exchange. Corresponds to the JSON property neighborSystemId

Returns:

  • (String)


37223
37224
37225
# File 'lib/google/apis/compute_alpha/classes.rb', line 37223

def neighbor_system_id
  @neighbor_system_id
end

#stateString

The state of a LACP link, which can take one of the following values:

  • ACTIVE: The link is configured and active within the bundle.
  • DETACHED: The link is not configured within the bundle. This means that the rest of the object should be empty. Corresponds to the JSON property state

Returns:

  • (String)


37232
37233
37234
# File 'lib/google/apis/compute_alpha/classes.rb', line 37232

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



37239
37240
37241
37242
37243
# File 'lib/google/apis/compute_alpha/classes.rb', line 37239

def update!(**args)
  @google_system_id = args[:google_system_id] if args.key?(:google_system_id)
  @neighbor_system_id = args[:neighbor_system_id] if args.key?(:neighbor_system_id)
  @state = args[:state] if args.key?(:state)
end