Class: Google::Apis::ComputeAlpha::InterconnectDiagnosticsLinkStatus

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectDiagnosticsLinkStatus

Returns a new instance of InterconnectDiagnosticsLinkStatus.



37559
37560
37561
# File 'lib/google/apis/compute_alpha/classes.rb', line 37559

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#arp_cachesArray<Google::Apis::ComputeAlpha::InterconnectDiagnosticsArpEntry>

A list of InterconnectDiagnostics.ARPEntry objects, describing the ARP neighbor entries seen on this link. This will be empty if the link is bundled Corresponds to the JSON property arpCaches



37520
37521
37522
# File 'lib/google/apis/compute_alpha/classes.rb', line 37520

def arp_caches
  @arp_caches
end

#circuit_idString

The unique ID for this link assigned during turn up by Google. Corresponds to the JSON property circuitId

Returns:

  • (String)


37525
37526
37527
# File 'lib/google/apis/compute_alpha/classes.rb', line 37525

def circuit_id
  @circuit_id
end

#google_demarcString

The Demarc address assigned by Google and provided in the LoA. Corresponds to the JSON property googleDemarc

Returns:

  • (String)


37530
37531
37532
# File 'lib/google/apis/compute_alpha/classes.rb', line 37530

def google_demarc
  @google_demarc
end

#lacp_statusGoogle::Apis::ComputeAlpha::InterconnectDiagnosticsLinkLacpStatus

Corresponds to the JSON property lacpStatus



37535
37536
37537
# File 'lib/google/apis/compute_alpha/classes.rb', line 37535

def lacp_status
  @lacp_status
end

#macsecGoogle::Apis::ComputeAlpha::InterconnectDiagnosticsMacsecStatus

Describes the status of MACsec encryption on the link. Corresponds to the JSON property macsec



37540
37541
37542
# File 'lib/google/apis/compute_alpha/classes.rb', line 37540

def macsec
  @macsec
end

#operational_statusString

The operational status of the link. Corresponds to the JSON property operationalStatus

Returns:

  • (String)


37545
37546
37547
# File 'lib/google/apis/compute_alpha/classes.rb', line 37545

def operational_status
  @operational_status
end

#receiving_optical_powerGoogle::Apis::ComputeAlpha::InterconnectDiagnosticsLinkOpticalPower

An InterconnectDiagnostics.LinkOpticalPower object, describing the current value and status of the received light level. Corresponds to the JSON property receivingOpticalPower



37551
37552
37553
# File 'lib/google/apis/compute_alpha/classes.rb', line 37551

def receiving_optical_power
  @receiving_optical_power
end

#transmitting_optical_powerGoogle::Apis::ComputeAlpha::InterconnectDiagnosticsLinkOpticalPower

An InterconnectDiagnostics.LinkOpticalPower object, describing the current value and status of the transmitted light level. Corresponds to the JSON property transmittingOpticalPower



37557
37558
37559
# File 'lib/google/apis/compute_alpha/classes.rb', line 37557

def transmitting_optical_power
  @transmitting_optical_power
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



37564
37565
37566
37567
37568
37569
37570
37571
37572
37573
# File 'lib/google/apis/compute_alpha/classes.rb', line 37564

def update!(**args)
  @arp_caches = args[:arp_caches] if args.key?(:arp_caches)
  @circuit_id = args[:circuit_id] if args.key?(:circuit_id)
  @google_demarc = args[:google_demarc] if args.key?(:google_demarc)
  @lacp_status = args[:lacp_status] if args.key?(:lacp_status)
  @macsec = args[:macsec] if args.key?(:macsec)
  @operational_status = args[:operational_status] if args.key?(:operational_status)
  @receiving_optical_power = args[:receiving_optical_power] if args.key?(:receiving_optical_power)
  @transmitting_optical_power = args[:transmitting_optical_power] if args.key?(:transmitting_optical_power)
end