Class: Google::Apis::ComputeAlpha::InterconnectGroupConfiguredTopologyCapabilityIntendedCapabilityBlockers

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

[Output Only] Reasons why configuration.topologyCapability.sla differs from intent.topologyCapability. This list is empty if and only if those are the same.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectGroupConfiguredTopologyCapabilityIntendedCapabilityBlockers

Returns a new instance of InterconnectGroupConfiguredTopologyCapabilityIntendedCapabilityBlockers.



36332
36333
36334
# File 'lib/google/apis/compute_alpha/classes.rb', line 36332

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#blocker_typeString

Corresponds to the JSON property blockerType

Returns:

  • (String)


36288
36289
36290
# File 'lib/google/apis/compute_alpha/classes.rb', line 36288

def blocker_type
  @blocker_type
end

Output only. [Output Only] The url of Google Cloud public documentation explaining this requirement. This is set for every type of requirement. Corresponds to the JSON property documentationLink

Returns:

  • (String)


36295
36296
36297
# File 'lib/google/apis/compute_alpha/classes.rb', line 36295

def documentation_link
  @documentation_link
end

#explanationString

Output only. [Output Only] A human-readable explanation of this requirement and why it's not met. This is set for every type of requirement. Corresponds to the JSON property explanation

Returns:

  • (String)


36302
36303
36304
# File 'lib/google/apis/compute_alpha/classes.rb', line 36302

def explanation
  @explanation
end

#facilitiesArray<String>

Output only. [Output Only] Facilities used to explain this blocker in more detail. Like physicalStructure.metros.facilities.facility, this is a numeric string like "5467". Corresponds to the JSON property facilities

Returns:

  • (Array<String>)


36310
36311
36312
# File 'lib/google/apis/compute_alpha/classes.rb', line 36310

def facilities
  @facilities
end

#interconnectsArray<String>

Output only. [Output Only] Interconnects used to explain this blocker in more detail. Corresponds to the JSON property interconnects

Returns:

  • (Array<String>)


36316
36317
36318
# File 'lib/google/apis/compute_alpha/classes.rb', line 36316

def interconnects
  @interconnects
end

#metrosArray<String>

Output only. [Output Only] Metros used to explain this blocker in more detail. These are three-letter lowercase strings like "iad". A blocker like INCOMPATIBLE_METROS will specify the problematic metros in this field. Corresponds to the JSON property metros

Returns:

  • (Array<String>)


36324
36325
36326
# File 'lib/google/apis/compute_alpha/classes.rb', line 36324

def metros
  @metros
end

#zonesArray<String>

Output only. [Output Only] Zones used to explain this blocker in more detail. Zone names are "zone1" and/or "zone2". Corresponds to the JSON property zones

Returns:

  • (Array<String>)


36330
36331
36332
# File 'lib/google/apis/compute_alpha/classes.rb', line 36330

def zones
  @zones
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



36337
36338
36339
36340
36341
36342
36343
36344
36345
# File 'lib/google/apis/compute_alpha/classes.rb', line 36337

def update!(**args)
  @blocker_type = args[:blocker_type] if args.key?(:blocker_type)
  @documentation_link = args[:documentation_link] if args.key?(:documentation_link)
  @explanation = args[:explanation] if args.key?(:explanation)
  @facilities = args[:facilities] if args.key?(:facilities)
  @interconnects = args[:interconnects] if args.key?(:interconnects)
  @metros = args[:metros] if args.key?(:metros)
  @zones = args[:zones] if args.key?(:zones)
end