Class: Google::Apis::ComputeAlpha::InterconnectGroupPhysicalStructure

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

[Output Only] An analysis of the physical layout of Interconnects in this group. Every Interconnect in the group is shown once in this structure.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectGroupPhysicalStructure

Returns a new instance of InterconnectGroupPhysicalStructure.



37877
37878
37879
# File 'lib/google/apis/compute_alpha/classes.rb', line 37877

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#metrosArray<Google::Apis::ComputeAlpha::InterconnectGroupPhysicalStructureMetros>

Corresponds to the JSON property metros



37875
37876
37877
# File 'lib/google/apis/compute_alpha/classes.rb', line 37875

def metros
  @metros
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



37882
37883
37884
# File 'lib/google/apis/compute_alpha/classes.rb', line 37882

def update!(**args)
  @metros = args[:metros] if args.key?(:metros)
end