Class: Google::Apis::ComputeAlpha::InterconnectGroupsGetOperationalStatusResponse
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::InterconnectGroupsGetOperationalStatusResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Response for the InterconnectGroupsGetOperationalStatusResponse.
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#result ⇒ Google::Apis::ComputeAlpha::InterconnectGroupsOperationalStatus
Request to get the status of the interconnect group with extra detail.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InterconnectGroupsGetOperationalStatusResponse
constructor
A new instance of InterconnectGroupsGetOperationalStatusResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InterconnectGroupsGetOperationalStatusResponse
Returns a new instance of InterconnectGroupsGetOperationalStatusResponse.
36693 36694 36695 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 36693 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
36686 36687 36688 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 36686 def etag @etag end |
#result ⇒ Google::Apis::ComputeAlpha::InterconnectGroupsOperationalStatus
Request to get the status of the interconnect group with extra detail.
Corresponds to the JSON property result
36691 36692 36693 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 36691 def result @result end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
36698 36699 36700 36701 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 36698 def update!(**args) @etag = args[:etag] if args.key?(:etag) @result = args[:result] if args.key?(:result) end |