Class: Google::Apis::ComputeAlpha::InterconnectLocationList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Response to the list request, and contains a list of interconnect locations.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectLocationList

Returns a new instance of InterconnectLocationList.



38787
38788
38789
# File 'lib/google/apis/compute_alpha/classes.rb', line 38787

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


38753
38754
38755
# File 'lib/google/apis/compute_alpha/classes.rb', line 38753

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::InterconnectLocation>

A list of InterconnectLocation resources. Corresponds to the JSON property items



38758
38759
38760
# File 'lib/google/apis/compute_alpha/classes.rb', line 38758

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# interconnectLocationList for lists of interconnect locations. Corresponds to the JSON property kind

Returns:

  • (String)


38765
38766
38767
# File 'lib/google/apis/compute_alpha/classes.rb', line 38765

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


38775
38776
38777
# File 'lib/google/apis/compute_alpha/classes.rb', line 38775

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


38780
38781
38782
# File 'lib/google/apis/compute_alpha/classes.rb', line 38780

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::InterconnectLocationList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



38785
38786
38787
# File 'lib/google/apis/compute_alpha/classes.rb', line 38785

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



38792
38793
38794
38795
38796
38797
38798
38799
# File 'lib/google/apis/compute_alpha/classes.rb', line 38792

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end