Class: Google::Apis::ComputeAlpha::InterconnectMacsec

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Configuration information for enabling Media Access Control security (MACsec) on this Cloud Interconnect connection between Google and your on-premises router.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectMacsec

Returns a new instance of InterconnectMacsec.



37695
37696
37697
# File 'lib/google/apis/compute_alpha/classes.rb', line 37695

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#fail_openBoolean Also known as: fail_open?

If set to true, the Interconnect connection is configured with ashould-secure MACsec security policy, that allows the Google router to fallback to cleartext traffic if the MKA session cannot be established. By default, the Interconnect connection is configured with amust- secure security policy that drops all traffic if the MKA session cannot be established with your router. Corresponds to the JSON property failOpen

Returns:

  • (Boolean)


37675
37676
37677
# File 'lib/google/apis/compute_alpha/classes.rb', line 37675

def fail_open
  @fail_open
end

#interconnect_key_groupString

Optional. URL of the InterconnectKeyGroup resource to use for MACsec, in the format: projects/project/locations/region/interconnectKeyGroups/ interconnectKeyGroup. Corresponds to the JSON property interconnectKeyGroup

Returns:

  • (String)


37684
37685
37686
# File 'lib/google/apis/compute_alpha/classes.rb', line 37684

def interconnect_key_group
  @interconnect_key_group
end

#pre_shared_keysArray<Google::Apis::ComputeAlpha::InterconnectMacsecPreSharedKey>

Required. A keychain placeholder describing a set of named key objects along with their start times. A MACsec CKN/CAK is generated for each key in the key chain. Google router automatically picks the key with the most recent startTime when establishing or re-establishing a MACsec secure link. Corresponds to the JSON property preSharedKeys



37693
37694
37695
# File 'lib/google/apis/compute_alpha/classes.rb', line 37693

def pre_shared_keys
  @pre_shared_keys
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



37700
37701
37702
37703
37704
# File 'lib/google/apis/compute_alpha/classes.rb', line 37700

def update!(**args)
  @fail_open = args[:fail_open] if args.key?(:fail_open)
  @interconnect_key_group = args[:interconnect_key_group] if args.key?(:interconnect_key_group)
  @pre_shared_keys = args[:pre_shared_keys] if args.key?(:pre_shared_keys)
end