Class: Google::Apis::ComputeAlpha::InterconnectMacsecConfigPreSharedKey
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::InterconnectMacsecConfigPreSharedKey
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Describes a pre-shared key used to setup MACsec in static connectivity association key (CAK) mode.
Instance Attribute Summary collapse
-
#cak ⇒ String
An auto-generated Connectivity Association Key (CAK) for this key.
-
#ckn ⇒ String
An auto-generated Connectivity Association Key Name (CKN) for this key.
-
#name ⇒ String
User provided name for this pre-shared key.
-
#start_time ⇒ String
User provided timestamp on or after which this key is valid.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InterconnectMacsecConfigPreSharedKey
constructor
A new instance of InterconnectMacsecConfigPreSharedKey.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InterconnectMacsecConfigPreSharedKey
Returns a new instance of InterconnectMacsecConfigPreSharedKey.
37395 37396 37397 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 37395 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cak ⇒ String
An auto-generated Connectivity Association Key (CAK) for this key.
Corresponds to the JSON property cak
37378 37379 37380 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 37378 def cak @cak end |
#ckn ⇒ String
An auto-generated Connectivity Association Key Name (CKN) for this key.
Corresponds to the JSON property ckn
37383 37384 37385 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 37383 def ckn @ckn end |
#name ⇒ String
User provided name for this pre-shared key.
Corresponds to the JSON property name
37388 37389 37390 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 37388 def name @name end |
#start_time ⇒ String
User provided timestamp on or after which this key is valid.
Corresponds to the JSON property startTime
37393 37394 37395 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 37393 def start_time @start_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
37400 37401 37402 37403 37404 37405 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 37400 def update!(**args) @cak = args[:cak] if args.key?(:cak) @ckn = args[:ckn] if args.key?(:ckn) @name = args[:name] if args.key?(:name) @start_time = args[:start_time] if args.key?(:start_time) end |