Class: Google::Apis::ComputeAlpha::InterconnectOutageNotification
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::InterconnectOutageNotification
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Description of a planned outage on this Interconnect.
Instance Attribute Summary collapse
-
#affected_circuits ⇒ Array<String>
If issue_type is IT_PARTIAL_OUTAGE, a list of the Google-side circuit IDs that will be affected.
-
#description ⇒ String
A description about the purpose of the outage.
-
#end_time ⇒ Fixnum
Scheduled end time for the outage (milliseconds since Unix epoch).
-
#issue_type ⇒ String
Form this outage is expected to take, which can take one of the following values:.
-
#name ⇒ String
Unique identifier for this outage notification.
-
#source ⇒ String
The party that generated this notification, which can take the following value:.
-
#start_time ⇒ Fixnum
Scheduled start time for the outage (milliseconds since Unix epoch).
-
#state ⇒ String
State of this notification, which can take one of the following values:.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InterconnectOutageNotification
constructor
A new instance of InterconnectOutageNotification.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InterconnectOutageNotification
Returns a new instance of InterconnectOutageNotification.
38907 38908 38909 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 38907 def initialize(**args) update!(**args) end |
Instance Attribute Details
#affected_circuits ⇒ Array<String>
If issue_type is IT_PARTIAL_OUTAGE, a list of the Google-side circuit
IDs that will be affected.
Corresponds to the JSON property affectedCircuits
38846 38847 38848 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 38846 def affected_circuits @affected_circuits end |
#description ⇒ String
A description about the purpose of the outage.
Corresponds to the JSON property description
38851 38852 38853 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 38851 def description @description end |
#end_time ⇒ Fixnum
Scheduled end time for the outage (milliseconds since Unix
epoch).
Corresponds to the JSON property endTime
38857 38858 38859 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 38857 def end_time @end_time end |
#issue_type ⇒ String
Form this outage is expected to take, which can take one of the following values:
- OUTAGE: The Interconnect may be completely out of service for some or all of the specified window.
- PARTIAL_OUTAGE: Some circuits comprising the Interconnect as a whole
should remain up, but with reduced bandwidth.
Note that the versions of this enum prefixed with "IT_" have been
deprecated in favor of the unprefixed values.
Corresponds to the JSON property
issueType
38870 38871 38872 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 38870 def issue_type @issue_type end |
#name ⇒ String
Unique identifier for this outage notification.
Corresponds to the JSON property name
38875 38876 38877 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 38875 def name @name end |
#source ⇒ String
The party that generated this notification, which can take the following value:
- GOOGLE: this notification as generated by Google.
Note that the value of NSRC_GOOGLE has been deprecated in favor of
GOOGLE.
Corresponds to the JSON property
source
38885 38886 38887 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 38885 def source @source end |
#start_time ⇒ Fixnum
Scheduled start time for the outage (milliseconds since Unix
epoch).
Corresponds to the JSON property startTime
38891 38892 38893 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 38891 def start_time @start_time end |
#state ⇒ String
State of this notification, which can take one of the following values:
- ACTIVE: This outage notification is active. The event could be in the past, present, or future. See start_time and end_time for scheduling.
- CANCELLED: The outage associated with this notification was cancelled before the outage was due to start.
- COMPLETED: The outage associated with this notification is complete.
Note that the versions of this enum prefixed with "NS_" have been
deprecated in favor of the unprefixed values.
Corresponds to the JSON property
state
38905 38906 38907 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 38905 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
38912 38913 38914 38915 38916 38917 38918 38919 38920 38921 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 38912 def update!(**args) @affected_circuits = args[:affected_circuits] if args.key?(:affected_circuits) @description = args[:description] if args.key?(:description) @end_time = args[:end_time] if args.key?(:end_time) @issue_type = args[:issue_type] if args.key?(:issue_type) @name = args[:name] if args.key?(:name) @source = args[:source] if args.key?(:source) @start_time = args[:start_time] if args.key?(:start_time) @state = args[:state] if args.key?(:state) end |