Class: Google::Apis::ComputeAlpha::InterconnectRemoteLocationList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Response to the list request, and contains a list of interconnect remote locations.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectRemoteLocationList

Returns a new instance of InterconnectRemoteLocationList.



39496
39497
39498
# File 'lib/google/apis/compute_alpha/classes.rb', line 39496

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


39462
39463
39464
# File 'lib/google/apis/compute_alpha/classes.rb', line 39462

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::InterconnectRemoteLocation>

A list of InterconnectRemoteLocation resources. Corresponds to the JSON property items



39467
39468
39469
# File 'lib/google/apis/compute_alpha/classes.rb', line 39467

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# interconnectRemoteLocationList for lists of interconnect remote locations. Corresponds to the JSON property kind

Returns:

  • (String)


39474
39475
39476
# File 'lib/google/apis/compute_alpha/classes.rb', line 39474

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token lets you get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


39484
39485
39486
# File 'lib/google/apis/compute_alpha/classes.rb', line 39484

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


39489
39490
39491
# File 'lib/google/apis/compute_alpha/classes.rb', line 39489

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::InterconnectRemoteLocationList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



39494
39495
39496
# File 'lib/google/apis/compute_alpha/classes.rb', line 39494

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



39501
39502
39503
39504
39505
39506
39507
39508
# File 'lib/google/apis/compute_alpha/classes.rb', line 39501

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end