Class: Google::Apis::ComputeAlpha::IpOwnerList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::IpOwnerList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Contains a list of IP owners.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::InternalIpOwner>
A list of InternalIpOwner resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::IpOwnerList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ IpOwnerList
constructor
A new instance of IpOwnerList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ IpOwnerList
Returns a new instance of IpOwnerList.
39731 39732 39733 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39731 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
39693 39694 39695 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39693 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::InternalIpOwner>
A list of InternalIpOwner resources.
Corresponds to the JSON property items
39698 39699 39700 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39698 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#ipOwnerList for
lists of IP owners.
Corresponds to the JSON property kind
39704 39705 39706 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39704 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
39714 39715 39716 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39714 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
39719 39720 39721 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39719 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
39724 39725 39726 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39724 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::IpOwnerList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
39729 39730 39731 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39729 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
39736 39737 39738 39739 39740 39741 39742 39743 39744 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39736 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |