Class: Google::Apis::ComputeAlpha::JwtHeader

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

[Deprecated] This message specifies a header location to extract JWT token. This message specifies a header location to extract JWT token.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ JwtHeader

Returns a new instance of JwtHeader.



38823
38824
38825
# File 'lib/google/apis/compute_alpha/classes.rb', line 38823

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nameString

The HTTP header name. Corresponds to the JSON property name

Returns:

  • (String)


38814
38815
38816
# File 'lib/google/apis/compute_alpha/classes.rb', line 38814

def name
  @name
end

#value_prefixString

The value prefix. The value format is "value_prefix" For example, for "Authorization: Bearer ", value_prefix="Bearer " with a space at the end. Corresponds to the JSON property valuePrefix

Returns:

  • (String)


38821
38822
38823
# File 'lib/google/apis/compute_alpha/classes.rb', line 38821

def value_prefix
  @value_prefix
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



38828
38829
38830
38831
# File 'lib/google/apis/compute_alpha/classes.rb', line 38828

def update!(**args)
  @name = args[:name] if args.key?(:name)
  @value_prefix = args[:value_prefix] if args.key?(:value_prefix)
end