Class: Google::Apis::ComputeAlpha::ListInstantSnapshotGroups

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of InstantSnapshotGroup resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListInstantSnapshotGroups

Returns a new instance of ListInstantSnapshotGroups.



40747
40748
40749
# File 'lib/google/apis/compute_alpha/classes.rb', line 40747

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


40704
40705
40706
# File 'lib/google/apis/compute_alpha/classes.rb', line 40704

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


40709
40710
40711
# File 'lib/google/apis/compute_alpha/classes.rb', line 40709

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::InstantSnapshotGroup>

A list of InstantSnapshotGroup resources. Corresponds to the JSON property items



40714
40715
40716
# File 'lib/google/apis/compute_alpha/classes.rb', line 40714

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


40719
40720
40721
# File 'lib/google/apis/compute_alpha/classes.rb', line 40719

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


40729
40730
40731
# File 'lib/google/apis/compute_alpha/classes.rb', line 40729

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


40734
40735
40736
# File 'lib/google/apis/compute_alpha/classes.rb', line 40734

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


40740
40741
40742
# File 'lib/google/apis/compute_alpha/classes.rb', line 40740

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::ListInstantSnapshotGroups::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



40745
40746
40747
# File 'lib/google/apis/compute_alpha/classes.rb', line 40745

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



40752
40753
40754
40755
40756
40757
40758
40759
40760
40761
# File 'lib/google/apis/compute_alpha/classes.rb', line 40752

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end