Class: Google::Apis::ComputeAlpha::ListVmExtensionStatesResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListVmExtensionStatesResponse

Returns a new instance of ListVmExtensionStatesResponse.



41025
41026
41027
# File 'lib/google/apis/compute_alpha/classes.rb', line 41025

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Output only. Fingerprint of this resource. A hash of the contents stored in this object. This field is used in optimistic locking. This field will be ignored when inserting a VmExtensionPolicy. An up-to-date fingerprint must be provided in order to update the VmExtensionPolicy. To see the latest value of the fingerprint, make a get() request to retrieve a VmExtensionPolicy. Corresponds to the JSON property etag

Returns:

  • (String)


40983
40984
40985
# File 'lib/google/apis/compute_alpha/classes.rb', line 40983

def etag
  @etag
end

#idString

Output only. Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


40988
40989
40990
# File 'lib/google/apis/compute_alpha/classes.rb', line 40988

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::VmExtensionState>

Output only. A list of VM extension policy resources. Corresponds to the JSON property items



40993
40994
40995
# File 'lib/google/apis/compute_alpha/classes.rb', line 40993

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


40998
40999
41000
# File 'lib/google/apis/compute_alpha/classes.rb', line 40998

def kind
  @kind
end

#next_page_tokenString

Output only. This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


41008
41009
41010
# File 'lib/google/apis/compute_alpha/classes.rb', line 41008

def next_page_token
  @next_page_token
end

Output only. Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


41013
41014
41015
# File 'lib/google/apis/compute_alpha/classes.rb', line 41013

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


41018
41019
41020
# File 'lib/google/apis/compute_alpha/classes.rb', line 41018

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::ListVmExtensionStatesResponse::Warning

Output only. Informational warning message. Corresponds to the JSON property warning



41023
41024
41025
# File 'lib/google/apis/compute_alpha/classes.rb', line 41023

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



41030
41031
41032
41033
41034
41035
41036
41037
41038
41039
# File 'lib/google/apis/compute_alpha/classes.rb', line 41030

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end