Class: Google::Apis::ComputeAlpha::MachineType

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Represents a Machine Type resource. You can use specific machine types for your VM instances based on performance and pricing requirements. For more information, readMachine Types.

Defined Under Namespace

Classes: Accelerator

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MachineType

Returns a new instance of MachineType.



41676
41677
41678
# File 'lib/google/apis/compute_alpha/classes.rb', line 41676

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#acceleratorsArray<Google::Apis::ComputeAlpha::MachineType::Accelerator>

[Output Only] A list of accelerator configurations assigned to this machine type. Corresponds to the JSON property accelerators



41584
41585
41586
# File 'lib/google/apis/compute_alpha/classes.rb', line 41584

def accelerators
  @accelerators
end

#architectureString

[Output Only] The architecture of the machine type. Corresponds to the JSON property architecture

Returns:

  • (String)


41589
41590
41591
# File 'lib/google/apis/compute_alpha/classes.rb', line 41589

def architecture
  @architecture
end

#bundled_local_ssdsGoogle::Apis::ComputeAlpha::BundledLocalSsds

[Output Only] The configuration of bundled local SSD for the machine type. Corresponds to the JSON property bundledLocalSsds



41594
41595
41596
# File 'lib/google/apis/compute_alpha/classes.rb', line 41594

def bundled_local_ssds
  @bundled_local_ssds
end

#creation_timestampString

[Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


41600
41601
41602
# File 'lib/google/apis/compute_alpha/classes.rb', line 41600

def creation_timestamp
  @creation_timestamp
end

#deprecatedGoogle::Apis::ComputeAlpha::DeprecationStatus

Deprecation status for a public resource. Corresponds to the JSON property deprecated



41605
41606
41607
# File 'lib/google/apis/compute_alpha/classes.rb', line 41605

def deprecated
  @deprecated
end

#descriptionString

[Output Only] An optional textual description of the resource. Corresponds to the JSON property description

Returns:

  • (String)


41610
41611
41612
# File 'lib/google/apis/compute_alpha/classes.rb', line 41610

def description
  @description
end

#guest_cpusFixnum

[Output Only] The number of virtual CPUs that are available to the instance. Corresponds to the JSON property guestCpus

Returns:

  • (Fixnum)


41616
41617
41618
# File 'lib/google/apis/compute_alpha/classes.rb', line 41616

def guest_cpus
  @guest_cpus
end

#idFixnum

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


41622
41623
41624
# File 'lib/google/apis/compute_alpha/classes.rb', line 41622

def id
  @id
end

#is_shared_cpuBoolean Also known as: is_shared_cpu?

[Output Only] Whether this machine type has a shared CPU. SeeShared-core machine types for more information. Corresponds to the JSON property isSharedCpu

Returns:

  • (Boolean)


41629
41630
41631
# File 'lib/google/apis/compute_alpha/classes.rb', line 41629

def is_shared_cpu
  @is_shared_cpu
end

#kindString

Output only. [Output Only] The type of the resource. Alwayscompute#machineType for machine types. Corresponds to the JSON property kind

Returns:

  • (String)


41636
41637
41638
# File 'lib/google/apis/compute_alpha/classes.rb', line 41636

def kind
  @kind
end

#maximum_persistent_disksFixnum

[Output Only] Maximum persistent disks allowed. Corresponds to the JSON property maximumPersistentDisks

Returns:

  • (Fixnum)


41641
41642
41643
# File 'lib/google/apis/compute_alpha/classes.rb', line 41641

def maximum_persistent_disks
  @maximum_persistent_disks
end

#maximum_persistent_disks_size_gbFixnum

[Output Only] Maximum total persistent disks size (GB) allowed. Corresponds to the JSON property maximumPersistentDisksSizeGb

Returns:

  • (Fixnum)


41646
41647
41648
# File 'lib/google/apis/compute_alpha/classes.rb', line 41646

def maximum_persistent_disks_size_gb
  @maximum_persistent_disks_size_gb
end

#memory_mbFixnum

[Output Only] The amount of physical memory available to the instance, defined in MB. Corresponds to the JSON property memoryMb

Returns:

  • (Fixnum)


41652
41653
41654
# File 'lib/google/apis/compute_alpha/classes.rb', line 41652

def memory_mb
  @memory_mb
end

#nameString

[Output Only] Name of the resource. Corresponds to the JSON property name

Returns:

  • (String)


41657
41658
41659
# File 'lib/google/apis/compute_alpha/classes.rb', line 41657

def name
  @name
end

[Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


41662
41663
41664
# File 'lib/google/apis/compute_alpha/classes.rb', line 41662

def self_link
  @self_link
end

Output only. [Output Only] Server-defined URL for this resource with the resource id. Corresponds to the JSON property selfLinkWithId

Returns:

  • (String)


41668
41669
41670
# File 'lib/google/apis/compute_alpha/classes.rb', line 41668

def self_link_with_id
  @self_link_with_id
end

#zoneString

[Output Only] The name of the zone where the machine type resides, such as us-central1-a. Corresponds to the JSON property zone

Returns:

  • (String)


41674
41675
41676
# File 'lib/google/apis/compute_alpha/classes.rb', line 41674

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



41681
41682
41683
41684
41685
41686
41687
41688
41689
41690
41691
41692
41693
41694
41695
41696
41697
41698
41699
# File 'lib/google/apis/compute_alpha/classes.rb', line 41681

def update!(**args)
  @accelerators = args[:accelerators] if args.key?(:accelerators)
  @architecture = args[:architecture] if args.key?(:architecture)
  @bundled_local_ssds = args[:bundled_local_ssds] if args.key?(:bundled_local_ssds)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @deprecated = args[:deprecated] if args.key?(:deprecated)
  @description = args[:description] if args.key?(:description)
  @guest_cpus = args[:guest_cpus] if args.key?(:guest_cpus)
  @id = args[:id] if args.key?(:id)
  @is_shared_cpu = args[:is_shared_cpu] if args.key?(:is_shared_cpu)
  @kind = args[:kind] if args.key?(:kind)
  @maximum_persistent_disks = args[:maximum_persistent_disks] if args.key?(:maximum_persistent_disks)
  @maximum_persistent_disks_size_gb = args[:maximum_persistent_disks_size_gb] if args.key?(:maximum_persistent_disks_size_gb)
  @memory_mb = args[:memory_mb] if args.key?(:memory_mb)
  @name = args[:name] if args.key?(:name)
  @self_link = args[:self_link] if args.key?(:self_link)
  @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id)
  @zone = args[:zone] if args.key?(:zone)
end