Class: Google::Apis::ComputeAlpha::ManagedInstance

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

A Managed Instance resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ManagedInstance

Returns a new instance of ManagedInstance.



42461
42462
42463
# File 'lib/google/apis/compute_alpha/classes.rb', line 42461

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#all_instances_configGoogle::Apis::ComputeAlpha::ManagedInstanceAllInstancesConfig

Output only. [Output Only] Current all-instances configuration revision applied to this instance. Corresponds to the JSON property allInstancesConfig



42314
42315
42316
# File 'lib/google/apis/compute_alpha/classes.rb', line 42314

def all_instances_config
  @all_instances_config
end

#current_actionString

Output only. [Output Only] The current action that the managed instance group has scheduled for the instance. Possible values:

  • NONE The instance is running, and the managed instance group does not have any scheduled actions for this instance.
  • CREATING The managed instance group is creating this instance. If the group fails to create this instance, it will try again until it is successful.
  • CREATING_WITHOUT_RETRIES The managed instance group is attempting to create this instance only once. If the group fails to create this instance, it does not try again and the group'stargetSize value is decreased instead.
  • RECREATING The managed instance group is recreating this instance.
  • DELETING The managed instance group is permanently deleting this instance.
  • ABANDONING The managed instance group is abandoning this instance. The instance will be removed from the instance group and from any target pools that are associated with this group.
  • RESTARTING The managed instance group is restarting the instance.
  • REFRESHING The managed instance group is applying configuration changes to the instance without stopping it. For example, the group can update the target pool list for an instance without stopping that instance.
  • VERIFYING The managed instance group has created the instance and it is in the process of being verified. Corresponds to the JSON property currentAction

Returns:

  • (String)


42346
42347
42348
# File 'lib/google/apis/compute_alpha/classes.rb', line 42346

def current_action
  @current_action
end

#current_action_detailsGoogle::Apis::ComputeAlpha::ManagedInstanceCurrentActionDetails

Corresponds to the JSON property currentActionDetails



42351
42352
42353
# File 'lib/google/apis/compute_alpha/classes.rb', line 42351

def current_action_details
  @current_action_details
end

#idFixnum

Output only. [Output only] The unique identifier for this resource. This field is empty when instance does not exist. Corresponds to the JSON property id

Returns:

  • (Fixnum)


42358
42359
42360
# File 'lib/google/apis/compute_alpha/classes.rb', line 42358

def id
  @id
end

#instanceString

Output only. [Output Only] The URL of the instance. The URL can exist even if the instance has not yet been created. Corresponds to the JSON property instance

Returns:

  • (String)


42365
42366
42367
# File 'lib/google/apis/compute_alpha/classes.rb', line 42365

def instance
  @instance
end

#instance_flexibility_overrideGoogle::Apis::ComputeAlpha::ManagedInstanceInstanceFlexibilityOverride

Output only. [Output Only] The overrides to instance properties resulting from InstanceFlexibilityPolicy. Corresponds to the JSON property instanceFlexibilityOverride



42371
42372
42373
# File 'lib/google/apis/compute_alpha/classes.rb', line 42371

def instance_flexibility_override
  @instance_flexibility_override
end

#instance_healthArray<Google::Apis::ComputeAlpha::ManagedInstanceInstanceHealth>

Output only. [Output Only] Health state of the instance per health-check. Corresponds to the JSON property instanceHealth



42376
42377
42378
# File 'lib/google/apis/compute_alpha/classes.rb', line 42376

def instance_health
  @instance_health
end

#instance_statusString

Output only. [Output Only] The status of the instance. This field is empty when the instance does not exist. Corresponds to the JSON property instanceStatus

Returns:

  • (String)


42383
42384
42385
# File 'lib/google/apis/compute_alpha/classes.rb', line 42383

def instance_status
  @instance_status
end

#instance_templateString

Output only. [Output Only] The intended template of the instance. This field is empty when current_action is one of DELETING, ABANDONING. Corresponds to the JSON property instanceTemplate

Returns:

  • (String)


42390
42391
42392
# File 'lib/google/apis/compute_alpha/classes.rb', line 42390

def instance_template
  @instance_template
end

#last_attemptGoogle::Apis::ComputeAlpha::ManagedInstanceLastAttempt

Output only. [Output Only] Information about the last attempt to create or delete the instance. Corresponds to the JSON property lastAttempt



42397
42398
42399
# File 'lib/google/apis/compute_alpha/classes.rb', line 42397

def last_attempt
  @last_attempt
end

#nameString

Output only. [Output Only] The name of the instance. The name always exists even if the instance has not yet been created. Corresponds to the JSON property name

Returns:

  • (String)


42404
42405
42406
# File 'lib/google/apis/compute_alpha/classes.rb', line 42404

def name
  @name
end

#preserved_state_from_configGoogle::Apis::ComputeAlpha::PreservedState

Preserved state for a given instance. Corresponds to the JSON property preservedStateFromConfig



42409
42410
42411
# File 'lib/google/apis/compute_alpha/classes.rb', line 42409

def preserved_state_from_config
  @preserved_state_from_config
end

#preserved_state_from_policyGoogle::Apis::ComputeAlpha::PreservedState

Preserved state for a given instance. Corresponds to the JSON property preservedStateFromPolicy



42414
42415
42416
# File 'lib/google/apis/compute_alpha/classes.rb', line 42414

def preserved_state_from_policy
  @preserved_state_from_policy
end

#properties_from_flexibility_policyGoogle::Apis::ComputeAlpha::ManagedInstancePropertiesFromFlexibilityPolicy

Output only. [Output Only] Instance properties selected for this instance resulting from InstanceFlexibilityPolicy. Corresponds to the JSON property propertiesFromFlexibilityPolicy



42421
42422
42423
# File 'lib/google/apis/compute_alpha/classes.rb', line 42421

def properties_from_flexibility_policy
  @properties_from_flexibility_policy
end

#schedulingGoogle::Apis::ComputeAlpha::ManagedInstanceScheduling

Output only. Information about the termination timestamp of the instance, if applicable. Corresponds to the JSON property scheduling



42427
42428
42429
# File 'lib/google/apis/compute_alpha/classes.rb', line 42427

def scheduling
  @scheduling
end

#shutdown_detailsGoogle::Apis::ComputeAlpha::ManagedInstanceShutdownDetails

Output only. Specifies the graceful shutdown details if the instance is in PENDING_STOP state or there is a programmed stop scheduled. Corresponds to the JSON property shutdownDetails



42433
42434
42435
# File 'lib/google/apis/compute_alpha/classes.rb', line 42433

def shutdown_details
  @shutdown_details
end

#size_in_unitFloat

Output only. [Output only] The size of the VM represented by this Managed Instance. This is how much this Managed Instance contributes to the size of the group. Corresponds to the JSON property sizeInUnit

Returns:

  • (Float)


42441
42442
42443
# File 'lib/google/apis/compute_alpha/classes.rb', line 42441

def size_in_unit
  @size_in_unit
end

#tagString

Output only. [Output Only] Tag describing the version. Corresponds to the JSON property tag

Returns:

  • (String)


42446
42447
42448
# File 'lib/google/apis/compute_alpha/classes.rb', line 42446

def tag
  @tag
end

#target_statusString

Output only. [Output Only] The eventual status of the instance. The instance group manager will not be identified as stable till each managed instance reaches its targetStatus. Corresponds to the JSON property targetStatus

Returns:

  • (String)


42454
42455
42456
# File 'lib/google/apis/compute_alpha/classes.rb', line 42454

def target_status
  @target_status
end

#versionGoogle::Apis::ComputeAlpha::ManagedInstanceVersion

Output only. [Output Only] Intended version of this instance. Corresponds to the JSON property version



42459
42460
42461
# File 'lib/google/apis/compute_alpha/classes.rb', line 42459

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



42466
42467
42468
42469
42470
42471
42472
42473
42474
42475
42476
42477
42478
42479
42480
42481
42482
42483
42484
42485
42486
42487
# File 'lib/google/apis/compute_alpha/classes.rb', line 42466

def update!(**args)
  @all_instances_config = args[:all_instances_config] if args.key?(:all_instances_config)
  @current_action = args[:current_action] if args.key?(:current_action)
  @current_action_details = args[:current_action_details] if args.key?(:current_action_details)
  @id = args[:id] if args.key?(:id)
  @instance = args[:instance] if args.key?(:instance)
  @instance_flexibility_override = args[:instance_flexibility_override] if args.key?(:instance_flexibility_override)
  @instance_health = args[:instance_health] if args.key?(:instance_health)
  @instance_status = args[:instance_status] if args.key?(:instance_status)
  @instance_template = args[:instance_template] if args.key?(:instance_template)
  @last_attempt = args[:last_attempt] if args.key?(:last_attempt)
  @name = args[:name] if args.key?(:name)
  @preserved_state_from_config = args[:preserved_state_from_config] if args.key?(:preserved_state_from_config)
  @preserved_state_from_policy = args[:preserved_state_from_policy] if args.key?(:preserved_state_from_policy)
  @properties_from_flexibility_policy = args[:properties_from_flexibility_policy] if args.key?(:properties_from_flexibility_policy)
  @scheduling = args[:scheduling] if args.key?(:scheduling)
  @shutdown_details = args[:shutdown_details] if args.key?(:shutdown_details)
  @size_in_unit = args[:size_in_unit] if args.key?(:size_in_unit)
  @tag = args[:tag] if args.key?(:tag)
  @target_status = args[:target_status] if args.key?(:target_status)
  @version = args[:version] if args.key?(:version)
end