Class: Google::Apis::ComputeAlpha::ManagedInstanceInstanceFlexibilityOverride

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ManagedInstanceInstanceFlexibilityOverride

Returns a new instance of ManagedInstanceInstanceFlexibilityOverride.



42365
42366
42367
# File 'lib/google/apis/compute_alpha/classes.rb', line 42365

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#disksArray<Google::Apis::ComputeAlpha::AttachedDisk>

List of disks to be attached to the instance. Corresponds to the JSON property disks



42347
42348
42349
# File 'lib/google/apis/compute_alpha/classes.rb', line 42347

def disks
  @disks
end

#machine_typeString

The machine type to be used for this instance. Corresponds to the JSON property machineType

Returns:

  • (String)


42352
42353
42354
# File 'lib/google/apis/compute_alpha/classes.rb', line 42352

def machine_type
  @machine_type
end

#min_cpu_platformString

Name of the minimum CPU platform to be used by this instance. e.g. 'Intel Ice Lake'. Corresponds to the JSON property minCpuPlatform

Returns:

  • (String)


42358
42359
42360
# File 'lib/google/apis/compute_alpha/classes.rb', line 42358

def min_cpu_platform
  @min_cpu_platform
end

#provisioning_modelString

The provisioning model to be used for this instance. Corresponds to the JSON property provisioningModel

Returns:

  • (String)


42363
42364
42365
# File 'lib/google/apis/compute_alpha/classes.rb', line 42363

def provisioning_model
  @provisioning_model
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



42370
42371
42372
42373
42374
42375
# File 'lib/google/apis/compute_alpha/classes.rb', line 42370

def update!(**args)
  @disks = args[:disks] if args.key?(:disks)
  @machine_type = args[:machine_type] if args.key?(:machine_type)
  @min_cpu_platform = args[:min_cpu_platform] if args.key?(:min_cpu_platform)
  @provisioning_model = args[:provisioning_model] if args.key?(:provisioning_model)
end