Class: Google::Apis::ComputeAlpha::ManagedInstanceLastAttempt::Errors

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Output only. [Output Only] Encountered errors during the last attempt to create or delete the instance.

Defined Under Namespace

Classes: Error

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Errors

Returns a new instance of Errors.



41370
41371
41372
# File 'lib/google/apis/compute_alpha/classes.rb', line 41370

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#errorsArray<Google::Apis::ComputeAlpha::ManagedInstanceLastAttempt::Errors::Error>

[Output Only] The array of errors encountered while processing this operation. Corresponds to the JSON property errors



41368
41369
41370
# File 'lib/google/apis/compute_alpha/classes.rb', line 41368

def errors
  @errors
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



41375
41376
41377
# File 'lib/google/apis/compute_alpha/classes.rb', line 41375

def update!(**args)
  @errors = args[:errors] if args.key?(:errors)
end