Class: Google::Apis::ComputeAlpha::ManagedInstanceLastAttempt::Errors::Error

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: ErrorDetail

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Error

Returns a new instance of Error.



41202
41203
41204
# File 'lib/google/apis/compute_alpha/classes.rb', line 41202

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#codeString

[Output Only] The error type identifier for this error. Corresponds to the JSON property code

Returns:

  • (String)


41180
41181
41182
# File 'lib/google/apis/compute_alpha/classes.rb', line 41180

def code
  @code
end

#error_detailsArray<Google::Apis::ComputeAlpha::ManagedInstanceLastAttempt::Errors::Error::ErrorDetail>

[Output Only] An optional list of messages that contain the error details. There is a set of defined message types to use for providing details.The syntax depends on the error code. For example, QuotaExceededInfo will have details when the error code is QUOTA_EXCEEDED. Corresponds to the JSON property errorDetails



41189
41190
41191
# File 'lib/google/apis/compute_alpha/classes.rb', line 41189

def error_details
  @error_details
end

#locationString

[Output Only] Indicates the field in the request that caused the error. This property is optional. Corresponds to the JSON property location

Returns:

  • (String)


41195
41196
41197
# File 'lib/google/apis/compute_alpha/classes.rb', line 41195

def location
  @location
end

#messageString

[Output Only] An optional, human-readable error message. Corresponds to the JSON property message

Returns:

  • (String)


41200
41201
41202
# File 'lib/google/apis/compute_alpha/classes.rb', line 41200

def message
  @message
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



41207
41208
41209
41210
41211
41212
# File 'lib/google/apis/compute_alpha/classes.rb', line 41207

def update!(**args)
  @code = args[:code] if args.key?(:code)
  @error_details = args[:error_details] if args.key?(:error_details)
  @location = args[:location] if args.key?(:location)
  @message = args[:message] if args.key?(:message)
end