Class: Google::Apis::ComputeAlpha::ManagedInstanceLastAttempt::Errors::Error::ErrorDetail
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::ManagedInstanceLastAttempt::Errors::Error::ErrorDetail
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#error_info ⇒ Google::Apis::ComputeAlpha::ErrorInfo
Describes the cause of the error with structured details.
-
#help ⇒ Google::Apis::ComputeAlpha::Help
Provides links to documentation or for performing an out of band action.
-
#localized_message ⇒ Google::Apis::ComputeAlpha::LocalizedMessage
Provides a localized error message that is safe to return to the user which can be attached to an RPC error.
-
#quota_info ⇒ Google::Apis::ComputeAlpha::QuotaExceededInfo
Additional details for quota exceeded error for resource quota.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ErrorDetail
constructor
A new instance of ErrorDetail.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ErrorDetail
Returns a new instance of ErrorDetail.
40364 40365 40366 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 40364 def initialize(**args) update!(**args) end |
Instance Attribute Details
#error_info ⇒ Google::Apis::ComputeAlpha::ErrorInfo
Describes the cause of the error with structured details.
Example of an error when contacting the "pubsub.googleapis.com" API when it
is not enabled:
"reason": "API_DISABLED"
"domain": "googleapis.com"
"metadata":
"resource": "projects/123",
"service": "pubsub.googleapis.com"
This response indicates that the pubsub.googleapis.com API is not enabled.
Example of an error that is returned when attempting to create a Spanner
instance in a region that is out of stock:
"reason": "STOCKOUT"
"domain": "spanner.googleapis.com",
"metadata":
"availableRegions": "us-central1,us-east2"
Corresponds to the JSON property errorInfo
40343 40344 40345 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 40343 def error_info @error_info end |
#help ⇒ Google::Apis::ComputeAlpha::Help
Provides links to documentation or for performing an out of band action.
For example, if a quota check failed with an error indicating the calling
project hasn't enabled the accessed service, this can contain a URL pointing
directly to the right place in the developer console to flip the bit.
Corresponds to the JSON property help
40351 40352 40353 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 40351 def help @help end |
#localized_message ⇒ Google::Apis::ComputeAlpha::LocalizedMessage
Provides a localized error message that is safe to return to the user
which can be attached to an RPC error.
Corresponds to the JSON property localizedMessage
40357 40358 40359 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 40357 def @localized_message end |
#quota_info ⇒ Google::Apis::ComputeAlpha::QuotaExceededInfo
Additional details for quota exceeded error for resource quota.
Corresponds to the JSON property quotaInfo
40362 40363 40364 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 40362 def quota_info @quota_info end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
40369 40370 40371 40372 40373 40374 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 40369 def update!(**args) @error_info = args[:error_info] if args.key?(:error_info) @help = args[:help] if args.key?(:help) @localized_message = args[:localized_message] if args.key?(:localized_message) @quota_info = args[:quota_info] if args.key?(:quota_info) end |