Class: Google::Apis::ComputeAlpha::ManagedRuleset

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Represents a ManagedRuleset resource. Managed internally by Cloud Armor CLH for Managed Rules features. Customers can only view these resources to modify their Security Policies. For more information, see https://cloud.google.com/armor/docs/.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ManagedRuleset

Returns a new instance of ManagedRuleset.



42745
42746
42747
# File 'lib/google/apis/compute_alpha/classes.rb', line 42745

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#change_logString

Output only. [Output Only] The change log for this managed ruleset. Corresponds to the JSON property changeLog

Returns:

  • (String)


42697
42698
42699
# File 'lib/google/apis/compute_alpha/classes.rb', line 42697

def change_log
  @change_log
end

#creation_timestampString

Output only. [Output Only] Creation timestamp in RFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


42702
42703
42704
# File 'lib/google/apis/compute_alpha/classes.rb', line 42702

def creation_timestamp
  @creation_timestamp
end

#descriptionString

[Output Only] An optional description of this resource. Corresponds to the JSON property description

Returns:

  • (String)


42707
42708
42709
# File 'lib/google/apis/compute_alpha/classes.rb', line 42707

def description
  @description
end

#idFixnum

Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


42714
42715
42716
# File 'lib/google/apis/compute_alpha/classes.rb', line 42714

def id
  @id
end

#nameString

Name of the resource. Generated internally when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


42725
42726
42727
# File 'lib/google/apis/compute_alpha/classes.rb', line 42725

def name
  @name
end

#rule_idsArray<String>

Output only. [Output Only] The list of managed rule IDs that are included in this managed ruleset. Corresponds to the JSON property ruleIds

Returns:

  • (Array<String>)


42731
42732
42733
# File 'lib/google/apis/compute_alpha/classes.rb', line 42731

def rule_ids
  @rule_ids
end

#ruleset_idString

Output only. [Output Only] The managed ruleset identifier that can be configured in Security Policy rules. Corresponds to the JSON property rulesetId

Returns:

  • (String)


42738
42739
42740
# File 'lib/google/apis/compute_alpha/classes.rb', line 42738

def ruleset_id
  @ruleset_id
end

Output only. [Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


42743
42744
42745
# File 'lib/google/apis/compute_alpha/classes.rb', line 42743

def self_link
  @self_link
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



42750
42751
42752
42753
42754
42755
42756
42757
42758
42759
# File 'lib/google/apis/compute_alpha/classes.rb', line 42750

def update!(**args)
  @change_log = args[:change_log] if args.key?(:change_log)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @id = args[:id] if args.key?(:id)
  @name = args[:name] if args.key?(:name)
  @rule_ids = args[:rule_ids] if args.key?(:rule_ids)
  @ruleset_id = args[:ruleset_id] if args.key?(:ruleset_id)
  @self_link = args[:self_link] if args.key?(:self_link)
end