Class: Google::Apis::ComputeAlpha::MetadataCredentialsFromPlugin
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::MetadataCredentialsFromPlugin
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
[Deprecated] Custom authenticator credentials. Custom authenticator credentials.
Instance Attribute Summary collapse
-
#name ⇒ String
Plugin name.
-
#struct_config ⇒ String
A text proto that conforms to a Struct type definition interpreted by the plugin.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MetadataCredentialsFromPlugin
constructor
A new instance of MetadataCredentialsFromPlugin.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MetadataCredentialsFromPlugin
Returns a new instance of MetadataCredentialsFromPlugin.
42747 42748 42749 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 42747 def initialize(**args) update!(**args) end |
Instance Attribute Details
#name ⇒ String
Plugin name.
Corresponds to the JSON property name
42739 42740 42741 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 42739 def name @name end |
#struct_config ⇒ String
A text proto that conforms to a Struct type definition interpreted by the
plugin.
Corresponds to the JSON property structConfig
42745 42746 42747 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 42745 def struct_config @struct_config end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
42752 42753 42754 42755 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 42752 def update!(**args) @name = args[:name] if args.key?(:name) @struct_config = args[:struct_config] if args.key?(:struct_config) end |