Class: Google::Apis::ComputeAlpha::MetadataFilterLabelMatch
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::MetadataFilterLabelMatch
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
MetadataFilter label name value pairs that are expected to match corresponding labels presented as metadata to the load balancer.
Instance Attribute Summary collapse
-
#name ⇒ String
Name of metadata label.
-
#value ⇒ String
The value of the label must match the specified value.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MetadataFilterLabelMatch
constructor
A new instance of MetadataFilterLabelMatch.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MetadataFilterLabelMatch
Returns a new instance of MetadataFilterLabelMatch.
43105 43106 43107 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 43105 def initialize(**args) update!(**args) end |
Instance Attribute Details
#name ⇒ String
Name of metadata label.
The name can have a maximum length of 1024 characters and must be at
least 1 character long.
Corresponds to the JSON property name
43097 43098 43099 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 43097 def name @name end |
#value ⇒ String
The value of the label must match the specified value.
value can have a maximum length of 1024 characters.
Corresponds to the JSON property value
43103 43104 43105 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 43103 def value @value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
43110 43111 43112 43113 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 43110 def update!(**args) @name = args[:name] if args.key?(:name) @value = args[:value] if args.key?(:value) end |