Class: Google::Apis::ComputeAlpha::MultiMig
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::MultiMig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Multi-MIG represents a group of managed instance groups.
Instance Attribute Summary collapse
-
#creation_timestamp ⇒ String
Output only.
-
#description ⇒ String
An optional description of this resource.
-
#id ⇒ Fixnum
Output only.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
The name of the multi-MIG.
-
#region ⇒ String
Output only.
-
#resource_policies ⇒ Google::Apis::ComputeAlpha::MultiMigResourcePolicies
Resource policies message for a multi-MIG.
-
#self_link ⇒ String
Output only.
-
#status ⇒ Google::Apis::ComputeAlpha::MultiMigStatus
Corresponds to the JSON property
status.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MultiMig
constructor
A new instance of MultiMig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MultiMig
Returns a new instance of MultiMig.
42937 42938 42939 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 42937 def initialize(**args) update!(**args) end |
Instance Attribute Details
#creation_timestamp ⇒ String
Output only. [Output only] The creation timestamp of this multi-MIG in RFC3339
text format.
Corresponds to the JSON property creationTimestamp
42882 42883 42884 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 42882 def @creation_timestamp end |
#description ⇒ String
An optional description of this resource.
Corresponds to the JSON property description
42887 42888 42889 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 42887 def description @description end |
#id ⇒ Fixnum
Output only. [Output only] The unique identifier for this resource type. The
server
generates this identifier.
Corresponds to the JSON property id
42894 42895 42896 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 42894 def id @id end |
#kind ⇒ String
Output only. [Output only] Type of the resource. Alwayscompute#multiMig for
multi-MIGs.
Corresponds to the JSON property kind
42900 42901 42902 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 42900 def kind @kind end |
#name ⇒ String
The name of the multi-MIG.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character
must be a lowercase letter, and all following characters must be a dash,
lowercase letter, or digit, except the last character, which cannot be a
dash.
Corresponds to the JSON property name
42911 42912 42913 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 42911 def name @name end |
#region ⇒ String
Output only. [Output only] The URL of the region where the resource resides.
You must
specify this field as part of the HTTP request URL. You cannot set the
region as a field in the request body.
Corresponds to the JSON property region
42919 42920 42921 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 42919 def region @region end |
#resource_policies ⇒ Google::Apis::ComputeAlpha::MultiMigResourcePolicies
Resource policies message for a multi-MIG. Specifies the workload policy
configuration of the multi-MIG.
Corresponds to the JSON property resourcePolicies
42925 42926 42927 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 42925 def resource_policies @resource_policies end |
#self_link ⇒ String
Output only. [Output only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
42930 42931 42932 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 42930 def self_link @self_link end |
#status ⇒ Google::Apis::ComputeAlpha::MultiMigStatus
Corresponds to the JSON property status
42935 42936 42937 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 42935 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
42942 42943 42944 42945 42946 42947 42948 42949 42950 42951 42952 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 42942 def update!(**args) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @region = args[:region] if args.key?(:region) @resource_policies = args[:resource_policies] if args.key?(:resource_policies) @self_link = args[:self_link] if args.key?(:self_link) @status = args[:status] if args.key?(:status) end |