Class: Google::Apis::ComputeAlpha::MultiMigMemberList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MultiMigMemberList

Returns a new instance of MultiMigMemberList.



43558
43559
43560
# File 'lib/google/apis/compute_alpha/classes.rb', line 43558

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


43525
43526
43527
# File 'lib/google/apis/compute_alpha/classes.rb', line 43525

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::MultiMigMember>

A list of multi-MIG member resources. Corresponds to the JSON property items



43530
43531
43532
# File 'lib/google/apis/compute_alpha/classes.rb', line 43530

def items
  @items
end

#kindString

Output only. Type of the resource. Alwayscompute#multiMigMember for a list of multi-MIG members. Corresponds to the JSON property kind

Returns:

  • (String)


43536
43537
43538
# File 'lib/google/apis/compute_alpha/classes.rb', line 43536

def kind
  @kind
end

#next_page_tokenString

This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


43546
43547
43548
# File 'lib/google/apis/compute_alpha/classes.rb', line 43546

def next_page_token
  @next_page_token
end

Output only. [Output only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


43551
43552
43553
# File 'lib/google/apis/compute_alpha/classes.rb', line 43551

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::MultiMigMemberList::Warning

Informational warning message. Corresponds to the JSON property warning



43556
43557
43558
# File 'lib/google/apis/compute_alpha/classes.rb', line 43556

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



43563
43564
43565
43566
43567
43568
43569
43570
# File 'lib/google/apis/compute_alpha/classes.rb', line 43563

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end