Class: Google::Apis::ComputeAlpha::MultiMigStatusAcceleratorTopology

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MultiMigStatusAcceleratorTopology

Returns a new instance of MultiMigStatusAcceleratorTopology.



43521
43522
43523
# File 'lib/google/apis/compute_alpha/classes.rb', line 43521

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#accelerator_topologyString

Output only. [Output Only] Topology in the format of: "16x16", "4x4x4", etc. The value is the same as configured in the WorkloadPolicy. Corresponds to the JSON property acceleratorTopology

Returns:

  • (String)


43508
43509
43510
# File 'lib/google/apis/compute_alpha/classes.rb', line 43508

def accelerator_topology
  @accelerator_topology
end

#accelerator_topology_stateString

Output only. [Output Only] The state of the accelerator topology. Corresponds to the JSON property acceleratorTopologyState

Returns:

  • (String)


43513
43514
43515
# File 'lib/google/apis/compute_alpha/classes.rb', line 43513

def accelerator_topology_state
  @accelerator_topology_state
end

#accelerator_topology_state_last_checkGoogle::Apis::ComputeAlpha::MultiMigStatusAcceleratorTopologyAcceleratorTopologyStateLastCheck

Output only. [Output Only] The result of the latest accelerator topology state check. Corresponds to the JSON property acceleratorTopologyStateLastCheck



43519
43520
43521
# File 'lib/google/apis/compute_alpha/classes.rb', line 43519

def accelerator_topology_state_last_check
  @accelerator_topology_state_last_check
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



43526
43527
43528
43529
43530
# File 'lib/google/apis/compute_alpha/classes.rb', line 43526

def update!(**args)
  @accelerator_topology = args[:accelerator_topology] if args.key?(:accelerator_topology)
  @accelerator_topology_state = args[:accelerator_topology_state] if args.key?(:accelerator_topology_state)
  @accelerator_topology_state_last_check = args[:accelerator_topology_state_last_check] if args.key?(:accelerator_topology_state_last_check)
end