Class: Google::Apis::ComputeAlpha::MultiMigsList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MultiMigsList

Returns a new instance of MultiMigsList.



43946
43947
43948
# File 'lib/google/apis/compute_alpha/classes.rb', line 43946

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


43915
43916
43917
# File 'lib/google/apis/compute_alpha/classes.rb', line 43915

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::MultiMig>

A list of multi-MIGs in the specified project and region. Corresponds to the JSON property items



43920
43921
43922
# File 'lib/google/apis/compute_alpha/classes.rb', line 43920

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


43925
43926
43927
# File 'lib/google/apis/compute_alpha/classes.rb', line 43925

def kind
  @kind
end

#next_page_tokenString

This token allows you to get the next page of results formaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


43934
43935
43936
# File 'lib/google/apis/compute_alpha/classes.rb', line 43934

def next_page_token
  @next_page_token
end

Output only. [Output only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


43939
43940
43941
# File 'lib/google/apis/compute_alpha/classes.rb', line 43939

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::MultiMigsList::Warning

Informational warning message. Corresponds to the JSON property warning



43944
43945
43946
# File 'lib/google/apis/compute_alpha/classes.rb', line 43944

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



43951
43952
43953
43954
43955
43956
43957
43958
# File 'lib/google/apis/compute_alpha/classes.rb', line 43951

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end