Class: Google::Apis::ComputeAlpha::MutualTls
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::MutualTls
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
[Deprecated] Configuration for the mutual Tls mode for peer authentication. Configuration for the mutual Tls mode for peer authentication.
Instance Attribute Summary collapse
-
#mode ⇒ String
Specifies if the server TLS is configured to be strict or permissive.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MutualTls
constructor
A new instance of MutualTls.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MutualTls
Returns a new instance of MutualTls.
41347 41348 41349 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 41347 def initialize(**args) update!(**args) end |
Instance Attribute Details
#mode ⇒ String
Specifies if the server TLS is configured to be strict or permissive. This
field can be set to one of the following:
STRICT: Client certificate must be presented, connection is in TLS.
PERMISSIVE: Client certificate can be omitted, connection can be either
plaintext or TLS.
Corresponds to the JSON property mode
41345 41346 41347 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 41345 def mode @mode end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
41352 41353 41354 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 41352 def update!(**args) @mode = args[:mode] if args.key?(:mode) end |