Class: Google::Apis::ComputeAlpha::NetworkAttachmentList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkAttachmentList

Returns a new instance of NetworkAttachmentList.



44770
44771
44772
# File 'lib/google/apis/compute_alpha/classes.rb', line 44770

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


44738
44739
44740
# File 'lib/google/apis/compute_alpha/classes.rb', line 44738

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::NetworkAttachment>

A list of NetworkAttachment resources. Corresponds to the JSON property items



44743
44744
44745
# File 'lib/google/apis/compute_alpha/classes.rb', line 44743

def items
  @items
end

#kindString

Corresponds to the JSON property kind

Returns:

  • (String)


44748
44749
44750
# File 'lib/google/apis/compute_alpha/classes.rb', line 44748

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


44758
44759
44760
# File 'lib/google/apis/compute_alpha/classes.rb', line 44758

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


44763
44764
44765
# File 'lib/google/apis/compute_alpha/classes.rb', line 44763

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::NetworkAttachmentList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



44768
44769
44770
# File 'lib/google/apis/compute_alpha/classes.rb', line 44768

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



44775
44776
44777
44778
44779
44780
44781
44782
# File 'lib/google/apis/compute_alpha/classes.rb', line 44775

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end