Class: Google::Apis::ComputeAlpha::NetworkEdgeSecurityService
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::NetworkEdgeSecurityService
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Represents a Google Cloud Armor network edge security service resource.
Instance Attribute Summary collapse
-
#creation_timestamp ⇒ String
Output only.
-
#description ⇒ String
An optional description of this resource.
-
#fingerprint ⇒ String
Fingerprint of this resource.
-
#id ⇒ Fixnum
Output only.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
Name of the resource.
-
#region ⇒ String
Output only.
-
#security_policy ⇒ String
The resource URL for the network edge security service associated with this network edge security service.
-
#self_link ⇒ String
Output only.
-
#self_link_with_id ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NetworkEdgeSecurityService
constructor
A new instance of NetworkEdgeSecurityService.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NetworkEdgeSecurityService
Returns a new instance of NetworkEdgeSecurityService.
44527 44528 44529 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 44527 def initialize(**args) update!(**args) end |
Instance Attribute Details
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
44457 44458 44459 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 44457 def @creation_timestamp end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
44463 44464 44465 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 44463 def description @description end |
#fingerprint ⇒ String
Fingerprint of this resource. A hash of the contents stored in this object.
This field is used in optimistic locking. This field will be ignored when
inserting a NetworkEdgeSecurityService. An up-to-date fingerprint must be
provided in order to update the NetworkEdgeSecurityService,
otherwise the request will fail with error412 conditionNotMet.
To see the latest fingerprint, make a get() request to
retrieve a NetworkEdgeSecurityService.
Corresponds to the JSON property fingerprint
NOTE: Values are automatically base64 encoded/decoded in the client library.
44475 44476 44477 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 44475 def fingerprint @fingerprint end |
#id ⇒ Fixnum
Output only. [Output Only] The unique identifier for the resource. This
identifier is
defined by the server.
Corresponds to the JSON property id
44482 44483 44484 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 44482 def id @id end |
#kind ⇒ String
Output only. [Output only] Type of the resource. Alwayscompute#
networkEdgeSecurityService for
NetworkEdgeSecurityServices
Corresponds to the JSON property kind
44489 44490 44491 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 44489 def kind @kind end |
#name ⇒ String
Name of the resource. Provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must
be a dash, lowercase letter, or digit, except the last character, which
cannot be a dash.
Corresponds to the JSON property name
44500 44501 44502 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 44500 def name @name end |
#region ⇒ String
Output only. [Output Only] URL of the region where the resource resides. You
must
specify this field as part of the HTTP request URL. It is not settable as a
field in the request body.
Corresponds to the JSON property region
44508 44509 44510 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 44508 def region @region end |
#security_policy ⇒ String
The resource URL for the network edge security service associated with this
network edge security service.
Corresponds to the JSON property securityPolicy
44514 44515 44516 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 44514 def security_policy @security_policy end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
44519 44520 44521 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 44519 def self_link @self_link end |
#self_link_with_id ⇒ String
Output only. [Output Only] Server-defined URL for this resource with the
resource id.
Corresponds to the JSON property selfLinkWithId
44525 44526 44527 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 44525 def self_link_with_id @self_link_with_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
44532 44533 44534 44535 44536 44537 44538 44539 44540 44541 44542 44543 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 44532 def update!(**args) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @fingerprint = args[:fingerprint] if args.key?(:fingerprint) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @region = args[:region] if args.key?(:region) @security_policy = args[:security_policy] if args.key?(:security_policy) @self_link = args[:self_link] if args.key?(:self_link) @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id) end |