Class: Google::Apis::ComputeAlpha::NetworkEndpointGroupList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkEndpointGroupList

Returns a new instance of NetworkEndpointGroupList.



45951
45952
45953
# File 'lib/google/apis/compute_alpha/classes.rb', line 45951

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


45917
45918
45919
# File 'lib/google/apis/compute_alpha/classes.rb', line 45917

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::NetworkEndpointGroup>

A list of NetworkEndpointGroup resources. Corresponds to the JSON property items



45922
45923
45924
# File 'lib/google/apis/compute_alpha/classes.rb', line 45922

def items
  @items
end

#kindString

Output only. [Output Only] The resource type, which is alwayscompute# networkEndpointGroupList for network endpoint group lists. Corresponds to the JSON property kind

Returns:

  • (String)


45929
45930
45931
# File 'lib/google/apis/compute_alpha/classes.rb', line 45929

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


45939
45940
45941
# File 'lib/google/apis/compute_alpha/classes.rb', line 45939

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


45944
45945
45946
# File 'lib/google/apis/compute_alpha/classes.rb', line 45944

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::NetworkEndpointGroupList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



45949
45950
45951
# File 'lib/google/apis/compute_alpha/classes.rb', line 45949

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



45956
45957
45958
45959
45960
45961
45962
45963
# File 'lib/google/apis/compute_alpha/classes.rb', line 45956

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end