Class: Google::Apis::ComputeAlpha::NetworkEndpointGroupPscData

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

All data that is specifically relevant to only network endpoint groups of type PRIVATE_SERVICE_CONNECT.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkEndpointGroupPscData

Returns a new instance of NetworkEndpointGroupPscData.



43356
43357
43358
# File 'lib/google/apis/compute_alpha/classes.rb', line 43356

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#consumer_psc_addressString

Output only. [Output Only] Address allocated from given subnetwork for PSC. This IP address acts as a VIP for a PSC NEG, allowing it to act as an endpoint in L7 PSC-XLB. Corresponds to the JSON property consumerPscAddress

Returns:

  • (String)


43335
43336
43337
# File 'lib/google/apis/compute_alpha/classes.rb', line 43335

def consumer_psc_address
  @consumer_psc_address
end

#producer_portFixnum

The psc producer port is used to connect PSC NEG with specific port on the PSC Producer side; should only be used for the PRIVATE_SERVICE_CONNECT NEG type Corresponds to the JSON property producerPort

Returns:

  • (Fixnum)


43342
43343
43344
# File 'lib/google/apis/compute_alpha/classes.rb', line 43342

def producer_port
  @producer_port
end

#psc_connection_idFixnum

Output only. [Output Only] The PSC connection id of the PSC Network Endpoint Group Consumer. Corresponds to the JSON property pscConnectionId

Returns:

  • (Fixnum)


43349
43350
43351
# File 'lib/google/apis/compute_alpha/classes.rb', line 43349

def psc_connection_id
  @psc_connection_id
end

#psc_connection_statusString

Output only. [Output Only] The connection status of the PSC Forwarding Rule. Corresponds to the JSON property pscConnectionStatus

Returns:

  • (String)


43354
43355
43356
# File 'lib/google/apis/compute_alpha/classes.rb', line 43354

def psc_connection_status
  @psc_connection_status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



43361
43362
43363
43364
43365
43366
# File 'lib/google/apis/compute_alpha/classes.rb', line 43361

def update!(**args)
  @consumer_psc_address = args[:consumer_psc_address] if args.key?(:consumer_psc_address)
  @producer_port = args[:producer_port] if args.key?(:producer_port)
  @psc_connection_id = args[:psc_connection_id] if args.key?(:psc_connection_id)
  @psc_connection_status = args[:psc_connection_status] if args.key?(:psc_connection_status)
end