Class: Google::Apis::ComputeAlpha::NetworkEndpointGroupServerlessDeployment

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Configuration for a serverless network endpoint group (NEG). Theplatform must be provided. Note: The target backend service must be in the same project and located in the same region as the Serverless NEG.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkEndpointGroupServerlessDeployment

Returns a new instance of NetworkEndpointGroupServerlessDeployment.



45913
45914
45915
# File 'lib/google/apis/compute_alpha/classes.rb', line 45913

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#platformString

The platform of the backend target(s) of this NEG. The only supported value is API Gateway: apigateway.googleapis.com. Corresponds to the JSON property platform

Returns:

  • (String)


45869
45870
45871
# File 'lib/google/apis/compute_alpha/classes.rb', line 45869

def platform
  @platform
end

#resourceString

The user-defined name of the workload/instance. This value must be provided explicitly or in the urlMask. The resource identified by this value is platform-specific and is as follows:

  1. API Gateway: The gateway ID
  2. App Engine: The service name
  3. Cloud Functions: The function name
  4. Cloud Run: The service name Corresponds to the JSON property resource

Returns:

  • (String)


45882
45883
45884
# File 'lib/google/apis/compute_alpha/classes.rb', line 45882

def resource
  @resource
end

#url_maskString

An URL mask is one of the main components of the Cloud Function. A template to parse platform-specific fields from a request URL. URL mask allows for routing to multiple resources on the same serverless platform without having to create multiple Network Endpoint Groups and backend resources. The fields parsed by this template are platform-specific and are as follows:

  1. API Gateway: The gateway ID
  2. App Engine: The service and version
  3. Cloud Functions: The function name
  4. Cloud Run: The service and tag Corresponds to the JSON property urlMask

Returns:

  • (String)


45899
45900
45901
# File 'lib/google/apis/compute_alpha/classes.rb', line 45899

def url_mask
  @url_mask
end

#versionString

The optional resource version. The version identified by this value is platform-specific and is follows:

  1. API Gateway: Unused
  2. App Engine: The service version
  3. Cloud Functions: Unused
  4. Cloud Run: The service tag Corresponds to the JSON property version

Returns:

  • (String)


45911
45912
45913
# File 'lib/google/apis/compute_alpha/classes.rb', line 45911

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



45918
45919
45920
45921
45922
45923
# File 'lib/google/apis/compute_alpha/classes.rb', line 45918

def update!(**args)
  @platform = args[:platform] if args.key?(:platform)
  @resource = args[:resource] if args.key?(:resource)
  @url_mask = args[:url_mask] if args.key?(:url_mask)
  @version = args[:version] if args.key?(:version)
end