Class: Google::Apis::ComputeAlpha::NetworkEndpointGroupsScopedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkEndpointGroupsScopedList

Returns a new instance of NetworkEndpointGroupsScopedList.



46151
46152
46153
# File 'lib/google/apis/compute_alpha/classes.rb', line 46151

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#network_endpoint_groupsArray<Google::Apis::ComputeAlpha::NetworkEndpointGroup>

Output only. [Output Only] The list ofnetwork endpoint groups that are contained in this scope. Corresponds to the JSON property networkEndpointGroups



46142
46143
46144
# File 'lib/google/apis/compute_alpha/classes.rb', line 46142

def network_endpoint_groups
  @network_endpoint_groups
end

#warningGoogle::Apis::ComputeAlpha::NetworkEndpointGroupsScopedList::Warning

Output only. [Output Only] An informational warning that replaces the list of network endpoint groups when the list is empty. Corresponds to the JSON property warning



46149
46150
46151
# File 'lib/google/apis/compute_alpha/classes.rb', line 46149

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



46156
46157
46158
46159
# File 'lib/google/apis/compute_alpha/classes.rb', line 46156

def update!(**args)
  @network_endpoint_groups = args[:network_endpoint_groups] if args.key?(:network_endpoint_groups)
  @warning = args[:warning] if args.key?(:warning)
end