Class: Google::Apis::ComputeAlpha::NetworkFirewallPolicyAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkFirewallPolicyAggregatedList

Returns a new instance of NetworkFirewallPolicyAggregatedList.



46531
46532
46533
# File 'lib/google/apis/compute_alpha/classes.rb', line 46531

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


46492
46493
46494
# File 'lib/google/apis/compute_alpha/classes.rb', line 46492

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::FirewallPoliciesScopedList>

A list of FirewallPoliciesScopedList resources. Corresponds to the JSON property items



46497
46498
46499
# File 'lib/google/apis/compute_alpha/classes.rb', line 46497

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# networkFirewallPoliciesAggregatedList for lists of network firewall policies. Corresponds to the JSON property kind

Returns:

  • (String)


46504
46505
46506
# File 'lib/google/apis/compute_alpha/classes.rb', line 46504

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


46514
46515
46516
# File 'lib/google/apis/compute_alpha/classes.rb', line 46514

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


46519
46520
46521
# File 'lib/google/apis/compute_alpha/classes.rb', line 46519

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


46524
46525
46526
# File 'lib/google/apis/compute_alpha/classes.rb', line 46524

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::NetworkFirewallPolicyAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



46529
46530
46531
# File 'lib/google/apis/compute_alpha/classes.rb', line 46529

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



46536
46537
46538
46539
46540
46541
46542
46543
46544
# File 'lib/google/apis/compute_alpha/classes.rb', line 46536

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end