Class: Google::Apis::ComputeAlpha::NetworkPoliciesScopedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkPoliciesScopedList

Returns a new instance of NetworkPoliciesScopedList.



45807
45808
45809
# File 'lib/google/apis/compute_alpha/classes.rb', line 45807

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#network_policiesArray<Google::Apis::ComputeAlpha::NetworkPolicy>

A list of network policies contained in this scope. Corresponds to the JSON property networkPolicies



45799
45800
45801
# File 'lib/google/apis/compute_alpha/classes.rb', line 45799

def network_policies
  @network_policies
end

#warningGoogle::Apis::ComputeAlpha::NetworkPoliciesScopedList::Warning

Informational warning which replaces the list of network policies when the list is empty. Corresponds to the JSON property warning



45805
45806
45807
# File 'lib/google/apis/compute_alpha/classes.rb', line 45805

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



45812
45813
45814
45815
# File 'lib/google/apis/compute_alpha/classes.rb', line 45812

def update!(**args)
  @network_policies = args[:network_policies] if args.key?(:network_policies)
  @warning = args[:warning] if args.key?(:warning)
end