Class: Google::Apis::ComputeAlpha::NetworkPolicy
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::NetworkPolicy
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Represents a Network Policy resource.
Instance Attribute Summary collapse
-
#associations ⇒ Array<Google::Apis::ComputeAlpha::NetworkPolicyAssociation>
Output only.
-
#creation_timestamp ⇒ String
Output only.
-
#description ⇒ String
An optional description of this resource.
-
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
Name of the resource.
-
#region ⇒ String
Output only.
-
#rule_tuple_count ⇒ Fixnum
Output only.
-
#self_link ⇒ String
Output only.
-
#self_link_with_id ⇒ String
Output only.
-
#traffic_classification_rules ⇒ Array<Google::Apis::ComputeAlpha::NetworkPolicyTrafficClassificationRule>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NetworkPolicy
constructor
A new instance of NetworkPolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NetworkPolicy
Returns a new instance of NetworkPolicy.
47017 47018 47019 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 47017 def initialize(**args) update!(**args) end |
Instance Attribute Details
#associations ⇒ Array<Google::Apis::ComputeAlpha::NetworkPolicyAssociation>
Output only. [Output Only] A list of associations that belong to this network
policy.
Corresponds to the JSON property associations
46953 46954 46955 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 46953 def associations @associations end |
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
46959 46960 46961 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 46959 def @creation_timestamp end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
46965 46966 46967 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 46965 def description @description end |
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
46971 46972 46973 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 46971 def id @id end |
#kind ⇒ String
Output only. [Output only] Type of the resource. Alwayscompute#networkPolicy
for network policies
Corresponds to the JSON property kind
46977 46978 46979 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 46977 def kind @kind end |
#name ⇒ String
Name of the resource.
Corresponds to the JSON property name
46982 46983 46984 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 46982 def name @name end |
#region ⇒ String
Output only. [Output Only] URL of the region where the regional network policy
resides.
You must specify this field as part of the HTTP request URL. It is
not settable as a field in the request body.
Corresponds to the JSON property region
46990 46991 46992 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 46990 def region @region end |
#rule_tuple_count ⇒ Fixnum
Output only. [Output Only] Total count of all network policy rule tuples. A
network
policy can not exceed a set number of tuples.
Corresponds to the JSON property ruleTupleCount
46997 46998 46999 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 46997 def rule_tuple_count @rule_tuple_count end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
47002 47003 47004 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 47002 def self_link @self_link end |
#self_link_with_id ⇒ String
Output only. [Output Only] Server-defined URL for this resource with the
resource id.
Corresponds to the JSON property selfLinkWithId
47008 47009 47010 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 47008 def self_link_with_id @self_link_with_id end |
#traffic_classification_rules ⇒ Array<Google::Apis::ComputeAlpha::NetworkPolicyTrafficClassificationRule>
Output only. [Output Only] A list of traffic classification rules that belong
to this
policy.
Corresponds to the JSON property trafficClassificationRules
47015 47016 47017 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 47015 def traffic_classification_rules @traffic_classification_rules end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
47022 47023 47024 47025 47026 47027 47028 47029 47030 47031 47032 47033 47034 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 47022 def update!(**args) @associations = args[:associations] if args.key?(:associations) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @region = args[:region] if args.key?(:region) @rule_tuple_count = args[:rule_tuple_count] if args.key?(:rule_tuple_count) @self_link = args[:self_link] if args.key?(:self_link) @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id) @traffic_classification_rules = args[:traffic_classification_rules] if args.key?(:traffic_classification_rules) end |