Class: Google::Apis::ComputeAlpha::NetworkPolicyAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkPolicyAggregatedList

Returns a new instance of NetworkPolicyAggregatedList.



47603
47604
47605
# File 'lib/google/apis/compute_alpha/classes.rb', line 47603

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


47564
47565
47566
# File 'lib/google/apis/compute_alpha/classes.rb', line 47564

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::NetworkPoliciesScopedList>

A list of NetworkPoliciesScopedList resources. Corresponds to the JSON property items



47569
47570
47571
# File 'lib/google/apis/compute_alpha/classes.rb', line 47569

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# networkPolicyAggregatedList for lists of network policies. Corresponds to the JSON property kind

Returns:

  • (String)


47576
47577
47578
# File 'lib/google/apis/compute_alpha/classes.rb', line 47576

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


47586
47587
47588
# File 'lib/google/apis/compute_alpha/classes.rb', line 47586

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


47591
47592
47593
# File 'lib/google/apis/compute_alpha/classes.rb', line 47591

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


47596
47597
47598
# File 'lib/google/apis/compute_alpha/classes.rb', line 47596

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::NetworkPolicyAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



47601
47602
47603
# File 'lib/google/apis/compute_alpha/classes.rb', line 47601

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



47608
47609
47610
47611
47612
47613
47614
47615
47616
# File 'lib/google/apis/compute_alpha/classes.rb', line 47608

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end