Class: Google::Apis::ComputeAlpha::NetworkPolicyAssociation
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::NetworkPolicyAssociation
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#attachment_target ⇒ String
The target that the network policy is attached to.
-
#name ⇒ String
The name for an association.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NetworkPolicyAssociation
constructor
A new instance of NetworkPolicyAssociation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NetworkPolicyAssociation
Returns a new instance of NetworkPolicyAssociation.
45909 45910 45911 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 45909 def initialize(**args) update!(**args) end |
Instance Attribute Details
#attachment_target ⇒ String
The target that the network policy is attached to.
Corresponds to the JSON property attachmentTarget
45902 45903 45904 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 45902 def @attachment_target end |
#name ⇒ String
The name for an association.
Corresponds to the JSON property name
45907 45908 45909 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 45907 def name @name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
45914 45915 45916 45917 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 45914 def update!(**args) @attachment_target = args[:attachment_target] if args.key?(:attachment_target) @name = args[:name] if args.key?(:name) end |