Class: Google::Apis::ComputeAlpha::NetworkPolicyList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkPolicyList

Returns a new instance of NetworkPolicyList.



47749
47750
47751
# File 'lib/google/apis/compute_alpha/classes.rb', line 47749

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


47721
47722
47723
# File 'lib/google/apis/compute_alpha/classes.rb', line 47721

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::NetworkPolicy>

A list of NetworkPolicy resources. Corresponds to the JSON property items



47726
47727
47728
# File 'lib/google/apis/compute_alpha/classes.rb', line 47726

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute#networkPolicyList for lists of network policies. Corresponds to the JSON property kind

Returns:

  • (String)


47732
47733
47734
# File 'lib/google/apis/compute_alpha/classes.rb', line 47732

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


47742
47743
47744
# File 'lib/google/apis/compute_alpha/classes.rb', line 47742

def next_page_token
  @next_page_token
end

#warningGoogle::Apis::ComputeAlpha::NetworkPolicyList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



47747
47748
47749
# File 'lib/google/apis/compute_alpha/classes.rb', line 47747

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



47754
47755
47756
47757
47758
47759
47760
# File 'lib/google/apis/compute_alpha/classes.rb', line 47754

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @warning = args[:warning] if args.key?(:warning)
end