Class: Google::Apis::ComputeAlpha::NetworkProfilesListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of network profiles.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkProfilesListResponse

Returns a new instance of NetworkProfilesListResponse.



48538
48539
48540
# File 'lib/google/apis/compute_alpha/classes.rb', line 48538

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


48492
48493
48494
# File 'lib/google/apis/compute_alpha/classes.rb', line 48492

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


48497
48498
48499
# File 'lib/google/apis/compute_alpha/classes.rb', line 48497

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::NetworkProfile>

A list of NetworkProfile resources. Corresponds to the JSON property items



48502
48503
48504
# File 'lib/google/apis/compute_alpha/classes.rb', line 48502

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute#networkProfileList for network profiles. Corresponds to the JSON property kind

Returns:

  • (String)


48508
48509
48510
# File 'lib/google/apis/compute_alpha/classes.rb', line 48508

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


48520
48521
48522
# File 'lib/google/apis/compute_alpha/classes.rb', line 48520

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


48525
48526
48527
# File 'lib/google/apis/compute_alpha/classes.rb', line 48525

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


48531
48532
48533
# File 'lib/google/apis/compute_alpha/classes.rb', line 48531

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::NetworkProfilesListResponse::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



48536
48537
48538
# File 'lib/google/apis/compute_alpha/classes.rb', line 48536

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



48543
48544
48545
48546
48547
48548
48549
48550
48551
48552
# File 'lib/google/apis/compute_alpha/classes.rb', line 48543

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end