Class: Google::Apis::ComputeAlpha::NetworksGetEffectiveFirewallsResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworksGetEffectiveFirewallsResponse

Returns a new instance of NetworksGetEffectiveFirewallsResponse.



47213
47214
47215
# File 'lib/google/apis/compute_alpha/classes.rb', line 47213

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#firewall_policysArray<Google::Apis::ComputeAlpha::NetworksGetEffectiveFirewallsResponseEffectiveFirewallPolicy>

[Output Only] Effective firewalls from firewall policy. It returns Global Network Firewall Policies and Hierarchical Firewall Policies. UseregionNetworkFirewallPolicies.getEffectiveFirewalls to get Regional Network Firewall Policies as well. Corresponds to the JSON property firewallPolicys



47201
47202
47203
# File 'lib/google/apis/compute_alpha/classes.rb', line 47201

def firewall_policys
  @firewall_policys
end

#firewallsArray<Google::Apis::ComputeAlpha::Firewall>

Effective firewalls on the network. Corresponds to the JSON property firewalls



47206
47207
47208
# File 'lib/google/apis/compute_alpha/classes.rb', line 47206

def firewalls
  @firewalls
end

#organization_firewallsArray<Google::Apis::ComputeAlpha::NetworksGetEffectiveFirewallsResponseOrganizationFirewallPolicy>

Effective firewalls from organization policies. Corresponds to the JSON property organizationFirewalls



47211
47212
47213
# File 'lib/google/apis/compute_alpha/classes.rb', line 47211

def organization_firewalls
  @organization_firewalls
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



47218
47219
47220
47221
47222
# File 'lib/google/apis/compute_alpha/classes.rb', line 47218

def update!(**args)
  @firewall_policys = args[:firewall_policys] if args.key?(:firewall_policys)
  @firewalls = args[:firewalls] if args.key?(:firewalls)
  @organization_firewalls = args[:organization_firewalls] if args.key?(:organization_firewalls)
end