Class: Google::Apis::ComputeAlpha::NetworksUpdatePeeringRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworksUpdatePeeringRequest

Returns a new instance of NetworksUpdatePeeringRequest.



48704
48705
48706
# File 'lib/google/apis/compute_alpha/classes.rb', line 48704

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#network_peeringGoogle::Apis::ComputeAlpha::NetworkPeering

A network peering attached to a network resource. The message includes the peering name, peer network, peering state, and a flag indicating whether Google Compute Engine should automatically create routes for the peering. Corresponds to the JSON property networkPeering



48702
48703
48704
# File 'lib/google/apis/compute_alpha/classes.rb', line 48702

def network_peering
  @network_peering
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



48709
48710
48711
# File 'lib/google/apis/compute_alpha/classes.rb', line 48709

def update!(**args)
  @network_peering = args[:network_peering] if args.key?(:network_peering)
end