Class: Google::Apis::ComputeAlpha::NodeGroupMaintenanceWindow

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Time window specified for daily maintenance operations. GCE's internal maintenance will be performed within this window.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NodeGroupMaintenanceWindow

Returns a new instance of NodeGroupMaintenanceWindow.



49424
49425
49426
# File 'lib/google/apis/compute_alpha/classes.rb', line 49424

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#durationString

Output only. [Output only] A predetermined duration for the window, automatically chosen to be the smallest possible in the given scenario. Corresponds to the JSON property duration

Returns:

  • (String)


49407
49408
49409
# File 'lib/google/apis/compute_alpha/classes.rb', line 49407

def duration
  @duration
end

#maintenance_durationGoogle::Apis::ComputeAlpha::Duration

A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution. It is independent of any calendar and concepts like "day" or "month". Range is approximately 10,000 years. Corresponds to the JSON property maintenanceDuration



49415
49416
49417
# File 'lib/google/apis/compute_alpha/classes.rb', line 49415

def maintenance_duration
  @maintenance_duration
end

#start_timeString

Start time of the window. This must be in UTC format that resolves to one of 00:00, 04:00, 08:00,12:00, 16:00, or 20:00. For example, both 13:00-5 and 08:00 are valid. Corresponds to the JSON property startTime

Returns:

  • (String)


49422
49423
49424
# File 'lib/google/apis/compute_alpha/classes.rb', line 49422

def start_time
  @start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



49429
49430
49431
49432
49433
# File 'lib/google/apis/compute_alpha/classes.rb', line 49429

def update!(**args)
  @duration = args[:duration] if args.key?(:duration)
  @maintenance_duration = args[:maintenance_duration] if args.key?(:maintenance_duration)
  @start_time = args[:start_time] if args.key?(:start_time)
end