Class: Google::Apis::ComputeAlpha::NodeGroupsListNodes

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NodeGroupsListNodes

Returns a new instance of NodeGroupsListNodes.



49615
49616
49617
# File 'lib/google/apis/compute_alpha/classes.rb', line 49615

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Output only. [Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


49580
49581
49582
# File 'lib/google/apis/compute_alpha/classes.rb', line 49580

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::NodeGroupNode>

A list of Node resources. Corresponds to the JSON property items



49585
49586
49587
# File 'lib/google/apis/compute_alpha/classes.rb', line 49585

def items
  @items
end

#kindString

Output only. [Output Only] The resource type, which is alwayscompute. nodeGroupsListNodes for the list of nodes in the specified node group. Corresponds to the JSON property kind

Returns:

  • (String)


49592
49593
49594
# File 'lib/google/apis/compute_alpha/classes.rb', line 49592

def kind
  @kind
end

#next_page_tokenString

Output only. [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


49603
49604
49605
# File 'lib/google/apis/compute_alpha/classes.rb', line 49603

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


49608
49609
49610
# File 'lib/google/apis/compute_alpha/classes.rb', line 49608

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::NodeGroupsListNodes::Warning

Output only. [Output Only] Informational warning message. Corresponds to the JSON property warning



49613
49614
49615
# File 'lib/google/apis/compute_alpha/classes.rb', line 49613

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



49620
49621
49622
49623
49624
49625
49626
49627
# File 'lib/google/apis/compute_alpha/classes.rb', line 49620

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end