Class: Google::Apis::ComputeAlpha::NodeTemplateList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of node templates.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NodeTemplateList

Returns a new instance of NodeTemplateList.



50176
50177
50178
# File 'lib/google/apis/compute_alpha/classes.rb', line 50176

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


50143
50144
50145
# File 'lib/google/apis/compute_alpha/classes.rb', line 50143

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::NodeTemplate>

A list of NodeTemplate resources. Corresponds to the JSON property items



50148
50149
50150
# File 'lib/google/apis/compute_alpha/classes.rb', line 50148

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource.Always compute#nodeTemplateList for lists of node templates. Corresponds to the JSON property kind

Returns:

  • (String)


50154
50155
50156
# File 'lib/google/apis/compute_alpha/classes.rb', line 50154

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


50164
50165
50166
# File 'lib/google/apis/compute_alpha/classes.rb', line 50164

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


50169
50170
50171
# File 'lib/google/apis/compute_alpha/classes.rb', line 50169

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::NodeTemplateList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



50174
50175
50176
# File 'lib/google/apis/compute_alpha/classes.rb', line 50174

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



50181
50182
50183
50184
50185
50186
50187
50188
# File 'lib/google/apis/compute_alpha/classes.rb', line 50181

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end