Class: Google::Apis::ComputeAlpha::Operation::Error::Error

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: ErrorDetail

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Error

Returns a new instance of Error.



49621
49622
49623
# File 'lib/google/apis/compute_alpha/classes.rb', line 49621

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#codeString

[Output Only] The error type identifier for this error. Corresponds to the JSON property code

Returns:

  • (String)


49599
49600
49601
# File 'lib/google/apis/compute_alpha/classes.rb', line 49599

def code
  @code
end

#error_detailsArray<Google::Apis::ComputeAlpha::Operation::Error::Error::ErrorDetail>

[Output Only] An optional list of messages that contain the error details. There is a set of defined message types to use for providing details.The syntax depends on the error code. For example, QuotaExceededInfo will have details when the error code is QUOTA_EXCEEDED. Corresponds to the JSON property errorDetails



49608
49609
49610
# File 'lib/google/apis/compute_alpha/classes.rb', line 49608

def error_details
  @error_details
end

#locationString

[Output Only] Indicates the field in the request that caused the error. This property is optional. Corresponds to the JSON property location

Returns:

  • (String)


49614
49615
49616
# File 'lib/google/apis/compute_alpha/classes.rb', line 49614

def location
  @location
end

#messageString

[Output Only] An optional, human-readable error message. Corresponds to the JSON property message

Returns:

  • (String)


49619
49620
49621
# File 'lib/google/apis/compute_alpha/classes.rb', line 49619

def message
  @message
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



49626
49627
49628
49629
49630
49631
# File 'lib/google/apis/compute_alpha/classes.rb', line 49626

def update!(**args)
  @code = args[:code] if args.key?(:code)
  @error_details = args[:error_details] if args.key?(:error_details)
  @location = args[:location] if args.key?(:location)
  @message = args[:message] if args.key?(:message)
end