Class: Google::Apis::ComputeAlpha::Operation::Error::Error::ErrorDetail

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ErrorDetail

Returns a new instance of ErrorDetail.



49679
49680
49681
# File 'lib/google/apis/compute_alpha/classes.rb', line 49679

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#error_infoGoogle::Apis::ComputeAlpha::ErrorInfo

Describes the cause of the error with structured details. Example of an error when contacting the "pubsub.googleapis.com" API when it is not enabled: "reason": "API_DISABLED" "domain": "googleapis.com" "metadata": "resource": "projects/123", "service": "pubsub.googleapis.com" This response indicates that the pubsub.googleapis.com API is not enabled. Example of an error that is returned when attempting to create a Spanner instance in a region that is out of stock: "reason": "STOCKOUT" "domain": "spanner.googleapis.com", "metadata": "availableRegions": "us-central1,us-east2" Corresponds to the JSON property errorInfo



49658
49659
49660
# File 'lib/google/apis/compute_alpha/classes.rb', line 49658

def error_info
  @error_info
end

#helpGoogle::Apis::ComputeAlpha::Help

Provides links to documentation or for performing an out of band action. For example, if a quota check failed with an error indicating the calling project hasn't enabled the accessed service, this can contain a URL pointing directly to the right place in the developer console to flip the bit. Corresponds to the JSON property help



49666
49667
49668
# File 'lib/google/apis/compute_alpha/classes.rb', line 49666

def help
  @help
end

#localized_messageGoogle::Apis::ComputeAlpha::LocalizedMessage

Provides a localized error message that is safe to return to the user which can be attached to an RPC error. Corresponds to the JSON property localizedMessage



49672
49673
49674
# File 'lib/google/apis/compute_alpha/classes.rb', line 49672

def localized_message
  @localized_message
end

#quota_infoGoogle::Apis::ComputeAlpha::QuotaExceededInfo

Additional details for quota exceeded error for resource quota. Corresponds to the JSON property quotaInfo



49677
49678
49679
# File 'lib/google/apis/compute_alpha/classes.rb', line 49677

def quota_info
  @quota_info
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



49684
49685
49686
49687
49688
49689
# File 'lib/google/apis/compute_alpha/classes.rb', line 49684

def update!(**args)
  @error_info = args[:error_info] if args.key?(:error_info)
  @help = args[:help] if args.key?(:help)
  @localized_message = args[:localized_message] if args.key?(:localized_message)
  @quota_info = args[:quota_info] if args.key?(:quota_info)
end