Class: Google::Apis::ComputeAlpha::OperationAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OperationAggregatedList

Returns a new instance of OperationAggregatedList.



51830
51831
51832
# File 'lib/google/apis/compute_alpha/classes.rb', line 51830

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


51791
51792
51793
# File 'lib/google/apis/compute_alpha/classes.rb', line 51791

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::OperationsScopedList>

[Output Only] A map of scoped operation lists. Corresponds to the JSON property items



51796
51797
51798
# File 'lib/google/apis/compute_alpha/classes.rb', line 51796

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute# operationAggregatedList for aggregated lists of operations. Corresponds to the JSON property kind

Returns:

  • (String)


51803
51804
51805
# File 'lib/google/apis/compute_alpha/classes.rb', line 51803

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


51813
51814
51815
# File 'lib/google/apis/compute_alpha/classes.rb', line 51813

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


51818
51819
51820
# File 'lib/google/apis/compute_alpha/classes.rb', line 51818

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


51823
51824
51825
# File 'lib/google/apis/compute_alpha/classes.rb', line 51823

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::OperationAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



51828
51829
51830
# File 'lib/google/apis/compute_alpha/classes.rb', line 51828

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



51835
51836
51837
51838
51839
51840
51841
51842
51843
# File 'lib/google/apis/compute_alpha/classes.rb', line 51835

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end