Class: Google::Apis::ComputeAlpha::OutlierDetection

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Settings controlling the eviction of unhealthy hosts from the load balancing pool for the backend service.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OutlierDetection

Returns a new instance of OutlierDetection.



52312
52313
52314
# File 'lib/google/apis/compute_alpha/classes.rb', line 52312

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#base_ejection_timeGoogle::Apis::ComputeAlpha::Duration

A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution. It is independent of any calendar and concepts like "day" or "month". Range is approximately 10,000 years. Corresponds to the JSON property baseEjectionTime



52227
52228
52229
# File 'lib/google/apis/compute_alpha/classes.rb', line 52227

def base_ejection_time
  @base_ejection_time
end

#consecutive_errorsFixnum

Number of consecutive errors before a backend endpoint is ejected from the load balancing pool. When the backend endpoint is accessed over HTTP, a 5xx return code qualifies as an error. Defaults to 5. Corresponds to the JSON property consecutiveErrors

Returns:

  • (Fixnum)


52234
52235
52236
# File 'lib/google/apis/compute_alpha/classes.rb', line 52234

def consecutive_errors
  @consecutive_errors
end

#consecutive_gateway_failureFixnum

The number of consecutive gateway failures (502, 503, 504 status or connection errors that are mapped to one of those status codes) before a consecutive gateway failure ejection occurs. Defaults to 3. Corresponds to the JSON property consecutiveGatewayFailure

Returns:

  • (Fixnum)


52241
52242
52243
# File 'lib/google/apis/compute_alpha/classes.rb', line 52241

def consecutive_gateway_failure
  @consecutive_gateway_failure
end

#enforcing_consecutive_errorsFixnum

The percentage chance that a backend endpoint will be ejected when an outlier status is detected through consecutive 5xx. This setting can be used to disable ejection or to ramp it up slowly. Defaults to 0. Corresponds to the JSON property enforcingConsecutiveErrors

Returns:

  • (Fixnum)


52248
52249
52250
# File 'lib/google/apis/compute_alpha/classes.rb', line 52248

def enforcing_consecutive_errors
  @enforcing_consecutive_errors
end

#enforcing_consecutive_gateway_failureFixnum

The percentage chance that a backend endpoint will be ejected when an outlier status is detected through consecutive gateway failures. This setting can be used to disable ejection or to ramp it up slowly. Defaults to 100. Corresponds to the JSON property enforcingConsecutiveGatewayFailure

Returns:

  • (Fixnum)


52256
52257
52258
# File 'lib/google/apis/compute_alpha/classes.rb', line 52256

def enforcing_consecutive_gateway_failure
  @enforcing_consecutive_gateway_failure
end

#enforcing_success_rateFixnum

The percentage chance that a backend endpoint will be ejected when an outlier status is detected through success rate statistics. This setting can be used to disable ejection or to ramp it up slowly. Defaults to 100. Not supported when the backend service uses Serverless NEG. Corresponds to the JSON property enforcingSuccessRate

Returns:

  • (Fixnum)


52264
52265
52266
# File 'lib/google/apis/compute_alpha/classes.rb', line 52264

def enforcing_success_rate
  @enforcing_success_rate
end

#intervalGoogle::Apis::ComputeAlpha::Duration

A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution. It is independent of any calendar and concepts like "day" or "month". Range is approximately 10,000 years. Corresponds to the JSON property interval



52272
52273
52274
# File 'lib/google/apis/compute_alpha/classes.rb', line 52272

def interval
  @interval
end

#max_ejection_percentFixnum

Maximum percentage of backend endpoints in the load balancing pool for the backend service that can be ejected if the ejection conditions are met. Defaults to 50%. Corresponds to the JSON property maxEjectionPercent

Returns:

  • (Fixnum)


52279
52280
52281
# File 'lib/google/apis/compute_alpha/classes.rb', line 52279

def max_ejection_percent
  @max_ejection_percent
end

#success_rate_minimum_hostsFixnum

The number of backend endpoints in the load balancing pool that must have enough request volume to detect success rate outliers. If the number of backend endpoints is fewer than this setting, outlier detection via success rate statistics is not performed for any backend endpoint in the load balancing pool. Defaults to 5. Not supported when the backend service uses Serverless NEG. Corresponds to the JSON property successRateMinimumHosts

Returns:

  • (Fixnum)


52289
52290
52291
# File 'lib/google/apis/compute_alpha/classes.rb', line 52289

def success_rate_minimum_hosts
  @success_rate_minimum_hosts
end

#success_rate_request_volumeFixnum

The minimum number of total requests that must be collected in one interval (as defined by the interval duration above) to include this backend endpoint in success rate based outlier detection. If the volume is lower than this setting, outlier detection via success rate statistics is not performed for that backend endpoint. Defaults to 100. Not supported when the backend service uses Serverless NEG. Corresponds to the JSON property successRateRequestVolume

Returns:

  • (Fixnum)


52299
52300
52301
# File 'lib/google/apis/compute_alpha/classes.rb', line 52299

def success_rate_request_volume
  @success_rate_request_volume
end

#success_rate_stdev_factorFixnum

This factor is used to determine the ejection threshold for success rate outlier ejection. The ejection threshold is the difference between the mean success rate, and the product of this factor and the standard deviation of the mean success rate: mean - (stdev * successRateStdevFactor). This factor is divided by a thousand to get a double. That is, if the desired factor is 1.9, the runtime value should be 1900. Defaults to 1900. Not supported when the backend service uses Serverless NEG. Corresponds to the JSON property successRateStdevFactor

Returns:

  • (Fixnum)


52310
52311
52312
# File 'lib/google/apis/compute_alpha/classes.rb', line 52310

def success_rate_stdev_factor
  @success_rate_stdev_factor
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



52317
52318
52319
52320
52321
52322
52323
52324
52325
52326
52327
52328
52329
# File 'lib/google/apis/compute_alpha/classes.rb', line 52317

def update!(**args)
  @base_ejection_time = args[:base_ejection_time] if args.key?(:base_ejection_time)
  @consecutive_errors = args[:consecutive_errors] if args.key?(:consecutive_errors)
  @consecutive_gateway_failure = args[:consecutive_gateway_failure] if args.key?(:consecutive_gateway_failure)
  @enforcing_consecutive_errors = args[:enforcing_consecutive_errors] if args.key?(:enforcing_consecutive_errors)
  @enforcing_consecutive_gateway_failure = args[:enforcing_consecutive_gateway_failure] if args.key?(:enforcing_consecutive_gateway_failure)
  @enforcing_success_rate = args[:enforcing_success_rate] if args.key?(:enforcing_success_rate)
  @interval = args[:interval] if args.key?(:interval)
  @max_ejection_percent = args[:max_ejection_percent] if args.key?(:max_ejection_percent)
  @success_rate_minimum_hosts = args[:success_rate_minimum_hosts] if args.key?(:success_rate_minimum_hosts)
  @success_rate_request_volume = args[:success_rate_request_volume] if args.key?(:success_rate_request_volume)
  @success_rate_stdev_factor = args[:success_rate_stdev_factor] if args.key?(:success_rate_stdev_factor)
end