Class: Google::Apis::ComputeAlpha::PacketIntervals
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::PacketIntervals
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Next free: 7
Instance Attribute Summary collapse
-
#avg_ms ⇒ Fixnum
Average observed inter-packet interval in milliseconds.
-
#duration ⇒ String
From how long ago in the past these intervals were observed.
-
#max_ms ⇒ Fixnum
Maximum observed inter-packet interval in milliseconds.
-
#min_ms ⇒ Fixnum
Minimum observed inter-packet interval in milliseconds.
-
#num_intervals ⇒ Fixnum
Number of inter-packet intervals from which these statistics were derived.
-
#type ⇒ String
The type of packets for which inter-packet intervals were computed.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PacketIntervals
constructor
A new instance of PacketIntervals.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PacketIntervals
Returns a new instance of PacketIntervals.
52607 52608 52609 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 52607 def initialize(**args) update!(**args) end |
Instance Attribute Details
#avg_ms ⇒ Fixnum
Average observed inter-packet interval in milliseconds.
Corresponds to the JSON property avgMs
52580 52581 52582 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 52580 def avg_ms @avg_ms end |
#duration ⇒ String
From how long ago in the past these intervals were observed.
Corresponds to the JSON property duration
52585 52586 52587 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 52585 def duration @duration end |
#max_ms ⇒ Fixnum
Maximum observed inter-packet interval in milliseconds.
Corresponds to the JSON property maxMs
52590 52591 52592 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 52590 def max_ms @max_ms end |
#min_ms ⇒ Fixnum
Minimum observed inter-packet interval in milliseconds.
Corresponds to the JSON property minMs
52595 52596 52597 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 52595 def min_ms @min_ms end |
#num_intervals ⇒ Fixnum
Number of inter-packet intervals from which these statistics were derived.
Corresponds to the JSON property numIntervals
52600 52601 52602 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 52600 def num_intervals @num_intervals end |
#type ⇒ String
The type of packets for which inter-packet intervals were computed.
Corresponds to the JSON property type
52605 52606 52607 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 52605 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
52612 52613 52614 52615 52616 52617 52618 52619 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 52612 def update!(**args) @avg_ms = args[:avg_ms] if args.key?(:avg_ms) @duration = args[:duration] if args.key?(:duration) @max_ms = args[:max_ms] if args.key?(:max_ms) @min_ms = args[:min_ms] if args.key?(:min_ms) @num_intervals = args[:num_intervals] if args.key?(:num_intervals) @type = args[:type] if args.key?(:type) end |