Class: Google::Apis::ComputeAlpha::PacketMirroring

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Represents a Packet Mirroring resource. Packet Mirroring clones the traffic of specified instances in your Virtual Private Cloud (VPC) network and forwards it to a collector destination, such as an instance group of an internal TCP/UDP load balancer, for analysis or examination. For more information about setting up Packet Mirroring, seeUsing Packet Mirroring.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PacketMirroring

Returns a new instance of PacketMirroring.



52729
52730
52731
# File 'lib/google/apis/compute_alpha/classes.rb', line 52729

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#collector_ilbGoogle::Apis::ComputeAlpha::PacketMirroringForwardingRuleInfo

The Forwarding Rule resource of typeloadBalancingScheme=INTERNAL that will be used as collector for mirrored traffic. The specified forwarding rule must have isMirroringCollector set to true. Corresponds to the JSON property collectorIlb



52639
52640
52641
# File 'lib/google/apis/compute_alpha/classes.rb', line 52639

def collector_ilb
  @collector_ilb
end

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


52645
52646
52647
# File 'lib/google/apis/compute_alpha/classes.rb', line 52645

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


52651
52652
52653
# File 'lib/google/apis/compute_alpha/classes.rb', line 52651

def description
  @description
end

#enableString

Indicates whether or not this packet mirroring takes effect. If set to FALSE, this packet mirroring policy will not be enforced on the network. The default is TRUE. Corresponds to the JSON property enable

Returns:

  • (String)


52659
52660
52661
# File 'lib/google/apis/compute_alpha/classes.rb', line 52659

def enable
  @enable
end

#filterGoogle::Apis::ComputeAlpha::PacketMirroringFilter

Filter for mirrored traffic. If unspecified, all IPv4 traffic is mirrored. Corresponds to the JSON property filter



52664
52665
52666
# File 'lib/google/apis/compute_alpha/classes.rb', line 52664

def filter
  @filter
end

#idFixnum

Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


52671
52672
52673
# File 'lib/google/apis/compute_alpha/classes.rb', line 52671

def id
  @id
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute#packetMirroring for packet mirrorings. Corresponds to the JSON property kind

Returns:

  • (String)


52677
52678
52679
# File 'lib/google/apis/compute_alpha/classes.rb', line 52677

def kind
  @kind
end

#mirrored_resourcesGoogle::Apis::ComputeAlpha::PacketMirroringMirroredResourceInfo

PacketMirroring mirroredResourceInfos. MirroredResourceInfo specifies a set of mirrored VM instances, subnetworks and/or tags for which traffic from/to all VM instances will be mirrored. Corresponds to the JSON property mirroredResources



52684
52685
52686
# File 'lib/google/apis/compute_alpha/classes.rb', line 52684

def mirrored_resources
  @mirrored_resources
end

#nameString

Name of the resource; provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


52695
52696
52697
# File 'lib/google/apis/compute_alpha/classes.rb', line 52695

def name
  @name
end

#networkGoogle::Apis::ComputeAlpha::PacketMirroringNetworkInfo

Specifies the mirrored VPC network. Only packets in this network will be mirrored. All mirrored VMs should have a NIC in the given network. All mirrored subnetworks should belong to the given network. Corresponds to the JSON property network



52702
52703
52704
# File 'lib/google/apis/compute_alpha/classes.rb', line 52702

def network
  @network
end

#priorityFixnum

The priority of applying this configuration. Priority is used to break ties in cases where there is more than one matching rule. In the case of two rules that apply for a given Instance, the one with the lowest-numbered priority value wins. Default value is 1000. Valid range is 0 through 65535. Corresponds to the JSON property priority

Returns:

  • (Fixnum)


52711
52712
52713
# File 'lib/google/apis/compute_alpha/classes.rb', line 52711

def priority
  @priority
end

#regionString

[Output Only] URI of the region where the packetMirroring resides. Corresponds to the JSON property region

Returns:

  • (String)


52716
52717
52718
# File 'lib/google/apis/compute_alpha/classes.rb', line 52716

def region
  @region
end

Output only. [Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


52721
52722
52723
# File 'lib/google/apis/compute_alpha/classes.rb', line 52721

def self_link
  @self_link
end

Output only. [Output Only] Server-defined URL for this resource with the resource id. Corresponds to the JSON property selfLinkWithId

Returns:

  • (String)


52727
52728
52729
# File 'lib/google/apis/compute_alpha/classes.rb', line 52727

def self_link_with_id
  @self_link_with_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



52734
52735
52736
52737
52738
52739
52740
52741
52742
52743
52744
52745
52746
52747
52748
52749
# File 'lib/google/apis/compute_alpha/classes.rb', line 52734

def update!(**args)
  @collector_ilb = args[:collector_ilb] if args.key?(:collector_ilb)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @enable = args[:enable] if args.key?(:enable)
  @filter = args[:filter] if args.key?(:filter)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @mirrored_resources = args[:mirrored_resources] if args.key?(:mirrored_resources)
  @name = args[:name] if args.key?(:name)
  @network = args[:network] if args.key?(:network)
  @priority = args[:priority] if args.key?(:priority)
  @region = args[:region] if args.key?(:region)
  @self_link = args[:self_link] if args.key?(:self_link)
  @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id)
end