Class: Google::Apis::ComputeAlpha::PacketMirroringAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::PacketMirroringAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Contains a list of packetMirrorings.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::PacketMirroringsScopedList>
A list of PacketMirroring resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::PacketMirroringAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PacketMirroringAggregatedList
constructor
A new instance of PacketMirroringAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PacketMirroringAggregatedList
Returns a new instance of PacketMirroringAggregatedList.
52796 52797 52798 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 52796 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
52759 52760 52761 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 52759 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::PacketMirroringsScopedList>
A list of PacketMirroring resources.
Corresponds to the JSON property items
52764 52765 52766 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 52764 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
52769 52770 52771 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 52769 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
52779 52780 52781 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 52779 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
52784 52785 52786 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 52784 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
52789 52790 52791 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 52789 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::PacketMirroringAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
52794 52795 52796 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 52794 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
52801 52802 52803 52804 52805 52806 52807 52808 52809 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 52801 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |