Class: Google::Apis::ComputeAlpha::PartnerMetadata
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::PartnerMetadata
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Model definition of partner_metadata field. To be used in dedicated Partner Metadata methods and to be inlined in the Instance and InstanceTemplate resources.
Instance Attribute Summary collapse
-
#fingerprint ⇒ String
Instance-level hash to be used for optimistic locking.
-
#partner_metadata ⇒ Hash<String,Google::Apis::ComputeAlpha::StructuredEntries>
Partner Metadata assigned to the instance.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PartnerMetadata
constructor
A new instance of PartnerMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PartnerMetadata
Returns a new instance of PartnerMetadata.
53314 53315 53316 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53314 def initialize(**args) update!(**args) end |
Instance Attribute Details
#fingerprint ⇒ String
Instance-level hash to be used for optimistic
locking.
Corresponds to the JSON property fingerprint
NOTE: Values are automatically base64 encoded/decoded in the client library.
53303 53304 53305 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53303 def fingerprint @fingerprint end |
#partner_metadata ⇒ Hash<String,Google::Apis::ComputeAlpha::StructuredEntries>
Partner Metadata assigned to the instance. A map from a subdomain to
entries map. Subdomain name must be compliant withRFC1035
definition. The total size of all keys and values must be less than 2MB.
Subdomain 'metadata.compute.googleapis.com' is reserverd for instance's
metadata.
Corresponds to the JSON property partnerMetadata
53312 53313 53314 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53312 def @partner_metadata end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
53319 53320 53321 53322 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53319 def update!(**args) @fingerprint = args[:fingerprint] if args.key?(:fingerprint) @partner_metadata = args[:partner_metadata] if args.key?(:partner_metadata) end |