Class: Google::Apis::ComputeAlpha::PerInstanceConfig
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::PerInstanceConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#fingerprint ⇒ String
Fingerprint of this per-instance config.
-
#name ⇒ String
The name of a per-instance configuration and its corresponding instance.
-
#preserved_state ⇒ Google::Apis::ComputeAlpha::PreservedState
Preserved state for a given instance.
-
#status ⇒ String
The status of applying this per-instance configuration on the corresponding managed instance.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PerInstanceConfig
constructor
A new instance of PerInstanceConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PerInstanceConfig
Returns a new instance of PerInstanceConfig.
53316 53317 53318 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53316 def initialize(**args) update!(**args) end |
Instance Attribute Details
#fingerprint ⇒ String
Fingerprint of this per-instance config. This field can be used in
optimistic locking. It is ignored when inserting a per-instance
config. An up-to-date fingerprint must be provided in order to update an
existing per-instance configuration or the field needs to be unset.
Corresponds to the JSON property fingerprint
NOTE: Values are automatically base64 encoded/decoded in the client library.
53292 53293 53294 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53292 def fingerprint @fingerprint end |
#name ⇒ String
The name of a per-instance configuration and its corresponding instance.
Serves as a merge key during UpdatePerInstanceConfigs
operations, that is, if a per-instance configuration with the same name
exists then it will be updated, otherwise a new one will be created for the
VM instance with the same name. An attempt to create a per-instance
configuration for a VM instance that either doesn't exist or is not part
of the group will result in an error.
Corresponds to the JSON property name
53303 53304 53305 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53303 def name @name end |
#preserved_state ⇒ Google::Apis::ComputeAlpha::PreservedState
Preserved state for a given instance.
Corresponds to the JSON property preservedState
53308 53309 53310 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53308 def preserved_state @preserved_state end |
#status ⇒ String
The status of applying this per-instance configuration on the corresponding
managed instance.
Corresponds to the JSON property status
53314 53315 53316 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53314 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
53321 53322 53323 53324 53325 53326 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53321 def update!(**args) @fingerprint = args[:fingerprint] if args.key?(:fingerprint) @name = args[:name] if args.key?(:name) @preserved_state = args[:preserved_state] if args.key?(:preserved_state) @status = args[:status] if args.key?(:status) end |