Class: Google::Apis::ComputeAlpha::Permission

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

[Deprecated] All fields defined in a permission are ANDed.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Permission

Returns a new instance of Permission.



53701
53702
53703
# File 'lib/google/apis/compute_alpha/classes.rb', line 53701

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#constraintsArray<Google::Apis::ComputeAlpha::PermissionConstraint>

Extra custom constraints. The constraints are ANDed together. Corresponds to the JSON property constraints



53657
53658
53659
# File 'lib/google/apis/compute_alpha/classes.rb', line 53657

def constraints
  @constraints
end

#hostsArray<String>

Used in Ingress or Egress Gateway cases to specify hosts that the policy applies to. Exact match, prefix match, and suffix match are supported. Corresponds to the JSON property hosts

Returns:

  • (Array<String>)


53663
53664
53665
# File 'lib/google/apis/compute_alpha/classes.rb', line 53663

def hosts
  @hosts
end

#methods_propArray<String>

HTTP method. Corresponds to the JSON property methods

Returns:

  • (Array<String>)


53668
53669
53670
# File 'lib/google/apis/compute_alpha/classes.rb', line 53668

def methods_prop
  @methods_prop
end

#not_hostsArray<String>

Negate of hosts. Specifies exclusions. Corresponds to the JSON property notHosts

Returns:

  • (Array<String>)


53673
53674
53675
# File 'lib/google/apis/compute_alpha/classes.rb', line 53673

def not_hosts
  @not_hosts
end

#not_methodsArray<String>

Negate of methods. Specifies exclusions. Corresponds to the JSON property notMethods

Returns:

  • (Array<String>)


53678
53679
53680
# File 'lib/google/apis/compute_alpha/classes.rb', line 53678

def not_methods
  @not_methods
end

#not_pathsArray<String>

Negate of paths. Specifies exclusions. Corresponds to the JSON property notPaths

Returns:

  • (Array<String>)


53683
53684
53685
# File 'lib/google/apis/compute_alpha/classes.rb', line 53683

def not_paths
  @not_paths
end

#not_portsArray<String>

Negate of ports. Specifies exclusions. Corresponds to the JSON property notPorts

Returns:

  • (Array<String>)


53688
53689
53690
# File 'lib/google/apis/compute_alpha/classes.rb', line 53688

def not_ports
  @not_ports
end

#pathsArray<String>

HTTP request paths or gRPC methods. Exact match, prefix match, and suffix match are supported. Corresponds to the JSON property paths

Returns:

  • (Array<String>)


53694
53695
53696
# File 'lib/google/apis/compute_alpha/classes.rb', line 53694

def paths
  @paths
end

#portsArray<String>

Port names or numbers. Corresponds to the JSON property ports

Returns:

  • (Array<String>)


53699
53700
53701
# File 'lib/google/apis/compute_alpha/classes.rb', line 53699

def ports
  @ports
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



53706
53707
53708
53709
53710
53711
53712
53713
53714
53715
53716
# File 'lib/google/apis/compute_alpha/classes.rb', line 53706

def update!(**args)
  @constraints = args[:constraints] if args.key?(:constraints)
  @hosts = args[:hosts] if args.key?(:hosts)
  @methods_prop = args[:methods_prop] if args.key?(:methods_prop)
  @not_hosts = args[:not_hosts] if args.key?(:not_hosts)
  @not_methods = args[:not_methods] if args.key?(:not_methods)
  @not_paths = args[:not_paths] if args.key?(:not_paths)
  @not_ports = args[:not_ports] if args.key?(:not_ports)
  @paths = args[:paths] if args.key?(:paths)
  @ports = args[:ports] if args.key?(:ports)
end