Class: Google::Apis::ComputeAlpha::PersistentDiskResourceCommitment

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Commitment for a particular persistent disk resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PersistentDiskResourceCommitment

Returns a new instance of PersistentDiskResourceCommitment.



53239
53240
53241
# File 'lib/google/apis/compute_alpha/classes.rb', line 53239

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#amountFixnum

Required. The amount of the resource to commit to, in GiB. Corresponds to the JSON property amount

Returns:

  • (Fixnum)


53226
53227
53228
# File 'lib/google/apis/compute_alpha/classes.rb', line 53226

def amount
  @amount
end

#dimension_typeString

The specific dimension of the product for this amount. Corresponds to the JSON property dimensionType

Returns:

  • (String)


53231
53232
53233
# File 'lib/google/apis/compute_alpha/classes.rb', line 53231

def dimension_type
  @dimension_type
end

#product_typeString

The PD product being committed to. All entries in a Commitment.persistent_disk_resources list must have the same product_type. Corresponds to the JSON property productType

Returns:

  • (String)


53237
53238
53239
# File 'lib/google/apis/compute_alpha/classes.rb', line 53237

def product_type
  @product_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



53244
53245
53246
53247
53248
# File 'lib/google/apis/compute_alpha/classes.rb', line 53244

def update!(**args)
  @amount = args[:amount] if args.key?(:amount)
  @dimension_type = args[:dimension_type] if args.key?(:dimension_type)
  @product_type = args[:product_type] if args.key?(:product_type)
end