Class: Google::Apis::ComputeAlpha::PreservedStatePreservedNetworkIpIpAddress
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::PreservedStatePreservedNetworkIpIpAddress
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#address ⇒ String
The URL of the reservation for this IP address.
-
#literal ⇒ String
An IPv4 internal network address to assign to the instance for this network interface.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PreservedStatePreservedNetworkIpIpAddress
constructor
A new instance of PreservedStatePreservedNetworkIpIpAddress.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PreservedStatePreservedNetworkIpIpAddress
Returns a new instance of PreservedStatePreservedNetworkIpIpAddress.
51738 51739 51740 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 51738 def initialize(**args) update!(**args) end |
Instance Attribute Details
#address ⇒ String
The URL of the reservation for this IP address.
Corresponds to the JSON property address
51730 51731 51732 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 51730 def address @address end |
#literal ⇒ String
An IPv4 internal network address to assign to the instance for this
network interface.
Corresponds to the JSON property literal
51736 51737 51738 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 51736 def literal @literal end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
51743 51744 51745 51746 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 51743 def update!(**args) @address = args[:address] if args.key?(:address) @literal = args[:literal] if args.key?(:literal) end |