Class: Google::Apis::ComputeAlpha::PreviewFeatureStatusReleaseStatus

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

[Output Only] The release status of the feature.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PreviewFeatureStatusReleaseStatus

Returns a new instance of PreviewFeatureStatusReleaseStatus.



51302
51303
51304
# File 'lib/google/apis/compute_alpha/classes.rb', line 51302

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#stageString

Output only. [Output Only] The stage of the feature. Corresponds to the JSON property stage

Returns:

  • (String)


51283
51284
51285
# File 'lib/google/apis/compute_alpha/classes.rb', line 51283

def stage
  @stage
end

#update_dateGoogle::Apis::ComputeAlpha::Date

Represents a whole or partial calendar date, such as a birthday. The time of day and time zone are either specified elsewhere or are insignificant. The date is relative to the Gregorian Calendar. This can represent one of the following:

  • A full date, with non-zero year, month, and day values.
  • A month and day, with a zero year (for example, an anniversary).
  • A year on its own, with a zero month and a zero day.
  • A year and month, with a zero day (for example, a credit card expiration date). Related types:
  • google.type.TimeOfDay
  • google.type.DateTime
  • google.protobuf.Timestamp Corresponds to the JSON property updateDate


51300
51301
51302
# File 'lib/google/apis/compute_alpha/classes.rb', line 51300

def update_date
  @update_date
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



51307
51308
51309
51310
# File 'lib/google/apis/compute_alpha/classes.rb', line 51307

def update!(**args)
  @stage = args[:stage] if args.key?(:stage)
  @update_date = args[:update_date] if args.key?(:update_date)
end