Class: Google::Apis::ComputeAlpha::Principal

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

[Deprecated] All fields defined in a principal are ANDed.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Principal

Returns a new instance of Principal.



54447
54448
54449
# File 'lib/google/apis/compute_alpha/classes.rb', line 54447

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#conditionString

An expression to specify custom condition. Corresponds to the JSON property condition

Returns:

  • (String)


54396
54397
54398
# File 'lib/google/apis/compute_alpha/classes.rb', line 54396

def condition
  @condition
end

#groupsArray<String>

The groups the principal belongs to. Exact match, prefix match, and suffix match are supported. Corresponds to the JSON property groups

Returns:

  • (Array<String>)


54402
54403
54404
# File 'lib/google/apis/compute_alpha/classes.rb', line 54402

def groups
  @groups
end

#ipsArray<String>

IPv4 or IPv6 address or range (In CIDR format) Corresponds to the JSON property ips

Returns:

  • (Array<String>)


54407
54408
54409
# File 'lib/google/apis/compute_alpha/classes.rb', line 54407

def ips
  @ips
end

#namespacesArray<String>

The namespaces. Exact match, prefix match, and suffix match are supported. Corresponds to the JSON property namespaces

Returns:

  • (Array<String>)


54412
54413
54414
# File 'lib/google/apis/compute_alpha/classes.rb', line 54412

def namespaces
  @namespaces
end

#not_groupsArray<String>

Negate of groups. Specifies exclusions. Corresponds to the JSON property notGroups

Returns:

  • (Array<String>)


54417
54418
54419
# File 'lib/google/apis/compute_alpha/classes.rb', line 54417

def not_groups
  @not_groups
end

#not_ipsArray<String>

Negate of IPs. Specifies exclusions. Corresponds to the JSON property notIps

Returns:

  • (Array<String>)


54422
54423
54424
# File 'lib/google/apis/compute_alpha/classes.rb', line 54422

def not_ips
  @not_ips
end

#not_namespacesArray<String>

Negate of namespaces. Specifies exclusions. Corresponds to the JSON property notNamespaces

Returns:

  • (Array<String>)


54427
54428
54429
# File 'lib/google/apis/compute_alpha/classes.rb', line 54427

def not_namespaces
  @not_namespaces
end

#not_usersArray<String>

Negate of users. Specifies exclusions. Corresponds to the JSON property notUsers

Returns:

  • (Array<String>)


54432
54433
54434
# File 'lib/google/apis/compute_alpha/classes.rb', line 54432

def not_users
  @not_users
end

#propertiesHash<String,String>

A map of Istio attribute to expected values. Exact match, prefix match, and suffix match are supported for values. For example, request.headers[version]: "v1". The properties are ANDed together. Corresponds to the JSON property properties

Returns:

  • (Hash<String,String>)


54439
54440
54441
# File 'lib/google/apis/compute_alpha/classes.rb', line 54439

def properties
  @properties
end

#usersArray<String>

The user names/IDs or service accounts. Exact match, prefix match, and suffix match are supported. Corresponds to the JSON property users

Returns:

  • (Array<String>)


54445
54446
54447
# File 'lib/google/apis/compute_alpha/classes.rb', line 54445

def users
  @users
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



54452
54453
54454
54455
54456
54457
54458
54459
54460
54461
54462
54463
# File 'lib/google/apis/compute_alpha/classes.rb', line 54452

def update!(**args)
  @condition = args[:condition] if args.key?(:condition)
  @groups = args[:groups] if args.key?(:groups)
  @ips = args[:ips] if args.key?(:ips)
  @namespaces = args[:namespaces] if args.key?(:namespaces)
  @not_groups = args[:not_groups] if args.key?(:not_groups)
  @not_ips = args[:not_ips] if args.key?(:not_ips)
  @not_namespaces = args[:not_namespaces] if args.key?(:not_namespaces)
  @not_users = args[:not_users] if args.key?(:not_users)
  @properties = args[:properties] if args.key?(:properties)
  @users = args[:users] if args.key?(:users)
end