Class: Google::Apis::ComputeAlpha::Project
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::Project
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Represents a Project resource. A project is used to organize resources in a Google Cloud Platform environment. For more information, read about the Resource Hierarchy.
Instance Attribute Summary collapse
-
#cloud_armor_tier ⇒ String
Output only.
-
#common_instance_metadata ⇒ Google::Apis::ComputeAlpha::Metadata
A metadata key/value entry.
-
#creation_timestamp ⇒ String
[Output Only] Creation timestamp inRFC3339 text format.
-
#default_network_tier ⇒ String
This signifies the default network tier used for configuring resources of the project and can only take the following values:PREMIUM, STANDARD.
-
#default_service_account ⇒ String
[Output Only] Default service account used by VMs running in this project.
-
#description ⇒ String
An optional textual description of the resource.
-
#enabled_features ⇒ Array<String>
An optional list of restricted features enabled for use on this project.
-
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource.
-
#kind ⇒ String
Output only.
-
#managed_protection_tier ⇒ String
Output only.
-
#name ⇒ String
The project ID.
-
#quotas ⇒ Array<Google::Apis::ComputeAlpha::Quota>
[Output Only] Quotas assigned to this project.
-
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
-
#usage_export_location ⇒ Google::Apis::ComputeAlpha::UsageExportLocation
The location in Cloud Storage and naming method of the daily usage report.
-
#vm_dns_setting ⇒ String
Output only.
-
#xpn_project_status ⇒ String
[Output Only] The role this project has in a shared VPC configuration.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Project
constructor
A new instance of Project.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Project
Returns a new instance of Project.
54045 54046 54047 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54045 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cloud_armor_tier ⇒ String
Output only. [Output Only] The Cloud Armor tier for this project. It can be
one of the
following values: CA_STANDARD,CA_ENTERPRISE_PAYGO.
If this field is not specified, it is assumed to beCA_STANDARD.
Corresponds to the JSON property cloudArmorTier
53953 53954 53955 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53953 def cloud_armor_tier @cloud_armor_tier end |
#common_instance_metadata ⇒ Google::Apis::ComputeAlpha::Metadata
A metadata key/value entry.
Corresponds to the JSON property commonInstanceMetadata
53958 53959 53960 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53958 def @common_instance_metadata end |
#creation_timestamp ⇒ String
[Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
53964 53965 53966 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53964 def @creation_timestamp end |
#default_network_tier ⇒ String
This signifies the default network tier used for configuring resources of
the project and can only take the following values:PREMIUM, STANDARD.
Initially the default network
tier is PREMIUM.
Corresponds to the JSON property defaultNetworkTier
53972 53973 53974 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53972 def default_network_tier @default_network_tier end |
#default_service_account ⇒ String
[Output Only] Default service account used by VMs running in this project.
Corresponds to the JSON property defaultServiceAccount
53977 53978 53979 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53977 def default_service_account @default_service_account end |
#description ⇒ String
An optional textual description of the resource.
Corresponds to the JSON property description
53982 53983 53984 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53982 def description @description end |
#enabled_features ⇒ Array<String>
An optional list of restricted features enabled for use on this project.
Corresponds to the JSON property enabledFeatures
53987 53988 53989 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53987 def enabled_features @enabled_features end |
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource. This identifier is
defined by the server. This is not the project ID, and is
just a unique ID used by Compute Engine to identify resources.
Corresponds to the JSON property id
53994 53995 53996 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53994 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Always compute#project for
projects.
Corresponds to the JSON property kind
54000 54001 54002 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54000 def kind @kind end |
#managed_protection_tier ⇒ String
Output only. [Output Only] The Cloud Armor Managed Protection (CAMP) tier for
this project. It can be one of the following values:CA_STANDARD,
CAMP_PLUS_PAYGO.
If this field is not specified, it is assumed to beCA_STANDARD.
Corresponds to the JSON property managedProtectionTier
54008 54009 54010 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54008 def managed_protection_tier @managed_protection_tier end |
#name ⇒ String
The project ID. For example: my-example-project. Use the
project ID to make requests to Compute Engine.
Corresponds to the JSON property name
54014 54015 54016 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54014 def name @name end |
#quotas ⇒ Array<Google::Apis::ComputeAlpha::Quota>
[Output Only] Quotas assigned to this project.
Corresponds to the JSON property quotas
54019 54020 54021 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54019 def quotas @quotas end |
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
54024 54025 54026 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54024 def self_link @self_link end |
#usage_export_location ⇒ Google::Apis::ComputeAlpha::UsageExportLocation
The location in Cloud Storage and naming method of the daily usage
report. Contains bucket_name and report_name prefix.
Corresponds to the JSON property usageExportLocation
54030 54031 54032 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54030 def usage_export_location @usage_export_location end |
#vm_dns_setting ⇒ String
Output only. [Output Only] Default internal DNS setting used by VMs running in
this project.
Corresponds to the JSON property vmDnsSetting
54036 54037 54038 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54036 def vm_dns_setting @vm_dns_setting end |
#xpn_project_status ⇒ String
[Output Only] The role this project has in a shared VPC configuration.
Currently, only projects with the host role, which is specified by the
value HOST, are differentiated.
Corresponds to the JSON property xpnProjectStatus
54043 54044 54045 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54043 def xpn_project_status @xpn_project_status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
54050 54051 54052 54053 54054 54055 54056 54057 54058 54059 54060 54061 54062 54063 54064 54065 54066 54067 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54050 def update!(**args) @cloud_armor_tier = args[:cloud_armor_tier] if args.key?(:cloud_armor_tier) @common_instance_metadata = args[:common_instance_metadata] if args.key?(:common_instance_metadata) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @default_network_tier = args[:default_network_tier] if args.key?(:default_network_tier) @default_service_account = args[:default_service_account] if args.key?(:default_service_account) @description = args[:description] if args.key?(:description) @enabled_features = args[:enabled_features] if args.key?(:enabled_features) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @managed_protection_tier = args[:managed_protection_tier] if args.key?(:managed_protection_tier) @name = args[:name] if args.key?(:name) @quotas = args[:quotas] if args.key?(:quotas) @self_link = args[:self_link] if args.key?(:self_link) @usage_export_location = args[:usage_export_location] if args.key?(:usage_export_location) @vm_dns_setting = args[:vm_dns_setting] if args.key?(:vm_dns_setting) @xpn_project_status = args[:xpn_project_status] if args.key?(:xpn_project_status) end |