Class: Google::Apis::ComputeAlpha::PublicAdvertisedPrefixList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PublicAdvertisedPrefixList

Returns a new instance of PublicAdvertisedPrefixList.



55007
55008
55009
# File 'lib/google/apis/compute_alpha/classes.rb', line 55007

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


54974
54975
54976
# File 'lib/google/apis/compute_alpha/classes.rb', line 54974

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::PublicAdvertisedPrefix>

A list of PublicAdvertisedPrefix resources. Corresponds to the JSON property items



54979
54980
54981
# File 'lib/google/apis/compute_alpha/classes.rb', line 54979

def items
  @items
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# publicAdvertisedPrefix for public advertised prefixes. Corresponds to the JSON property kind

Returns:

  • (String)


54985
54986
54987
# File 'lib/google/apis/compute_alpha/classes.rb', line 54985

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


54995
54996
54997
# File 'lib/google/apis/compute_alpha/classes.rb', line 54995

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


55000
55001
55002
# File 'lib/google/apis/compute_alpha/classes.rb', line 55000

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::PublicAdvertisedPrefixList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



55005
55006
55007
# File 'lib/google/apis/compute_alpha/classes.rb', line 55005

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



55012
55013
55014
55015
55016
55017
55018
55019
# File 'lib/google/apis/compute_alpha/classes.rb', line 55012

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end