Class: Google::Apis::ComputeAlpha::PublicAdvertisedPrefixPublicDelegatedPrefix
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::PublicAdvertisedPrefixPublicDelegatedPrefix
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Represents a CIDR range which can be used to assign addresses.
Instance Attribute Summary collapse
-
#ip_range ⇒ String
The IP address range of the public delegated prefix Corresponds to the JSON property
ipRange. -
#name ⇒ String
The name of the public delegated prefix Corresponds to the JSON property
name. -
#project ⇒ String
The project number of the public delegated prefix Corresponds to the JSON property
project. -
#region ⇒ String
The region of the public delegated prefix if it is regional.
-
#status ⇒ String
The status of the public delegated prefix.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PublicAdvertisedPrefixPublicDelegatedPrefix
constructor
A new instance of PublicAdvertisedPrefixPublicDelegatedPrefix.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PublicAdvertisedPrefixPublicDelegatedPrefix
Returns a new instance of PublicAdvertisedPrefixPublicDelegatedPrefix.
54884 54885 54886 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54884 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ip_range ⇒ String
The IP address range of the public delegated prefix
Corresponds to the JSON property ipRange
54858 54859 54860 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54858 def ip_range @ip_range end |
#name ⇒ String
The name of the public delegated prefix
Corresponds to the JSON property name
54863 54864 54865 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54863 def name @name end |
#project ⇒ String
The project number of the public delegated prefix
Corresponds to the JSON property project
54868 54869 54870 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54868 def project @project end |
#region ⇒ String
The region of the public delegated prefix if it is regional. If absent,
the prefix is global.
Corresponds to the JSON property region
54874 54875 54876 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54874 def region @region end |
#status ⇒ String
The status of the public delegated prefix. Possible values are:
INITIALIZING: The public delegated prefix is being initialized and
addresses cannot be created yet.
ANNOUNCED: The public delegated prefix is active.
Corresponds to the JSON property status
54882 54883 54884 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54882 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
54889 54890 54891 54892 54893 54894 54895 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54889 def update!(**args) @ip_range = args[:ip_range] if args.key?(:ip_range) @name = args[:name] if args.key?(:name) @project = args[:project] if args.key?(:project) @region = args[:region] if args.key?(:region) @status = args[:status] if args.key?(:status) end |