Class: Google::Apis::ComputeAlpha::QueuedResourcesAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::QueuedResourcesAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::QueuedResourcesScopedList>
A list of QueuedResourcesScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::QueuedResourcesAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ QueuedResourcesAggregatedList
constructor
A new instance of QueuedResourcesAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ QueuedResourcesAggregatedList
Returns a new instance of QueuedResourcesAggregatedList.
56257 56258 56259 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 56257 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
56218 56219 56220 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 56218 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::QueuedResourcesScopedList>
A list of QueuedResourcesScopedList resources.
Corresponds to the JSON property items
56223 56224 56225 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 56223 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
queuedResourcesAggregatedList for lists of
QueuedResource.
Corresponds to the JSON property kind
56230 56231 56232 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 56230 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
56240 56241 56242 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 56240 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
56245 56246 56247 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 56245 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
56250 56251 56252 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 56250 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::QueuedResourcesAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
56255 56256 56257 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 56255 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
56262 56263 56264 56265 56266 56267 56268 56269 56270 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 56262 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |