Class: Google::Apis::ComputeAlpha::RecoverableSnapshot

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Represents a RecoverableSnapshot resource. A RecoverableSnapshot represents a snapshot in recycle bin.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RecoverableSnapshot

Returns a new instance of RecoverableSnapshot.



56669
56670
56671
# File 'lib/google/apis/compute_alpha/classes.rb', line 56669

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


56598
56599
56600
# File 'lib/google/apis/compute_alpha/classes.rb', line 56598

def creation_timestamp
  @creation_timestamp
end

#descriptionString

Optional. An optional description of this resource. Corresponds to the JSON property description

Returns:

  • (String)


56603
56604
56605
# File 'lib/google/apis/compute_alpha/classes.rb', line 56603

def description
  @description
end

#idFixnum

Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


56610
56611
56612
# File 'lib/google/apis/compute_alpha/classes.rb', line 56610

def id
  @id
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# recoverableSnapshot for RecoverableSnapshot resources. Corresponds to the JSON property kind

Returns:

  • (String)


56617
56618
56619
# File 'lib/google/apis/compute_alpha/classes.rb', line 56617

def kind
  @kind
end

#nameString

Output only. Identifier. Name of the recoverable snapshot generated on the deletion of the snapshot. The name will be 1-63 characters long, and comply withRFC1035. Specifically, the name will be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character will be a lowercase letter, and all following characters can be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


56629
56630
56631
# File 'lib/google/apis/compute_alpha/classes.rb', line 56629

def name
  @name
end

#original_resourceGoogle::Apis::ComputeAlpha::RecoverableSnapshotOriginalSnapshot

Output only. Output Only] The original snapshot resource. Corresponds to the JSON property originalResource



56634
56635
56636
# File 'lib/google/apis/compute_alpha/classes.rb', line 56634

def original_resource
  @original_resource
end

#purge_timestampString

Output only. [Output Only] Purge timestamp of recoverable snapshot inRFC3339 text format. Corresponds to the JSON property purgeTimestamp

Returns:

  • (String)


56640
56641
56642
# File 'lib/google/apis/compute_alpha/classes.rb', line 56640

def purge_timestamp
  @purge_timestamp
end

#satisfies_pziBoolean Also known as: satisfies_pzi?

Output only. [Output Only] Reserved for future use. Corresponds to the JSON property satisfiesPzi

Returns:

  • (Boolean)


56645
56646
56647
# File 'lib/google/apis/compute_alpha/classes.rb', line 56645

def satisfies_pzi
  @satisfies_pzi
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

Output only. [Output Only] Reserved for future use. Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


56651
56652
56653
# File 'lib/google/apis/compute_alpha/classes.rb', line 56651

def satisfies_pzs
  @satisfies_pzs
end

Output only. [Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


56657
56658
56659
# File 'lib/google/apis/compute_alpha/classes.rb', line 56657

def self_link
  @self_link
end

Output only. [Output Only] Server-defined URL for this resource's resource id. Corresponds to the JSON property selfLinkWithId

Returns:

  • (String)


56662
56663
56664
# File 'lib/google/apis/compute_alpha/classes.rb', line 56662

def self_link_with_id
  @self_link_with_id
end

#statusString

Output only. [Output Only] Status of the recoverable snapshot. Corresponds to the JSON property status

Returns:

  • (String)


56667
56668
56669
# File 'lib/google/apis/compute_alpha/classes.rb', line 56667

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



56674
56675
56676
56677
56678
56679
56680
56681
56682
56683
56684
56685
56686
56687
# File 'lib/google/apis/compute_alpha/classes.rb', line 56674

def update!(**args)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @original_resource = args[:original_resource] if args.key?(:original_resource)
  @purge_timestamp = args[:purge_timestamp] if args.key?(:purge_timestamp)
  @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @self_link = args[:self_link] if args.key?(:self_link)
  @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id)
  @status = args[:status] if args.key?(:status)
end