Class: Google::Apis::ComputeAlpha::Reference

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Represents a reference to a resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Reference

Returns a new instance of Reference.



57178
57179
57180
# File 'lib/google/apis/compute_alpha/classes.rb', line 57178

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#kindString

Output only. [Output Only] Type of the resource. Always compute#reference for references. Corresponds to the JSON property kind

Returns:

  • (String)


57157
57158
57159
# File 'lib/google/apis/compute_alpha/classes.rb', line 57157

def kind
  @kind
end

#reference_typeString

A description of the reference type with no implied semantics. Possible values include:

  1. MEMBER_OF Corresponds to the JSON property referenceType

Returns:

  • (String)


57166
57167
57168
# File 'lib/google/apis/compute_alpha/classes.rb', line 57166

def reference_type
  @reference_type
end

#referrerString

URL of the resource which refers to the target. Corresponds to the JSON property referrer

Returns:

  • (String)


57171
57172
57173
# File 'lib/google/apis/compute_alpha/classes.rb', line 57171

def referrer
  @referrer
end

#targetString

URL of the resource to which this reference points. Corresponds to the JSON property target

Returns:

  • (String)


57176
57177
57178
# File 'lib/google/apis/compute_alpha/classes.rb', line 57176

def target
  @target
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



57183
57184
57185
57186
57187
57188
# File 'lib/google/apis/compute_alpha/classes.rb', line 57183

def update!(**args)
  @kind = args[:kind] if args.key?(:kind)
  @reference_type = args[:reference_type] if args.key?(:reference_type)
  @referrer = args[:referrer] if args.key?(:referrer)
  @target = args[:target] if args.key?(:target)
end