Class: Google::Apis::ComputeAlpha::RegionDiskUpdateKmsKeyRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RegionDiskUpdateKmsKeyRequest

Returns a new instance of RegionDiskUpdateKmsKeyRequest.



55592
55593
55594
# File 'lib/google/apis/compute_alpha/classes.rb', line 55592

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#kms_key_nameString

Optional. The new KMS key to replace the current one on the disk. If empty, the disk will be re-encrypted using the primary version of the disk's current KMS key. The KMS key can be provided in the following formats:

  • projects/project_id/locations/location/keyRings/key_ring/cryptoKeys/key Where project is the project ID or project number. Corresponds to the JSON property kmsKeyName

Returns:

  • (String)


55590
55591
55592
# File 'lib/google/apis/compute_alpha/classes.rb', line 55590

def kms_key_name
  @kms_key_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



55597
55598
55599
# File 'lib/google/apis/compute_alpha/classes.rb', line 55597

def update!(**args)
  @kms_key_name = args[:kms_key_name] if args.key?(:kms_key_name)
end