Class: Google::Apis::ComputeAlpha::RegionDisksResizeRequest
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::RegionDisksResizeRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#size_gb ⇒ Fixnum
The new size of the regional persistent disk, which is specified in GB.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RegionDisksResizeRequest
constructor
A new instance of RegionDisksResizeRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RegionDisksResizeRequest
Returns a new instance of RegionDisksResizeRequest.
57790 57791 57792 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 57790 def initialize(**args) update!(**args) end |
Instance Attribute Details
#size_gb ⇒ Fixnum
The new size of the regional persistent disk, which is specified in GB.
Corresponds to the JSON property sizeGb
57788 57789 57790 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 57788 def size_gb @size_gb end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
57795 57796 57797 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 57795 def update!(**args) @size_gb = args[:size_gb] if args.key?(:size_gb) end |