Class: Google::Apis::ComputeAlpha::RegionInstanceGroupList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of InstanceGroup resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RegionInstanceGroupList

Returns a new instance of RegionInstanceGroupList.



57598
57599
57600
# File 'lib/google/apis/compute_alpha/classes.rb', line 57598

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Output only. [Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


57565
57566
57567
# File 'lib/google/apis/compute_alpha/classes.rb', line 57565

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::InstanceGroup>

A list of InstanceGroup resources. Corresponds to the JSON property items



57570
57571
57572
# File 'lib/google/apis/compute_alpha/classes.rb', line 57570

def items
  @items
end

#kindString

Output only. The resource type. Corresponds to the JSON property kind

Returns:

  • (String)


57575
57576
57577
# File 'lib/google/apis/compute_alpha/classes.rb', line 57575

def kind
  @kind
end

#next_page_tokenString

Output only. [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


57586
57587
57588
# File 'lib/google/apis/compute_alpha/classes.rb', line 57586

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


57591
57592
57593
# File 'lib/google/apis/compute_alpha/classes.rb', line 57591

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::RegionInstanceGroupList::Warning

Output only. [Output Only] Informational warning message. Corresponds to the JSON property warning



57596
57597
57598
# File 'lib/google/apis/compute_alpha/classes.rb', line 57596

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



57603
57604
57605
57606
57607
57608
57609
57610
# File 'lib/google/apis/compute_alpha/classes.rb', line 57603

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end