Class: Google::Apis::ComputeAlpha::RegionInstanceGroupManagerResizeRequestsListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RegionInstanceGroupManagerResizeRequestsListResponse

Returns a new instance of RegionInstanceGroupManagerResizeRequestsListResponse.



58453
58454
58455
# File 'lib/google/apis/compute_alpha/classes.rb', line 58453

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


58408
58409
58410
# File 'lib/google/apis/compute_alpha/classes.rb', line 58408

def etag
  @etag
end

#idString

Output only. Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


58413
58414
58415
# File 'lib/google/apis/compute_alpha/classes.rb', line 58413

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::InstanceGroupManagerResizeRequest>

A list of Resize Request resources. Corresponds to the JSON property items



58418
58419
58420
# File 'lib/google/apis/compute_alpha/classes.rb', line 58418

def items
  @items
end

#kindString

Output only. Type of the resource. Alwayscompute# regionInstanceGroupManagerResizeRequestList for a list of Resize Requests. Corresponds to the JSON property kind

Returns:

  • (String)


58425
58426
58427
# File 'lib/google/apis/compute_alpha/classes.rb', line 58425

def kind
  @kind
end

#next_page_tokenString

Output only. This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


58435
58436
58437
# File 'lib/google/apis/compute_alpha/classes.rb', line 58435

def next_page_token
  @next_page_token
end

Output only. Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


58440
58441
58442
# File 'lib/google/apis/compute_alpha/classes.rb', line 58440

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


58446
58447
58448
# File 'lib/google/apis/compute_alpha/classes.rb', line 58446

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::RegionInstanceGroupManagerResizeRequestsListResponse::Warning

Output only. Informational warning message. Corresponds to the JSON property warning



58451
58452
58453
# File 'lib/google/apis/compute_alpha/classes.rb', line 58451

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



58458
58459
58460
58461
58462
58463
58464
58465
58466
58467
# File 'lib/google/apis/compute_alpha/classes.rb', line 58458

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end