Class: Google::Apis::ComputeAlpha::RegionInstanceGroupManagersListInstanceConfigsResp

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RegionInstanceGroupManagersListInstanceConfigsResp

Returns a new instance of RegionInstanceGroupManagersListInstanceConfigsResp.



58795
58796
58797
# File 'lib/google/apis/compute_alpha/classes.rb', line 58795

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#itemsArray<Google::Apis::ComputeAlpha::PerInstanceConfig>

Output only. [Output Only] The list of PerInstanceConfig. Corresponds to the JSON property items



58777
58778
58779
# File 'lib/google/apis/compute_alpha/classes.rb', line 58777

def items
  @items
end

#next_page_tokenString

Output only. [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


58788
58789
58790
# File 'lib/google/apis/compute_alpha/classes.rb', line 58788

def next_page_token
  @next_page_token
end

#warningGoogle::Apis::ComputeAlpha::RegionInstanceGroupManagersListInstanceConfigsResp::Warning

Output only. [Output Only] Informational warning message. Corresponds to the JSON property warning



58793
58794
58795
# File 'lib/google/apis/compute_alpha/classes.rb', line 58793

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



58800
58801
58802
58803
58804
# File 'lib/google/apis/compute_alpha/classes.rb', line 58800

def update!(**args)
  @items = args[:items] if args.key?(:items)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @warning = args[:warning] if args.key?(:warning)
end