Class: Google::Apis::ComputeAlpha::RegionInstanceGroupManagersResizeAdvancedRequest
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::RegionInstanceGroupManagersResizeAdvancedRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#no_creation_retries ⇒ Boolean
(also: #no_creation_retries?)
If this flag is true, the managed instance group attempts to create all instances initiated by this resize request only once.
-
#scale_in_protection ⇒ Boolean
(also: #scale_in_protection?)
If this flag is enabled within a request to decrease a MIG's target size, then the MIG declines that request.
-
#target_size ⇒ Fixnum
The number of running instances that the managed instance group should maintain at any given time.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RegionInstanceGroupManagersResizeAdvancedRequest
constructor
A new instance of RegionInstanceGroupManagersResizeAdvancedRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RegionInstanceGroupManagersResizeAdvancedRequest
Returns a new instance of RegionInstanceGroupManagersResizeAdvancedRequest.
56778 56779 56780 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 56778 def initialize(**args) update!(**args) end |
Instance Attribute Details
#no_creation_retries ⇒ Boolean Also known as: no_creation_retries?
If this flag is true, the managed instance group attempts to create all
instances initiated by this resize request only once. If there is an error
during creation, the managed instance group does not retry create this
instance, and we will decrease the targetSize of the request
instead. If the flag is false, the group attempts to recreate each instance
continuously until it succeeds.
This flag matters only in the first attempt of creation of an instance.
After an instance is successfully created while this flag is enabled, the
instance behaves the same way as all the other instances created with a
regular resize request. In particular, if a running instance dies
unexpectedly at a later time and needs to be recreated, this mode does not
affect the recreation behavior in that scenario.
This flag is applicable only to the current resize request. It does not
influence other resize requests in any way.
You can see which instances ar being created in which mode by calling
the get or listManagedInstances API.
Corresponds to the JSON property noCreationRetries
56761 56762 56763 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 56761 def no_creation_retries @no_creation_retries end |
#scale_in_protection ⇒ Boolean Also known as: scale_in_protection?
If this flag is enabled within a request to decrease a MIG's target size,
then the MIG declines that request.
Corresponds to the JSON property scaleInProtection
56768 56769 56770 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 56768 def scale_in_protection @scale_in_protection end |
#target_size ⇒ Fixnum
The number of running instances that the managed instance group should
maintain at any given time. The group automatically adds or removes
instances to maintain the number of instances specified by this parameter.
Corresponds to the JSON property targetSize
56776 56777 56778 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 56776 def target_size @target_size end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
56783 56784 56785 56786 56787 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 56783 def update!(**args) @no_creation_retries = args[:no_creation_retries] if args.key?(:no_creation_retries) @scale_in_protection = args[:scale_in_protection] if args.key?(:scale_in_protection) @target_size = args[:target_size] if args.key?(:target_size) end |