Class: Google::Apis::ComputeAlpha::RegionInstanceGroupManagersStopInstancesRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RegionInstanceGroupManagersStopInstancesRequest

Returns a new instance of RegionInstanceGroupManagersStopInstancesRequest.



55884
55885
55886
# File 'lib/google/apis/compute_alpha/classes.rb', line 55884

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#force_stopBoolean Also known as: force_stop?

If this flag is set to true, the Instance Group Manager will proceed to stop the instances, skipping initialization on them. Corresponds to the JSON property forceStop

Returns:

  • (Boolean)


55875
55876
55877
# File 'lib/google/apis/compute_alpha/classes.rb', line 55875

def force_stop
  @force_stop
end

#instancesArray<String>

The URLs of one or more instances to stop. This can be a full URL or a partial URL, such as zones/[ZONE]/instances/[INSTANCE_NAME]. Corresponds to the JSON property instances

Returns:

  • (Array<String>)


55882
55883
55884
# File 'lib/google/apis/compute_alpha/classes.rb', line 55882

def instances
  @instances
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



55889
55890
55891
55892
# File 'lib/google/apis/compute_alpha/classes.rb', line 55889

def update!(**args)
  @force_stop = args[:force_stop] if args.key?(:force_stop)
  @instances = args[:instances] if args.key?(:instances)
end