Class: Google::Apis::ComputeAlpha::RegionInstanceGroupManagersSuspendInstancesRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RegionInstanceGroupManagersSuspendInstancesRequest

Returns a new instance of RegionInstanceGroupManagersSuspendInstancesRequest.



55912
55913
55914
# File 'lib/google/apis/compute_alpha/classes.rb', line 55912

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#force_suspendBoolean Also known as: force_suspend?

If this flag is set to true, the Instance Group Manager will proceed to suspend the instances, skipping initialization on them. Corresponds to the JSON property forceSuspend

Returns:

  • (Boolean)


55903
55904
55905
# File 'lib/google/apis/compute_alpha/classes.rb', line 55903

def force_suspend
  @force_suspend
end

#instancesArray<String>

The URLs of one or more instances to suspend. This can be a full URL or a partial URL, such as zones/[ZONE]/instances/[INSTANCE_NAME]. Corresponds to the JSON property instances

Returns:

  • (Array<String>)


55910
55911
55912
# File 'lib/google/apis/compute_alpha/classes.rb', line 55910

def instances
  @instances
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



55917
55918
55919
55920
# File 'lib/google/apis/compute_alpha/classes.rb', line 55917

def update!(**args)
  @force_suspend = args[:force_suspend] if args.key?(:force_suspend)
  @instances = args[:instances] if args.key?(:instances)
end