Class: Google::Apis::ComputeAlpha::RegionSnapshotUpdateKmsKeyRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RegionSnapshotUpdateKmsKeyRequest

Returns a new instance of RegionSnapshotUpdateKmsKeyRequest.



57533
57534
57535
# File 'lib/google/apis/compute_alpha/classes.rb', line 57533

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#kms_key_nameString

Optional. The new KMS key to replace the current one on the snapshot. If empty, the snapshot will be re-encrypted using the primary version of the snapshot's current KMS key. The KMS key can be provided in the following formats:

  • projects/project_id/locations/region/keyRings/region/cryptoKeys/key Corresponds to the JSON property kmsKeyName

Returns:

  • (String)


57531
57532
57533
# File 'lib/google/apis/compute_alpha/classes.rb', line 57531

def kms_key_name
  @kms_key_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



57538
57539
57540
# File 'lib/google/apis/compute_alpha/classes.rb', line 57538

def update!(**args)
  @kms_key_name = args[:kms_key_name] if args.key?(:kms_key_name)
end