Class: Google::Apis::ComputeAlpha::ReliabilityRisk
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::ReliabilityRisk
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Represents a ReliabilityRisk resource.
Instance Attribute Summary collapse
-
#creation_timestamp ⇒ String
Output only.
-
#description ⇒ String
An optional textual description of the resource; provided when the resource is created.
-
#details ⇒ Google::Apis::ComputeAlpha::RiskDetails
Detailed insights and metrics about a detected reliability risk.
-
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
Name of the resource.
-
#recommendation ⇒ Google::Apis::ComputeAlpha::RiskRecommendation
Recommendation for mitigating a reliability risk, including a reference URL.
-
#self_link ⇒ String
Output only.
-
#self_link_with_id ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReliabilityRisk
constructor
A new instance of ReliabilityRisk.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReliabilityRisk
Returns a new instance of ReliabilityRisk.
59869 59870 59871 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59869 def initialize(**args) update!(**args) end |
Instance Attribute Details
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp in RFC3339
text format.
Corresponds to the JSON property creationTimestamp
59822 59823 59824 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59822 def @creation_timestamp end |
#description ⇒ String
An optional textual description of the resource; provided when the
resource is created.
Corresponds to the JSON property description
59828 59829 59830 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59828 def description @description end |
#details ⇒ Google::Apis::ComputeAlpha::RiskDetails
Detailed insights and metrics about a detected reliability risk.
Corresponds to the JSON property details
59833 59834 59835 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59833 def details @details end |
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
59839 59840 59841 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59839 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#reliabilityRisk
for reliability risks.
Corresponds to the JSON property kind
59845 59846 59847 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59845 def kind @kind end |
#name ⇒ String
Name of the resource. The name must be 1-63 characters long and
comply with RFC1035.
Corresponds to the JSON property name
59851 59852 59853 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59851 def name @name end |
#recommendation ⇒ Google::Apis::ComputeAlpha::RiskRecommendation
Recommendation for mitigating a reliability risk, including a reference URL.
Corresponds to the JSON property recommendation
59856 59857 59858 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59856 def recommendation @recommendation end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
59861 59862 59863 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59861 def self_link @self_link end |
#self_link_with_id ⇒ String
Output only. [Output Only] Server-defined URL for this resource with the
resource id.
Corresponds to the JSON property selfLinkWithId
59867 59868 59869 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59867 def self_link_with_id @self_link_with_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
59874 59875 59876 59877 59878 59879 59880 59881 59882 59883 59884 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59874 def update!(**args) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @details = args[:details] if args.key?(:details) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @recommendation = args[:recommendation] if args.key?(:recommendation) @self_link = args[:self_link] if args.key?(:self_link) @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id) end |