Class: Google::Apis::ComputeAlpha::ReplicationDetails

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReplicationDetails

Returns a new instance of ReplicationDetails.



60036
60037
60038
# File 'lib/google/apis/compute_alpha/classes.rb', line 60036

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#last_replication_timeString

Output only. The last sync time of the device pair. Corresponds to the JSON property lastReplicationTime

Returns:

  • (String)


60025
60026
60027
# File 'lib/google/apis/compute_alpha/classes.rb', line 60025

def last_replication_time
  @last_replication_time
end

#seconds_since_last_replicationFixnum

Output only. Replication lag in seconds. This will only be populated if device is in replicating state. Note that the value is calculated sometime during request processing and at the instant the client receives the response, the current replication_lag may have changed. Corresponds to the JSON property secondsSinceLastReplication

Returns:

  • (Fixnum)


60034
60035
60036
# File 'lib/google/apis/compute_alpha/classes.rb', line 60034

def seconds_since_last_replication
  @seconds_since_last_replication
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



60041
60042
60043
60044
# File 'lib/google/apis/compute_alpha/classes.rb', line 60041

def update!(**args)
  @last_replication_time = args[:last_replication_time] if args.key?(:last_replication_time)
  @seconds_since_last_replication = args[:seconds_since_last_replication] if args.key?(:seconds_since_last_replication)
end