Class: Google::Apis::ComputeAlpha::ReservationBlockPhysicalTopology
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::ReservationBlockPhysicalTopology
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#block ⇒ String
The hash of the capacity block within the cluster.
-
#cluster ⇒ String
The cluster name of the reservation block.
-
#instances ⇒ Array<Google::Apis::ComputeAlpha::ReservationBlockPhysicalTopologyInstance>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReservationBlockPhysicalTopology
constructor
A new instance of ReservationBlockPhysicalTopology.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReservationBlockPhysicalTopology
Returns a new instance of ReservationBlockPhysicalTopology.
60461 60462 60463 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 60461 def initialize(**args) update!(**args) end |
Instance Attribute Details
#block ⇒ String
The hash of the capacity block within the cluster.
Corresponds to the JSON property block
60449 60450 60451 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 60449 def block @block end |
#cluster ⇒ String
The cluster name of the reservation block.
Corresponds to the JSON property cluster
60454 60455 60456 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 60454 def cluster @cluster end |
#instances ⇒ Array<Google::Apis::ComputeAlpha::ReservationBlockPhysicalTopologyInstance>
Output only. The detailed instances information for a given Block
Corresponds to the JSON property instances
60459 60460 60461 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 60459 def instances @instances end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
60466 60467 60468 60469 60470 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 60466 def update!(**args) @block = args[:block] if args.key?(:block) @cluster = args[:cluster] if args.key?(:cluster) @instances = args[:instances] if args.key?(:instances) end |