Class: Google::Apis::ComputeAlpha::ReservationBlockPhysicalTopologyInstancePhysicalHostTopology
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::ReservationBlockPhysicalTopologyInstancePhysicalHostTopology
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
The PhysicalHostTopology of the instance within a Block resource.
Instance Attribute Summary collapse
-
#host ⇒ String
Host hash for a given instance Corresponds to the JSON property
host. -
#sub_block ⇒ String
Sub block hash for a given instance Corresponds to the JSON property
subBlock.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReservationBlockPhysicalTopologyInstancePhysicalHostTopology
constructor
A new instance of ReservationBlockPhysicalTopologyInstancePhysicalHostTopology.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReservationBlockPhysicalTopologyInstancePhysicalHostTopology
Returns a new instance of ReservationBlockPhysicalTopologyInstancePhysicalHostTopology.
60785 60786 60787 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 60785 def initialize(**args) update!(**args) end |
Instance Attribute Details
#host ⇒ String
Host hash for a given instance
Corresponds to the JSON property host
60778 60779 60780 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 60778 def host @host end |
#sub_block ⇒ String
Sub block hash for a given instance
Corresponds to the JSON property subBlock
60783 60784 60785 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 60783 def sub_block @sub_block end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
60790 60791 60792 60793 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 60790 def update!(**args) @host = args[:host] if args.key?(:host) @sub_block = args[:sub_block] if args.key?(:sub_block) end |