Class: Google::Apis::ComputeAlpha::ReservationConsumedInstancesListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Response message for listing reservation consumed instances.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReservationConsumedInstancesListResponse

Returns a new instance of ReservationConsumedInstancesListResponse.



61149
61150
61151
# File 'lib/google/apis/compute_alpha/classes.rb', line 61149

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Uniquely identifies the type of this resource. Corresponds to the JSON property id

Returns:

  • (String)


61120
61121
61122
# File 'lib/google/apis/compute_alpha/classes.rb', line 61120

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::ReservationConsumedInstance>

A list of ReservationConsumedInstance resources. Corresponds to the JSON property items



61125
61126
61127
# File 'lib/google/apis/compute_alpha/classes.rb', line 61125

def items
  @items
end

#kindString

Identifies the resource as a list of reservation consumed instances. Corresponds to the JSON property kind

Returns:

  • (String)


61130
61131
61132
# File 'lib/google/apis/compute_alpha/classes.rb', line 61130

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


61136
61137
61138
# File 'lib/google/apis/compute_alpha/classes.rb', line 61136

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


61141
61142
61143
# File 'lib/google/apis/compute_alpha/classes.rb', line 61141

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::ReservationConsumedInstancesListResponse::Warning

[Output Only] Informational warning which replaces the result in some cases. Corresponds to the JSON property warning



61147
61148
61149
# File 'lib/google/apis/compute_alpha/classes.rb', line 61147

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



61154
61155
61156
61157
61158
61159
61160
61161
# File 'lib/google/apis/compute_alpha/classes.rb', line 61154

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end