Class: Google::Apis::ComputeAlpha::ReservationSlot
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::ReservationSlot
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Represents a reservation slot resource.
Instance Attribute Summary collapse
-
#creation_timestamp ⇒ String
Output only.
-
#id ⇒ Fixnum
Output only.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
Output only.
-
#physical_topology ⇒ Google::Apis::ComputeAlpha::ReservationSlotPhysicalTopology
Output only.
-
#self_link ⇒ String
Output only.
-
#self_link_with_id ⇒ String
Output only.
-
#share_settings ⇒ Google::Apis::ComputeAlpha::ShareSettings
The share setting for reservations and sole tenancy node groups.
-
#state ⇒ String
Output only.
-
#status ⇒ Google::Apis::ComputeAlpha::ReservationSlotStatus
Output only.
-
#zone ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReservationSlot
constructor
A new instance of ReservationSlot.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReservationSlot
Returns a new instance of ReservationSlot.
61183 61184 61185 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61183 def initialize(**args) update!(**args) end |
Instance Attribute Details
#creation_timestamp ⇒ String
Output only. [Output Only] The creation timestamp, formatted asRFC3339 text.
Corresponds to the JSON property creationTimestamp
61126 61127 61128 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61126 def @creation_timestamp end |
#id ⇒ Fixnum
Output only. [Output Only] The unique identifier for this resource. This
identifier is
defined by the server.
Corresponds to the JSON property id
61133 61134 61135 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61133 def id @id end |
#kind ⇒ String
Output only. [Output Only] The type of resource. Alwayscompute#reservationSlot
for reservation slots.
Corresponds to the JSON property kind
61139 61140 61141 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61139 def kind @kind end |
#name ⇒ String
Output only. [Output Only] The name of the reservation slot.
Corresponds to the JSON property name
61144 61145 61146 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61144 def name @name end |
#physical_topology ⇒ Google::Apis::ComputeAlpha::ReservationSlotPhysicalTopology
Output only. [Output Only] The physical topology of the reservation slot.
Corresponds to the JSON property physicalTopology
61149 61150 61151 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61149 def physical_topology @physical_topology end |
#self_link ⇒ String
Output only. [Output Only] A server-defined fully-qualified URL for this
resource.
Corresponds to the JSON property selfLink
61155 61156 61157 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61155 def self_link @self_link end |
#self_link_with_id ⇒ String
Output only. [Output Only] A server-defined URL for this resource with the
resource ID.
Corresponds to the JSON property selfLinkWithId
61161 61162 61163 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61161 def self_link_with_id @self_link_with_id end |
#share_settings ⇒ Google::Apis::ComputeAlpha::ShareSettings
The share setting for reservations and sole tenancy node groups.
Corresponds to the JSON property shareSettings
61166 61167 61168 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61166 def share_settings @share_settings end |
#state ⇒ String
Output only. [Output Only] The state of the reservation slot.
Corresponds to the JSON property state
61171 61172 61173 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61171 def state @state end |
#status ⇒ Google::Apis::ComputeAlpha::ReservationSlotStatus
Output only. [Output Only] The status of the reservation slot.
Corresponds to the JSON property status
61176 61177 61178 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61176 def status @status end |
#zone ⇒ String
Output only. [Output Only] The zone in which the reservation slot resides.
Corresponds to the JSON property zone
61181 61182 61183 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61181 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
61188 61189 61190 61191 61192 61193 61194 61195 61196 61197 61198 61199 61200 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61188 def update!(**args) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @physical_topology = args[:physical_topology] if args.key?(:physical_topology) @self_link = args[:self_link] if args.key?(:self_link) @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id) @share_settings = args[:share_settings] if args.key?(:share_settings) @state = args[:state] if args.key?(:state) @status = args[:status] if args.key?(:status) @zone = args[:zone] if args.key?(:zone) end |