Class: Google::Apis::ComputeAlpha::ReservationSlotPhysicalTopology

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReservationSlotPhysicalTopology

Returns a new instance of ReservationSlotPhysicalTopology.



61495
61496
61497
# File 'lib/google/apis/compute_alpha/classes.rb', line 61495

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#blockString

The unique identifier of the capacity block within the cluster. Corresponds to the JSON property block

Returns:

  • (String)


61477
61478
61479
# File 'lib/google/apis/compute_alpha/classes.rb', line 61477

def block
  @block
end

#clusterString

The cluster name of the reservation sub-block. Corresponds to the JSON property cluster

Returns:

  • (String)


61482
61483
61484
# File 'lib/google/apis/compute_alpha/classes.rb', line 61482

def cluster
  @cluster
end

#hostString

The unique identifier of the capacity host within the capacity sub-block. Corresponds to the JSON property host

Returns:

  • (String)


61487
61488
61489
# File 'lib/google/apis/compute_alpha/classes.rb', line 61487

def host
  @host
end

#sub_blockString

The unique identifier of the capacity sub-block within the capacity block. Corresponds to the JSON property subBlock

Returns:

  • (String)


61493
61494
61495
# File 'lib/google/apis/compute_alpha/classes.rb', line 61493

def sub_block
  @sub_block
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



61500
61501
61502
61503
61504
61505
# File 'lib/google/apis/compute_alpha/classes.rb', line 61500

def update!(**args)
  @block = args[:block] if args.key?(:block)
  @cluster = args[:cluster] if args.key?(:cluster)
  @host = args[:host] if args.key?(:host)
  @sub_block = args[:sub_block] if args.key?(:sub_block)
end