Class: Google::Apis::ComputeAlpha::ReservationSubBlocksReportFaultyRequestFaultReason

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

The reason for the fault experienced with the subBlock.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReservationSubBlocksReportFaultyRequestFaultReason

Returns a new instance of ReservationSubBlocksReportFaultyRequestFaultReason.



62111
62112
62113
# File 'lib/google/apis/compute_alpha/classes.rb', line 62111

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#behaviorString

The behavior of the fault experienced with the subBlock. Corresponds to the JSON property behavior

Returns:

  • (String)


62104
62105
62106
# File 'lib/google/apis/compute_alpha/classes.rb', line 62104

def behavior
  @behavior
end

#descriptionString

The description of the fault experienced with the subBlock. Corresponds to the JSON property description

Returns:

  • (String)


62109
62110
62111
# File 'lib/google/apis/compute_alpha/classes.rb', line 62109

def description
  @description
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



62116
62117
62118
62119
# File 'lib/google/apis/compute_alpha/classes.rb', line 62116

def update!(**args)
  @behavior = args[:behavior] if args.key?(:behavior)
  @description = args[:description] if args.key?(:description)
end