Class: Google::Apis::ComputeAlpha::ReservationsBlocksPerformMaintenanceRequest
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::ReservationsBlocksPerformMaintenanceRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#maintenance_scope ⇒ String
Specifies if all, running or unused hosts are in scope for this request.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReservationsBlocksPerformMaintenanceRequest
constructor
A new instance of ReservationsBlocksPerformMaintenanceRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReservationsBlocksPerformMaintenanceRequest
Returns a new instance of ReservationsBlocksPerformMaintenanceRequest.
60201 60202 60203 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 60201 def initialize(**args) update!(**args) end |
Instance Attribute Details
#maintenance_scope ⇒ String
Specifies if all, running or unused hosts are in scope for this request.
Corresponds to the JSON property maintenanceScope
60199 60200 60201 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 60199 def maintenance_scope @maintenance_scope end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
60206 60207 60208 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 60206 def update!(**args) @maintenance_scope = args[:maintenance_scope] if args.key?(:maintenance_scope) end |