Class: Google::Apis::ComputeAlpha::ReservationsScopedList::Warning

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Informational warning which replaces the list of reservations when the list is empty.

Defined Under Namespace

Classes: Datum

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Warning

Returns a new instance of Warning.



61966
61967
61968
# File 'lib/google/apis/compute_alpha/classes.rb', line 61966

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#codeString

[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response. Corresponds to the JSON property code

Returns:

  • (String)


61948
61949
61950
# File 'lib/google/apis/compute_alpha/classes.rb', line 61948

def code
  @code
end

#dataArray<Google::Apis::ComputeAlpha::ReservationsScopedList::Warning::Datum>

[Output Only] Metadata about this warning in key: value format. For example: "data": [ "key": "scope", "value": "zones/us-east1-d" ] Corresponds to the JSON property data



61959
61960
61961
# File 'lib/google/apis/compute_alpha/classes.rb', line 61959

def data
  @data
end

#messageString

[Output Only] A human-readable description of the warning code. Corresponds to the JSON property message

Returns:

  • (String)


61964
61965
61966
# File 'lib/google/apis/compute_alpha/classes.rb', line 61964

def message
  @message
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



61971
61972
61973
61974
61975
# File 'lib/google/apis/compute_alpha/classes.rb', line 61971

def update!(**args)
  @code = args[:code] if args.key?(:code)
  @data = args[:data] if args.key?(:data)
  @message = args[:message] if args.key?(:message)
end