Class: Google::Apis::ComputeAlpha::ResourceGroupReference
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::ResourceGroupReference
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#group ⇒ String
A URI referencing one of the instance groups or network endpoint groups listed in the backend service.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ResourceGroupReference
constructor
A new instance of ResourceGroupReference.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ResourceGroupReference
Returns a new instance of ResourceGroupReference.
60432 60433 60434 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 60432 def initialize(**args) update!(**args) end |
Instance Attribute Details
#group ⇒ String
A URI referencing one of the instance groups or network endpoint groups
listed in the backend service.
Corresponds to the JSON property group
60430 60431 60432 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 60430 def group @group end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
60437 60438 60439 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 60437 def update!(**args) @group = args[:group] if args.key?(:group) end |