Class: Google::Apis::ComputeAlpha::ResourcePolicyDailyCycle
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::ResourcePolicyDailyCycle
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Time window specified for daily operations.
Instance Attribute Summary collapse
-
#days_in_cycle ⇒ Fixnum
Defines a schedule with units measured in days.
-
#duration ⇒ String
Output only.
-
#start_time ⇒ String
Start time of the window.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ResourcePolicyDailyCycle
constructor
A new instance of ResourcePolicyDailyCycle.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ResourcePolicyDailyCycle
Returns a new instance of ResourcePolicyDailyCycle.
60831 60832 60833 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 60831 def initialize(**args) update!(**args) end |
Instance Attribute Details
#days_in_cycle ⇒ Fixnum
Defines a schedule with units measured in days. The value determines
how many days pass between the start of each cycle.
Corresponds to the JSON property daysInCycle
60815 60816 60817 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 60815 def days_in_cycle @days_in_cycle end |
#duration ⇒ String
Output only. [Output only] A predetermined duration for the window,
automatically
chosen to be the smallest possible in the given scenario.
Corresponds to the JSON property duration
60822 60823 60824 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 60822 def duration @duration end |
#start_time ⇒ String
Start time of the window. This must be in UTC format that resolves to one
of 00:00, 04:00, 08:00,12:00, 16:00, or 20:00. For
example, both 13:00-5 and 08:00 are valid.
Corresponds to the JSON property startTime
60829 60830 60831 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 60829 def start_time @start_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
60836 60837 60838 60839 60840 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 60836 def update!(**args) @days_in_cycle = args[:days_in_cycle] if args.key?(:days_in_cycle) @duration = args[:duration] if args.key?(:duration) @start_time = args[:start_time] if args.key?(:start_time) end |