Class: Google::Apis::ComputeAlpha::ResourcePolicySnapshotSchedulePolicy
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::ResourcePolicySnapshotSchedulePolicy
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
A snapshot schedule policy specifies when and how frequently snapshots are to be created for the target disk. Also specifies how many and how long these scheduled snapshots should be retained.
Instance Attribute Summary collapse
-
#retention_policy ⇒ Google::Apis::ComputeAlpha::ResourcePolicySnapshotSchedulePolicyRetentionPolicy
Policy for retention of scheduled snapshots.
-
#schedule ⇒ Google::Apis::ComputeAlpha::ResourcePolicySnapshotSchedulePolicySchedule
A schedule for disks where the schedueled operations are performed.
-
#snapshot_properties ⇒ Google::Apis::ComputeAlpha::ResourcePolicySnapshotSchedulePolicySnapshotProperties
Specified snapshot properties for scheduled snapshots created by this policy.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ResourcePolicySnapshotSchedulePolicy
constructor
A new instance of ResourcePolicySnapshotSchedulePolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ResourcePolicySnapshotSchedulePolicy
Returns a new instance of ResourcePolicySnapshotSchedulePolicy.
63142 63143 63144 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63142 def initialize(**args) update!(**args) end |
Instance Attribute Details
#retention_policy ⇒ Google::Apis::ComputeAlpha::ResourcePolicySnapshotSchedulePolicyRetentionPolicy
Policy for retention of scheduled snapshots.
Corresponds to the JSON property retentionPolicy
63129 63130 63131 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63129 def retention_policy @retention_policy end |
#schedule ⇒ Google::Apis::ComputeAlpha::ResourcePolicySnapshotSchedulePolicySchedule
A schedule for disks where the schedueled operations are performed.
Corresponds to the JSON property schedule
63134 63135 63136 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63134 def schedule @schedule end |
#snapshot_properties ⇒ Google::Apis::ComputeAlpha::ResourcePolicySnapshotSchedulePolicySnapshotProperties
Specified snapshot properties for scheduled snapshots created by this
policy.
Corresponds to the JSON property snapshotProperties
63140 63141 63142 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63140 def snapshot_properties @snapshot_properties end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
63147 63148 63149 63150 63151 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63147 def update!(**args) @retention_policy = args[:retention_policy] if args.key?(:retention_policy) @schedule = args[:schedule] if args.key?(:schedule) @snapshot_properties = args[:snapshot_properties] if args.key?(:snapshot_properties) end |