Class: Google::Apis::ComputeAlpha::ResourcePolicySnapshotSchedulePolicyRetentionPolicy
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::ResourcePolicySnapshotSchedulePolicyRetentionPolicy
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Policy for retention of scheduled snapshots.
Instance Attribute Summary collapse
-
#max_retention_days ⇒ Fixnum
Maximum age of the snapshot that is allowed to be kept.
-
#on_policy_switch ⇒ String
Corresponds to the JSON property
onPolicySwitch. -
#on_source_disk_delete ⇒ String
Specifies the behavior to apply to scheduled snapshots when the source disk is deleted.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ResourcePolicySnapshotSchedulePolicyRetentionPolicy
constructor
A new instance of ResourcePolicySnapshotSchedulePolicyRetentionPolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ResourcePolicySnapshotSchedulePolicyRetentionPolicy
Returns a new instance of ResourcePolicySnapshotSchedulePolicyRetentionPolicy.
63174 63175 63176 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63174 def initialize(**args) update!(**args) end |
Instance Attribute Details
#max_retention_days ⇒ Fixnum
Maximum age of the snapshot that is allowed to be kept.
Corresponds to the JSON property maxRetentionDays
63161 63162 63163 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63161 def max_retention_days @max_retention_days end |
#on_policy_switch ⇒ String
Corresponds to the JSON property onPolicySwitch
63166 63167 63168 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63166 def on_policy_switch @on_policy_switch end |
#on_source_disk_delete ⇒ String
Specifies the behavior to apply to scheduled snapshots when
the source disk is deleted.
Corresponds to the JSON property onSourceDiskDelete
63172 63173 63174 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63172 def on_source_disk_delete @on_source_disk_delete end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
63179 63180 63181 63182 63183 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63179 def update!(**args) @max_retention_days = args[:max_retention_days] if args.key?(:max_retention_days) @on_policy_switch = args[:on_policy_switch] if args.key?(:on_policy_switch) @on_source_disk_delete = args[:on_source_disk_delete] if args.key?(:on_source_disk_delete) end |