Class: Google::Apis::ComputeAlpha::ResourcePolicyWeeklyCycleDayOfWeek
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::ResourcePolicyWeeklyCycleDayOfWeek
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#day ⇒ String
Defines a schedule that runs on specific days of the week.
-
#duration ⇒ String
Output only.
-
#start_time ⇒ String
Time within the window to start the operations.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ResourcePolicyWeeklyCycleDayOfWeek
constructor
A new instance of ResourcePolicyWeeklyCycleDayOfWeek.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ResourcePolicyWeeklyCycleDayOfWeek
Returns a new instance of ResourcePolicyWeeklyCycleDayOfWeek.
60888 60889 60890 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 60888 def initialize(**args) update!(**args) end |
Instance Attribute Details
#day ⇒ String
Defines a schedule that runs on specific days of the week. Specify
one or more days. The following options are available:
MONDAY, TUESDAY, WEDNESDAY, THURSDAY, FRIDAY, SATURDAY, SUNDAY.
Corresponds to the JSON property day
60873 60874 60875 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 60873 def day @day end |
#duration ⇒ String
Output only. [Output only] Duration of the time window, automatically chosen
to be
smallest possible in the given scenario.
Corresponds to the JSON property duration
60880 60881 60882 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 60880 def duration @duration end |
#start_time ⇒ String
Time within the window to start the operations.
It must be in format "HH:MM", where HH : [00-23] and MM : [00-00] GMT.
Corresponds to the JSON property startTime
60886 60887 60888 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 60886 def start_time @start_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
60893 60894 60895 60896 60897 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 60893 def update!(**args) @day = args[:day] if args.key?(:day) @duration = args[:duration] if args.key?(:duration) @start_time = args[:start_time] if args.key?(:start_time) end |