Class: Google::Apis::ComputeAlpha::ResourceStatus

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains output only fields. Use this sub-message for actual values set on Instance attributes as compared to the value requested by the user (intent) in their instance CRUD calls.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ResourceStatus

Returns a new instance of ResourceStatus.



63513
63514
63515
# File 'lib/google/apis/compute_alpha/classes.rb', line 63513

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#accelerator_statusArray<Google::Apis::ComputeAlpha::ResourceStatusAcceleratorStatus>

Output only. [Output Only] Accelerators status show results of GPU scans. These scans are specialized diagnostic tests designed to uncover latent manufacturing defects or other issues that could potentially lead to data corruption or impede the customer's ability to efficiently execute GPU workloads. Corresponds to the JSON property acceleratorStatus



63444
63445
63446
# File 'lib/google/apis/compute_alpha/classes.rb', line 63444

def accelerator_status
  @accelerator_status
end

#consumed_reservationString

Output only. [Output Only] The full resource name of the reservation that this instance is consuming from. Corresponds to the JSON property consumedReservation

Returns:

  • (String)


63451
63452
63453
# File 'lib/google/apis/compute_alpha/classes.rb', line 63451

def consumed_reservation
  @consumed_reservation
end

#consumed_reservation_blockString

Output only. [Output Only] The full resource name of the reservation block that this instance is consuming from. Corresponds to the JSON property consumedReservationBlock

Returns:

  • (String)


63458
63459
63460
# File 'lib/google/apis/compute_alpha/classes.rb', line 63458

def consumed_reservation_block
  @consumed_reservation_block
end

#effective_instance_metadataGoogle::Apis::ComputeAlpha::ResourceStatusEffectiveInstanceMetadata

Effective values of predefined metadata keys for an instance. Corresponds to the JSON property effectiveInstanceMetadata



63463
63464
63465
# File 'lib/google/apis/compute_alpha/classes.rb', line 63463

def 
  @effective_instance_metadata
end

#last_instance_termination_detailsGoogle::Apis::ComputeAlpha::ResourceStatusLastInstanceTerminationDetails

Output only. [Output Only] Contains last termination details why the instance was terminated. Corresponds to the JSON property lastInstanceTerminationDetails



63470
63471
63472
# File 'lib/google/apis/compute_alpha/classes.rb', line 63470

def last_instance_termination_details
  @last_instance_termination_details
end

#physical_hostString

Output only. [Output Only] The precise location of your instance within the zone's data center, including the block, sub-block, and host. The field is formatted as follows: blockId/subBlockId/hostId. Corresponds to the JSON property physicalHost

Returns:

  • (String)


63478
63479
63480
# File 'lib/google/apis/compute_alpha/classes.rb', line 63478

def physical_host
  @physical_host
end

#physical_host_topologyGoogle::Apis::ComputeAlpha::ResourceStatusPhysicalHostTopology

Represents the physical host topology of the host on which the VM is running. Corresponds to the JSON property physicalHostTopology



63484
63485
63486
# File 'lib/google/apis/compute_alpha/classes.rb', line 63484

def physical_host_topology
  @physical_host_topology
end

#reservation_consumption_infoGoogle::Apis::ComputeAlpha::ResourceStatusReservationConsumptionInfo

Reservation consumption information that the instance is consuming from. Corresponds to the JSON property reservationConsumptionInfo



63489
63490
63491
# File 'lib/google/apis/compute_alpha/classes.rb', line 63489

def reservation_consumption_info
  @reservation_consumption_info
end

#schedulingGoogle::Apis::ComputeAlpha::ResourceStatusScheduling

Corresponds to the JSON property scheduling



63494
63495
63496
# File 'lib/google/apis/compute_alpha/classes.rb', line 63494

def scheduling
  @scheduling
end

#service_integration_statusesHash<String,Google::Apis::ComputeAlpha::ResourceStatusServiceIntegrationStatus>

[Output Only] Represents the status of the service integration specs defined by the user in instance.serviceIntegrationSpecs. Corresponds to the JSON property serviceIntegrationStatuses



63500
63501
63502
# File 'lib/google/apis/compute_alpha/classes.rb', line 63500

def service_integration_statuses
  @service_integration_statuses
end

#shutdown_detailsGoogle::Apis::ComputeAlpha::ResourceStatusShutdownDetails

Specifies if the instance is in PENDING_STOP state or there is a programmed stop scheduled. Corresponds to the JSON property shutdownDetails



63506
63507
63508
# File 'lib/google/apis/compute_alpha/classes.rb', line 63506

def shutdown_details
  @shutdown_details
end

#upcoming_maintenanceGoogle::Apis::ComputeAlpha::UpcomingMaintenance

Upcoming Maintenance notification information. Corresponds to the JSON property upcomingMaintenance



63511
63512
63513
# File 'lib/google/apis/compute_alpha/classes.rb', line 63511

def upcoming_maintenance
  @upcoming_maintenance
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



63518
63519
63520
63521
63522
63523
63524
63525
63526
63527
63528
63529
63530
63531
# File 'lib/google/apis/compute_alpha/classes.rb', line 63518

def update!(**args)
  @accelerator_status = args[:accelerator_status] if args.key?(:accelerator_status)
  @consumed_reservation = args[:consumed_reservation] if args.key?(:consumed_reservation)
  @consumed_reservation_block = args[:consumed_reservation_block] if args.key?(:consumed_reservation_block)
  @effective_instance_metadata = args[:effective_instance_metadata] if args.key?(:effective_instance_metadata)
  @last_instance_termination_details = args[:last_instance_termination_details] if args.key?(:last_instance_termination_details)
  @physical_host = args[:physical_host] if args.key?(:physical_host)
  @physical_host_topology = args[:physical_host_topology] if args.key?(:physical_host_topology)
  @reservation_consumption_info = args[:reservation_consumption_info] if args.key?(:reservation_consumption_info)
  @scheduling = args[:scheduling] if args.key?(:scheduling)
  @service_integration_statuses = args[:service_integration_statuses] if args.key?(:service_integration_statuses)
  @shutdown_details = args[:shutdown_details] if args.key?(:shutdown_details)
  @upcoming_maintenance = args[:upcoming_maintenance] if args.key?(:upcoming_maintenance)
end