Class: Google::Apis::ComputeAlpha::ResourceStatusAcceleratorStatus
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::ResourceStatusAcceleratorStatus
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
The status of an individual accelerator resource.
Instance Attribute Summary collapse
-
#passed_scans ⇒ Array<Google::Apis::ComputeAlpha::ResourceStatusAcceleratorStatusPassedScan>
The details of scans that passed for an accelerator.
-
#recommended_scans ⇒ Array<Google::Apis::ComputeAlpha::ResourceStatusAcceleratorStatusRecommendedScan>
The details of recommended scans for an accelerator.
-
#serial_number ⇒ String
The serial number of the accelerator.
-
#uuid ⇒ String
The UUID of the accelerator.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ResourceStatusAcceleratorStatus
constructor
A new instance of ResourceStatusAcceleratorStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ResourceStatusAcceleratorStatus
Returns a new instance of ResourceStatusAcceleratorStatus.
63558 63559 63560 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63558 def initialize(**args) update!(**args) end |
Instance Attribute Details
#passed_scans ⇒ Array<Google::Apis::ComputeAlpha::ResourceStatusAcceleratorStatusPassedScan>
The details of scans that passed for an accelerator.
Corresponds to the JSON property passedScans
63541 63542 63543 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63541 def passed_scans @passed_scans end |
#recommended_scans ⇒ Array<Google::Apis::ComputeAlpha::ResourceStatusAcceleratorStatusRecommendedScan>
The details of recommended scans for an accelerator.
Corresponds to the JSON property recommendedScans
63546 63547 63548 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63546 def recommended_scans @recommended_scans end |
#serial_number ⇒ String
The serial number of the accelerator.
Corresponds to the JSON property serialNumber
63551 63552 63553 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63551 def serial_number @serial_number end |
#uuid ⇒ String
The UUID of the accelerator.
Corresponds to the JSON property uuid
63556 63557 63558 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63556 def uuid @uuid end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
63563 63564 63565 63566 63567 63568 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63563 def update!(**args) @passed_scans = args[:passed_scans] if args.key?(:passed_scans) @recommended_scans = args[:recommended_scans] if args.key?(:recommended_scans) @serial_number = args[:serial_number] if args.key?(:serial_number) @uuid = args[:uuid] if args.key?(:uuid) end |