Class: Google::Apis::ComputeAlpha::RiskDetails

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Detailed insights and metrics about a detected reliability risk.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RiskDetails

Returns a new instance of RiskDetails.



64012
64013
64014
# File 'lib/google/apis/compute_alpha/classes.rb', line 64012

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#durationString

The duration of the risk since it was detected. Corresponds to the JSON property duration

Returns:

  • (String)


63990
63991
63992
# File 'lib/google/apis/compute_alpha/classes.rb', line 63990

def duration
  @duration
end

#global_dns_insightGoogle::Apis::ComputeAlpha::RiskDetailsGlobalDnsInsight

Detailed insights for a global DNS reliability risk. Corresponds to the JSON property globalDnsInsight



63995
63996
63997
# File 'lib/google/apis/compute_alpha/classes.rb', line 63995

def global_dns_insight
  @global_dns_insight
end

#last_update_timestampString

The last time the risk was updated. Corresponds to the JSON property lastUpdateTimestamp

Returns:

  • (String)


64000
64001
64002
# File 'lib/google/apis/compute_alpha/classes.rb', line 64000

def last_update_timestamp
  @last_update_timestamp
end

#severityString

The severity of the risk. Corresponds to the JSON property severity

Returns:

  • (String)


64005
64006
64007
# File 'lib/google/apis/compute_alpha/classes.rb', line 64005

def severity
  @severity
end

#typeString

The type of risk. Corresponds to the JSON property type

Returns:

  • (String)


64010
64011
64012
# File 'lib/google/apis/compute_alpha/classes.rb', line 64010

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



64017
64018
64019
64020
64021
64022
64023
# File 'lib/google/apis/compute_alpha/classes.rb', line 64017

def update!(**args)
  @duration = args[:duration] if args.key?(:duration)
  @global_dns_insight = args[:global_dns_insight] if args.key?(:global_dns_insight)
  @last_update_timestamp = args[:last_update_timestamp] if args.key?(:last_update_timestamp)
  @severity = args[:severity] if args.key?(:severity)
  @type = args[:type] if args.key?(:type)
end