Class: Google::Apis::ComputeAlpha::RiskDetailsGlobalDnsInsight

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Detailed insights for a global DNS reliability risk.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RiskDetailsGlobalDnsInsight

Returns a new instance of RiskDetailsGlobalDnsInsight.



63491
63492
63493
# File 'lib/google/apis/compute_alpha/classes.rb', line 63491

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#project_default_is_global_dnsBoolean Also known as: project_default_is_global_dns?

Indicates whether the project's default DNS setting is global DNS. Corresponds to the JSON property projectDefaultIsGlobalDns

Returns:

  • (Boolean)


63472
63473
63474
# File 'lib/google/apis/compute_alpha/classes.rb', line 63472

def project_default_is_global_dns
  @project_default_is_global_dns
end

#query_observation_windowString

The observation window for the query counts. Corresponds to the JSON property queryObservationWindow

Returns:

  • (String)


63478
63479
63480
# File 'lib/google/apis/compute_alpha/classes.rb', line 63478

def query_observation_window
  @query_observation_window
end

#risky_query_countFixnum

The number of queries that are risky. This is always less than or equal to total_query_count. Corresponds to the JSON property riskyQueryCount

Returns:

  • (Fixnum)


63484
63485
63486
# File 'lib/google/apis/compute_alpha/classes.rb', line 63484

def risky_query_count
  @risky_query_count
end

#total_query_countFixnum

The total number of queries in the observation window. Corresponds to the JSON property totalQueryCount

Returns:

  • (Fixnum)


63489
63490
63491
# File 'lib/google/apis/compute_alpha/classes.rb', line 63489

def total_query_count
  @total_query_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



63496
63497
63498
63499
63500
63501
# File 'lib/google/apis/compute_alpha/classes.rb', line 63496

def update!(**args)
  @project_default_is_global_dns = args[:project_default_is_global_dns] if args.key?(:project_default_is_global_dns)
  @query_observation_window = args[:query_observation_window] if args.key?(:query_observation_window)
  @risky_query_count = args[:risky_query_count] if args.key?(:risky_query_count)
  @total_query_count = args[:total_query_count] if args.key?(:total_query_count)
end