Class: Google::Apis::ComputeAlpha::RolloutPlanWave

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

A single wave in a rollout plan.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RolloutPlanWave

Returns a new instance of RolloutPlanWave.



64074
64075
64076
# File 'lib/google/apis/compute_alpha/classes.rb', line 64074

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

Optional. The display name of this wave of the rollout plan. Corresponds to the JSON property displayName

Returns:

  • (String)


64047
64048
64049
# File 'lib/google/apis/compute_alpha/classes.rb', line 64047

def display_name
  @display_name
end

#numberFixnum

Output only. The wave number. Corresponds to the JSON property number

Returns:

  • (Fixnum)


64052
64053
64054
# File 'lib/google/apis/compute_alpha/classes.rb', line 64052

def number
  @number
end

#orchestration_optionsGoogle::Apis::ComputeAlpha::RolloutPlanWaveOrchestrationOptions

Options to control the pace of orchestration of a wave. These options are required only if the resource being rolled out follows the Orchestrated pattern. Corresponds to the JSON property orchestrationOptions



64059
64060
64061
# File 'lib/google/apis/compute_alpha/classes.rb', line 64059

def orchestration_options
  @orchestration_options
end

#selectorsArray<Google::Apis::ComputeAlpha::RolloutPlanWaveSelector>

Required. The selectors for this wave. There is a logical AND between each selector defined in a wave, so a resource must satisfy the criteria of all the specified selectors to be in scope for the wave. Corresponds to the JSON property selectors



64067
64068
64069
# File 'lib/google/apis/compute_alpha/classes.rb', line 64067

def selectors
  @selectors
end

#validationGoogle::Apis::ComputeAlpha::RolloutPlanWaveValidation

The validation to be performed before progressing to the next wave. Corresponds to the JSON property validation



64072
64073
64074
# File 'lib/google/apis/compute_alpha/classes.rb', line 64072

def validation
  @validation
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



64079
64080
64081
64082
64083
64084
64085
# File 'lib/google/apis/compute_alpha/classes.rb', line 64079

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @number = args[:number] if args.key?(:number)
  @orchestration_options = args[:orchestration_options] if args.key?(:orchestration_options)
  @selectors = args[:selectors] if args.key?(:selectors)
  @validation = args[:validation] if args.key?(:validation)
end