Class: Google::Apis::ComputeAlpha::RolloutPlanWaveOrchestrationOptions
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::RolloutPlanWaveOrchestrationOptions
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Options to control the pace of orchestration of a wave. These options are required only if the resource being rolled out follows the Orchestrated pattern.
Instance Attribute Summary collapse
-
#delays ⇒ Array<Google::Apis::ComputeAlpha::RolloutPlanWaveOrchestrationOptionsDelay>
Optional.
-
#max_concurrent_locations ⇒ Fixnum
Optional.
-
#max_concurrent_resources_per_location ⇒ Fixnum
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RolloutPlanWaveOrchestrationOptions
constructor
A new instance of RolloutPlanWaveOrchestrationOptions.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RolloutPlanWaveOrchestrationOptions
Returns a new instance of RolloutPlanWaveOrchestrationOptions.
64380 64381 64382 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64380 def initialize(**args) update!(**args) end |
Instance Attribute Details
#delays ⇒ Array<Google::Apis::ComputeAlpha::RolloutPlanWaveOrchestrationOptionsDelay>
Optional. Delays, if any, to be added between batches of projects. We allow
multiple Delays to be specified, letting users set separate delays
between batches of projects corresponding to different locations and
batches of projects corresponding to the same location.
Corresponds to the JSON property delays
64367 64368 64369 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64367 def delays @delays end |
#max_concurrent_locations ⇒ Fixnum
Optional. Maximum number of locations to be orchestrated in parallel.
Corresponds to the JSON property maxConcurrentLocations
64372 64373 64374 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64372 def max_concurrent_locations @max_concurrent_locations end |
#max_concurrent_resources_per_location ⇒ Fixnum
Optional. Maximum number of resources to be orchestrated per location in
parallel.
Corresponds to the JSON property maxConcurrentResourcesPerLocation
64378 64379 64380 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64378 def max_concurrent_resources_per_location @max_concurrent_resources_per_location end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
64385 64386 64387 64388 64389 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64385 def update!(**args) @delays = args[:delays] if args.key?(:delays) @max_concurrent_locations = args[:max_concurrent_locations] if args.key?(:max_concurrent_locations) @max_concurrent_resources_per_location = args[:max_concurrent_resources_per_location] if args.key?(:max_concurrent_resources_per_location) end |