Class: Google::Apis::ComputeAlpha::RolloutPlanWaveSelector
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::RolloutPlanWaveSelector
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
A selector which specifies what resource(s) are included in a given wave.
Instance Attribute Summary collapse
-
#location_selector ⇒ Google::Apis::ComputeAlpha::RolloutPlanWaveSelectorLocationSelector
Roll out to resources by location.
-
#resource_hierarchy_selector ⇒ Google::Apis::ComputeAlpha::RolloutPlanWaveSelectorResourceHierarchySelector
Roll out to resources by Cloud Resource Manager resource hierarchy nodes such as projects, folders, orgs.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RolloutPlanWaveSelector
constructor
A new instance of RolloutPlanWaveSelector.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RolloutPlanWaveSelector
Returns a new instance of RolloutPlanWaveSelector.
63884 63885 63886 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63884 def initialize(**args) update!(**args) end |
Instance Attribute Details
#location_selector ⇒ Google::Apis::ComputeAlpha::RolloutPlanWaveSelectorLocationSelector
Roll out to resources by location.
Corresponds to the JSON property locationSelector
63876 63877 63878 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63876 def location_selector @location_selector end |
#resource_hierarchy_selector ⇒ Google::Apis::ComputeAlpha::RolloutPlanWaveSelectorResourceHierarchySelector
Roll out to resources by Cloud Resource Manager resource hierarchy
nodes such as projects, folders, orgs.
Corresponds to the JSON property resourceHierarchySelector
63882 63883 63884 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63882 def resource_hierarchy_selector @resource_hierarchy_selector end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
63889 63890 63891 63892 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63889 def update!(**args) @location_selector = args[:location_selector] if args.key?(:location_selector) @resource_hierarchy_selector = args[:resource_hierarchy_selector] if args.key?(:resource_hierarchy_selector) end |