Class: Google::Apis::ComputeAlpha::RolloutPlanWaveValidation

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

The validation to be performed before progressing to the next wave.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RolloutPlanWaveValidation

Returns a new instance of RolloutPlanWaveValidation.



61993
61994
61995
# File 'lib/google/apis/compute_alpha/classes.rb', line 61993

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#time_based_validation_metadataGoogle::Apis::ComputeAlpha::RolloutPlanWaveValidationTimeBasedValidationMetadata

Metadata required if type = "time". Corresponds to the JSON property timeBasedValidationMetadata



61978
61979
61980
# File 'lib/google/apis/compute_alpha/classes.rb', line 61978

def 
  @time_based_validation_metadata
end

#typeString

Required. The type of the validation. If a type of validation is associated with a metadata object, the appropriate metadata field mapping to the validation type must be provided in the validation message. Possible values are in quotes below alongside an explanation: "manual": The system waits for an end-user approval API before progressing to the next wave. "time": The system waits for a user specified duration before progressing to the next wave. TimeBasedValidation must be provided. Corresponds to the JSON property type

Returns:

  • (String)


61991
61992
61993
# File 'lib/google/apis/compute_alpha/classes.rb', line 61991

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



61998
61999
62000
62001
# File 'lib/google/apis/compute_alpha/classes.rb', line 61998

def update!(**args)
  @time_based_validation_metadata = args[:time_based_validation_metadata] if args.key?(:time_based_validation_metadata)
  @type = args[:type] if args.key?(:type)
end