Class: Google::Apis::ComputeAlpha::RolloutPlansListResponse
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::RolloutPlansListResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Contains a list of RolloutPlan resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::RolloutPlan>
A list of RolloutPlan resources.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::RolloutPlansListResponse::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RolloutPlansListResponse
constructor
A new instance of RolloutPlansListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RolloutPlansListResponse
Returns a new instance of RolloutPlansListResponse.
64606 64607 64608 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64606 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
64568 64569 64570 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64568 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
64573 64574 64575 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64573 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::RolloutPlan>
A list of RolloutPlan resources.
Corresponds to the JSON property items
64578 64579 64580 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64578 def items @items end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
64588 64589 64590 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64588 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
64593 64594 64595 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64593 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
end_interface: MixerListResponseWithEtagBuilder
Corresponds to the JSON property unreachables
64599 64600 64601 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64599 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::RolloutPlansListResponse::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
64604 64605 64606 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64604 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
64611 64612 64613 64614 64615 64616 64617 64618 64619 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64611 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |