Class: Google::Apis::ComputeAlpha::RolloutRolloutEntityOrchestratedEntity

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

This message is used if the resource type follows the Orchestrated integration model with ProgressiveRollout.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RolloutRolloutEntityOrchestratedEntity

Returns a new instance of RolloutRolloutEntityOrchestratedEntity.



61172
61173
61174
# File 'lib/google/apis/compute_alpha/classes.rb', line 61172

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#conflict_behaviorString

Required. Specifies the behavior of the Rollout if an out of band update is detected in a project during a Rollout. It can be one of the following values: 1) overwrite : Overwrite the local value with the rollout value. 2) no_overwrite : Do not overwrite the local value with the rollout value. Corresponds to the JSON property conflictBehavior

Returns:

  • (String)


61147
61148
61149
# File 'lib/google/apis/compute_alpha/classes.rb', line 61147

def conflict_behavior
  @conflict_behavior
end

#orchestration_actionString

Required. Orchestration action during the Rollout. It can be one of the following values: 1) "update": Resources will be updated by the rollout. 2) "delete": Resources will be deleted by the rollout. Corresponds to the JSON property orchestrationAction

Returns:

  • (String)


61156
61157
61158
# File 'lib/google/apis/compute_alpha/classes.rb', line 61156

def orchestration_action
  @orchestration_action
end

#orchestration_sourceString

Required. Fully qualified resource name of the resource which contains the source of truth of the configuration being rolled out across locations/projects. For example, in the case of a global Rollout which is applied across regions, this contains the name of the global resource created by the user which contains a payload for a resource that is orchestrated across regions. This follows the following format: //.googleapis.com/projects//locations/global// e.g. //osconfig.googleapis.com/projects/1/locations/global/policyOrchestrators/po1 Corresponds to the JSON property orchestrationSource

Returns:

  • (String)


61170
61171
61172
# File 'lib/google/apis/compute_alpha/classes.rb', line 61170

def orchestration_source
  @orchestration_source
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



61177
61178
61179
61180
61181
# File 'lib/google/apis/compute_alpha/classes.rb', line 61177

def update!(**args)
  @conflict_behavior = args[:conflict_behavior] if args.key?(:conflict_behavior)
  @orchestration_action = args[:orchestration_action] if args.key?(:orchestration_action)
  @orchestration_source = args[:orchestration_source] if args.key?(:orchestration_source)
end