Class: Google::Apis::ComputeAlpha::Router

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Represents a Cloud Router resource. For more information about Cloud Router, read theCloud Router overview.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Router

Returns a new instance of Router.



65799
65800
65801
# File 'lib/google/apis/compute_alpha/classes.rb', line 65799

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bgpGoogle::Apis::ComputeAlpha::RouterBgp

BGP information specific to this router. Corresponds to the JSON property bgp



65683
65684
65685
# File 'lib/google/apis/compute_alpha/classes.rb', line 65683

def bgp
  @bgp
end

#bgp_peersArray<Google::Apis::ComputeAlpha::RouterBgpPeer>

BGP information that must be configured into the routing stack to establish BGP peering. This information must specify the peer ASN and either the interface name, IP address, or peer IP address. Please refer toRFC4273. Corresponds to the JSON property bgpPeers



65691
65692
65693
# File 'lib/google/apis/compute_alpha/classes.rb', line 65691

def bgp_peers
  @bgp_peers
end

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


65697
65698
65699
# File 'lib/google/apis/compute_alpha/classes.rb', line 65697

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


65703
65704
65705
# File 'lib/google/apis/compute_alpha/classes.rb', line 65703

def description
  @description
end

#encrypted_interconnect_routerBoolean Also known as: encrypted_interconnect_router?

Indicates if a router is dedicated for use with encrypted VLAN attachments (interconnectAttachments). Corresponds to the JSON property encryptedInterconnectRouter

Returns:

  • (Boolean)


65709
65710
65711
# File 'lib/google/apis/compute_alpha/classes.rb', line 65709

def encrypted_interconnect_router
  @encrypted_interconnect_router
end

#etagString

ETag for optimistic concurrency control as described by AIP 154. Used to prevent conflicting updates. If provided, the request will succeed only if the etag matches the current etag of the router; otherwise, the request fails with an ABORTED error. Corresponds to the JSON property etag

Returns:

  • (String)


65718
65719
65720
# File 'lib/google/apis/compute_alpha/classes.rb', line 65718

def etag
  @etag
end

#idFixnum

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


65724
65725
65726
# File 'lib/google/apis/compute_alpha/classes.rb', line 65724

def id
  @id
end

#interfacesArray<Google::Apis::ComputeAlpha::RouterInterface>

Router interfaces. To create a BGP peer that uses a router interface, the interface must have one of the following fields specified:

  • linkedVpnTunnel
  • linkedInterconnectAttachment
  • subnetwork You can create a router interface without any of these fields specified. However, you cannot create a BGP peer that uses that interface. Corresponds to the JSON property interfaces


65737
65738
65739
# File 'lib/google/apis/compute_alpha/classes.rb', line 65737

def interfaces
  @interfaces
end

#kindString

Output only. [Output Only] Type of resource. Always compute#router for routers. Corresponds to the JSON property kind

Returns:

  • (String)


65743
65744
65745
# File 'lib/google/apis/compute_alpha/classes.rb', line 65743

def kind
  @kind
end

#md5_authentication_keysArray<Google::Apis::ComputeAlpha::RouterMd5AuthenticationKey>

Keys used for MD5 authentication. Corresponds to the JSON property md5AuthenticationKeys



65748
65749
65750
# File 'lib/google/apis/compute_alpha/classes.rb', line 65748

def md5_authentication_keys
  @md5_authentication_keys
end

#nameString

Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


65759
65760
65761
# File 'lib/google/apis/compute_alpha/classes.rb', line 65759

def name
  @name
end

#natsArray<Google::Apis::ComputeAlpha::RouterNat>

A list of NAT services created in this router. Corresponds to the JSON property nats



65764
65765
65766
# File 'lib/google/apis/compute_alpha/classes.rb', line 65764

def nats
  @nats
end

#ncc_gatewayString

URI of the ncc_gateway to which this router associated. Corresponds to the JSON property nccGateway

Returns:

  • (String)


65769
65770
65771
# File 'lib/google/apis/compute_alpha/classes.rb', line 65769

def ncc_gateway
  @ncc_gateway
end

#networkString

URI of the network to which this router belongs. Corresponds to the JSON property network

Returns:

  • (String)


65774
65775
65776
# File 'lib/google/apis/compute_alpha/classes.rb', line 65774

def network
  @network
end

#paramsGoogle::Apis::ComputeAlpha::RouterParams

Additional router parameters. Corresponds to the JSON property params



65779
65780
65781
# File 'lib/google/apis/compute_alpha/classes.rb', line 65779

def params
  @params
end

#regionString

[Output Only] URI of the region where the router resides. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body. Corresponds to the JSON property region

Returns:

  • (String)


65786
65787
65788
# File 'lib/google/apis/compute_alpha/classes.rb', line 65786

def region
  @region
end

[Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


65791
65792
65793
# File 'lib/google/apis/compute_alpha/classes.rb', line 65791

def self_link
  @self_link
end

Output only. [Output Only] Server-defined URL for this resource with the resource id. Corresponds to the JSON property selfLinkWithId

Returns:

  • (String)


65797
65798
65799
# File 'lib/google/apis/compute_alpha/classes.rb', line 65797

def self_link_with_id
  @self_link_with_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



65804
65805
65806
65807
65808
65809
65810
65811
65812
65813
65814
65815
65816
65817
65818
65819
65820
65821
65822
65823
# File 'lib/google/apis/compute_alpha/classes.rb', line 65804

def update!(**args)
  @bgp = args[:bgp] if args.key?(:bgp)
  @bgp_peers = args[:bgp_peers] if args.key?(:bgp_peers)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @encrypted_interconnect_router = args[:encrypted_interconnect_router] if args.key?(:encrypted_interconnect_router)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @interfaces = args[:interfaces] if args.key?(:interfaces)
  @kind = args[:kind] if args.key?(:kind)
  @md5_authentication_keys = args[:md5_authentication_keys] if args.key?(:md5_authentication_keys)
  @name = args[:name] if args.key?(:name)
  @nats = args[:nats] if args.key?(:nats)
  @ncc_gateway = args[:ncc_gateway] if args.key?(:ncc_gateway)
  @network = args[:network] if args.key?(:network)
  @params = args[:params] if args.key?(:params)
  @region = args[:region] if args.key?(:region)
  @self_link = args[:self_link] if args.key?(:self_link)
  @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id)
end