Class: Google::Apis::ComputeAlpha::RouterAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of routers.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RouterAggregatedList

Returns a new instance of RouterAggregatedList.



65895
65896
65897
# File 'lib/google/apis/compute_alpha/classes.rb', line 65895

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


65858
65859
65860
# File 'lib/google/apis/compute_alpha/classes.rb', line 65858

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::RoutersScopedList>

A list of Router resources. Corresponds to the JSON property items



65863
65864
65865
# File 'lib/google/apis/compute_alpha/classes.rb', line 65863

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


65868
65869
65870
# File 'lib/google/apis/compute_alpha/classes.rb', line 65868

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


65878
65879
65880
# File 'lib/google/apis/compute_alpha/classes.rb', line 65878

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


65883
65884
65885
# File 'lib/google/apis/compute_alpha/classes.rb', line 65883

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


65888
65889
65890
# File 'lib/google/apis/compute_alpha/classes.rb', line 65888

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::RouterAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



65893
65894
65895
# File 'lib/google/apis/compute_alpha/classes.rb', line 65893

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



65900
65901
65902
65903
65904
65905
65906
65907
65908
# File 'lib/google/apis/compute_alpha/classes.rb', line 65900

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end