Class: Google::Apis::ComputeAlpha::RouterList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of Router resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RouterList

Returns a new instance of RouterList.



66542
66543
66544
# File 'lib/google/apis/compute_alpha/classes.rb', line 66542

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


66509
66510
66511
# File 'lib/google/apis/compute_alpha/classes.rb', line 66509

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::Router>

A list of Router resources. Corresponds to the JSON property items



66514
66515
66516
# File 'lib/google/apis/compute_alpha/classes.rb', line 66514

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#router for routers. Corresponds to the JSON property kind

Returns:

  • (String)


66520
66521
66522
# File 'lib/google/apis/compute_alpha/classes.rb', line 66520

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


66530
66531
66532
# File 'lib/google/apis/compute_alpha/classes.rb', line 66530

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


66535
66536
66537
# File 'lib/google/apis/compute_alpha/classes.rb', line 66535

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::RouterList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



66540
66541
66542
# File 'lib/google/apis/compute_alpha/classes.rb', line 66540

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



66547
66548
66549
66550
66551
66552
66553
66554
# File 'lib/google/apis/compute_alpha/classes.rb', line 66547

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end