Class: Google::Apis::ComputeAlpha::RouterStatusBgpPeerStatus

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RouterStatusBgpPeerStatus

Returns a new instance of RouterStatusBgpPeerStatus.



67304
67305
67306
# File 'lib/google/apis/compute_alpha/classes.rb', line 67304

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#advertised_routesArray<Google::Apis::ComputeAlpha::Route>

Routes that were advertised to the remote BGP peer Corresponds to the JSON property advertisedRoutes



67178
67179
67180
# File 'lib/google/apis/compute_alpha/classes.rb', line 67178

def advertised_routes
  @advertised_routes
end

#bfd_statusGoogle::Apis::ComputeAlpha::BfdStatus

Next free: 15 Corresponds to the JSON property bfdStatus



67183
67184
67185
# File 'lib/google/apis/compute_alpha/classes.rb', line 67183

def bfd_status
  @bfd_status
end

#depreferencedBoolean Also known as: depreferenced?

Output only. [Output Only] Indicates whether the BGP peer is in a depreferenced state. Corresponds to the JSON property depreferenced

Returns:

  • (Boolean)


67189
67190
67191
# File 'lib/google/apis/compute_alpha/classes.rb', line 67189

def depreferenced
  @depreferenced
end

#enable_ipv4Boolean Also known as: enable_ipv4?

Output only. Enable IPv4 traffic over BGP Peer. It is enabled by default if the peerIpAddress is version 4. Corresponds to the JSON property enableIpv4

Returns:

  • (Boolean)


67196
67197
67198
# File 'lib/google/apis/compute_alpha/classes.rb', line 67196

def enable_ipv4
  @enable_ipv4
end

#enable_ipv6Boolean Also known as: enable_ipv6?

Output only. Enable IPv6 traffic over BGP Peer. It is enabled by default if the peerIpAddress is version 6. Corresponds to the JSON property enableIpv6

Returns:

  • (Boolean)


67203
67204
67205
# File 'lib/google/apis/compute_alpha/classes.rb', line 67203

def enable_ipv6
  @enable_ipv6
end

#ip_addressString

Output only. IP address of the local BGP interface. Corresponds to the JSON property ipAddress

Returns:

  • (String)


67209
67210
67211
# File 'lib/google/apis/compute_alpha/classes.rb', line 67209

def ip_address
  @ip_address
end

#ipv4_nexthop_addressString

Output only. IPv4 address of the local BGP interface. Corresponds to the JSON property ipv4NexthopAddress

Returns:

  • (String)


67214
67215
67216
# File 'lib/google/apis/compute_alpha/classes.rb', line 67214

def ipv4_nexthop_address
  @ipv4_nexthop_address
end

#ipv6_nexthop_addressString

Output only. IPv6 address of the local BGP interface. Corresponds to the JSON property ipv6NexthopAddress

Returns:

  • (String)


67219
67220
67221
# File 'lib/google/apis/compute_alpha/classes.rb', line 67219

def ipv6_nexthop_address
  @ipv6_nexthop_address
end

#linked_custom_hardwareString

Output only. The URI of the linked custom hardware resource, CustomHardwareLinkAttachment. This CustomHardwareLinkAttachment resource is the one that will establish the BGP session from the Cloud Router. Corresponds to the JSON property linkedCustomHardware

Returns:

  • (String)


67226
67227
67228
# File 'lib/google/apis/compute_alpha/classes.rb', line 67226

def linked_custom_hardware
  @linked_custom_hardware
end

#linked_vpn_tunnelString

Output only. URL of the VPN tunnel that this BGP peer controls. Corresponds to the JSON property linkedVpnTunnel

Returns:

  • (String)


67231
67232
67233
# File 'lib/google/apis/compute_alpha/classes.rb', line 67231

def linked_vpn_tunnel
  @linked_vpn_tunnel
end

#md5_auth_enabledBoolean Also known as: md5_auth_enabled?

Informs whether MD5 authentication is enabled on this BGP peer. Corresponds to the JSON property md5AuthEnabled

Returns:

  • (Boolean)


67236
67237
67238
# File 'lib/google/apis/compute_alpha/classes.rb', line 67236

def md5_auth_enabled
  @md5_auth_enabled
end

#nameString

Output only. Name of this BGP peer. Unique within the Routers resource. Corresponds to the JSON property name

Returns:

  • (String)


67242
67243
67244
# File 'lib/google/apis/compute_alpha/classes.rb', line 67242

def name
  @name
end

#num_learned_routesFixnum

Output only. Number of routes learned from the remote BGP Peer. Corresponds to the JSON property numLearnedRoutes

Returns:

  • (Fixnum)


67247
67248
67249
# File 'lib/google/apis/compute_alpha/classes.rb', line 67247

def num_learned_routes
  @num_learned_routes
end

#peer_ip_addressString

Output only. IP address of the remote BGP interface. Corresponds to the JSON property peerIpAddress

Returns:

  • (String)


67252
67253
67254
# File 'lib/google/apis/compute_alpha/classes.rb', line 67252

def peer_ip_address
  @peer_ip_address
end

#peer_ipv4_nexthop_addressString

Output only. IPv4 address of the remote BGP interface. Corresponds to the JSON property peerIpv4NexthopAddress

Returns:

  • (String)


67257
67258
67259
# File 'lib/google/apis/compute_alpha/classes.rb', line 67257

def peer_ipv4_nexthop_address
  @peer_ipv4_nexthop_address
end

#peer_ipv6_nexthop_addressString

Output only. IPv6 address of the remote BGP interface. Corresponds to the JSON property peerIpv6NexthopAddress

Returns:

  • (String)


67262
67263
67264
# File 'lib/google/apis/compute_alpha/classes.rb', line 67262

def peer_ipv6_nexthop_address
  @peer_ipv6_nexthop_address
end

#router_appliance_instanceString

Output only. [Output only] URI of the VM instance that is used as third-party router appliances such as Next Gen Firewalls, Virtual Routers, or Router Appliances. The VM instance is the peer side of the BGP session. Corresponds to the JSON property routerApplianceInstance

Returns:

  • (String)


67271
67272
67273
# File 'lib/google/apis/compute_alpha/classes.rb', line 67271

def router_appliance_instance
  @router_appliance_instance
end

#stateString

Output only. The state of the BGP session. For a list of possible values for this field, seeBGP session states. Corresponds to the JSON property state

Returns:

  • (String)


67278
67279
67280
# File 'lib/google/apis/compute_alpha/classes.rb', line 67278

def state
  @state
end

#statusString

Output only. Status of the BGP peer: UP, DOWN Corresponds to the JSON property status

Returns:

  • (String)


67283
67284
67285
# File 'lib/google/apis/compute_alpha/classes.rb', line 67283

def status
  @status
end

#status_reasonString

Indicates why particular status was returned. Corresponds to the JSON property statusReason

Returns:

  • (String)


67288
67289
67290
# File 'lib/google/apis/compute_alpha/classes.rb', line 67288

def status_reason
  @status_reason
end

#uptimeString

Output only. Time this session has been up. Format: 14 years, 51 weeks, 6 days, 23 hours, 59 minutes, 59 seconds Corresponds to the JSON property uptime

Returns:

  • (String)


67295
67296
67297
# File 'lib/google/apis/compute_alpha/classes.rb', line 67295

def uptime
  @uptime
end

#uptime_secondsString

Output only. Time this session has been up, in seconds. Format: 145 Corresponds to the JSON property uptimeSeconds

Returns:

  • (String)


67302
67303
67304
# File 'lib/google/apis/compute_alpha/classes.rb', line 67302

def uptime_seconds
  @uptime_seconds
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



67309
67310
67311
67312
67313
67314
67315
67316
67317
67318
67319
67320
67321
67322
67323
67324
67325
67326
67327
67328
67329
67330
67331
67332
# File 'lib/google/apis/compute_alpha/classes.rb', line 67309

def update!(**args)
  @advertised_routes = args[:advertised_routes] if args.key?(:advertised_routes)
  @bfd_status = args[:bfd_status] if args.key?(:bfd_status)
  @depreferenced = args[:depreferenced] if args.key?(:depreferenced)
  @enable_ipv4 = args[:enable_ipv4] if args.key?(:enable_ipv4)
  @enable_ipv6 = args[:enable_ipv6] if args.key?(:enable_ipv6)
  @ip_address = args[:ip_address] if args.key?(:ip_address)
  @ipv4_nexthop_address = args[:ipv4_nexthop_address] if args.key?(:ipv4_nexthop_address)
  @ipv6_nexthop_address = args[:ipv6_nexthop_address] if args.key?(:ipv6_nexthop_address)
  @linked_custom_hardware = args[:linked_custom_hardware] if args.key?(:linked_custom_hardware)
  @linked_vpn_tunnel = args[:linked_vpn_tunnel] if args.key?(:linked_vpn_tunnel)
  @md5_auth_enabled = args[:md5_auth_enabled] if args.key?(:md5_auth_enabled)
  @name = args[:name] if args.key?(:name)
  @num_learned_routes = args[:num_learned_routes] if args.key?(:num_learned_routes)
  @peer_ip_address = args[:peer_ip_address] if args.key?(:peer_ip_address)
  @peer_ipv4_nexthop_address = args[:peer_ipv4_nexthop_address] if args.key?(:peer_ipv4_nexthop_address)
  @peer_ipv6_nexthop_address = args[:peer_ipv6_nexthop_address] if args.key?(:peer_ipv6_nexthop_address)
  @router_appliance_instance = args[:router_appliance_instance] if args.key?(:router_appliance_instance)
  @state = args[:state] if args.key?(:state)
  @status = args[:status] if args.key?(:status)
  @status_reason = args[:status_reason] if args.key?(:status_reason)
  @uptime = args[:uptime] if args.key?(:uptime)
  @uptime_seconds = args[:uptime_seconds] if args.key?(:uptime_seconds)
end