Class: Google::Apis::ComputeAlpha::RoutersListBgpRoutes

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RoutersListBgpRoutes

Returns a new instance of RoutersListBgpRoutes.



67310
67311
67312
# File 'lib/google/apis/compute_alpha/classes.rb', line 67310

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


67266
67267
67268
# File 'lib/google/apis/compute_alpha/classes.rb', line 67266

def etag
  @etag
end

#idString

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


67272
67273
67274
# File 'lib/google/apis/compute_alpha/classes.rb', line 67272

def id
  @id
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# routersListBgpRoutes for lists of bgp routes. Corresponds to the JSON property kind

Returns:

  • (String)


67278
67279
67280
# File 'lib/google/apis/compute_alpha/classes.rb', line 67278

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


67288
67289
67290
# File 'lib/google/apis/compute_alpha/classes.rb', line 67288

def next_page_token
  @next_page_token
end

#resultArray<Google::Apis::ComputeAlpha::BgpRoute>

[Output Only] A list of bgp routes. Corresponds to the JSON property result



67293
67294
67295
# File 'lib/google/apis/compute_alpha/classes.rb', line 67293

def result
  @result
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


67298
67299
67300
# File 'lib/google/apis/compute_alpha/classes.rb', line 67298

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


67303
67304
67305
# File 'lib/google/apis/compute_alpha/classes.rb', line 67303

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::RoutersListBgpRoutes::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



67308
67309
67310
# File 'lib/google/apis/compute_alpha/classes.rb', line 67308

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



67315
67316
67317
67318
67319
67320
67321
67322
67323
67324
# File 'lib/google/apis/compute_alpha/classes.rb', line 67315

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @result = args[:result] if args.key?(:result)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end