Class: Google::Apis::ComputeAlpha::SavedDisk
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::SavedDisk
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
An instance-attached disk resource.
Instance Attribute Summary collapse
-
#architecture ⇒ String
Output only.
-
#kind ⇒ String
Output only.
-
#source_disk ⇒ String
Output only.
-
#storage_bytes ⇒ Fixnum
Output only.
-
#storage_bytes_status ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SavedDisk
constructor
A new instance of SavedDisk.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SavedDisk
Returns a new instance of SavedDisk.
68314 68315 68316 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 68314 def initialize(**args) update!(**args) end |
Instance Attribute Details
#architecture ⇒ String
Output only. [Output Only] The architecture of the attached disk.
Corresponds to the JSON property architecture
68285 68286 68287 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 68285 def architecture @architecture end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Always compute#savedDisk
for attached disks.
Corresponds to the JSON property kind
68291 68292 68293 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 68291 def kind @kind end |
#source_disk ⇒ String
Output only. Specifies a URL of the disk attached to the source instance.
Corresponds to the JSON property sourceDisk
68296 68297 68298 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 68296 def source_disk @source_disk end |
#storage_bytes ⇒ Fixnum
Output only. [Output Only] Size of the individual disk snapshot used by this
machine
image.
Corresponds to the JSON property storageBytes
68303 68304 68305 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 68303 def storage_bytes @storage_bytes end |
#storage_bytes_status ⇒ String
Output only. [Output Only] An indicator whether storageBytes is in a
stable state or it is being adjusted as a result of shared storage
reallocation. This status can either be UPDATING, meaning
the size of the snapshot is being updated, or UP_TO_DATE,
meaning the size of the snapshot is up-to-date.
Corresponds to the JSON property storageBytesStatus
68312 68313 68314 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 68312 def storage_bytes_status @storage_bytes_status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
68319 68320 68321 68322 68323 68324 68325 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 68319 def update!(**args) @architecture = args[:architecture] if args.key?(:architecture) @kind = args[:kind] if args.key?(:kind) @source_disk = args[:source_disk] if args.key?(:source_disk) @storage_bytes = args[:storage_bytes] if args.key?(:storage_bytes) @storage_bytes_status = args[:storage_bytes_status] if args.key?(:storage_bytes_status) end |