Class: Google::Apis::ComputeAlpha::ScalingScheduleStatus

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ScalingScheduleStatus

Returns a new instance of ScalingScheduleStatus.



64680
64681
64682
# File 'lib/google/apis/compute_alpha/classes.rb', line 64680

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#last_start_timeString

[Output Only] The last time the scaling schedule became active. Note: this is a timestamp when a schedule actually became active, not when it was planned to do so. The timestamp is in RFC3339 text format. Corresponds to the JSON property lastStartTime

Returns:

  • (String)


64664
64665
64666
# File 'lib/google/apis/compute_alpha/classes.rb', line 64664

def last_start_time
  @last_start_time
end

#next_start_timeString

[Output Only] The next time the scaling schedule is to become active. Note: this is a timestamp when a schedule is planned to run, but the actual time might be slightly different. The timestamp is in RFC3339 text format. Corresponds to the JSON property nextStartTime

Returns:

  • (String)


64673
64674
64675
# File 'lib/google/apis/compute_alpha/classes.rb', line 64673

def next_start_time
  @next_start_time
end

#stateString

[Output Only] The current state of a scaling schedule. Corresponds to the JSON property state

Returns:

  • (String)


64678
64679
64680
# File 'lib/google/apis/compute_alpha/classes.rb', line 64678

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



64685
64686
64687
64688
64689
# File 'lib/google/apis/compute_alpha/classes.rb', line 64685

def update!(**args)
  @last_start_time = args[:last_start_time] if args.key?(:last_start_time)
  @next_start_time = args[:next_start_time] if args.key?(:next_start_time)
  @state = args[:state] if args.key?(:state)
end