Class: Google::Apis::ComputeAlpha::SchedulingGracefulShutdown

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

The configuration for gracefully shutting down the instance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SchedulingGracefulShutdown

Returns a new instance of SchedulingGracefulShutdown.



68607
68608
68609
# File 'lib/google/apis/compute_alpha/classes.rb', line 68607

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enabledBoolean Also known as: enabled?

Opts-in for graceful shutdown. Corresponds to the JSON property enabled

Returns:

  • (Boolean)


68596
68597
68598
# File 'lib/google/apis/compute_alpha/classes.rb', line 68596

def enabled
  @enabled
end

#max_durationGoogle::Apis::ComputeAlpha::Duration

A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution. It is independent of any calendar and concepts like "day" or "month". Range is approximately 10,000 years. Corresponds to the JSON property maxDuration



68605
68606
68607
# File 'lib/google/apis/compute_alpha/classes.rb', line 68605

def max_duration
  @max_duration
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



68612
68613
68614
68615
# File 'lib/google/apis/compute_alpha/classes.rb', line 68612

def update!(**args)
  @enabled = args[:enabled] if args.key?(:enabled)
  @max_duration = args[:max_duration] if args.key?(:max_duration)
end