Class: Google::Apis::ComputeAlpha::SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Configuration options for L7 DDoS detection. This field is only supported in Global Security Policies of type CLOUD_ARMOR.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfig

Returns a new instance of SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfig.



67402
67403
67404
# File 'lib/google/apis/compute_alpha/classes.rb', line 67402

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enableBoolean Also known as: enable?

If set to true, enables CAAP for L7 DDoS detection. This field is only supported in Global Security Policies of type CLOUD_ARMOR. Corresponds to the JSON property enable

Returns:

  • (Boolean)


67384
67385
67386
# File 'lib/google/apis/compute_alpha/classes.rb', line 67384

def enable
  @enable
end

#rule_visibilityString

Rule visibility can be one of the following: STANDARD - opaque rules. (default) PREMIUM - transparent rules. This field is only supported in Global Security Policies of type CLOUD_ARMOR. Corresponds to the JSON property ruleVisibility

Returns:

  • (String)


67394
67395
67396
# File 'lib/google/apis/compute_alpha/classes.rb', line 67394

def rule_visibility
  @rule_visibility
end

#threshold_configsArray<Google::Apis::ComputeAlpha::SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfig>

Configuration options for layer7 adaptive protection for various customizable thresholds. Corresponds to the JSON property thresholdConfigs



67400
67401
67402
# File 'lib/google/apis/compute_alpha/classes.rb', line 67400

def threshold_configs
  @threshold_configs
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



67407
67408
67409
67410
67411
# File 'lib/google/apis/compute_alpha/classes.rb', line 67407

def update!(**args)
  @enable = args[:enable] if args.key?(:enable)
  @rule_visibility = args[:rule_visibility] if args.key?(:rule_visibility)
  @threshold_configs = args[:threshold_configs] if args.key?(:threshold_configs)
end