Class: Google::Apis::ComputeAlpha::SecurityPolicyAssociation

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SecurityPolicyAssociation

Returns a new instance of SecurityPolicyAssociation.



69577
69578
69579
# File 'lib/google/apis/compute_alpha/classes.rb', line 69577

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#attachment_idString

The resource that the security policy is attached to. Corresponds to the JSON property attachmentId

Returns:

  • (String)


69543
69544
69545
# File 'lib/google/apis/compute_alpha/classes.rb', line 69543

def attachment_id
  @attachment_id
end

#display_nameString

Output only. [Output Only] The display name of the security policy of the association. Corresponds to the JSON property displayName

Returns:

  • (String)


69549
69550
69551
# File 'lib/google/apis/compute_alpha/classes.rb', line 69549

def display_name
  @display_name
end

#excluded_foldersArray<String>

A list of folders to exclude from the security policy. Corresponds to the JSON property excludedFolders

Returns:

  • (Array<String>)


69554
69555
69556
# File 'lib/google/apis/compute_alpha/classes.rb', line 69554

def excluded_folders
  @excluded_folders
end

#excluded_projectsArray<String>

A list of projects to exclude from the security policy. Corresponds to the JSON property excludedProjects

Returns:

  • (Array<String>)


69559
69560
69561
# File 'lib/google/apis/compute_alpha/classes.rb', line 69559

def excluded_projects
  @excluded_projects
end

#nameString

The name for an association. Corresponds to the JSON property name

Returns:

  • (String)


69564
69565
69566
# File 'lib/google/apis/compute_alpha/classes.rb', line 69564

def name
  @name
end

#security_policy_idString

Output only. [Output Only] The security policy ID of the association. Corresponds to the JSON property securityPolicyId

Returns:

  • (String)


69569
69570
69571
# File 'lib/google/apis/compute_alpha/classes.rb', line 69569

def security_policy_id
  @security_policy_id
end

#short_nameString

Output only. [Output Only] The short name of the security policy of the association. Corresponds to the JSON property shortName

Returns:

  • (String)


69575
69576
69577
# File 'lib/google/apis/compute_alpha/classes.rb', line 69575

def short_name
  @short_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



69582
69583
69584
69585
69586
69587
69588
69589
69590
# File 'lib/google/apis/compute_alpha/classes.rb', line 69582

def update!(**args)
  @attachment_id = args[:attachment_id] if args.key?(:attachment_id)
  @display_name = args[:display_name] if args.key?(:display_name)
  @excluded_folders = args[:excluded_folders] if args.key?(:excluded_folders)
  @excluded_projects = args[:excluded_projects] if args.key?(:excluded_projects)
  @name = args[:name] if args.key?(:name)
  @security_policy_id = args[:security_policy_id] if args.key?(:security_policy_id)
  @short_name = args[:short_name] if args.key?(:short_name)
end