Class: Google::Apis::ComputeAlpha::SecurityPolicyList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SecurityPolicyList

Returns a new instance of SecurityPolicyList.



69702
69703
69704
# File 'lib/google/apis/compute_alpha/classes.rb', line 69702

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


69664
69665
69666
# File 'lib/google/apis/compute_alpha/classes.rb', line 69664

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


69669
69670
69671
# File 'lib/google/apis/compute_alpha/classes.rb', line 69669

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::SecurityPolicy>

A list of SecurityPolicy resources. Corresponds to the JSON property items



69674
69675
69676
# File 'lib/google/apis/compute_alpha/classes.rb', line 69674

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute#securityPolicyList for listsof securityPolicies Corresponds to the JSON property kind

Returns:

  • (String)


69680
69681
69682
# File 'lib/google/apis/compute_alpha/classes.rb', line 69680

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


69690
69691
69692
# File 'lib/google/apis/compute_alpha/classes.rb', line 69690

def next_page_token
  @next_page_token
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


69695
69696
69697
# File 'lib/google/apis/compute_alpha/classes.rb', line 69695

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::SecurityPolicyList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



69700
69701
69702
# File 'lib/google/apis/compute_alpha/classes.rb', line 69700

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



69707
69708
69709
69710
69711
69712
69713
69714
69715
# File 'lib/google/apis/compute_alpha/classes.rb', line 69707

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end