Class: Google::Apis::ComputeAlpha::SecurityPolicyRecaptchaOptionsConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SecurityPolicyRecaptchaOptionsConfig

Returns a new instance of SecurityPolicyRecaptchaOptionsConfig.



69225
69226
69227
# File 'lib/google/apis/compute_alpha/classes.rb', line 69225

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#redirect_site_keyString

An optional field to supply a reCAPTCHA site key to be used for all the rules using the redirect action with the type of GOOGLE_RECAPTCHA under the security policy. The specified site key needs to be created from the reCAPTCHA API. The user is responsible for the validity of the specified site key. If not specified, a Google-managed site key is used. This field is only supported in Global Security Policies of type CLOUD_ARMOR. Corresponds to the JSON property redirectSiteKey

Returns:

  • (String)


69223
69224
69225
# File 'lib/google/apis/compute_alpha/classes.rb', line 69223

def redirect_site_key
  @redirect_site_key
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



69230
69231
69232
# File 'lib/google/apis/compute_alpha/classes.rb', line 69230

def update!(**args)
  @redirect_site_key = args[:redirect_site_key] if args.key?(:redirect_site_key)
end