Class: Google::Apis::ComputeAlpha::SecurityPolicyRuleMatcherConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SecurityPolicyRuleMatcherConfig

Returns a new instance of SecurityPolicyRuleMatcherConfig.



70160
70161
70162
# File 'lib/google/apis/compute_alpha/classes.rb', line 70160

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dest_ip_rangesArray<String>

CIDR IP address range. This field may only be specified when versioned_expr is set to FIREWALL. Corresponds to the JSON property destIpRanges

Returns:

  • (Array<String>)


70138
70139
70140
# File 'lib/google/apis/compute_alpha/classes.rb', line 70138

def dest_ip_ranges
  @dest_ip_ranges
end

#dest_portsArray<Google::Apis::ComputeAlpha::SecurityPolicyRuleMatcherConfigDestinationPort>

Pairs of IP protocols and ports that the rule should match. This field may only be specified when versioned_expr is set to FIREWALL. Corresponds to the JSON property destPorts



70145
70146
70147
# File 'lib/google/apis/compute_alpha/classes.rb', line 70145

def dest_ports
  @dest_ports
end

#layer4_configsArray<Google::Apis::ComputeAlpha::SecurityPolicyRuleMatcherConfigLayer4Config>

Pairs of IP protocols and ports that the rule should match. This field may only be specified when versioned_expr is set to FIREWALL. Corresponds to the JSON property layer4Configs



70152
70153
70154
# File 'lib/google/apis/compute_alpha/classes.rb', line 70152

def layer4_configs
  @layer4_configs
end

#src_ip_rangesArray<String>

CIDR IP address range. Maximum number of src_ip_ranges allowed is 10. Corresponds to the JSON property srcIpRanges

Returns:

  • (Array<String>)


70158
70159
70160
# File 'lib/google/apis/compute_alpha/classes.rb', line 70158

def src_ip_ranges
  @src_ip_ranges
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



70165
70166
70167
70168
70169
70170
# File 'lib/google/apis/compute_alpha/classes.rb', line 70165

def update!(**args)
  @dest_ip_ranges = args[:dest_ip_ranges] if args.key?(:dest_ip_ranges)
  @dest_ports = args[:dest_ports] if args.key?(:dest_ports)
  @layer4_configs = args[:layer4_configs] if args.key?(:layer4_configs)
  @src_ip_ranges = args[:src_ip_ranges] if args.key?(:src_ip_ranges)
end