Class: Google::Apis::ComputeAlpha::SecurityPolicyRuleMatcherExprOptionsRecaptchaOptions

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SecurityPolicyRuleMatcherExprOptionsRecaptchaOptions

Returns a new instance of SecurityPolicyRuleMatcherExprOptionsRecaptchaOptions.



69705
69706
69707
# File 'lib/google/apis/compute_alpha/classes.rb', line 69705

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#action_token_site_keysArray<String>

A list of site keys to be used during the validation of reCAPTCHA action-tokens. The provided site keys need to be created from reCAPTCHA API under the same project where the security policy is created. Corresponds to the JSON property actionTokenSiteKeys

Returns:

  • (Array<String>)


69695
69696
69697
# File 'lib/google/apis/compute_alpha/classes.rb', line 69695

def action_token_site_keys
  @action_token_site_keys
end

#session_token_site_keysArray<String>

A list of site keys to be used during the validation of reCAPTCHA session-tokens. The provided site keys need to be created from reCAPTCHA API under the same project where the security policy is created. Corresponds to the JSON property sessionTokenSiteKeys

Returns:

  • (Array<String>)


69703
69704
69705
# File 'lib/google/apis/compute_alpha/classes.rb', line 69703

def session_token_site_keys
  @session_token_site_keys
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



69710
69711
69712
69713
# File 'lib/google/apis/compute_alpha/classes.rb', line 69710

def update!(**args)
  @action_token_site_keys = args[:action_token_site_keys] if args.key?(:action_token_site_keys)
  @session_token_site_keys = args[:session_token_site_keys] if args.key?(:session_token_site_keys)
end