Class: Google::Apis::ComputeAlpha::SecurityPolicyRuleNetworkMatcher

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Represents a match condition that incoming network traffic is evaluated against.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SecurityPolicyRuleNetworkMatcher

Returns a new instance of SecurityPolicyRuleNetworkMatcher.



70347
70348
70349
# File 'lib/google/apis/compute_alpha/classes.rb', line 70347

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dest_ip_rangesArray<String>

Destination IPv4/IPv6 addresses or CIDR prefixes, in standard text format. Corresponds to the JSON property destIpRanges

Returns:

  • (Array<String>)


70303
70304
70305
# File 'lib/google/apis/compute_alpha/classes.rb', line 70303

def dest_ip_ranges
  @dest_ip_ranges
end

#dest_portsArray<String>

Destination port numbers for TCP/UDP/SCTP. Each element can be a 16-bit unsigned decimal number (e.g. "80") or range (e.g. "0-1023"). Corresponds to the JSON property destPorts

Returns:

  • (Array<String>)


70309
70310
70311
# File 'lib/google/apis/compute_alpha/classes.rb', line 70309

def dest_ports
  @dest_ports
end

#ip_protocolsArray<String>

IPv4 protocol / IPv6 next header (after extension headers). Each element can be an 8-bit unsigned decimal number (e.g. "6"), range (e.g. "253-254"), or one of the following protocol names: "tcp", "udp", "icmp", "esp", "ah", "ipip", or "sctp". Corresponds to the JSON property ipProtocols

Returns:

  • (Array<String>)


70317
70318
70319
# File 'lib/google/apis/compute_alpha/classes.rb', line 70317

def ip_protocols
  @ip_protocols
end

#src_asnsArray<Fixnum>

BGP Autonomous System Number associated with the source IP address. Corresponds to the JSON property srcAsns

Returns:

  • (Array<Fixnum>)


70322
70323
70324
# File 'lib/google/apis/compute_alpha/classes.rb', line 70322

def src_asns
  @src_asns
end

#src_ip_rangesArray<String>

Source IPv4/IPv6 addresses or CIDR prefixes, in standard text format. Corresponds to the JSON property srcIpRanges

Returns:

  • (Array<String>)


70327
70328
70329
# File 'lib/google/apis/compute_alpha/classes.rb', line 70327

def src_ip_ranges
  @src_ip_ranges
end

#src_portsArray<String>

Source port numbers for TCP/UDP/SCTP. Each element can be a 16-bit unsigned decimal number (e.g. "80") or range (e.g. "0-1023"). Corresponds to the JSON property srcPorts

Returns:

  • (Array<String>)


70333
70334
70335
# File 'lib/google/apis/compute_alpha/classes.rb', line 70333

def src_ports
  @src_ports
end

#src_region_codesArray<String>

Two-letter ISO 3166-1 alpha-2 country code associated with the source IP address. Corresponds to the JSON property srcRegionCodes

Returns:

  • (Array<String>)


70339
70340
70341
# File 'lib/google/apis/compute_alpha/classes.rb', line 70339

def src_region_codes
  @src_region_codes
end

#user_defined_fieldsArray<Google::Apis::ComputeAlpha::SecurityPolicyRuleNetworkMatcherUserDefinedFieldMatch>

User-defined fields. Each element names a defined field and lists the matching values for that field. Corresponds to the JSON property userDefinedFields



70345
70346
70347
# File 'lib/google/apis/compute_alpha/classes.rb', line 70345

def user_defined_fields
  @user_defined_fields
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



70352
70353
70354
70355
70356
70357
70358
70359
70360
70361
# File 'lib/google/apis/compute_alpha/classes.rb', line 70352

def update!(**args)
  @dest_ip_ranges = args[:dest_ip_ranges] if args.key?(:dest_ip_ranges)
  @dest_ports = args[:dest_ports] if args.key?(:dest_ports)
  @ip_protocols = args[:ip_protocols] if args.key?(:ip_protocols)
  @src_asns = args[:src_asns] if args.key?(:src_asns)
  @src_ip_ranges = args[:src_ip_ranges] if args.key?(:src_ip_ranges)
  @src_ports = args[:src_ports] if args.key?(:src_ports)
  @src_region_codes = args[:src_region_codes] if args.key?(:src_region_codes)
  @user_defined_fields = args[:user_defined_fields] if args.key?(:user_defined_fields)
end