Class: Google::Apis::ComputeAlpha::SecurityPolicyRulePreconfiguredWafConfig
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::SecurityPolicyRulePreconfiguredWafConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#exclusions ⇒ Array<Google::Apis::ComputeAlpha::SecurityPolicyRulePreconfiguredWafConfigExclusion>
A list of exclusions to apply during preconfigured WAF evaluation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SecurityPolicyRulePreconfiguredWafConfig
constructor
A new instance of SecurityPolicyRulePreconfiguredWafConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SecurityPolicyRulePreconfiguredWafConfig
Returns a new instance of SecurityPolicyRulePreconfiguredWafConfig.
69822 69823 69824 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 69822 def initialize(**args) update!(**args) end |
Instance Attribute Details
#exclusions ⇒ Array<Google::Apis::ComputeAlpha::SecurityPolicyRulePreconfiguredWafConfigExclusion>
A list of exclusions to apply during preconfigured WAF evaluation.
Corresponds to the JSON property exclusions
69820 69821 69822 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 69820 def exclusions @exclusions end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
69827 69828 69829 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 69827 def update!(**args) @exclusions = args[:exclusions] if args.key?(:exclusions) end |