Class: Google::Apis::ComputeAlpha::ServiceAttachmentConnectedEndpoint
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::ServiceAttachmentConnectedEndpoint
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
[Output Only] A connection connected to this service attachment.
Instance Attribute Summary collapse
-
#consumer_network ⇒ String
The url of the consumer network.
-
#endpoint ⇒ String
The url of a connected endpoint.
-
#endpoint_with_id ⇒ String
The url of a connected endpoint with resource id.
-
#nat_ips ⇒ Array<String>
NAT IPs of the connected PSC endpoint and those of other endpoints propagated from it.
-
#propagated_connection_count ⇒ Fixnum
The number of consumer Network Connectivity Center spokes that the connected Private Service Connect endpoint has propagated to.
-
#psc_connection_id ⇒ Fixnum
The PSC connection id of the connected endpoint.
-
#status ⇒ String
The status of a connected endpoint to this service attachment.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ServiceAttachmentConnectedEndpoint
constructor
A new instance of ServiceAttachmentConnectedEndpoint.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ServiceAttachmentConnectedEndpoint
Returns a new instance of ServiceAttachmentConnectedEndpoint.
71189 71190 71191 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 71189 def initialize(**args) update!(**args) end |
Instance Attribute Details
#consumer_network ⇒ String
The url of the consumer network.
Corresponds to the JSON property consumerNetwork
71155 71156 71157 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 71155 def consumer_network @consumer_network end |
#endpoint ⇒ String
The url of a connected endpoint.
Corresponds to the JSON property endpoint
71160 71161 71162 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 71160 def endpoint @endpoint end |
#endpoint_with_id ⇒ String
The url of a connected endpoint with resource id.
Corresponds to the JSON property endpointWithId
71165 71166 71167 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 71165 def endpoint_with_id @endpoint_with_id end |
#nat_ips ⇒ Array<String>
NAT IPs of the connected PSC endpoint and those of other endpoints
propagated from it.
Corresponds to the JSON property natIps
71171 71172 71173 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 71171 def nat_ips @nat_ips end |
#propagated_connection_count ⇒ Fixnum
The number of consumer Network Connectivity Center spokes that the
connected Private Service Connect endpoint has propagated to.
Corresponds to the JSON property propagatedConnectionCount
71177 71178 71179 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 71177 def propagated_connection_count @propagated_connection_count end |
#psc_connection_id ⇒ Fixnum
The PSC connection id of the connected endpoint.
Corresponds to the JSON property pscConnectionId
71182 71183 71184 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 71182 def psc_connection_id @psc_connection_id end |
#status ⇒ String
The status of a connected endpoint to this service attachment.
Corresponds to the JSON property status
71187 71188 71189 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 71187 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
71194 71195 71196 71197 71198 71199 71200 71201 71202 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 71194 def update!(**args) @consumer_network = args[:consumer_network] if args.key?(:consumer_network) @endpoint = args[:endpoint] if args.key?(:endpoint) @endpoint_with_id = args[:endpoint_with_id] if args.key?(:endpoint_with_id) @nat_ips = args[:nat_ips] if args.key?(:nat_ips) @propagated_connection_count = args[:propagated_connection_count] if args.key?(:propagated_connection_count) @psc_connection_id = args[:psc_connection_id] if args.key?(:psc_connection_id) @status = args[:status] if args.key?(:status) end |