Class: Google::Apis::ComputeAlpha::ServiceAttachmentConsumerProjectLimit
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::ServiceAttachmentConsumerProjectLimit
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#connection_limit ⇒ Fixnum
The value of the limit to set.
-
#endpoint_url ⇒ String
The URL for the PSC endpoint to accept Corresponds to the JSON property
endpointUrl. -
#network_url ⇒ String
The network URL for the network to set the limit for.
-
#project_id_or_num ⇒ String
The project id or number for the project to set the limit for.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ServiceAttachmentConsumerProjectLimit
constructor
A new instance of ServiceAttachmentConsumerProjectLimit.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ServiceAttachmentConsumerProjectLimit
Returns a new instance of ServiceAttachmentConsumerProjectLimit.
69555 69556 69557 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 69555 def initialize(**args) update!(**args) end |
Instance Attribute Details
#connection_limit ⇒ Fixnum
The value of the limit to set. For endpoint_url, the limit should be no
more than 1.
Corresponds to the JSON property connectionLimit
69538 69539 69540 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 69538 def connection_limit @connection_limit end |
#endpoint_url ⇒ String
The URL for the PSC endpoint to accept
Corresponds to the JSON property endpointUrl
69543 69544 69545 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 69543 def endpoint_url @endpoint_url end |
#network_url ⇒ String
The network URL for the network to set the limit for.
Corresponds to the JSON property networkUrl
69548 69549 69550 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 69548 def network_url @network_url end |
#project_id_or_num ⇒ String
The project id or number for the project to set the limit for.
Corresponds to the JSON property projectIdOrNum
69553 69554 69555 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 69553 def project_id_or_num @project_id_or_num end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
69560 69561 69562 69563 69564 69565 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 69560 def update!(**args) @connection_limit = args[:connection_limit] if args.key?(:connection_limit) @endpoint_url = args[:endpoint_url] if args.key?(:endpoint_url) @network_url = args[:network_url] if args.key?(:network_url) @project_id_or_num = args[:project_id_or_num] if args.key?(:project_id_or_num) end |