Class: Google::Apis::ComputeAlpha::ServiceAttachmentList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ServiceAttachmentList

Returns a new instance of ServiceAttachmentList.



71559
71560
71561
# File 'lib/google/apis/compute_alpha/classes.rb', line 71559

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


71526
71527
71528
# File 'lib/google/apis/compute_alpha/classes.rb', line 71526

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::ServiceAttachment>

A list of ServiceAttachment resources. Corresponds to the JSON property items



71531
71532
71533
# File 'lib/google/apis/compute_alpha/classes.rb', line 71531

def items
  @items
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# serviceAttachment for service attachments. Corresponds to the JSON property kind

Returns:

  • (String)


71537
71538
71539
# File 'lib/google/apis/compute_alpha/classes.rb', line 71537

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


71547
71548
71549
# File 'lib/google/apis/compute_alpha/classes.rb', line 71547

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


71552
71553
71554
# File 'lib/google/apis/compute_alpha/classes.rb', line 71552

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::ServiceAttachmentList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



71557
71558
71559
# File 'lib/google/apis/compute_alpha/classes.rb', line 71557

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



71564
71565
71566
71567
71568
71569
71570
71571
# File 'lib/google/apis/compute_alpha/classes.rb', line 71564

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end