Class: Google::Apis::ComputeAlpha::ServiceAttachmentTunnelingConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Use to configure this PSC connection in tunneling mode. In tunneling mode traffic from consumer to producer will be encapsulated as it crosses the VPC boundary and traffic from producer to consumer will be decapsulated in the same manner.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ServiceAttachmentTunnelingConfig

Returns a new instance of ServiceAttachmentTunnelingConfig.



71387
71388
71389
# File 'lib/google/apis/compute_alpha/classes.rb', line 71387

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#encapsulation_profileString

Specify the encapsulation protocol and what metadata to include in incoming encapsulated packet headers. Corresponds to the JSON property encapsulationProfile

Returns:

  • (String)


71379
71380
71381
# File 'lib/google/apis/compute_alpha/classes.rb', line 71379

def encapsulation_profile
  @encapsulation_profile
end

#routing_modeString

How this Service Attachment will treat traffic sent to the tunnel_ip, destined for the consumer network. Corresponds to the JSON property routingMode

Returns:

  • (String)


71385
71386
71387
# File 'lib/google/apis/compute_alpha/classes.rb', line 71385

def routing_mode
  @routing_mode
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



71392
71393
71394
71395
# File 'lib/google/apis/compute_alpha/classes.rb', line 71392

def update!(**args)
  @encapsulation_profile = args[:encapsulation_profile] if args.key?(:encapsulation_profile)
  @routing_mode = args[:routing_mode] if args.key?(:routing_mode)
end