Class: Google::Apis::ComputeAlpha::ShareSettings

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

The share setting for reservations and sole tenancy node groups.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ShareSettings

Returns a new instance of ShareSettings.



71318
71319
71320
# File 'lib/google/apis/compute_alpha/classes.rb', line 71318

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#folder_mapHash<String,Google::Apis::ComputeAlpha::ShareSettingsFolderConfig>

A map of folder id and folder config to specify consumer projects for this shared-reservation. This is only valid when share_type's value is DIRECT_PROJECTS_UNDER_SPECIFIC_FOLDERS. Folder id should be a string of number, and without "folders/" prefix. Corresponds to the JSON property folderMap



71298
71299
71300
# File 'lib/google/apis/compute_alpha/classes.rb', line 71298

def folder_map
  @folder_map
end

#project_mapHash<String,Google::Apis::ComputeAlpha::ShareSettingsProjectConfig>

A map of project id and project config. This is only valid when share_type's value is SPECIFIC_PROJECTS. Corresponds to the JSON property projectMap



71304
71305
71306
# File 'lib/google/apis/compute_alpha/classes.rb', line 71304

def project_map
  @project_map
end

#projectsArray<String>

A List of Project names to specify consumer projects for this shared-reservation. This is only valid when share_type's value is SPECIFIC_PROJECTS. Corresponds to the JSON property projects

Returns:

  • (Array<String>)


71311
71312
71313
# File 'lib/google/apis/compute_alpha/classes.rb', line 71311

def projects
  @projects
end

#share_typeString

Type of sharing for this shared-reservation Corresponds to the JSON property shareType

Returns:

  • (String)


71316
71317
71318
# File 'lib/google/apis/compute_alpha/classes.rb', line 71316

def share_type
  @share_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



71323
71324
71325
71326
71327
71328
# File 'lib/google/apis/compute_alpha/classes.rb', line 71323

def update!(**args)
  @folder_map = args[:folder_map] if args.key?(:folder_map)
  @project_map = args[:project_map] if args.key?(:project_map)
  @projects = args[:projects] if args.key?(:projects)
  @share_type = args[:share_type] if args.key?(:share_type)
end