Class: Google::Apis::ComputeAlpha::ShieldedInstanceIntegrityPolicy

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

The policy describes the baseline against which Instance boot integrity is measured.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ShieldedInstanceIntegrityPolicy

Returns a new instance of ShieldedInstanceIntegrityPolicy.



71491
71492
71493
# File 'lib/google/apis/compute_alpha/classes.rb', line 71491

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#update_auto_learn_policyBoolean Also known as: update_auto_learn_policy?

Updates the integrity policy baseline using the measurements from the VM instance's most recent boot. Corresponds to the JSON property updateAutoLearnPolicy

Returns:

  • (Boolean)


71488
71489
71490
# File 'lib/google/apis/compute_alpha/classes.rb', line 71488

def update_auto_learn_policy
  @update_auto_learn_policy
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



71496
71497
71498
# File 'lib/google/apis/compute_alpha/classes.rb', line 71496

def update!(**args)
  @update_auto_learn_policy = args[:update_auto_learn_policy] if args.key?(:update_auto_learn_policy)
end