Class: Google::Apis::ComputeAlpha::SignedUrlKey

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Represents a customer-supplied Signing Key used by Cloud CDN Signed URLs

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SignedUrlKey

Returns a new instance of SignedUrlKey.



71634
71635
71636
# File 'lib/google/apis/compute_alpha/classes.rb', line 71634

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#key_nameString

Name of the key. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property keyName

Returns:

  • (String)


71626
71627
71628
# File 'lib/google/apis/compute_alpha/classes.rb', line 71626

def key_name
  @key_name
end

#key_valueString

128-bit key value used for signing the URL. The key value must be a validRFC 4648 Section 5 base64url encoded string. Corresponds to the JSON property keyValue

Returns:

  • (String)


71632
71633
71634
# File 'lib/google/apis/compute_alpha/classes.rb', line 71632

def key_value
  @key_value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



71639
71640
71641
71642
# File 'lib/google/apis/compute_alpha/classes.rb', line 71639

def update!(**args)
  @key_name = args[:key_name] if args.key?(:key_name)
  @key_value = args[:key_value] if args.key?(:key_value)
end