Class: Google::Apis::ComputeAlpha::SnapshotGroupParameters
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::SnapshotGroupParameters
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#replica_zones ⇒ Array<String>
URLs of the zones where disks should be replicated to.
-
#source_snapshot_group ⇒ String
The source snapshot group used to create disks.
-
#type ⇒ String
URL of the disk type resource describing which disk type to use to create disks.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SnapshotGroupParameters
constructor
A new instance of SnapshotGroupParameters.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SnapshotGroupParameters
Returns a new instance of SnapshotGroupParameters.
70040 70041 70042 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 70040 def initialize(**args) update!(**args) end |
Instance Attribute Details
#replica_zones ⇒ Array<String>
URLs of the zones where disks should be replicated to. Only applicable
for regional resources.
Corresponds to the JSON property replicaZones
70017 70018 70019 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 70017 def replica_zones @replica_zones end |
#source_snapshot_group ⇒ String
The source snapshot group used to create disks. You can provide this as a partial or full URL to the resource. For example, the following are valid values:
- https://www.googleapis.com/compute/v1/projects/project/global/ snapshotGroups/snapshotGroup
- projects/project/global/snapshotGroups/snapshotGroup
- global/snapshotGroups/snapshotGroup
Corresponds to the JSON property
sourceSnapshotGroup
70030 70031 70032 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 70030 def source_snapshot_group @source_snapshot_group end |
#type ⇒ String
URL of the disk type resource describing which disk type to use to create
disks. Provide this when creating the disk. For example:projects/project/zones/
zone/diskTypes/pd-ssd. See Persistent disk
types.
Corresponds to the JSON property type
70038 70039 70040 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 70038 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
70045 70046 70047 70048 70049 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 70045 def update!(**args) @replica_zones = args[:replica_zones] if args.key?(:replica_zones) @source_snapshot_group = args[:source_snapshot_group] if args.key?(:source_snapshot_group) @type = args[:type] if args.key?(:type) end |