Class: Google::Apis::ComputeAlpha::SnapshotList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of Snapshot resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SnapshotList

Returns a new instance of SnapshotList.



72696
72697
72698
# File 'lib/google/apis/compute_alpha/classes.rb', line 72696

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


72664
72665
72666
# File 'lib/google/apis/compute_alpha/classes.rb', line 72664

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::Snapshot>

A list of Snapshot resources. Corresponds to the JSON property items



72669
72670
72671
# File 'lib/google/apis/compute_alpha/classes.rb', line 72669

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


72674
72675
72676
# File 'lib/google/apis/compute_alpha/classes.rb', line 72674

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


72684
72685
72686
# File 'lib/google/apis/compute_alpha/classes.rb', line 72684

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


72689
72690
72691
# File 'lib/google/apis/compute_alpha/classes.rb', line 72689

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::SnapshotList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



72694
72695
72696
# File 'lib/google/apis/compute_alpha/classes.rb', line 72694

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



72701
72702
72703
72704
72705
72706
72707
72708
# File 'lib/google/apis/compute_alpha/classes.rb', line 72701

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end