Class: Google::Apis::ComputeAlpha::SnapshotSettingsAccessLocation

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SnapshotSettingsAccessLocation

Returns a new instance of SnapshotSettingsAccessLocation.



72948
72949
72950
# File 'lib/google/apis/compute_alpha/classes.rb', line 72948

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#locationsHash<String,Google::Apis::ComputeAlpha::SnapshotSettingsAccessLocationAccessLocationPreference>

List of regions that can restore a regional snapshot from the current region Corresponds to the JSON property locations



72941
72942
72943
# File 'lib/google/apis/compute_alpha/classes.rb', line 72941

def locations
  @locations
end

#policyString

Policy of which location is allowed to access snapshot. Corresponds to the JSON property policy

Returns:

  • (String)


72946
72947
72948
# File 'lib/google/apis/compute_alpha/classes.rb', line 72946

def policy
  @policy
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



72953
72954
72955
72956
# File 'lib/google/apis/compute_alpha/classes.rb', line 72953

def update!(**args)
  @locations = args[:locations] if args.key?(:locations)
  @policy = args[:policy] if args.key?(:policy)
end