Class: Google::Apis::ComputeAlpha::SnapshotUpdateKmsKeyRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SnapshotUpdateKmsKeyRequest

Returns a new instance of SnapshotUpdateKmsKeyRequest.



70479
70480
70481
# File 'lib/google/apis/compute_alpha/classes.rb', line 70479

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#kms_key_nameString

Optional. The new KMS key to replace the current one on the snapshot. If empty, the snapshot will be re-encrypted using the primary version of the snapshot's current KMS key. The KMS key can be provided in the following formats:

  • projects/project_id/locations/region/keyRings/key_ring/cryptoKeys/key Corresponds to the JSON property kmsKeyName

Returns:

  • (String)


70477
70478
70479
# File 'lib/google/apis/compute_alpha/classes.rb', line 70477

def kms_key_name
  @kms_key_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



70484
70485
70486
# File 'lib/google/apis/compute_alpha/classes.rb', line 70484

def update!(**args)
  @kms_key_name = args[:kms_key_name] if args.key?(:kms_key_name)
end