Class: Google::Apis::ComputeAlpha::SnapshotsGetEffectiveRecycleBinRuleResponse
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::SnapshotsGetEffectiveRecycleBinRuleResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#retention_duration_days ⇒ Fixnum
The retention duration of the snapshot in recycle bin.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SnapshotsGetEffectiveRecycleBinRuleResponse
constructor
A new instance of SnapshotsGetEffectiveRecycleBinRuleResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SnapshotsGetEffectiveRecycleBinRuleResponse
Returns a new instance of SnapshotsGetEffectiveRecycleBinRuleResponse.
70721 70722 70723 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 70721 def initialize(**args) update!(**args) end |
Instance Attribute Details
#retention_duration_days ⇒ Fixnum
The retention duration of the snapshot in recycle bin.
Corresponds to the JSON property retentionDurationDays
70719 70720 70721 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 70719 def retention_duration_days @retention_duration_days end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
70726 70727 70728 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 70726 def update!(**args) @retention_duration_days = args[:retention_duration_days] if args.key?(:retention_duration_days) end |