Class: Google::Apis::ComputeAlpha::SourceDiskEncryptionKey

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SourceDiskEncryptionKey

Returns a new instance of SourceDiskEncryptionKey.



70849
70850
70851
# File 'lib/google/apis/compute_alpha/classes.rb', line 70849

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#disk_encryption_keyGoogle::Apis::ComputeAlpha::CustomerEncryptionKey

Thecustomer-supplied encryption key of the source disk. Required if the source disk is protected by a customer-supplied encryption key. Corresponds to the JSON property diskEncryptionKey



70835
70836
70837
# File 'lib/google/apis/compute_alpha/classes.rb', line 70835

def disk_encryption_key
  @disk_encryption_key
end

#source_diskString

URL of the disk attached to the source instance. This can be a full or valid partial URL. For example, the following are valid values:

Returns:

  • (String)


70847
70848
70849
# File 'lib/google/apis/compute_alpha/classes.rb', line 70847

def source_disk
  @source_disk
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



70854
70855
70856
70857
# File 'lib/google/apis/compute_alpha/classes.rb', line 70854

def update!(**args)
  @disk_encryption_key = args[:disk_encryption_key] if args.key?(:disk_encryption_key)
  @source_disk = args[:source_disk] if args.key?(:source_disk)
end