Class: Google::Apis::ComputeAlpha::SslCertificate
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::SslCertificate
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Represents an SSL certificate resource. Google Compute Engine has two SSL certificate resources:
- Global
Regional The global SSL certificates (sslCertificates) are used by:
Global external Application Load Balancers
Classic Application Load Balancers
Proxy Network Load Balancers (with target SSL proxies) The regional SSL certificates (regionSslCertificates) are used by:
Regional external Application Load Balancers
Regional internal Application Load Balancers Optionally, certificate file contents that you upload can contain a set of up to five PEM-encoded certificates. The API call creates an object (sslCertificate) that holds this data. You can use SSL keys and certificates to secure connections to a load balancer. For more information, read Creating and using SSL certificates,SSL certificates quotas and limits, and Troubleshooting SSL certificates.
Instance Attribute Summary collapse
-
#certificate ⇒ String
A value read into memory from a certificate file.
-
#creation_timestamp ⇒ String
[Output Only] Creation timestamp inRFC3339 text format.
-
#description ⇒ String
An optional description of this resource.
-
#expire_time ⇒ String
Output only.
-
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource.
-
#kind ⇒ String
Output only.
-
#managed ⇒ Google::Apis::ComputeAlpha::SslCertificateManagedSslCertificate
Configuration and status of a managed SSL certificate.
-
#name ⇒ String
Name of the resource.
-
#private_key ⇒ String
A value read into memory from a write-only private key file.
-
#region ⇒ String
Output only.
-
#self_link ⇒ String
[Output only] Server-defined URL for the resource.
-
#self_link_with_id ⇒ String
Output only.
-
#self_managed ⇒ Google::Apis::ComputeAlpha::SslCertificateSelfManagedSslCertificate
Configuration and status of a self-managed SSL certificate.
-
#subject_alternative_names ⇒ Array<String>
Output only.
-
#type ⇒ String
(Optional) Specifies the type of SSL certificate, either "SELF_MANAGED" or "MANAGED".
Instance Method Summary collapse
-
#initialize(**args) ⇒ SslCertificate
constructor
A new instance of SslCertificate.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SslCertificate
Returns a new instance of SslCertificate.
71133 71134 71135 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 71133 def initialize(**args) update!(**args) end |
Instance Attribute Details
#certificate ⇒ String
A value read into memory from a certificate file. The certificate file must
be in PEM format. The certificate chain must be no greater than 5 certs
long. The chain must include at least one intermediate cert.
Corresponds to the JSON property certificate
71043 71044 71045 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 71043 def certificate @certificate end |
#creation_timestamp ⇒ String
[Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
71049 71050 71051 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 71049 def @creation_timestamp end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
71055 71056 71057 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 71055 def description @description end |
#expire_time ⇒ String
Output only. [Output Only] Expire time of the certificate. RFC3339
Corresponds to the JSON property expireTime
71060 71061 71062 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 71060 def expire_time @expire_time end |
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
71066 71067 71068 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 71066 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#sslCertificate
for SSL certificates.
Corresponds to the JSON property kind
71072 71073 71074 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 71072 def kind @kind end |
#managed ⇒ Google::Apis::ComputeAlpha::SslCertificateManagedSslCertificate
Configuration and status of a managed SSL certificate.
Corresponds to the JSON property managed
71077 71078 71079 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 71077 def managed @managed end |
#name ⇒ String
Name of the resource. Provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must
be a dash, lowercase letter, or digit, except the last character, which
cannot be a dash.
Corresponds to the JSON property name
71088 71089 71090 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 71088 def name @name end |
#private_key ⇒ String
A value read into memory from a write-only private key file. The private
key file must be in PEM format. For security, only insert
requests include this field.
Corresponds to the JSON property privateKey
71095 71096 71097 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 71095 def private_key @private_key end |
#region ⇒ String
Output only. [Output Only] URL of the region where the regional SSL
Certificate
resides. This field is not applicable to global SSL Certificate.
Corresponds to the JSON property region
71102 71103 71104 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 71102 def region @region end |
#self_link ⇒ String
[Output only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
71107 71108 71109 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 71107 def self_link @self_link end |
#self_link_with_id ⇒ String
Output only. [Output Only] Server-defined URL for this resource with the
resource id.
Corresponds to the JSON property selfLinkWithId
71113 71114 71115 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 71113 def self_link_with_id @self_link_with_id end |
#self_managed ⇒ Google::Apis::ComputeAlpha::SslCertificateSelfManagedSslCertificate
Configuration and status of a self-managed SSL certificate.
Corresponds to the JSON property selfManaged
71118 71119 71120 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 71118 def self_managed @self_managed end |
#subject_alternative_names ⇒ Array<String>
Output only. [Output Only] Domains associated with the certificate via Subject
Alternative Name.
Corresponds to the JSON property subjectAlternativeNames
71124 71125 71126 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 71124 def subject_alternative_names @subject_alternative_names end |
#type ⇒ String
(Optional) Specifies the type of SSL certificate, either "SELF_MANAGED" or
"MANAGED". If not specified, the certificate is self-managed and the
fieldscertificate and private_key are used.
Corresponds to the JSON property type
71131 71132 71133 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 71131 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
71138 71139 71140 71141 71142 71143 71144 71145 71146 71147 71148 71149 71150 71151 71152 71153 71154 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 71138 def update!(**args) @certificate = args[:certificate] if args.key?(:certificate) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @expire_time = args[:expire_time] if args.key?(:expire_time) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @managed = args[:managed] if args.key?(:managed) @name = args[:name] if args.key?(:name) @private_key = args[:private_key] if args.key?(:private_key) @region = args[:region] if args.key?(:region) @self_link = args[:self_link] if args.key?(:self_link) @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id) @self_managed = args[:self_managed] if args.key?(:self_managed) @subject_alternative_names = args[:subject_alternative_names] if args.key?(:subject_alternative_names) @type = args[:type] if args.key?(:type) end |