Class: Google::Apis::ComputeAlpha::SslCertificateAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SslCertificateAggregatedList

Returns a new instance of SslCertificateAggregatedList.



73818
73819
73820
# File 'lib/google/apis/compute_alpha/classes.rb', line 73818

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


73779
73780
73781
# File 'lib/google/apis/compute_alpha/classes.rb', line 73779

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::SslCertificatesScopedList>

A list of SslCertificatesScopedList resources. Corresponds to the JSON property items



73784
73785
73786
# File 'lib/google/apis/compute_alpha/classes.rb', line 73784

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# sslCertificateAggregatedList for lists of SSL Certificates. Corresponds to the JSON property kind

Returns:

  • (String)


73791
73792
73793
# File 'lib/google/apis/compute_alpha/classes.rb', line 73791

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


73801
73802
73803
# File 'lib/google/apis/compute_alpha/classes.rb', line 73801

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


73806
73807
73808
# File 'lib/google/apis/compute_alpha/classes.rb', line 73806

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


73811
73812
73813
# File 'lib/google/apis/compute_alpha/classes.rb', line 73811

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::SslCertificateAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



73816
73817
73818
# File 'lib/google/apis/compute_alpha/classes.rb', line 73816

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



73823
73824
73825
73826
73827
73828
73829
73830
73831
# File 'lib/google/apis/compute_alpha/classes.rb', line 73823

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end