Class: Google::Apis::ComputeAlpha::SslCertificateList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::SslCertificateList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Contains a list of SslCertificate resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::SslCertificate>
A list of SslCertificate resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::SslCertificateList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SslCertificateList
constructor
A new instance of SslCertificateList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SslCertificateList
Returns a new instance of SslCertificateList.
73943 73944 73945 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 73943 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
73911 73912 73913 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 73911 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::SslCertificate>
A list of SslCertificate resources.
Corresponds to the JSON property items
73916 73917 73918 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 73916 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
73921 73922 73923 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 73921 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
73931 73932 73933 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 73931 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
73936 73937 73938 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 73936 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::SslCertificateList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
73941 73942 73943 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 73941 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
73948 73949 73950 73951 73952 73953 73954 73955 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 73948 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |