Class: Google::Apis::ComputeAlpha::SslCertificateManagedSslCertificate

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Configuration and status of a managed SSL certificate.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SslCertificateManagedSslCertificate

Returns a new instance of SslCertificateManagedSslCertificate.



70296
70297
70298
# File 'lib/google/apis/compute_alpha/classes.rb', line 70296

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#domain_statusHash<String,String>

Output only. [Output only] Detailed statuses of the domains specified for managed certificate resource. Corresponds to the JSON property domainStatus

Returns:

  • (Hash<String,String>)


70281
70282
70283
# File 'lib/google/apis/compute_alpha/classes.rb', line 70281

def domain_status
  @domain_status
end

#domainsArray<String>

The domains for which a managed SSL certificate will be generated. Each Google-managed SSL certificate supports up to the maximum number of domains per Google-managed SSL certificate. Corresponds to the JSON property domains

Returns:

  • (Array<String>)


70289
70290
70291
# File 'lib/google/apis/compute_alpha/classes.rb', line 70289

def domains
  @domains
end

#statusString

Output only. [Output only] Status of the managed certificate resource. Corresponds to the JSON property status

Returns:

  • (String)


70294
70295
70296
# File 'lib/google/apis/compute_alpha/classes.rb', line 70294

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



70301
70302
70303
70304
70305
# File 'lib/google/apis/compute_alpha/classes.rb', line 70301

def update!(**args)
  @domain_status = args[:domain_status] if args.key?(:domain_status)
  @domains = args[:domains] if args.key?(:domains)
  @status = args[:status] if args.key?(:status)
end