Class: Google::Apis::ComputeAlpha::SslCertificateSelfManagedSslCertificate

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Configuration and status of a self-managed SSL certificate.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SslCertificateSelfManagedSslCertificate

Returns a new instance of SslCertificateSelfManagedSslCertificate.



73805
73806
73807
# File 'lib/google/apis/compute_alpha/classes.rb', line 73805

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#certificateString

A local certificate file. The certificate must be in PEM format. The certificate chain must be no greater than 5 certs long. The chain must include at least one intermediate cert. Corresponds to the JSON property certificate

Returns:

  • (String)


73797
73798
73799
# File 'lib/google/apis/compute_alpha/classes.rb', line 73797

def certificate
  @certificate
end

#private_keyString

A write-only private key in PEM format. Only insert requests will include this field. Corresponds to the JSON property privateKey

Returns:

  • (String)


73803
73804
73805
# File 'lib/google/apis/compute_alpha/classes.rb', line 73803

def private_key
  @private_key
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



73810
73811
73812
73813
# File 'lib/google/apis/compute_alpha/classes.rb', line 73810

def update!(**args)
  @certificate = args[:certificate] if args.key?(:certificate)
  @private_key = args[:private_key] if args.key?(:private_key)
end