Class: Google::Apis::ComputeAlpha::SslHealthCheck

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SslHealthCheck

Returns a new instance of SslHealthCheck.



67857
67858
67859
# File 'lib/google/apis/compute_alpha/classes.rb', line 67857

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#portFixnum

The TCP port number to which the health check prober sends packets. The default value is 443. Valid values are 1 through65535. Corresponds to the JSON property port

Returns:

  • (Fixnum)


67799
67800
67801
# File 'lib/google/apis/compute_alpha/classes.rb', line 67799

def port
  @port
end

#port_nameString

Not supported. Corresponds to the JSON property portName

Returns:

  • (String)


67804
67805
67806
# File 'lib/google/apis/compute_alpha/classes.rb', line 67804

def port_name
  @port_name
end

#port_specificationString

Specifies how a port is selected for health checking. Can be one of the following values: USE_FIXED_PORT: Specifies a port number explicitly using theport field in the health check. Supported by backend services for passthrough load balancers and backend services for proxy load balancers. Not supported by target pools. The health check supports all backends supported by the backend service provided the backend can be health checked. For example, GCE_VM_IP network endpoint groups, GCE_VM_IP_PORT network endpoint groups, and instance group backends. USE_NAMED_PORT: Not supported. USE_SERVING_PORT: Provides an indirect method of specifying the health check port by referring to the backend service. Only supported by backend services for proxy load balancers. Not supported by target pools. Not supported by backend services for passthrough load balancers. Supports all backends that can be health checked; for example,GCE_VM_IP_PORT network endpoint groups and instance group backends. For GCE_VM_IP_PORT network endpoint group backends, the health check uses the port number specified for each endpoint in the network endpoint group. For instance group backends, the health check uses the port number determined by looking up the backend service's named port in the instance group's list of named ports. Corresponds to the JSON property portSpecification

Returns:

  • (String)


67831
67832
67833
# File 'lib/google/apis/compute_alpha/classes.rb', line 67831

def port_specification
  @port_specification
end

#proxy_headerString

Specifies the type of proxy header to append before sending data to the backend, either NONE or PROXY_V1. The default is NONE. Corresponds to the JSON property proxyHeader

Returns:

  • (String)


67838
67839
67840
# File 'lib/google/apis/compute_alpha/classes.rb', line 67838

def proxy_header
  @proxy_header
end

#requestString

Instructs the health check prober to send this exact ASCII string, up to 1024 bytes in length, after establishing the TCP connection and SSL handshake. Corresponds to the JSON property request

Returns:

  • (String)


67845
67846
67847
# File 'lib/google/apis/compute_alpha/classes.rb', line 67845

def request
  @request
end

#responseString

Creates a content-based SSL health check. In addition to establishing a TCP connection and the TLS handshake, you can configure the health check to pass only when the backend sends this exact response ASCII string, up to 1024 bytes in length. For details, see: https://cloud.google.com/load-balancing/docs/health-check-concepts#criteria- protocol-ssl-tcp Corresponds to the JSON property response

Returns:

  • (String)


67855
67856
67857
# File 'lib/google/apis/compute_alpha/classes.rb', line 67855

def response
  @response
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



67862
67863
67864
67865
67866
67867
67868
67869
# File 'lib/google/apis/compute_alpha/classes.rb', line 67862

def update!(**args)
  @port = args[:port] if args.key?(:port)
  @port_name = args[:port_name] if args.key?(:port_name)
  @port_specification = args[:port_specification] if args.key?(:port_specification)
  @proxy_header = args[:proxy_header] if args.key?(:proxy_header)
  @request = args[:request] if args.key?(:request)
  @response = args[:response] if args.key?(:response)
end