Class: Google::Apis::ComputeAlpha::StoragePool

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Represents a zonal storage pool resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StoragePool

Returns a new instance of StoragePool.



75116
75117
75118
# File 'lib/google/apis/compute_alpha/classes.rb', line 75116

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#capacity_provisioning_typeString

Provisioning type of the byte capacity of the pool. Corresponds to the JSON property capacityProvisioningType

Returns:

  • (String)


74960
74961
74962
# File 'lib/google/apis/compute_alpha/classes.rb', line 74960

def capacity_provisioning_type
  @capacity_provisioning_type
end

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


74966
74967
74968
# File 'lib/google/apis/compute_alpha/classes.rb', line 74966

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


74972
74973
74974
# File 'lib/google/apis/compute_alpha/classes.rb', line 74972

def description
  @description
end

#exapool_provisioned_capacity_gbGoogle::Apis::ComputeAlpha::StoragePoolExapoolProvisionedCapacityGb

Exapool provisioned capacities for each SKU type Corresponds to the JSON property exapoolProvisionedCapacityGb



74977
74978
74979
# File 'lib/google/apis/compute_alpha/classes.rb', line 74977

def exapool_provisioned_capacity_gb
  @exapool_provisioned_capacity_gb
end

#idFixnum

Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


74984
74985
74986
# File 'lib/google/apis/compute_alpha/classes.rb', line 74984

def id
  @id
end

#kindString

Output only. [Output Only] Type of the resource. Always compute#storagePool for storage pools. Corresponds to the JSON property kind

Returns:

  • (String)


74990
74991
74992
# File 'lib/google/apis/compute_alpha/classes.rb', line 74990

def kind
  @kind
end

#label_fingerprintString

A fingerprint for the labels being applied to this storage pool, which is essentially a hash of the labels set used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update labels. You must always provide an up-to-date fingerprint hash in order to update or change labels, otherwise the request will fail with error412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve a storage pool. Corresponds to the JSON property labelFingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


75003
75004
75005
# File 'lib/google/apis/compute_alpha/classes.rb', line 75003

def label_fingerprint
  @label_fingerprint
end

#labelsHash<String,String>

Labels to apply to this storage pool. These can be later modified by the setLabels method. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


75009
75010
75011
# File 'lib/google/apis/compute_alpha/classes.rb', line 75009

def labels
  @labels
end

#nameString

Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


75020
75021
75022
# File 'lib/google/apis/compute_alpha/classes.rb', line 75020

def name
  @name
end

#paramsGoogle::Apis::ComputeAlpha::StoragePoolParams

Additional storage pool params. Corresponds to the JSON property params



75025
75026
75027
# File 'lib/google/apis/compute_alpha/classes.rb', line 75025

def params
  @params
end

#performance_provisioning_typeString

Provisioning type of the performance-related parameters of the pool, such as throughput and IOPS. Corresponds to the JSON property performanceProvisioningType

Returns:

  • (String)


75031
75032
75033
# File 'lib/google/apis/compute_alpha/classes.rb', line 75031

def performance_provisioning_type
  @performance_provisioning_type
end

#pool_provisioned_capacity_gbFixnum

Size of the storage pool in GiB. For more information about the size limits, see https://cloud.google.com/compute/docs/disks/storage-pools. Corresponds to the JSON property poolProvisionedCapacityGb

Returns:

  • (Fixnum)


75037
75038
75039
# File 'lib/google/apis/compute_alpha/classes.rb', line 75037

def pool_provisioned_capacity_gb
  @pool_provisioned_capacity_gb
end

#pool_provisioned_iopsFixnum

Provisioned IOPS of the storage pool. Only relevant if the storage pool type is hyperdisk-balanced. Corresponds to the JSON property poolProvisionedIops

Returns:

  • (Fixnum)


75043
75044
75045
# File 'lib/google/apis/compute_alpha/classes.rb', line 75043

def pool_provisioned_iops
  @pool_provisioned_iops
end

#pool_provisioned_throughputFixnum

Provisioned throughput of the storage pool in MiB/s. Only relevant if the storage pool type is hyperdisk-balanced or hyperdisk-throughput. Corresponds to the JSON property poolProvisionedThroughput

Returns:

  • (Fixnum)


75049
75050
75051
# File 'lib/google/apis/compute_alpha/classes.rb', line 75049

def pool_provisioned_throughput
  @pool_provisioned_throughput
end

#provisioned_iopsFixnum

DEPRECATED -- use "pool provisioned IOPS". Corresponds to the JSON property provisionedIops

Returns:

  • (Fixnum)


75054
75055
75056
# File 'lib/google/apis/compute_alpha/classes.rb', line 75054

def provisioned_iops
  @provisioned_iops
end

#provisioned_throughputFixnum

DEPRECATED -- use "pool provisioned throughput". Corresponds to the JSON property provisionedThroughput

Returns:

  • (Fixnum)


75059
75060
75061
# File 'lib/google/apis/compute_alpha/classes.rb', line 75059

def provisioned_throughput
  @provisioned_throughput
end

#resource_statusGoogle::Apis::ComputeAlpha::StoragePoolResourceStatus

[Output Only] Contains output only fields. Corresponds to the JSON property resourceStatus



75064
75065
75066
# File 'lib/google/apis/compute_alpha/classes.rb', line 75064

def resource_status
  @resource_status
end

Output only. [Output Only] Server-defined fully-qualified URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


75070
75071
75072
# File 'lib/google/apis/compute_alpha/classes.rb', line 75070

def self_link
  @self_link
end

Output only. [Output Only] Server-defined URL for this resource's resource id. Corresponds to the JSON property selfLinkWithId

Returns:

  • (String)


75075
75076
75077
# File 'lib/google/apis/compute_alpha/classes.rb', line 75075

def self_link_with_id
  @self_link_with_id
end

#share_settingsGoogle::Apis::ComputeAlpha::StoragePoolShareSettings

Share settings for the storage pool. Corresponds to the JSON property shareSettings



75080
75081
75082
# File 'lib/google/apis/compute_alpha/classes.rb', line 75080

def share_settings
  @share_settings
end

#size_gbFixnum

DEPRECATED -- use "pool provisioned capacity gb". Corresponds to the JSON property sizeGb

Returns:

  • (Fixnum)


75085
75086
75087
# File 'lib/google/apis/compute_alpha/classes.rb', line 75085

def size_gb
  @size_gb
end

#stateString

Output only. [Output Only] The status of storage pool creation.

  • CREATING: Storage pool is provisioning. storagePool.
  • FAILED: Storage pool creation failed.
  • READY: Storage pool is ready for use.
  • DELETING: Storage pool is deleting. Corresponds to the JSON property state

Returns:

  • (String)


75097
75098
75099
# File 'lib/google/apis/compute_alpha/classes.rb', line 75097

def state
  @state
end

#statusGoogle::Apis::ComputeAlpha::StoragePoolResourceStatus

[Output Only] Contains output only fields. Corresponds to the JSON property status



75102
75103
75104
# File 'lib/google/apis/compute_alpha/classes.rb', line 75102

def status
  @status
end

#storage_pool_typeString

Type of the storage pool. Corresponds to the JSON property storagePoolType

Returns:

  • (String)


75107
75108
75109
# File 'lib/google/apis/compute_alpha/classes.rb', line 75107

def storage_pool_type
  @storage_pool_type
end

#zoneString

Output only. [Output Only] URL of the zone where the storage pool resides. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body. Corresponds to the JSON property zone

Returns:

  • (String)


75114
75115
75116
# File 'lib/google/apis/compute_alpha/classes.rb', line 75114

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



75121
75122
75123
75124
75125
75126
75127
75128
75129
75130
75131
75132
75133
75134
75135
75136
75137
75138
75139
75140
75141
75142
75143
75144
75145
75146
75147
# File 'lib/google/apis/compute_alpha/classes.rb', line 75121

def update!(**args)
  @capacity_provisioning_type = args[:capacity_provisioning_type] if args.key?(:capacity_provisioning_type)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @exapool_provisioned_capacity_gb = args[:exapool_provisioned_capacity_gb] if args.key?(:exapool_provisioned_capacity_gb)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @label_fingerprint = args[:label_fingerprint] if args.key?(:label_fingerprint)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @params = args[:params] if args.key?(:params)
  @performance_provisioning_type = args[:performance_provisioning_type] if args.key?(:performance_provisioning_type)
  @pool_provisioned_capacity_gb = args[:pool_provisioned_capacity_gb] if args.key?(:pool_provisioned_capacity_gb)
  @pool_provisioned_iops = args[:pool_provisioned_iops] if args.key?(:pool_provisioned_iops)
  @pool_provisioned_throughput = args[:pool_provisioned_throughput] if args.key?(:pool_provisioned_throughput)
  @provisioned_iops = args[:provisioned_iops] if args.key?(:provisioned_iops)
  @provisioned_throughput = args[:provisioned_throughput] if args.key?(:provisioned_throughput)
  @resource_status = args[:resource_status] if args.key?(:resource_status)
  @self_link = args[:self_link] if args.key?(:self_link)
  @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id)
  @share_settings = args[:share_settings] if args.key?(:share_settings)
  @size_gb = args[:size_gb] if args.key?(:size_gb)
  @state = args[:state] if args.key?(:state)
  @status = args[:status] if args.key?(:status)
  @storage_pool_type = args[:storage_pool_type] if args.key?(:storage_pool_type)
  @zone = args[:zone] if args.key?(:zone)
end