Class: Google::Apis::ComputeAlpha::StoragePoolList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

A list of StoragePool resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StoragePoolList

Returns a new instance of StoragePoolList.



75452
75453
75454
# File 'lib/google/apis/compute_alpha/classes.rb', line 75452

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


75408
75409
75410
# File 'lib/google/apis/compute_alpha/classes.rb', line 75408

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


75413
75414
75415
# File 'lib/google/apis/compute_alpha/classes.rb', line 75413

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::StoragePool>

A list of StoragePool resources. Corresponds to the JSON property items



75418
75419
75420
# File 'lib/google/apis/compute_alpha/classes.rb', line 75418

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#storagePoolList for lists of storagePools. Corresponds to the JSON property kind

Returns:

  • (String)


75424
75425
75426
# File 'lib/google/apis/compute_alpha/classes.rb', line 75424

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


75434
75435
75436
# File 'lib/google/apis/compute_alpha/classes.rb', line 75434

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


75439
75440
75441
# File 'lib/google/apis/compute_alpha/classes.rb', line 75439

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


75445
75446
75447
# File 'lib/google/apis/compute_alpha/classes.rb', line 75445

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::StoragePoolList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



75450
75451
75452
# File 'lib/google/apis/compute_alpha/classes.rb', line 75450

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



75457
75458
75459
75460
75461
75462
75463
75464
75465
75466
# File 'lib/google/apis/compute_alpha/classes.rb', line 75457

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end