Class: Google::Apis::ComputeAlpha::StoragePoolListDisks

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StoragePoolListDisks

Returns a new instance of StoragePoolListDisks.



75593
75594
75595
# File 'lib/google/apis/compute_alpha/classes.rb', line 75593

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


75546
75547
75548
# File 'lib/google/apis/compute_alpha/classes.rb', line 75546

def etag
  @etag
end

#idString

Output only. [Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


75552
75553
75554
# File 'lib/google/apis/compute_alpha/classes.rb', line 75552

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::StoragePoolDisk>

A list of StoragePoolDisk resources. Corresponds to the JSON property items



75557
75558
75559
# File 'lib/google/apis/compute_alpha/classes.rb', line 75557

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# storagePoolListDisks for lists of disks in a storagePool. Corresponds to the JSON property kind

Returns:

  • (String)


75564
75565
75566
# File 'lib/google/apis/compute_alpha/classes.rb', line 75564

def kind
  @kind
end

#next_page_tokenString

Output only. [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


75575
75576
75577
# File 'lib/google/apis/compute_alpha/classes.rb', line 75575

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


75580
75581
75582
# File 'lib/google/apis/compute_alpha/classes.rb', line 75580

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


75586
75587
75588
# File 'lib/google/apis/compute_alpha/classes.rb', line 75586

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::StoragePoolListDisks::Warning

Output only. [Output Only] Informational warning message. Corresponds to the JSON property warning



75591
75592
75593
# File 'lib/google/apis/compute_alpha/classes.rb', line 75591

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



75598
75599
75600
75601
75602
75603
75604
75605
75606
75607
# File 'lib/google/apis/compute_alpha/classes.rb', line 75598

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end