Class: Google::Apis::ComputeAlpha::StructuredEntries
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::StructuredEntries
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#entries ⇒ Hash<String,Object>
Map of a partner metadata that belong to the same subdomain.
Instance Method Summary collapse
-
#initialize(**args) ⇒ StructuredEntries
constructor
A new instance of StructuredEntries.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ StructuredEntries
Returns a new instance of StructuredEntries.
73857 73858 73859 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 73857 def initialize(**args) update!(**args) end |
Instance Attribute Details
#entries ⇒ Hash<String,Object>
Map of a partner metadata that belong to the same subdomain.
It accepts any value including google.protobuf.Struct.
Corresponds to the JSON property entries
73855 73856 73857 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 73855 def entries @entries end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
73862 73863 73864 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 73862 def update!(**args) @entries = args[:entries] if args.key?(:entries) end |