Class: Google::Apis::ComputeAlpha::SubnetworkList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of Subnetwork resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SubnetworkList

Returns a new instance of SubnetworkList.



76776
76777
76778
# File 'lib/google/apis/compute_alpha/classes.rb', line 76776

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


76743
76744
76745
# File 'lib/google/apis/compute_alpha/classes.rb', line 76743

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::Subnetwork>

A list of Subnetwork resources. Corresponds to the JSON property items



76748
76749
76750
# File 'lib/google/apis/compute_alpha/classes.rb', line 76748

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#subnetworkList for lists of subnetworks. Corresponds to the JSON property kind

Returns:

  • (String)


76754
76755
76756
# File 'lib/google/apis/compute_alpha/classes.rb', line 76754

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


76764
76765
76766
# File 'lib/google/apis/compute_alpha/classes.rb', line 76764

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


76769
76770
76771
# File 'lib/google/apis/compute_alpha/classes.rb', line 76769

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::SubnetworkList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



76774
76775
76776
# File 'lib/google/apis/compute_alpha/classes.rb', line 76774

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



76781
76782
76783
76784
76785
76786
76787
76788
# File 'lib/google/apis/compute_alpha/classes.rb', line 76781

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end