Class: Google::Apis::ComputeAlpha::TargetHttpsProxyList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of TargetHttpsProxy resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetHttpsProxyList

Returns a new instance of TargetHttpsProxyList.



79141
79142
79143
# File 'lib/google/apis/compute_alpha/classes.rb', line 79141

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


79108
79109
79110
# File 'lib/google/apis/compute_alpha/classes.rb', line 79108

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::TargetHttpsProxy>

A list of TargetHttpsProxy resources. Corresponds to the JSON property items



79113
79114
79115
# File 'lib/google/apis/compute_alpha/classes.rb', line 79113

def items
  @items
end

#kindString

Output only. Type of resource. Always compute#targetHttpsProxyList for lists of target HTTPS proxies. Corresponds to the JSON property kind

Returns:

  • (String)


79119
79120
79121
# File 'lib/google/apis/compute_alpha/classes.rb', line 79119

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


79129
79130
79131
# File 'lib/google/apis/compute_alpha/classes.rb', line 79129

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


79134
79135
79136
# File 'lib/google/apis/compute_alpha/classes.rb', line 79134

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::TargetHttpsProxyList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



79139
79140
79141
# File 'lib/google/apis/compute_alpha/classes.rb', line 79139

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



79146
79147
79148
79149
79150
79151
79152
79153
# File 'lib/google/apis/compute_alpha/classes.rb', line 79146

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end