Class: Google::Apis::ComputeAlpha::TargetInstancesScopedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetInstancesScopedList

Returns a new instance of TargetInstancesScopedList.



79611
79612
79613
# File 'lib/google/apis/compute_alpha/classes.rb', line 79611

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#target_instancesArray<Google::Apis::ComputeAlpha::TargetInstance>

A list of target instances contained in this scope. Corresponds to the JSON property targetInstances



79603
79604
79605
# File 'lib/google/apis/compute_alpha/classes.rb', line 79603

def target_instances
  @target_instances
end

#warningGoogle::Apis::ComputeAlpha::TargetInstancesScopedList::Warning

Informational warning which replaces the list of addresses when the list is empty. Corresponds to the JSON property warning



79609
79610
79611
# File 'lib/google/apis/compute_alpha/classes.rb', line 79609

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



79616
79617
79618
79619
# File 'lib/google/apis/compute_alpha/classes.rb', line 79616

def update!(**args)
  @target_instances = args[:target_instances] if args.key?(:target_instances)
  @warning = args[:warning] if args.key?(:warning)
end