Class: Google::Apis::ComputeAlpha::TargetPoolAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetPoolAggregatedList

Returns a new instance of TargetPoolAggregatedList.



79889
79890
79891
# File 'lib/google/apis/compute_alpha/classes.rb', line 79889

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


79850
79851
79852
# File 'lib/google/apis/compute_alpha/classes.rb', line 79850

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::TargetPoolsScopedList>

A list of TargetPool resources. Corresponds to the JSON property items



79855
79856
79857
# File 'lib/google/apis/compute_alpha/classes.rb', line 79855

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# targetPoolAggregatedList for aggregated lists of target pools. Corresponds to the JSON property kind

Returns:

  • (String)


79862
79863
79864
# File 'lib/google/apis/compute_alpha/classes.rb', line 79862

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


79872
79873
79874
# File 'lib/google/apis/compute_alpha/classes.rb', line 79872

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


79877
79878
79879
# File 'lib/google/apis/compute_alpha/classes.rb', line 79877

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


79882
79883
79884
# File 'lib/google/apis/compute_alpha/classes.rb', line 79882

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::TargetPoolAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



79887
79888
79889
# File 'lib/google/apis/compute_alpha/classes.rb', line 79887

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



79894
79895
79896
79897
79898
79899
79900
79901
79902
# File 'lib/google/apis/compute_alpha/classes.rb', line 79894

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end