Class: Google::Apis::ComputeAlpha::TargetPoolsScopedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetPoolsScopedList

Returns a new instance of TargetPoolsScopedList.



79953
79954
79955
# File 'lib/google/apis/compute_alpha/classes.rb', line 79953

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#target_poolsArray<Google::Apis::ComputeAlpha::TargetPool>

A list of target pools contained in this scope. Corresponds to the JSON property targetPools



79945
79946
79947
# File 'lib/google/apis/compute_alpha/classes.rb', line 79945

def target_pools
  @target_pools
end

#warningGoogle::Apis::ComputeAlpha::TargetPoolsScopedList::Warning

Informational warning which replaces the list of addresses when the list is empty. Corresponds to the JSON property warning



79951
79952
79953
# File 'lib/google/apis/compute_alpha/classes.rb', line 79951

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



79958
79959
79960
79961
# File 'lib/google/apis/compute_alpha/classes.rb', line 79958

def update!(**args)
  @target_pools = args[:target_pools] if args.key?(:target_pools)
  @warning = args[:warning] if args.key?(:warning)
end