Class: Google::Apis::ComputeAlpha::TargetTcpProxyList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of TargetTcpProxy resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetTcpProxyList

Returns a new instance of TargetTcpProxyList.



81055
81056
81057
# File 'lib/google/apis/compute_alpha/classes.rb', line 81055

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


81023
81024
81025
# File 'lib/google/apis/compute_alpha/classes.rb', line 81023

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::TargetTcpProxy>

A list of TargetTcpProxy resources. Corresponds to the JSON property items



81028
81029
81030
# File 'lib/google/apis/compute_alpha/classes.rb', line 81028

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


81033
81034
81035
# File 'lib/google/apis/compute_alpha/classes.rb', line 81033

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


81043
81044
81045
# File 'lib/google/apis/compute_alpha/classes.rb', line 81043

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


81048
81049
81050
# File 'lib/google/apis/compute_alpha/classes.rb', line 81048

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::TargetTcpProxyList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



81053
81054
81055
# File 'lib/google/apis/compute_alpha/classes.rb', line 81053

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



81060
81061
81062
81063
81064
81065
81066
81067
# File 'lib/google/apis/compute_alpha/classes.rb', line 81060

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end