Class: Google::Apis::ComputeAlpha::TargetVpnGatewayAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetVpnGatewayAggregatedList

Returns a new instance of TargetVpnGatewayAggregatedList.



81316
81317
81318
# File 'lib/google/apis/compute_alpha/classes.rb', line 81316

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


81278
81279
81280
# File 'lib/google/apis/compute_alpha/classes.rb', line 81278

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::TargetVpnGatewaysScopedList>

A list of TargetVpnGateway resources. Corresponds to the JSON property items



81283
81284
81285
# File 'lib/google/apis/compute_alpha/classes.rb', line 81283

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute#targetVpnGateway for target VPN gateways. Corresponds to the JSON property kind

Returns:

  • (String)


81289
81290
81291
# File 'lib/google/apis/compute_alpha/classes.rb', line 81289

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


81299
81300
81301
# File 'lib/google/apis/compute_alpha/classes.rb', line 81299

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


81304
81305
81306
# File 'lib/google/apis/compute_alpha/classes.rb', line 81304

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


81309
81310
81311
# File 'lib/google/apis/compute_alpha/classes.rb', line 81309

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::TargetVpnGatewayAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



81314
81315
81316
# File 'lib/google/apis/compute_alpha/classes.rb', line 81314

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



81321
81322
81323
81324
81325
81326
81327
81328
81329
# File 'lib/google/apis/compute_alpha/classes.rb', line 81321

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end