Class: Google::Apis::ComputeAlpha::TlsCertificateContext
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::TlsCertificateContext
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
[Deprecated] Defines the mechanism to obtain the client or server certificate. Defines the mechanism to obtain the client or server certificate.
Instance Attribute Summary collapse
-
#certificate_paths ⇒ Google::Apis::ComputeAlpha::TlsCertificatePaths
[Deprecated] The paths to the mounted TLS Certificates and private key.
-
#certificate_source ⇒ String
Defines how TLS certificates are obtained.
-
#sds_config ⇒ Google::Apis::ComputeAlpha::SdsConfig
[Deprecated] The configuration to access the SDS server.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TlsCertificateContext
constructor
A new instance of TlsCertificateContext.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TlsCertificateContext
Returns a new instance of TlsCertificateContext.
79203 79204 79205 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 79203 def initialize(**args) update!(**args) end |
Instance Attribute Details
#certificate_paths ⇒ Google::Apis::ComputeAlpha::TlsCertificatePaths
[Deprecated] The paths to the mounted TLS Certificates and private key.
The paths to the mounted TLS Certificates and private key.
Corresponds to the JSON property certificatePaths
79190 79191 79192 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 79190 def certificate_paths @certificate_paths end |
#certificate_source ⇒ String
Defines how TLS certificates are obtained.
Corresponds to the JSON property certificateSource
79195 79196 79197 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 79195 def certificate_source @certificate_source end |
#sds_config ⇒ Google::Apis::ComputeAlpha::SdsConfig
[Deprecated] The configuration to access the SDS server.
The configuration to access the SDS server.
Corresponds to the JSON property sdsConfig
79201 79202 79203 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 79201 def sds_config @sds_config end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
79208 79209 79210 79211 79212 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 79208 def update!(**args) @certificate_paths = args[:certificate_paths] if args.key?(:certificate_paths) @certificate_source = args[:certificate_source] if args.key?(:certificate_source) @sds_config = args[:sds_config] if args.key?(:sds_config) end |