Class: Google::Apis::ComputeAlpha::TlsContext
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::TlsContext
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
[Deprecated] The TLS settings for the client or server. The TLS settings for the client or server.
Instance Attribute Summary collapse
-
#certificate_context ⇒ Google::Apis::ComputeAlpha::TlsCertificateContext
[Deprecated] Defines the mechanism to obtain the client or server certificate.
-
#validation_context ⇒ Google::Apis::ComputeAlpha::TlsValidationContext
[Deprecated] Defines the mechanism to obtain the Certificate Authority certificate to validate the client/server certificate.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TlsContext
constructor
A new instance of TlsContext.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TlsContext
Returns a new instance of TlsContext.
81598 81599 81600 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 81598 def initialize(**args) update!(**args) end |
Instance Attribute Details
#certificate_context ⇒ Google::Apis::ComputeAlpha::TlsCertificateContext
[Deprecated] Defines the mechanism to obtain the client or server
certificate.
Defines the mechanism to obtain the client or server certificate.
Corresponds to the JSON property certificateContext
81589 81590 81591 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 81589 def certificate_context @certificate_context end |
#validation_context ⇒ Google::Apis::ComputeAlpha::TlsValidationContext
[Deprecated] Defines the mechanism to obtain the Certificate Authority
certificate to validate the client/server certificate.
validate the client/server certificate.
Corresponds to the JSON property validationContext
81596 81597 81598 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 81596 def validation_context @validation_context end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
81603 81604 81605 81606 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 81603 def update!(**args) @certificate_context = args[:certificate_context] if args.key?(:certificate_context) @validation_context = args[:validation_context] if args.key?(:validation_context) end |