Class: Google::Apis::ComputeAlpha::TlsValidationContext

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

[Deprecated] Defines the mechanism to obtain the Certificate Authority certificate to validate the client/server certificate. validate the client/server certificate.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TlsValidationContext

Returns a new instance of TlsValidationContext.



79901
79902
79903
# File 'lib/google/apis/compute_alpha/classes.rb', line 79901

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#certificate_pathString

The path to the file holding the CA certificate to validate the client or server certificate. Corresponds to the JSON property certificatePath

Returns:

  • (String)


79888
79889
79890
# File 'lib/google/apis/compute_alpha/classes.rb', line 79888

def certificate_path
  @certificate_path
end

#sds_configGoogle::Apis::ComputeAlpha::SdsConfig

[Deprecated] The configuration to access the SDS server. The configuration to access the SDS server. Corresponds to the JSON property sdsConfig



79894
79895
79896
# File 'lib/google/apis/compute_alpha/classes.rb', line 79894

def sds_config
  @sds_config
end

#validation_sourceString

Defines how TLS certificates are obtained. Corresponds to the JSON property validationSource

Returns:

  • (String)


79899
79900
79901
# File 'lib/google/apis/compute_alpha/classes.rb', line 79899

def validation_source
  @validation_source
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



79906
79907
79908
79909
79910
# File 'lib/google/apis/compute_alpha/classes.rb', line 79906

def update!(**args)
  @certificate_path = args[:certificate_path] if args.key?(:certificate_path)
  @sds_config = args[:sds_config] if args.key?(:sds_config)
  @validation_source = args[:validation_source] if args.key?(:validation_source)
end