Class: Google::Apis::ComputeAlpha::UdpHealthCheck
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::UdpHealthCheck
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#port ⇒ Fixnum
The UDP port number to which the health check prober sends packets.
-
#port_name ⇒ String
Not supported.
-
#request ⇒ String
Raw data of request to send in payload of UDP packet.
-
#response ⇒ String
The bytes to match against the beginning of the response data.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UdpHealthCheck
constructor
A new instance of UdpHealthCheck.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UdpHealthCheck
Returns a new instance of UdpHealthCheck.
81948 81949 81950 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 81948 def initialize(**args) update!(**args) end |
Instance Attribute Details
#port ⇒ Fixnum
The UDP port number to which the health check prober sends packets. Valid
values are 1 through 65535.
Corresponds to the JSON property port
81929 81930 81931 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 81929 def port @port end |
#port_name ⇒ String
Not supported.
Corresponds to the JSON property portName
81934 81935 81936 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 81934 def port_name @port_name end |
#request ⇒ String
Raw data of request to send in payload of UDP packet. It is an error if
this is empty. The request data can only be ASCII.
Corresponds to the JSON property request
81940 81941 81942 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 81940 def request @request end |
#response ⇒ String
The bytes to match against the beginning of the response data.
It is an error if this is empty. The response data can only be ASCII.
Corresponds to the JSON property response
81946 81947 81948 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 81946 def response @response end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
81953 81954 81955 81956 81957 81958 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 81953 def update!(**args) @port = args[:port] if args.key?(:port) @port_name = args[:port_name] if args.key?(:port_name) @request = args[:request] if args.key?(:request) @response = args[:response] if args.key?(:response) end |