Class: Google::Apis::ComputeAlpha::UrlMapList::Warning::Datum
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::UrlMapList::Warning::Datum
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#key ⇒ String
[Output Only] A key that provides more detail on the warning being returned.
-
#value ⇒ String
[Output Only] A warning data value corresponding to the key.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Datum
constructor
A new instance of Datum.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Datum
Returns a new instance of Datum.
80452 80453 80454 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 80452 def initialize(**args) update!(**args) end |
Instance Attribute Details
#key ⇒ String
[Output Only] A key that provides more detail on the warning being
returned. For example, for warnings where there are no results in a list
request for a particular zone, this key might be scope and
the key value might be the zone name. Other examples might be a key
indicating a deprecated resource and a suggested replacement, or a
warning about invalid network settings (for example, if an instance
attempts to perform IP forwarding but is not enabled for IP forwarding).
Corresponds to the JSON property key
80445 80446 80447 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 80445 def key @key end |
#value ⇒ String
[Output Only] A warning data value corresponding to the key.
Corresponds to the JSON property value
80450 80451 80452 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 80450 def value @value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
80457 80458 80459 80460 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 80457 def update!(**args) @key = args[:key] if args.key?(:key) @value = args[:value] if args.key?(:value) end |