Class: Google::Apis::ComputeAlpha::UrlMapQuotaUsage
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::UrlMapQuotaUsage
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Message representing the quota usage for a UrlMap.
Instance Attribute Summary collapse
-
#forwarding_rules ⇒ Fixnum
Output only.
-
#units ⇒ Fixnum
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UrlMapQuotaUsage
constructor
A new instance of UrlMapQuotaUsage.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UrlMapQuotaUsage
Returns a new instance of UrlMapQuotaUsage.
82430 82431 82432 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 82430 def initialize(**args) update!(**args) end |
Instance Attribute Details
#forwarding_rules ⇒ Fixnum
Output only. The number of forwarding rules that uses this UrlMap.
Corresponds to the JSON property forwardingRules
82423 82424 82425 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 82423 def forwarding_rules @forwarding_rules end |
#units ⇒ Fixnum
Output only. The number of quota units calculated for this UrlMap.
Corresponds to the JSON property units
82428 82429 82430 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 82428 def units @units end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
82435 82436 82437 82438 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 82435 def update!(**args) @forwarding_rules = args[:forwarding_rules] if args.key?(:forwarding_rules) @units = args[:units] if args.key?(:units) end |