Class: Google::Apis::ComputeAlpha::UrlMapValidationResult
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::UrlMapValidationResult
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Message representing the validation result for a UrlMap.
Instance Attribute Summary collapse
-
#load_errors ⇒ Array<String>
Corresponds to the JSON property
loadErrors. -
#load_succeeded ⇒ Boolean
(also: #load_succeeded?)
Whether the given UrlMap can be successfully loaded.
-
#test_failures ⇒ Array<Google::Apis::ComputeAlpha::TestFailure>
Corresponds to the JSON property
testFailures. -
#test_passed ⇒ Boolean
(also: #test_passed?)
If successfully loaded, this field indicates whether the test passed.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UrlMapValidationResult
constructor
A new instance of UrlMapValidationResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UrlMapValidationResult
Returns a new instance of UrlMapValidationResult.
78739 78740 78741 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 78739 def initialize(**args) update!(**args) end |
Instance Attribute Details
#load_errors ⇒ Array<String>
Corresponds to the JSON property loadErrors
78718 78719 78720 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 78718 def load_errors @load_errors end |
#load_succeeded ⇒ Boolean Also known as: load_succeeded?
Whether the given UrlMap can be successfully loaded.
If false, 'loadErrors' indicates the reasons.
Corresponds to the JSON property loadSucceeded
78724 78725 78726 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 78724 def load_succeeded @load_succeeded end |
#test_failures ⇒ Array<Google::Apis::ComputeAlpha::TestFailure>
Corresponds to the JSON property testFailures
78730 78731 78732 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 78730 def test_failures @test_failures end |
#test_passed ⇒ Boolean Also known as: test_passed?
If successfully loaded, this field indicates whether the test passed.
If false, 'testFailures's indicate the reason of failure.
Corresponds to the JSON property testPassed
78736 78737 78738 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 78736 def test_passed @test_passed end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
78744 78745 78746 78747 78748 78749 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 78744 def update!(**args) @load_errors = args[:load_errors] if args.key?(:load_errors) @load_succeeded = args[:load_succeeded] if args.key?(:load_succeeded) @test_failures = args[:test_failures] if args.key?(:test_failures) @test_passed = args[:test_passed] if args.key?(:test_passed) end |