Class: Google::Apis::ComputeAlpha::UrlMapsValidateRequest
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::UrlMapsValidateRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#load_balancing_schemes ⇒ Array<String>
Specifies the load balancer type(s) this validation request is for.
-
#resource ⇒ Google::Apis::ComputeAlpha::UrlMap
Represents a URL Map resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UrlMapsValidateRequest
constructor
A new instance of UrlMapsValidateRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UrlMapsValidateRequest
Returns a new instance of UrlMapsValidateRequest.
79030 79031 79032 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 79030 def initialize(**args) update!(**args) end |
Instance Attribute Details
#load_balancing_schemes ⇒ Array<String>
Specifies the load balancer type(s) this validation request is for.
UseEXTERNAL_MANAGED for global external Application Load
Balancers and regional external Application Load Balancers.
Use EXTERNAL for classic Application Load Balancers.
Use INTERNAL_MANAGED for internal Application Load Balancers. For more
information, refer to Choosing
a load balancer.
If unspecified, the load balancing scheme will be inferred from the backend
service resources this URL map references. If that can not be inferred (for
example, this URL map only references backend buckets, or this Url map is
for rewrites and redirects only and doesn't reference any backends),EXTERNAL
will be used as the default type.
If specified, the scheme(s) must not conflict with the load balancing
scheme of the backend service resources this Url map references.
Corresponds to the JSON property loadBalancingSchemes
78999 79000 79001 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 78999 def load_balancing_schemes @load_balancing_schemes end |
#resource ⇒ Google::Apis::ComputeAlpha::UrlMap
Represents a URL Map resource. Compute Engine has two URL Map resources:
- Global
- Regional A URL map resource is a component of certain types of cloud load balancers and Traffic Director:
- urlMaps are used by global external Application Load Balancers, classic Application Load Balancers, and cross-region internal Application Load Balancers.
- regionUrlMaps are used by internal Application Load Balancers,
regional external Application Load Balancers and regional internal
Application Load Balancers.
For a list of supported URL map features by the load balancer type, see the
Load balancing features: Routing and traffic management table.
For a list of supported URL map features for Traffic Director, see the
Traffic Director features: Routing and traffic management table.
This resource defines mappings from hostnames and URL paths to either a
backend service or a backend bucket.
To use the global urlMaps resource, the backend service must
have a loadBalancingScheme of either EXTERNAL,EXTERNAL_MANAGED, or
INTERNAL_SELF_MANAGED. To use
the regionUrlMaps resource, the backend service must have aloadBalancingScheme
of INTERNAL_MANAGED. For more
information, read URL
Map Concepts.
Corresponds to the JSON property
resource
79028 79029 79030 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 79028 def resource @resource end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
79035 79036 79037 79038 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 79035 def update!(**args) @load_balancing_schemes = args[:load_balancing_schemes] if args.key?(:load_balancing_schemes) @resource = args[:resource] if args.key?(:resource) end |