Class: Google::Apis::ComputeAlpha::UrlRewrite
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::UrlRewrite
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
The spec for modifying the path before sending the request to the matched backend service.
Instance Attribute Summary collapse
-
#host_rewrite ⇒ String
Before forwarding the request to the selected service, the request's host header is replaced with contents of hostRewrite.
-
#path_prefix_rewrite ⇒ String
Before forwarding the request to the selected backend service, the matching portion of the request's path is replaced bypathPrefixRewrite.
-
#path_template_rewrite ⇒ String
If specified, the pattern rewrites the URL path (based on the :path header) using the HTTP template syntax.
-
#regex_rewrite ⇒ Google::Apis::ComputeAlpha::RegexRewrite
The spec for modifying the path using a regular expression.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UrlRewrite
constructor
A new instance of UrlRewrite.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UrlRewrite
Returns a new instance of UrlRewrite.
82420 82421 82422 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 82420 def initialize(**args) update!(**args) end |
Instance Attribute Details
#host_rewrite ⇒ String
Before forwarding the request to the selected service, the request's
host header is replaced with contents of hostRewrite.
The value must be from 1 to 255 characters.
Corresponds to the JSON property hostRewrite
82380 82381 82382 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 82380 def host_rewrite @host_rewrite end |
#path_prefix_rewrite ⇒ String
Before forwarding the request to the selected backend service, the
matching portion of the request's path is replaced bypathPrefixRewrite.
The value must be from 1 to 1024 characters.
Corresponds to the JSON property pathPrefixRewrite
82387 82388 82389 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 82387 def path_prefix_rewrite @path_prefix_rewrite end |
#path_template_rewrite ⇒ String
If specified, the pattern rewrites the URL path (based on the :path header) using the HTTP template syntax. A corresponding path_template_match must be specified. Any template variables must exist in the path_template_match field.
- -At least one variable must be specified in the path_template_match field
- You can omit variables from the rewritten URL
- The * and ** operators cannot be matched
unless they have a corresponding variable name - e.g.
format=*orvar=**. For example, a path_template_match of /static/format=**could be rewritten as /static/content/formatto prefix/content to the URL. Variables can also be re-ordered in a rewrite, so that /country/format/suffix=**can be rewritten as /content/format/country/suffix. At least one non-empty routeRules[].matchRules[].path_template_match is required. Only one of path_prefix_rewrite orpath_template_rewrite may be specified. Corresponds to the JSON propertypathTemplateRewrite
82413 82414 82415 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 82413 def path_template_rewrite @path_template_rewrite end |
#regex_rewrite ⇒ Google::Apis::ComputeAlpha::RegexRewrite
The spec for modifying the path using a regular expression.
Corresponds to the JSON property regexRewrite
82418 82419 82420 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 82418 def regex_rewrite @regex_rewrite end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
82425 82426 82427 82428 82429 82430 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 82425 def update!(**args) @host_rewrite = args[:host_rewrite] if args.key?(:host_rewrite) @path_prefix_rewrite = args[:path_prefix_rewrite] if args.key?(:path_prefix_rewrite) @path_template_rewrite = args[:path_template_rewrite] if args.key?(:path_template_rewrite) @regex_rewrite = args[:regex_rewrite] if args.key?(:regex_rewrite) end |