Class: Google::Apis::ComputeAlpha::UsableSubnetwork

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Subnetwork which the current user has compute.subnetworks.use permission on.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UsableSubnetwork

Returns a new instance of UsableSubnetwork.



82809
82810
82811
# File 'lib/google/apis/compute_alpha/classes.rb', line 82809

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#external_ipv6_prefixString

Output only. [Output Only] The external IPv6 address range that is assigned to this subnetwork. Corresponds to the JSON property externalIpv6Prefix

Returns:

  • (String)


82748
82749
82750
# File 'lib/google/apis/compute_alpha/classes.rb', line 82748

def external_ipv6_prefix
  @external_ipv6_prefix
end

#internal_ipv6_prefixString

Output only. [Output Only] The internal IPv6 address range that is assigned to this subnetwork. Corresponds to the JSON property internalIpv6Prefix

Returns:

  • (String)


82755
82756
82757
# File 'lib/google/apis/compute_alpha/classes.rb', line 82755

def internal_ipv6_prefix
  @internal_ipv6_prefix
end

#ip_cidr_rangeString

The range of internal addresses that are owned by this subnetwork. Corresponds to the JSON property ipCidrRange

Returns:

  • (String)


82760
82761
82762
# File 'lib/google/apis/compute_alpha/classes.rb', line 82760

def ip_cidr_range
  @ip_cidr_range
end

#ipv6_access_typeString

The access type of IPv6 address this subnet holds. It's immutable and can only be specified during creation or the first time the subnet is updated into IPV4_IPV6 dual stack. Corresponds to the JSON property ipv6AccessType

Returns:

  • (String)


82767
82768
82769
# File 'lib/google/apis/compute_alpha/classes.rb', line 82767

def ipv6_access_type
  @ipv6_access_type
end

#networkString

Network URL. Corresponds to the JSON property network

Returns:

  • (String)


82772
82773
82774
# File 'lib/google/apis/compute_alpha/classes.rb', line 82772

def network
  @network
end

#purposeString

Corresponds to the JSON property purpose

Returns:

  • (String)


82777
82778
82779
# File 'lib/google/apis/compute_alpha/classes.rb', line 82777

def purpose
  @purpose
end

#roleString

The role of subnetwork. Currently, this field is only used when purpose is set to GLOBAL_MANAGED_PROXY orREGIONAL_MANAGED_PROXY. The value can be set toACTIVE or BACKUP. An ACTIVE subnetwork is one that is currently being used for Envoy-based load balancers in a region. A BACKUP subnetwork is one that is ready to be promoted to ACTIVE or is currently draining. This field can be updated with a patch request. Corresponds to the JSON property role

Returns:

  • (String)


82788
82789
82790
# File 'lib/google/apis/compute_alpha/classes.rb', line 82788

def role
  @role
end

#secondary_ip_rangesArray<Google::Apis::ComputeAlpha::UsableSubnetworkSecondaryRange>

Secondary IP ranges. Corresponds to the JSON property secondaryIpRanges



82793
82794
82795
# File 'lib/google/apis/compute_alpha/classes.rb', line 82793

def secondary_ip_ranges
  @secondary_ip_ranges
end

#stack_typeString

The stack type for the subnet. If set to IPV4_ONLY, new VMs in the subnet are assigned IPv4 addresses only. If set toIPV4_IPV6, new VMs in the subnet can be assigned both IPv4 and IPv6 addresses. If not specified, IPV4_ONLY is used. This field can be both set at resource creation time and updated usingpatch. Corresponds to the JSON property stackType

Returns:

  • (String)


82802
82803
82804
# File 'lib/google/apis/compute_alpha/classes.rb', line 82802

def stack_type
  @stack_type
end

#subnetworkString

Subnetwork URL. Corresponds to the JSON property subnetwork

Returns:

  • (String)


82807
82808
82809
# File 'lib/google/apis/compute_alpha/classes.rb', line 82807

def subnetwork
  @subnetwork
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



82814
82815
82816
82817
82818
82819
82820
82821
82822
82823
82824
82825
# File 'lib/google/apis/compute_alpha/classes.rb', line 82814

def update!(**args)
  @external_ipv6_prefix = args[:external_ipv6_prefix] if args.key?(:external_ipv6_prefix)
  @internal_ipv6_prefix = args[:internal_ipv6_prefix] if args.key?(:internal_ipv6_prefix)
  @ip_cidr_range = args[:ip_cidr_range] if args.key?(:ip_cidr_range)
  @ipv6_access_type = args[:ipv6_access_type] if args.key?(:ipv6_access_type)
  @network = args[:network] if args.key?(:network)
  @purpose = args[:purpose] if args.key?(:purpose)
  @role = args[:role] if args.key?(:role)
  @secondary_ip_ranges = args[:secondary_ip_ranges] if args.key?(:secondary_ip_ranges)
  @stack_type = args[:stack_type] if args.key?(:stack_type)
  @subnetwork = args[:subnetwork] if args.key?(:subnetwork)
end