Class: Google::Apis::ComputeAlpha::UsableSubnetworksAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UsableSubnetworksAggregatedList

Returns a new instance of UsableSubnetworksAggregatedList.



83191
83192
83193
# File 'lib/google/apis/compute_alpha/classes.rb', line 83191

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


83142
83143
83144
# File 'lib/google/apis/compute_alpha/classes.rb', line 83142

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::UsableSubnetwork>

[Output] A list of usable subnetwork URLs. Corresponds to the JSON property items



83147
83148
83149
# File 'lib/google/apis/compute_alpha/classes.rb', line 83147

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# usableSubnetworksAggregatedList for aggregated lists of usable subnetworks. Corresponds to the JSON property kind

Returns:

  • (String)


83154
83155
83156
# File 'lib/google/apis/compute_alpha/classes.rb', line 83154

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. In special cases listUsable may return 0 subnetworks andnextPageToken which still should be used to get the next page of results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


83167
83168
83169
# File 'lib/google/apis/compute_alpha/classes.rb', line 83167

def next_page_token
  @next_page_token
end

#scoped_warningsArray<Google::Apis::ComputeAlpha::SubnetworksScopedWarning>

Output only. [Output Only] Informational warning messages for failures encountered from scopes. Corresponds to the JSON property scopedWarnings



83174
83175
83176
# File 'lib/google/apis/compute_alpha/classes.rb', line 83174

def scoped_warnings
  @scoped_warnings
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


83179
83180
83181
# File 'lib/google/apis/compute_alpha/classes.rb', line 83179

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


83184
83185
83186
# File 'lib/google/apis/compute_alpha/classes.rb', line 83184

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::UsableSubnetworksAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



83189
83190
83191
# File 'lib/google/apis/compute_alpha/classes.rb', line 83189

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



83196
83197
83198
83199
83200
83201
83202
83203
83204
83205
# File 'lib/google/apis/compute_alpha/classes.rb', line 83196

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @scoped_warnings = args[:scoped_warnings] if args.key?(:scoped_warnings)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end