Class: Google::Apis::ComputeAlpha::UsageExportLocation
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::UsageExportLocation
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
The location in Cloud Storage and naming method of the daily usage report. Contains bucket_name and report_name prefix.
Instance Attribute Summary collapse
-
#bucket_name ⇒ String
The name of an existing bucket in Cloud Storage where the usage report object is stored.
-
#report_name_prefix ⇒ String
An optional prefix for the name of the usage report object stored inbucketName.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UsageExportLocation
constructor
A new instance of UsageExportLocation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UsageExportLocation
Returns a new instance of UsageExportLocation.
82720 82721 82722 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 82720 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bucket_name ⇒ String
The name of an existing bucket in Cloud Storage where the usage report
object is stored. The Google Service Account is granted write access to
this bucket. This can either be the bucket name by itself, such asexample-
bucket, or the bucket name with gs://
or https://storage.googleapis.com/ in front of it, such
as gs://example-bucket.
Corresponds to the JSON property bucketName
82708 82709 82710 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 82708 def bucket_name @bucket_name end |
#report_name_prefix ⇒ String
An optional prefix for the name of the usage report object stored inbucketName.
If not supplied, defaults tousage_gce. The report is stored as a CSV file
namedreport_name_prefix_gce_YYYYMMDD.csv whereYYYYMMDD is the day of the usage
according to Pacific Time.
If you supply a prefix, it should conform to Cloud Storageobject naming
conventions.
Corresponds to the JSON property reportNamePrefix
82718 82719 82720 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 82718 def report_name_prefix @report_name_prefix end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
82725 82726 82727 82728 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 82725 def update!(**args) @bucket_name = args[:bucket_name] if args.key?(:bucket_name) @report_name_prefix = args[:report_name_prefix] if args.key?(:report_name_prefix) end |