Class: Google::Apis::ComputeAlpha::VmExtensionPoliciesScopedList::Warning

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Informational warning which replaces the list of backend services when the list is empty.

Defined Under Namespace

Classes: Datum

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Warning

Returns a new instance of Warning.



80782
80783
80784
# File 'lib/google/apis/compute_alpha/classes.rb', line 80782

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#codeString

[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response. Corresponds to the JSON property code

Returns:

  • (String)


80764
80765
80766
# File 'lib/google/apis/compute_alpha/classes.rb', line 80764

def code
  @code
end

#dataArray<Google::Apis::ComputeAlpha::VmExtensionPoliciesScopedList::Warning::Datum>

[Output Only] Metadata about this warning in key: value format. For example: "data": [ "key": "scope", "value": "zones/us-east1-d" Corresponds to the JSON property data



80775
80776
80777
# File 'lib/google/apis/compute_alpha/classes.rb', line 80775

def data
  @data
end

#messageString

[Output Only] A human-readable description of the warning code. Corresponds to the JSON property message

Returns:

  • (String)


80780
80781
80782
# File 'lib/google/apis/compute_alpha/classes.rb', line 80780

def message
  @message
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



80787
80788
80789
80790
80791
# File 'lib/google/apis/compute_alpha/classes.rb', line 80787

def update!(**args)
  @code = args[:code] if args.key?(:code)
  @data = args[:data] if args.key?(:data)
  @message = args[:message] if args.key?(:message)
end