Class: Google::Apis::ComputeAlpha::VpnTunnelAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VpnTunnelAggregatedList

Returns a new instance of VpnTunnelAggregatedList.



85398
85399
85400
# File 'lib/google/apis/compute_alpha/classes.rb', line 85398

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


85360
85361
85362
# File 'lib/google/apis/compute_alpha/classes.rb', line 85360

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::VpnTunnelsScopedList>

A list of VpnTunnelsScopedList resources. Corresponds to the JSON property items



85365
85366
85367
# File 'lib/google/apis/compute_alpha/classes.rb', line 85365

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#vpnTunnel for VPN tunnels. Corresponds to the JSON property kind

Returns:

  • (String)


85371
85372
85373
# File 'lib/google/apis/compute_alpha/classes.rb', line 85371

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


85381
85382
85383
# File 'lib/google/apis/compute_alpha/classes.rb', line 85381

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


85386
85387
85388
# File 'lib/google/apis/compute_alpha/classes.rb', line 85386

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


85391
85392
85393
# File 'lib/google/apis/compute_alpha/classes.rb', line 85391

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::VpnTunnelAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



85396
85397
85398
# File 'lib/google/apis/compute_alpha/classes.rb', line 85396

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



85403
85404
85405
85406
85407
85408
85409
85410
85411
# File 'lib/google/apis/compute_alpha/classes.rb', line 85403

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end