Class: Google::Apis::ComputeAlpha::WafExpressionSet
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::WafExpressionSet
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#aliases ⇒ Array<String>
A list of alternate IDs.
-
#expressions ⇒ Array<Google::Apis::ComputeAlpha::WafExpressionSetExpression>
List of available expressions.
-
#id ⇒ String
Google specified expression set ID.
Instance Method Summary collapse
-
#initialize(**args) ⇒ WafExpressionSet
constructor
A new instance of WafExpressionSet.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ WafExpressionSet
Returns a new instance of WafExpressionSet.
83733 83734 83735 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 83733 def initialize(**args) update!(**args) end |
Instance Attribute Details
#aliases ⇒ Array<String>
A list of alternate IDs. The format should be:
- E.g. XSS-stable
Generic suffix like "stable" is particularly useful if a policy
likes to avail newer set of expressions without having to change
the policy.
A given alias name can't be used for more than one entity set.
Corresponds to the JSON property
aliases
83719 83720 83721 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 83719 def aliases @aliases end |
#expressions ⇒ Array<Google::Apis::ComputeAlpha::WafExpressionSetExpression>
List of available expressions.
Corresponds to the JSON property expressions
83724 83725 83726 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 83724 def expressions @expressions end |
#id ⇒ String
Google specified expression set ID. The format should be:
- E.g. XSS-20170329
required
Corresponds to the JSON property
id
83731 83732 83733 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 83731 def id @id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
83738 83739 83740 83741 83742 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 83738 def update!(**args) @aliases = args[:aliases] if args.key?(:aliases) @expressions = args[:expressions] if args.key?(:expressions) @id = args[:id] if args.key?(:id) end |