Class: Google::Apis::ComputeAlpha::WireGroupList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Response for the list request.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WireGroupList

Returns a new instance of WireGroupList.



86336
86337
86338
# File 'lib/google/apis/compute_alpha/classes.rb', line 86336

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


86292
86293
86294
# File 'lib/google/apis/compute_alpha/classes.rb', line 86292

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


86297
86298
86299
# File 'lib/google/apis/compute_alpha/classes.rb', line 86297

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::WireGroup>

A list of wire group resources. Corresponds to the JSON property items



86302
86303
86304
# File 'lib/google/apis/compute_alpha/classes.rb', line 86302

def items
  @items
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute#wireGroups for wire groups. Corresponds to the JSON property kind

Returns:

  • (String)


86308
86309
86310
# File 'lib/google/apis/compute_alpha/classes.rb', line 86308

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


86318
86319
86320
# File 'lib/google/apis/compute_alpha/classes.rb', line 86318

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


86323
86324
86325
# File 'lib/google/apis/compute_alpha/classes.rb', line 86323

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


86329
86330
86331
# File 'lib/google/apis/compute_alpha/classes.rb', line 86329

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::WireGroupList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



86334
86335
86336
# File 'lib/google/apis/compute_alpha/classes.rb', line 86334

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



86341
86342
86343
86344
86345
86346
86347
86348
86349
86350
# File 'lib/google/apis/compute_alpha/classes.rb', line 86341

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end