Class: Google::Apis::ComputeAlpha::WireGroupWireInputs

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Optional settings for individual wires. Allows wire-level control that can be useful for migration purposes. If you use this field, you opt-out of the SLA for the wire group.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WireGroupWireInputs

Returns a new instance of WireGroupWireInputs.



86545
86546
86547
# File 'lib/google/apis/compute_alpha/classes.rb', line 86545

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#admin_enabledBoolean Also known as: admin_enabled?

Indicates whether the wire is enabled. When false, the wire is disabled. When true and when the wire group of the wire is also enabled, the wire is enabled. Defaults to true. Corresponds to the JSON property adminEnabled

Returns:

  • (Boolean)


86537
86538
86539
# File 'lib/google/apis/compute_alpha/classes.rb', line 86537

def admin_enabled
  @admin_enabled
end

#wire_property_overridesGoogle::Apis::ComputeAlpha::WireProperties

The properties of a wire. Corresponds to the JSON property wirePropertyOverrides



86543
86544
86545
# File 'lib/google/apis/compute_alpha/classes.rb', line 86543

def wire_property_overrides
  @wire_property_overrides
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



86550
86551
86552
86553
# File 'lib/google/apis/compute_alpha/classes.rb', line 86550

def update!(**args)
  @admin_enabled = args[:admin_enabled] if args.key?(:admin_enabled)
  @wire_property_overrides = args[:wire_property_overrides] if args.key?(:wire_property_overrides)
end