Class: Google::Apis::ComputeAlpha::WireProperties

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

The properties of a wire.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WireProperties

Returns a new instance of WireProperties.



86607
86608
86609
# File 'lib/google/apis/compute_alpha/classes.rb', line 86607

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bandwidth_allocationString

The configuration of the bandwidth allocation, one of the following:

  • ALLOCATE_PER_WIRE: configures a separate unmetered bandwidth allocation (and associated charges) for each wire in the group.
  • SHARED_WITH_WIRE_GROUP: this is the default behavior, which configures one unmetered bandwidth allocation for the wire group. The unmetered bandwidth is divided equally across each wire in the group, but dynamic throttling reallocates unused unmetered bandwidth from unused or underused wires to other wires in the group. Corresponds to the JSON property bandwidthAllocation

Returns:

  • (String)


86571
86572
86573
# File 'lib/google/apis/compute_alpha/classes.rb', line 86571

def bandwidth_allocation
  @bandwidth_allocation
end

#bandwidth_meteredFixnum

The metered bandwidth in Gigabits per second, using decimal units. 10 is 10 Gbps, 100 is 100 Gbps. The default value is 0. You can specify unlimited bandwidth by entering -1. However, actual data transfer is limited by the port speed. Corresponds to the JSON property bandwidthMetered

Returns:

  • (Fixnum)


86579
86580
86581
# File 'lib/google/apis/compute_alpha/classes.rb', line 86579

def bandwidth_metered
  @bandwidth_metered
end

#bandwidth_unmeteredFixnum

The unmetered bandwidth in Gigabits per second, using decimal units. 10 is 10 Gbps, 100 is 100 Gbps. The bandwidth must be greater than 0. Corresponds to the JSON property bandwidthUnmetered

Returns:

  • (Fixnum)


86585
86586
86587
# File 'lib/google/apis/compute_alpha/classes.rb', line 86585

def bandwidth_unmetered
  @bandwidth_unmetered
end

#fault_responseString

Response when a fault is detected in a pseudowire:

  • NONE: default.
  • DISABLE_PORT: set the port line protocol down when inline probes detect a fault. This setting is only permitted on port mode pseudowires. Corresponds to the JSON property faultResponse

Returns:

  • (String)


86595
86596
86597
# File 'lib/google/apis/compute_alpha/classes.rb', line 86595

def fault_response
  @fault_response
end

#flow_managementString

The flow management configuration for the wire. Corresponds to the JSON property flowManagement

Returns:

  • (String)


86600
86601
86602
# File 'lib/google/apis/compute_alpha/classes.rb', line 86600

def flow_management
  @flow_management
end

#network_service_classString

The network service class. Corresponds to the JSON property networkServiceClass

Returns:

  • (String)


86605
86606
86607
# File 'lib/google/apis/compute_alpha/classes.rb', line 86605

def network_service_class
  @network_service_class
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



86612
86613
86614
86615
86616
86617
86618
86619
# File 'lib/google/apis/compute_alpha/classes.rb', line 86612

def update!(**args)
  @bandwidth_allocation = args[:bandwidth_allocation] if args.key?(:bandwidth_allocation)
  @bandwidth_metered = args[:bandwidth_metered] if args.key?(:bandwidth_metered)
  @bandwidth_unmetered = args[:bandwidth_unmetered] if args.key?(:bandwidth_unmetered)
  @fault_response = args[:fault_response] if args.key?(:fault_response)
  @flow_management = args[:flow_management] if args.key?(:flow_management)
  @network_service_class = args[:network_service_class] if args.key?(:network_service_class)
end