Class: Google::Apis::ComputeAlpha::XpnHostList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ XpnHostList

Returns a new instance of XpnHostList.



86694
86695
86696
# File 'lib/google/apis/compute_alpha/classes.rb', line 86694

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


86661
86662
86663
# File 'lib/google/apis/compute_alpha/classes.rb', line 86661

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::Project>

[Output Only] A list of shared VPC host project URLs. Corresponds to the JSON property items



86666
86667
86668
# File 'lib/google/apis/compute_alpha/classes.rb', line 86666

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#xpnHostList for lists of shared VPC hosts. Corresponds to the JSON property kind

Returns:

  • (String)


86672
86673
86674
# File 'lib/google/apis/compute_alpha/classes.rb', line 86672

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


86682
86683
86684
# File 'lib/google/apis/compute_alpha/classes.rb', line 86682

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


86687
86688
86689
# File 'lib/google/apis/compute_alpha/classes.rb', line 86687

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::XpnHostList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



86692
86693
86694
# File 'lib/google/apis/compute_alpha/classes.rb', line 86692

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



86699
86700
86701
86702
86703
86704
86705
86706
# File 'lib/google/apis/compute_alpha/classes.rb', line 86699

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end