Class: Google::Apis::ComputeAlpha::Zone
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::Zone
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Represents a Zone resource. A zone is a deployment area. These deployment areas are subsets of a region. For example the zone us-east1-b is located in theus-east1 region. For more information, readRegions and Zones.
Instance Attribute Summary collapse
-
#available_cpu_platforms ⇒ Array<String>
[Output Only] Available cpu/platform selections for the zone.
-
#creation_timestamp ⇒ String
[Output Only] Creation timestamp inRFC3339 text format.
-
#deprecated ⇒ Google::Apis::ComputeAlpha::DeprecationStatus
Deprecation status for a public resource.
-
#description ⇒ String
[Output Only] Textual description of the resource.
-
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
[Output Only] Name of the resource.
-
#region ⇒ String
[Output Only] Full URL reference to the region which hosts the zone.
-
#resource_status ⇒ Google::Apis::ComputeAlpha::ZoneResourceStatus
Corresponds to the JSON property
resourceStatus. -
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
-
#status ⇒ String
[Output Only] Status of the zone, either UP orDOWN.
-
#supports_pzs ⇒ Boolean
(also: #supports_pzs?)
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Zone
constructor
A new instance of Zone.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Zone
Returns a new instance of Zone.
86501 86502 86503 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 86501 def initialize(**args) update!(**args) end |
Instance Attribute Details
#available_cpu_platforms ⇒ Array<String>
[Output Only] Available cpu/platform selections for the zone.
Corresponds to the JSON property availableCpuPlatforms
86440 86441 86442 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 86440 def available_cpu_platforms @available_cpu_platforms end |
#creation_timestamp ⇒ String
[Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
86446 86447 86448 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 86446 def @creation_timestamp end |
#deprecated ⇒ Google::Apis::ComputeAlpha::DeprecationStatus
Deprecation status for a public resource.
Corresponds to the JSON property deprecated
86451 86452 86453 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 86451 def deprecated @deprecated end |
#description ⇒ String
[Output Only] Textual description of the resource.
Corresponds to the JSON property description
86456 86457 86458 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 86456 def description @description end |
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
86462 86463 86464 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 86462 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Always compute#zone for
zones.
Corresponds to the JSON property kind
86468 86469 86470 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 86468 def kind @kind end |
#name ⇒ String
[Output Only] Name of the resource.
Corresponds to the JSON property name
86473 86474 86475 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 86473 def name @name end |
#region ⇒ String
[Output Only] Full URL reference to the region which hosts the zone.
Corresponds to the JSON property region
86478 86479 86480 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 86478 def region @region end |
#resource_status ⇒ Google::Apis::ComputeAlpha::ZoneResourceStatus
Corresponds to the JSON property resourceStatus
86483 86484 86485 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 86483 def resource_status @resource_status end |
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
86488 86489 86490 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 86488 def self_link @self_link end |
#status ⇒ String
[Output Only] Status of the zone, either UP orDOWN.
Corresponds to the JSON property status
86493 86494 86495 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 86493 def status @status end |
#supports_pzs ⇒ Boolean Also known as: supports_pzs?
Output only. [Output Only] Reserved for future use.
Corresponds to the JSON property supportsPzs
86498 86499 86500 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 86498 def supports_pzs @supports_pzs end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
86506 86507 86508 86509 86510 86511 86512 86513 86514 86515 86516 86517 86518 86519 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 86506 def update!(**args) @available_cpu_platforms = args[:available_cpu_platforms] if args.key?(:available_cpu_platforms) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @deprecated = args[:deprecated] if args.key?(:deprecated) @description = args[:description] if args.key?(:description) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @region = args[:region] if args.key?(:region) @resource_status = args[:resource_status] if args.key?(:resource_status) @self_link = args[:self_link] if args.key?(:self_link) @status = args[:status] if args.key?(:status) @supports_pzs = args[:supports_pzs] if args.key?(:supports_pzs) end |