Class: Google::Apis::ComputeAlpha::Address
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::Address
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Represents an IP Address resource. Google Compute Engine has two IP Address resources:
- Global (external and internal)
- Regional (external and internal) For more information, see Reserving a static external IP address.
Instance Attribute Summary collapse
-
#address ⇒ String
The static IP address represented by this resource.
-
#address_type ⇒ String
The type of address to reserve, either INTERNAL orEXTERNAL.
-
#creation_timestamp ⇒ String
Output only.
-
#description ⇒ String
An optional description of this resource.
-
#id ⇒ Fixnum
Output only.
-
#ip_collection ⇒ String
Reference to the source of IP addresses.
-
#ip_version ⇒ String
The IP version that will be used by this address.
-
#ipv6_endpoint_type ⇒ String
The endpoint type of this address, which should be VM or NETLB.
-
#kind ⇒ String
Output only.
-
#label_fingerprint ⇒ String
A fingerprint for the labels being applied to this Address, which is essentially a hash of the labels set used for optimistic locking.
-
#labels ⇒ Hash<String,String>
Labels for this resource.
-
#name ⇒ String
Name of the resource.
-
#network ⇒ String
The URL of the network in which to reserve the address.
-
#network_tier ⇒ String
This signifies the networking tier used for configuring this address and can only take the following values: PREMIUM orSTANDARD.
-
#prefix_length ⇒ Fixnum
The prefix length if the resource represents an IP range.
-
#purpose ⇒ String
The purpose of this resource, which can be one of the following values:.
-
#region ⇒ String
Output only.
-
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
-
#self_link_with_id ⇒ String
Output only.
-
#status ⇒ String
Output only.
-
#subnetwork ⇒ String
The URL of the subnetwork in which to reserve the address.
-
#users ⇒ Array<String>
[Output Only] The URLs of the resources that are using this address.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Address
constructor
A new instance of Address.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Address
Returns a new instance of Address.
1147 1148 1149 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 1147 def initialize(**args) update!(**args) end |
Instance Attribute Details
#address ⇒ String
The static IP address represented by this resource.
Corresponds to the JSON property address
950 951 952 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 950 def address @address end |
#address_type ⇒ String
The type of address to reserve, either INTERNAL orEXTERNAL. If unspecified,
defaults to EXTERNAL.
Corresponds to the JSON property addressType
956 957 958 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 956 def address_type @address_type end |
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
962 963 964 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 962 def @creation_timestamp end |
#description ⇒ String
An optional description of this resource. Provide this field when you
create the resource.
Corresponds to the JSON property description
968 969 970 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 968 def description @description end |
#id ⇒ Fixnum
Output only. [Output Only] The unique identifier for the resource. This
identifier is
defined by the server.
Corresponds to the JSON property id
975 976 977 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 975 def id @id end |
#ip_collection ⇒ String
Reference to the source of IP addresses. It supports the following cases:
- Case 1: PublicDelegatedPrefix (PDP) for BYOIP external IPv4
addresses. The PDP must support enhanced IPv4 allocations.
Case 2: Internal Range for global internal addresses. Use one of the following formats to specify the resource: For a Public Delegated Prefix:
- Full resource URL:https://www.googleapis.com/compute/v1/projects/projectId/ regions/region/publicDelegatedPrefixes/pdp
- Partial URL:
- projects/projectId/regions/region/publicDelegatedPrefixes/pdp-name
- regions/region/publicDelegatedPrefixes/pdp-name
For an Internal Range:
- Full URL:https://networkconnectivity.googleapis.com/v1/projects/project/ locations/global/internalRanges/internal-range
- Partial URL:projects/project/locations/global/internalRanges/internal-
range
Corresponds to the JSON property
ipCollection
1003 1004 1005 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 1003 def ip_collection @ip_collection end |
#ip_version ⇒ String
The IP version that will be used by this address. Valid options areIPV4 or
IPV6.
Corresponds to the JSON property ipVersion
1009 1010 1011 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 1009 def ip_version @ip_version end |
#ipv6_endpoint_type ⇒ String
The endpoint type of this address, which should be VM
or NETLB. This is used for deciding which type of endpoint
this address can be used after the external IPv6 address reservation.
Corresponds to the JSON property ipv6EndpointType
1016 1017 1018 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 1016 def ipv6_endpoint_type @ipv6_endpoint_type end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Always compute#address for
addresses.
Corresponds to the JSON property kind
1022 1023 1024 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 1022 def kind @kind end |
#label_fingerprint ⇒ String
A fingerprint for the labels being applied to this Address, which is
essentially a hash of the labels set used for optimistic locking. The
fingerprint is initially generated by Compute Engine and changes after
every request to modify or update labels. You must always provide an
up-to-date fingerprint hash in order to update or change labels,
otherwise the request will fail with error412 conditionNotMet.
To see the latest fingerprint, make a get() request to
retrieve an Address.
Corresponds to the JSON property labelFingerprint
NOTE: Values are automatically base64 encoded/decoded in the client library.
1035 1036 1037 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 1035 def label_fingerprint @label_fingerprint end |
#labels ⇒ Hash<String,String>
Labels for this resource. These can only be added or modified by thesetLabels
method. Each label key/value pair must comply withRFC1035.
Label values may be empty.
Corresponds to the JSON property labels
1042 1043 1044 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 1042 def labels @labels end |
#name ⇒ String
Name of the resource. Provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])?. The first character
must be a lowercase letter, and all following characters (except for the
last character) must be a dash, lowercase letter, or digit. The last
character must be a lowercase letter or digit.
Corresponds to the JSON property name
1053 1054 1055 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 1053 def name @name end |
#network ⇒ String
The URL of the network in which to reserve the address. This field can
only be used with INTERNAL type with theVPC_PEERING purpose.
Corresponds to the JSON property network
1059 1060 1061 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 1059 def network @network end |
#network_tier ⇒ String
This signifies the networking tier used for configuring this address and
can only take the following values: PREMIUM orSTANDARD. Internal IP addresses
are always Premium Tier;
global external IP addresses are always Premium Tier; regional external IP
addresses can be either Standard or Premium Tier.
If this field is not specified, it is assumed to be PREMIUM.
Corresponds to the JSON property networkTier
1069 1070 1071 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 1069 def network_tier @network_tier end |
#prefix_length ⇒ Fixnum
The prefix length if the resource represents an IP range.
Corresponds to the JSON property prefixLength
1074 1075 1076 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 1074 def prefix_length @prefix_length end |
#purpose ⇒ String
The purpose of this resource, which can be one of the following values:
- GCE_ENDPOINT for addresses that are used by VM instances, alias IP ranges, load balancers, and similar resources.
- DNS_RESOLVER for a DNS resolver address in a subnetwork for a Cloud DNS inbound forwarder IP addresses (regional internal IP address in a subnet of a VPC network)
- VPC_PEERING for global internal IP addresses used for
private services access allocated ranges.
- NAT_AUTO for the regional external IP addresses used by Cloud NAT when allocating addresses using
automatic NAT IP address allocation.
- IPSEC_INTERCONNECT for addresses created from a private IP range that are reserved for a VLAN attachment in an HA VPN over Cloud Interconnect configuration. These addresses are regional resources.
SHARED_LOADBALANCER_VIPfor an internal IP address that is assigned to multiple internal forwarding rules.PRIVATE_SERVICE_CONNECTfor a private network address that is used to configure Private Service Connect. Only global internal addresses can use this purpose. Corresponds to the JSON propertypurpose
1103 1104 1105 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 1103 def purpose @purpose end |
#region ⇒ String
Output only. [Output Only] The URL of the region where a regional address
resides.
For regional addresses, you must specify the region as a path parameter in
the HTTP request URL. This field is not applicable to global
addresses.
Corresponds to the JSON property region
1112 1113 1114 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 1112 def region @region end |
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
1117 1118 1119 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 1117 def self_link @self_link end |
#self_link_with_id ⇒ String
Output only. [Output Only] Server-defined URL for this resource with the
resource id.
Corresponds to the JSON property selfLinkWithId
1123 1124 1125 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 1123 def self_link_with_id @self_link_with_id end |
#status ⇒ String
Output only. [Output Only] The status of the address, which can be one
ofRESERVING, RESERVED, or IN_USE.
An address that is RESERVING is currently in the process of
being reserved. A RESERVED address is currently reserved and
available to use. An IN_USE address is currently being used
by another resource and is not available.
Corresponds to the JSON property status
1133 1134 1135 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 1133 def status @status end |
#subnetwork ⇒ String
The URL of the subnetwork in which to reserve the address. If an IP address
is specified, it must be within the subnetwork's IP range. This field can
only be used with INTERNAL type with aGCE_ENDPOINT or DNS_RESOLVER purpose.
Corresponds to the JSON property subnetwork
1140 1141 1142 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 1140 def subnetwork @subnetwork end |
#users ⇒ Array<String>
[Output Only] The URLs of the resources that are using this address.
Corresponds to the JSON property users
1145 1146 1147 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 1145 def users @users end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1152 1153 1154 1155 1156 1157 1158 1159 1160 1161 1162 1163 1164 1165 1166 1167 1168 1169 1170 1171 1172 1173 1174 1175 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 1152 def update!(**args) @address = args[:address] if args.key?(:address) @address_type = args[:address_type] if args.key?(:address_type) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @id = args[:id] if args.key?(:id) @ip_collection = args[:ip_collection] if args.key?(:ip_collection) @ip_version = args[:ip_version] if args.key?(:ip_version) @ipv6_endpoint_type = args[:ipv6_endpoint_type] if args.key?(:ipv6_endpoint_type) @kind = args[:kind] if args.key?(:kind) @label_fingerprint = args[:label_fingerprint] if args.key?(:label_fingerprint) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @network = args[:network] if args.key?(:network) @network_tier = args[:network_tier] if args.key?(:network_tier) @prefix_length = args[:prefix_length] if args.key?(:prefix_length) @purpose = args[:purpose] if args.key?(:purpose) @region = args[:region] if args.key?(:region) @self_link = args[:self_link] if args.key?(:self_link) @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id) @status = args[:status] if args.key?(:status) @subnetwork = args[:subnetwork] if args.key?(:subnetwork) @users = args[:users] if args.key?(:users) end |