Class: Google::Apis::ComputeAlpha::AddressAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AddressAggregatedList

Returns a new instance of AddressAggregatedList.



1224
1225
1226
# File 'lib/google/apis/compute_alpha/classes.rb', line 1224

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


1185
1186
1187
# File 'lib/google/apis/compute_alpha/classes.rb', line 1185

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::AddressesScopedList>

A list of AddressesScopedList resources. Corresponds to the JSON property items



1190
1191
1192
# File 'lib/google/apis/compute_alpha/classes.rb', line 1190

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# addressAggregatedList for aggregated lists of addresses. Corresponds to the JSON property kind

Returns:

  • (String)


1197
1198
1199
# File 'lib/google/apis/compute_alpha/classes.rb', line 1197

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


1207
1208
1209
# File 'lib/google/apis/compute_alpha/classes.rb', line 1207

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


1212
1213
1214
# File 'lib/google/apis/compute_alpha/classes.rb', line 1212

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


1217
1218
1219
# File 'lib/google/apis/compute_alpha/classes.rb', line 1217

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::AddressAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



1222
1223
1224
# File 'lib/google/apis/compute_alpha/classes.rb', line 1222

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1229
1230
1231
1232
1233
1234
1235
1236
1237
# File 'lib/google/apis/compute_alpha/classes.rb', line 1229

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end