Class: Google::Apis::ComputeAlpha::AddressAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AddressAggregatedList

Returns a new instance of AddressAggregatedList.



1012
1013
1014
# File 'lib/google/apis/compute_alpha/classes.rb', line 1012

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


973
974
975
# File 'lib/google/apis/compute_alpha/classes.rb', line 973

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::AddressesScopedList>

A list of AddressesScopedList resources. Corresponds to the JSON property items



978
979
980
# File 'lib/google/apis/compute_alpha/classes.rb', line 978

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# addressAggregatedList for aggregated lists of addresses. Corresponds to the JSON property kind

Returns:

  • (String)


985
986
987
# File 'lib/google/apis/compute_alpha/classes.rb', line 985

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


995
996
997
# File 'lib/google/apis/compute_alpha/classes.rb', line 995

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


1000
1001
1002
# File 'lib/google/apis/compute_alpha/classes.rb', line 1000

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


1005
1006
1007
# File 'lib/google/apis/compute_alpha/classes.rb', line 1005

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::AddressAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



1010
1011
1012
# File 'lib/google/apis/compute_alpha/classes.rb', line 1010

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1017
1018
1019
1020
1021
1022
1023
1024
1025
# File 'lib/google/apis/compute_alpha/classes.rb', line 1017

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end