Class: Google::Apis::ComputeAlpha::AddressList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of addresses.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AddressList

Returns a new instance of AddressList.



1377
1378
1379
# File 'lib/google/apis/compute_alpha/classes.rb', line 1377

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


1344
1345
1346
# File 'lib/google/apis/compute_alpha/classes.rb', line 1344

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::Address>

A list of Address resources. Corresponds to the JSON property items



1349
1350
1351
# File 'lib/google/apis/compute_alpha/classes.rb', line 1349

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#addressList for lists of addresses. Corresponds to the JSON property kind

Returns:

  • (String)


1355
1356
1357
# File 'lib/google/apis/compute_alpha/classes.rb', line 1355

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


1365
1366
1367
# File 'lib/google/apis/compute_alpha/classes.rb', line 1365

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


1370
1371
1372
# File 'lib/google/apis/compute_alpha/classes.rb', line 1370

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::AddressList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



1375
1376
1377
# File 'lib/google/apis/compute_alpha/classes.rb', line 1375

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1382
1383
1384
1385
1386
1387
1388
1389
# File 'lib/google/apis/compute_alpha/classes.rb', line 1382

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end