Class: Google::Apis::ComputeAlpha::AddressList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of addresses.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AddressList

Returns a new instance of AddressList.



1350
1351
1352
# File 'lib/google/apis/compute_alpha/classes.rb', line 1350

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


1317
1318
1319
# File 'lib/google/apis/compute_alpha/classes.rb', line 1317

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::Address>

A list of Address resources. Corresponds to the JSON property items



1322
1323
1324
# File 'lib/google/apis/compute_alpha/classes.rb', line 1322

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#addressList for lists of addresses. Corresponds to the JSON property kind

Returns:

  • (String)


1328
1329
1330
# File 'lib/google/apis/compute_alpha/classes.rb', line 1328

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


1338
1339
1340
# File 'lib/google/apis/compute_alpha/classes.rb', line 1338

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


1343
1344
1345
# File 'lib/google/apis/compute_alpha/classes.rb', line 1343

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::AddressList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



1348
1349
1350
# File 'lib/google/apis/compute_alpha/classes.rb', line 1348

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1355
1356
1357
1358
1359
1360
1361
1362
# File 'lib/google/apis/compute_alpha/classes.rb', line 1355

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end