Class: Google::Apis::ComputeAlpha::AliasIpRange
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::AliasIpRange
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
An alias IP range attached to an instance's network interface.
Instance Attribute Summary collapse
-
#candidate_subnetwork_range_names ⇒ Array<String>
Identifies the candidate subnetwork range names for the alias IPs to be allocated from.
-
#effective_subnetwork_range_name ⇒ String
Output only.
-
#ip_cidr_range ⇒ String
The IP alias ranges to allocate for this interface.
-
#subnetwork_range_name ⇒ String
The name of a subnetwork secondary IP range from which to allocate an IP alias range.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AliasIpRange
constructor
A new instance of AliasIpRange.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AliasIpRange
Returns a new instance of AliasIpRange.
1646 1647 1648 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 1646 def initialize(**args) update!(**args) end |
Instance Attribute Details
#candidate_subnetwork_range_names ⇒ Array<String>
Identifies the candidate subnetwork range names for the alias
IPs to be allocated from. When it is set, the IP would be allocated from
any subnetwork range defined here if the IPs are available.
Only one of subnetwork_range_name or candidate_subnetwork_range_names
should be set.
Corresponds to the JSON property candidateSubnetworkRangeNames
1623 1624 1625 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 1623 def candidate_subnetwork_range_names @candidate_subnetwork_range_names end |
#effective_subnetwork_range_name ⇒ String
Output only. [Output Only] The subnetwork range name where the IP is allocated.
It will be set to the subnetwork range where the IP is allocated only.
Corresponds to the JSON property effectiveSubnetworkRangeName
1629 1630 1631 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 1629 def effective_subnetwork_range_name @effective_subnetwork_range_name end |
#ip_cidr_range ⇒ String
The IP alias ranges to allocate for this interface. This IP CIDR range
must belong to the specified subnetwork and cannot contain IP addresses
reserved by system or used by other network interfaces. This range may be
a single IP address (such as 10.2.3.4), a netmask (such as/24) or a CIDR-
formatted string (such as10.1.2.0/24).
Corresponds to the JSON property ipCidrRange
1638 1639 1640 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 1638 def ip_cidr_range @ip_cidr_range end |
#subnetwork_range_name ⇒ String
The name of a subnetwork secondary IP range from which to allocate an IP
alias range. If not specified, the primary range of the subnetwork is used.
Corresponds to the JSON property subnetworkRangeName
1644 1645 1646 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 1644 def subnetwork_range_name @subnetwork_range_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1651 1652 1653 1654 1655 1656 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 1651 def update!(**args) @candidate_subnetwork_range_names = args[:candidate_subnetwork_range_names] if args.key?(:candidate_subnetwork_range_names) @effective_subnetwork_range_name = args[:effective_subnetwork_range_name] if args.key?(:effective_subnetwork_range_name) @ip_cidr_range = args[:ip_cidr_range] if args.key?(:ip_cidr_range) @subnetwork_range_name = args[:subnetwork_range_name] if args.key?(:subnetwork_range_name) end |