Class: Google::Apis::ComputeAlpha::AliasIpRange

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

An alias IP range attached to an instance's network interface.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AliasIpRange

Returns a new instance of AliasIpRange.



1419
1420
1421
# File 'lib/google/apis/compute_alpha/classes.rb', line 1419

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ip_cidr_rangeString

The IP alias ranges to allocate for this interface. This IP CIDR range must belong to the specified subnetwork and cannot contain IP addresses reserved by system or used by other network interfaces. This range may be a single IP address (such as 10.2.3.4), a netmask (such as/24) or a CIDR- formatted string (such as10.1.2.0/24). Corresponds to the JSON property ipCidrRange

Returns:

  • (String)


1411
1412
1413
# File 'lib/google/apis/compute_alpha/classes.rb', line 1411

def ip_cidr_range
  @ip_cidr_range
end

#subnetwork_range_nameString

The name of a subnetwork secondary IP range from which to allocate an IP alias range. If not specified, the primary range of the subnetwork is used. Corresponds to the JSON property subnetworkRangeName

Returns:

  • (String)


1417
1418
1419
# File 'lib/google/apis/compute_alpha/classes.rb', line 1417

def subnetwork_range_name
  @subnetwork_range_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1424
1425
1426
1427
# File 'lib/google/apis/compute_alpha/classes.rb', line 1424

def update!(**args)
  @ip_cidr_range = args[:ip_cidr_range] if args.key?(:ip_cidr_range)
  @subnetwork_range_name = args[:subnetwork_range_name] if args.key?(:subnetwork_range_name)
end