Class: Google::Apis::ComputeAlpha::AllocationAggregateReservation

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

This reservation type is specified by total resource amounts (e.g. total count of CPUs) and can account for multiple instance SKUs. In other words, one can create instances of varying shapes against this reservation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AllocationAggregateReservation

Returns a new instance of AllocationAggregateReservation.



1704
1705
1706
# File 'lib/google/apis/compute_alpha/classes.rb', line 1704

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#host_countFixnum

Count of reserved hosts of specified VM family. The host has fixed number of accelerators based on the accelerator/vm-family selected. Corresponds to the JSON property hostCount

Returns:

  • (Fixnum)


1669
1670
1671
# File 'lib/google/apis/compute_alpha/classes.rb', line 1669

def host_count
  @host_count
end

#in_use_host_countFixnum

Output only. Number of hosts currently in use. If there is one or more Instances running on the host, it is considered in use. Corresponds to the JSON property inUseHostCount

Returns:

  • (Fixnum)


1676
1677
1678
# File 'lib/google/apis/compute_alpha/classes.rb', line 1676

def in_use_host_count
  @in_use_host_count
end

#in_use_instance_countFixnum

Output only. Number of instances currently in use in this reservation. Corresponds to the JSON property inUseInstanceCount

Returns:

  • (Fixnum)


1681
1682
1683
# File 'lib/google/apis/compute_alpha/classes.rb', line 1681

def in_use_instance_count
  @in_use_instance_count
end

#in_use_resourcesArray<Google::Apis::ComputeAlpha::AllocationAggregateReservationReservedResourceInfo>

Output only. [Output only] List of resources currently in use. Corresponds to the JSON property inUseResources



1686
1687
1688
# File 'lib/google/apis/compute_alpha/classes.rb', line 1686

def in_use_resources
  @in_use_resources
end

#reserved_resourcesArray<Google::Apis::ComputeAlpha::AllocationAggregateReservationReservedResourceInfo>

List of reserved resources (CPUs, memory, accelerators). Corresponds to the JSON property reservedResources



1691
1692
1693
# File 'lib/google/apis/compute_alpha/classes.rb', line 1691

def reserved_resources
  @reserved_resources
end

#vm_familyString

The VM family that all instances scheduled against this reservation must belong to. Corresponds to the JSON property vmFamily

Returns:

  • (String)


1697
1698
1699
# File 'lib/google/apis/compute_alpha/classes.rb', line 1697

def vm_family
  @vm_family
end

#workload_typeString

The workload type of the instances that will target this reservation. Corresponds to the JSON property workloadType

Returns:

  • (String)


1702
1703
1704
# File 'lib/google/apis/compute_alpha/classes.rb', line 1702

def workload_type
  @workload_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1709
1710
1711
1712
1713
1714
1715
1716
1717
# File 'lib/google/apis/compute_alpha/classes.rb', line 1709

def update!(**args)
  @host_count = args[:host_count] if args.key?(:host_count)
  @in_use_host_count = args[:in_use_host_count] if args.key?(:in_use_host_count)
  @in_use_instance_count = args[:in_use_instance_count] if args.key?(:in_use_instance_count)
  @in_use_resources = args[:in_use_resources] if args.key?(:in_use_resources)
  @reserved_resources = args[:reserved_resources] if args.key?(:reserved_resources)
  @vm_family = args[:vm_family] if args.key?(:vm_family)
  @workload_type = args[:workload_type] if args.key?(:workload_type)
end