Class: Google::Apis::ComputeAlpha::AllocationResourceStatus
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::AllocationResourceStatus
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
[Output Only] Contains output only fields.
Instance Attribute Summary collapse
-
#aggregate_allocation ⇒ Google::Apis::ComputeAlpha::AllocationResourceStatusAggregateAllocation
Contains Properties set for the aggregate reservation.
-
#health_info ⇒ Google::Apis::ComputeAlpha::AllocationResourceStatusHealthInfo
Health information for the reservation.
-
#reservation_block_count ⇒ Fixnum
The number of reservation blocks associated with this reservation.
-
#reservation_maintenance ⇒ Google::Apis::ComputeAlpha::GroupMaintenanceInfo
Maintenance Info for ReservationBlocks.
-
#specific_sku_allocation ⇒ Google::Apis::ComputeAlpha::AllocationResourceStatusSpecificSkuAllocation
Contains Properties set for the reservation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AllocationResourceStatus
constructor
A new instance of AllocationResourceStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AllocationResourceStatus
Returns a new instance of AllocationResourceStatus.
1584 1585 1586 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 1584 def initialize(**args) update!(**args) end |
Instance Attribute Details
#aggregate_allocation ⇒ Google::Apis::ComputeAlpha::AllocationResourceStatusAggregateAllocation
Contains Properties set for the aggregate reservation.
Corresponds to the JSON property aggregateAllocation
1562 1563 1564 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 1562 def aggregate_allocation @aggregate_allocation end |
#health_info ⇒ Google::Apis::ComputeAlpha::AllocationResourceStatusHealthInfo
Health information for the reservation.
Corresponds to the JSON property healthInfo
1567 1568 1569 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 1567 def health_info @health_info end |
#reservation_block_count ⇒ Fixnum
The number of reservation blocks associated with this reservation.
Corresponds to the JSON property reservationBlockCount
1572 1573 1574 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 1572 def reservation_block_count @reservation_block_count end |
#reservation_maintenance ⇒ Google::Apis::ComputeAlpha::GroupMaintenanceInfo
Maintenance Info for ReservationBlocks.
Corresponds to the JSON property reservationMaintenance
1577 1578 1579 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 1577 def reservation_maintenance @reservation_maintenance end |
#specific_sku_allocation ⇒ Google::Apis::ComputeAlpha::AllocationResourceStatusSpecificSkuAllocation
Contains Properties set for the reservation.
Corresponds to the JSON property specificSkuAllocation
1582 1583 1584 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 1582 def specific_sku_allocation @specific_sku_allocation end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1589 1590 1591 1592 1593 1594 1595 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 1589 def update!(**args) @aggregate_allocation = args[:aggregate_allocation] if args.key?(:aggregate_allocation) @health_info = args[:health_info] if args.key?(:health_info) @reservation_block_count = args[:reservation_block_count] if args.key?(:reservation_block_count) @reservation_maintenance = args[:reservation_maintenance] if args.key?(:reservation_maintenance) @specific_sku_allocation = args[:specific_sku_allocation] if args.key?(:specific_sku_allocation) end |