Class: Google::Apis::ComputeAlpha::AllocationSpecificSkuAllocationAllocatedInstancePropertiesReservedDisk
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::AllocationSpecificSkuAllocationAllocatedInstancePropertiesReservedDisk
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#disk_size_gb ⇒ Fixnum
Specifies the size of the disk in base-2 GB.
-
#interface ⇒ String
Specifies the disk interface to use for attaching this disk, which is either SCSI or NVME.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AllocationSpecificSkuAllocationAllocatedInstancePropertiesReservedDisk
constructor
A new instance of AllocationSpecificSkuAllocationAllocatedInstancePropertiesReservedDisk.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AllocationSpecificSkuAllocationAllocatedInstancePropertiesReservedDisk
Returns a new instance of AllocationSpecificSkuAllocationAllocatedInstancePropertiesReservedDisk.
1691 1692 1693 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 1691 def initialize(**args) update!(**args) end |
Instance Attribute Details
#disk_size_gb ⇒ Fixnum
Specifies the size of the disk in base-2 GB.
Corresponds to the JSON property diskSizeGb
1682 1683 1684 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 1682 def disk_size_gb @disk_size_gb end |
#interface ⇒ String
Specifies the disk interface to use for attaching this disk, which is
either SCSI or NVME. The default isSCSI.
For performance characteristics of SCSI over NVMe, seeLocal SSD performance.
Corresponds to the JSON property interface
1689 1690 1691 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 1689 def interface @interface end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1696 1697 1698 1699 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 1696 def update!(**args) @disk_size_gb = args[:disk_size_gb] if args.key?(:disk_size_gb) @interface = args[:interface] if args.key?(:interface) end |