Class: Google::Apis::ComputeAlpha::AllocationSpecificSkuAllocationReservedInstanceProperties

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Properties of the SKU instances being reserved. Next ID: 10

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AllocationSpecificSkuAllocationReservedInstanceProperties

Returns a new instance of AllocationSpecificSkuAllocationReservedInstanceProperties.



1749
1750
1751
# File 'lib/google/apis/compute_alpha/classes.rb', line 1749

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#guest_acceleratorsArray<Google::Apis::ComputeAlpha::AcceleratorConfig>

Specifies accelerator type and count. Corresponds to the JSON property guestAccelerators



1710
1711
1712
# File 'lib/google/apis/compute_alpha/classes.rb', line 1710

def guest_accelerators
  @guest_accelerators
end

#local_ssdsArray<Google::Apis::ComputeAlpha::AllocationSpecificSkuAllocationAllocatedInstancePropertiesReservedDisk>

Specifies amount of local ssd to reserve with each instance. The type of disk is local-ssd. Corresponds to the JSON property localSsds



1716
1717
1718
# File 'lib/google/apis/compute_alpha/classes.rb', line 1716

def local_ssds
  @local_ssds
end

#location_hintString

An opaque location hint used to place the allocation close to other resources. This field is for use by internal tools that use the public API. Corresponds to the JSON property locationHint

Returns:

  • (String)


1723
1724
1725
# File 'lib/google/apis/compute_alpha/classes.rb', line 1723

def location_hint
  @location_hint
end

#machine_typeString

Specifies type of machine (name only) which has fixed number of vCPUs and fixed amount of memory. This also includes specifying custom machine type following custom-NUMBER_OF_CPUS-AMOUNT_OF_MEMORY pattern. Corresponds to the JSON property machineType

Returns:

  • (String)


1730
1731
1732
# File 'lib/google/apis/compute_alpha/classes.rb', line 1730

def machine_type
  @machine_type
end

#maintenance_freeze_duration_hoursFixnum

Specifies the number of hours after reservation creation where instances using the reservation won't be scheduled for maintenance. Corresponds to the JSON property maintenanceFreezeDurationHours

Returns:

  • (Fixnum)


1736
1737
1738
# File 'lib/google/apis/compute_alpha/classes.rb', line 1736

def maintenance_freeze_duration_hours
  @maintenance_freeze_duration_hours
end

#maintenance_intervalString

Specifies the frequency of planned maintenance events. The accepted values are: PERIODIC. Corresponds to the JSON property maintenanceInterval

Returns:

  • (String)


1742
1743
1744
# File 'lib/google/apis/compute_alpha/classes.rb', line 1742

def maintenance_interval
  @maintenance_interval
end

#min_cpu_platformString

Minimum cpu platform the reservation. Corresponds to the JSON property minCpuPlatform

Returns:

  • (String)


1747
1748
1749
# File 'lib/google/apis/compute_alpha/classes.rb', line 1747

def min_cpu_platform
  @min_cpu_platform
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1754
1755
1756
1757
1758
1759
1760
1761
1762
# File 'lib/google/apis/compute_alpha/classes.rb', line 1754

def update!(**args)
  @guest_accelerators = args[:guest_accelerators] if args.key?(:guest_accelerators)
  @local_ssds = args[:local_ssds] if args.key?(:local_ssds)
  @location_hint = args[:location_hint] if args.key?(:location_hint)
  @machine_type = args[:machine_type] if args.key?(:machine_type)
  @maintenance_freeze_duration_hours = args[:maintenance_freeze_duration_hours] if args.key?(:maintenance_freeze_duration_hours)
  @maintenance_interval = args[:maintenance_interval] if args.key?(:maintenance_interval)
  @min_cpu_platform = args[:min_cpu_platform] if args.key?(:min_cpu_platform)
end