Class: Google::Apis::ComputeAlpha::AllocationSpecificSkuReservation
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::AllocationSpecificSkuReservation
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
This reservation type allows to pre allocate specific instance configuration.
Instance Attribute Summary collapse
-
#assured_count ⇒ Fixnum
Output only.
-
#count ⇒ Fixnum
Specifies the number of resources that are allocated.
-
#in_use_count ⇒ Fixnum
Output only.
-
#instance_properties ⇒ Google::Apis::ComputeAlpha::AllocationSpecificSkuAllocationReservedInstanceProperties
Properties of the SKU instances being reserved.
-
#source_instance_template ⇒ String
Specifies the instance template to create the reservation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AllocationSpecificSkuReservation
constructor
A new instance of AllocationSpecificSkuReservation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AllocationSpecificSkuReservation
Returns a new instance of AllocationSpecificSkuReservation.
2075 2076 2077 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 2075 def initialize(**args) update!(**args) end |
Instance Attribute Details
#assured_count ⇒ Fixnum
Output only. [Output Only] Indicates how many instances are actually usable
currently.
Corresponds to the JSON property assuredCount
2043 2044 2045 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 2043 def assured_count @assured_count end |
#count ⇒ Fixnum
Specifies the number of resources that are allocated.
Corresponds to the JSON property count
2048 2049 2050 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 2048 def count @count end |
#in_use_count ⇒ Fixnum
Output only. [Output Only] Indicates how many instances are in use.
Corresponds to the JSON property inUseCount
2053 2054 2055 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 2053 def in_use_count @in_use_count end |
#instance_properties ⇒ Google::Apis::ComputeAlpha::AllocationSpecificSkuAllocationReservedInstanceProperties
Properties of the SKU instances being reserved.
Next ID: 10
Corresponds to the JSON property instanceProperties
2059 2060 2061 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 2059 def instance_properties @instance_properties end |
#source_instance_template ⇒ String
Specifies the instance template to create the reservation. If you use this field, you must exclude the instanceProperties field. This field is optional, and it can be a full or partial URL. For example, the following are all valid URLs to an instance template:
- https://www.googleapis.com/compute/v1/projects/project/global/ instanceTemplates/instanceTemplate
- projects/project/global/instanceTemplates/instanceTemplate
- global/instanceTemplates/instanceTemplate
Corresponds to the JSON property
sourceInstanceTemplate
2073 2074 2075 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 2073 def source_instance_template @source_instance_template end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2080 2081 2082 2083 2084 2085 2086 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 2080 def update!(**args) @assured_count = args[:assured_count] if args.key?(:assured_count) @count = args[:count] if args.key?(:count) @in_use_count = args[:in_use_count] if args.key?(:in_use_count) @instance_properties = args[:instance_properties] if args.key?(:instance_properties) @source_instance_template = args[:source_instance_template] if args.key?(:source_instance_template) end |