Class: Google::Apis::ComputeAlpha::AllocationSpecificSkuReservation
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::AllocationSpecificSkuReservation
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
This reservation type allows to pre allocate specific instance configuration.
Instance Attribute Summary collapse
-
#assured_count ⇒ Fixnum
Output only.
-
#count ⇒ Fixnum
Specifies the number of resources that are allocated.
-
#in_use_count ⇒ Fixnum
Output only.
-
#instance_properties ⇒ Google::Apis::ComputeAlpha::AllocationSpecificSkuAllocationReservedInstanceProperties
Properties of the SKU instances being reserved.
-
#source_instance_template ⇒ String
Specifies the instance template to create the reservation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AllocationSpecificSkuReservation
constructor
A new instance of AllocationSpecificSkuReservation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AllocationSpecificSkuReservation
Returns a new instance of AllocationSpecificSkuReservation.
1806 1807 1808 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 1806 def initialize(**args) update!(**args) end |
Instance Attribute Details
#assured_count ⇒ Fixnum
Output only. [Output Only] Indicates how many instances are actually usable
currently.
Corresponds to the JSON property assuredCount
1774 1775 1776 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 1774 def assured_count @assured_count end |
#count ⇒ Fixnum
Specifies the number of resources that are allocated.
Corresponds to the JSON property count
1779 1780 1781 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 1779 def count @count end |
#in_use_count ⇒ Fixnum
Output only. [Output Only] Indicates how many instances are in use.
Corresponds to the JSON property inUseCount
1784 1785 1786 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 1784 def in_use_count @in_use_count end |
#instance_properties ⇒ Google::Apis::ComputeAlpha::AllocationSpecificSkuAllocationReservedInstanceProperties
Properties of the SKU instances being reserved.
Next ID: 10
Corresponds to the JSON property instanceProperties
1790 1791 1792 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 1790 def instance_properties @instance_properties end |
#source_instance_template ⇒ String
Specifies the instance template to create the reservation. If you use this field, you must exclude the instanceProperties field. This field is optional, and it can be a full or partial URL. For example, the following are all valid URLs to an instance template:
- https://www.googleapis.com/compute/v1/projects/project/global/ instanceTemplates/instanceTemplate
- projects/project/global/instanceTemplates/instanceTemplate
- global/instanceTemplates/instanceTemplate
Corresponds to the JSON property
sourceInstanceTemplate
1804 1805 1806 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 1804 def source_instance_template @source_instance_template end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1811 1812 1813 1814 1815 1816 1817 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 1811 def update!(**args) @assured_count = args[:assured_count] if args.key?(:assured_count) @count = args[:count] if args.key?(:count) @in_use_count = args[:in_use_count] if args.key?(:in_use_count) @instance_properties = args[:instance_properties] if args.key?(:instance_properties) @source_instance_template = args[:source_instance_template] if args.key?(:source_instance_template) end |