Class: Google::Apis::ComputeAlpha::AttachedDiskInitializeParams
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::AttachedDiskInitializeParams
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
[Input Only] Specifies the parameters for a new disk that will be created alongside the new instance. Use initialization parameters to create boot disks or local SSDs attached to the new instance. This field is persisted and returned for instanceTemplate and not returned in the context of instance. This property is mutually exclusive with the source property; you can only define one or the other, but not both.
Instance Attribute Summary collapse
-
#architecture ⇒ String
The architecture of the attached disk.
-
#description ⇒ String
An optional description.
-
#disk_name ⇒ String
Specifies the disk name.
-
#disk_size_gb ⇒ Fixnum
Specifies the size of the disk in base-2 GB.
-
#disk_type ⇒ String
Specifies the disk type used for the boot disk or an additional data disk.
-
#enable_confidential_compute ⇒ Boolean
(also: #enable_confidential_compute?)
Whether this disk is using confidential compute mode.
-
#guest_os_features ⇒ Array<Google::Apis::ComputeAlpha::GuestOsFeature>
A list of features to enable on the guest operating system.
-
#interface ⇒ String
[Deprecated] Specifies the disk interface to use for attaching this disk, which is either SCSI or NVME.
-
#labels ⇒ Hash<String,String>
Labels to apply to this disk.
-
#license_codes ⇒ Array<Fixnum>
Integer license codes indicating which licenses are attached to this disk.
-
#licenses ⇒ Array<String>
A list of publicly visible licenses.
-
#multi_writer ⇒ Boolean
(also: #multi_writer?)
Indicates whether or not the disk can be read/write attached to more than one instance.
-
#on_update_action ⇒ String
Specifies which action to take on instance update with this disk.
-
#provisioned_iops ⇒ Fixnum
Indicates how many IOPS to provision for the disk.
-
#provisioned_throughput ⇒ Fixnum
Indicates how much throughput to provision for the disk.
-
#replica_zones ⇒ Array<String>
Required for each regional disk associated with the instance.
-
#resource_manager_tags ⇒ Hash<String,String>
Input only.
-
#resource_policies ⇒ Array<String>
Resource policies applied to this disk for automatic snapshot creations.
-
#source_image ⇒ String
The source image to create this disk.
-
#source_image_encryption_key ⇒ Google::Apis::ComputeAlpha::CustomerEncryptionKey
Thecustomer-supplied encryption key of the source image.
-
#source_instant_snapshot ⇒ String
The source instant-snapshot to create this disk.
-
#source_snapshot ⇒ String
The source snapshot to create this disk.
-
#source_snapshot_encryption_key ⇒ Google::Apis::ComputeAlpha::CustomerEncryptionKey
Thecustomer-supplied encryption key of the source snapshot.
-
#storage_pool ⇒ String
The storage pool in which the new disk is created.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AttachedDiskInitializeParams
constructor
A new instance of AttachedDiskInitializeParams.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AttachedDiskInitializeParams
Returns a new instance of AttachedDiskInitializeParams.
2558 2559 2560 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 2558 def initialize(**args) update!(**args) end |
Instance Attribute Details
#architecture ⇒ String
The architecture of the attached disk. Valid values are
arm64 or x86_64.
Corresponds to the JSON property architecture
2318 2319 2320 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 2318 def architecture @architecture end |
#description ⇒ String
An optional description. Provide this property when creating the disk.
Corresponds to the JSON property description
2323 2324 2325 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 2323 def description @description end |
#disk_name ⇒ String
Specifies the disk name. If not specified, the default is to use the name
of the instance. If a disk with the same name already exists in the given
region, the existing disk is attached to the new instance and the
new disk is not created.
Corresponds to the JSON property diskName
2331 2332 2333 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 2331 def disk_name @disk_name end |
#disk_size_gb ⇒ Fixnum
Specifies the size of the disk in base-2 GB. The size must be at least
10 GB. If you specify a sourceImage, which is required for
boot disks, the default size is the size of the sourceImage.
If you do not specify a sourceImage, the default disk size
is 500 GB.
Corresponds to the JSON property diskSizeGb
2340 2341 2342 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 2340 def disk_size_gb @disk_size_gb end |
#disk_type ⇒ String
Specifies the disk type used for the boot disk or an additional data disk. For valid disk type values, see Supported types for Hyperdisk volumes and Persistent Disk type variables. When creating a single instance, you must provide either the full or partial URL of the disk type. For example, the following values are valid:
- https://www.googleapis.com/compute/v1/projects/project/zones/zone/ diskTypes/diskType
- projects/project/zones/zone/diskTypes/diskType
zones/zone/diskTypes/diskType When creating an instance template, instance flexibility policy, or when creating or updating an all-instances configuration, you specify the disk type without a URL, for example, hyperdisk-balanced. If you omit this field for a disk, the default disk type depends on the instance's machine series, as follows.
For first- and second-generation machine series like N1, N2, T2, and M1, the default disk type is Standard Persistent Disk (pd-standard).
For C3, C3D, and M3 the default is Balanced Persistent Disk (pd-balanced).
For other third-generation machine series like A3, H3, Z3, all fourth-generation types like C4, N4, M4, and newer machine series, the default is Hyperdisk Balanced (hyperdisk-balanced). The disk type you specify must be compatible with the instance's machine series. For a list of machine series that support Persistent Disk, see Machine series support for Persistent Disk. For a list of machine series that support Hyperdisk, seeMachine series support for Hyperdisk. Corresponds to the JSON property
diskType
2380 2381 2382 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 2380 def disk_type @disk_type end |
#enable_confidential_compute ⇒ Boolean Also known as: enable_confidential_compute?
Whether this disk is using confidential compute mode.
Corresponds to the JSON property enableConfidentialCompute
2385 2386 2387 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 2385 def enable_confidential_compute @enable_confidential_compute end |
#guest_os_features ⇒ Array<Google::Apis::ComputeAlpha::GuestOsFeature>
A list of features to enable on the guest operating system. Applicable
only for bootable images. Read
Enabling guest operating system features to see a list of available
options.
Guest OS features are applied by merginginitializeParams.guestOsFeatures
anddisks.guestOsFeatures
Corresponds to the JSON property guestOsFeatures
2396 2397 2398 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 2396 def guest_os_features @guest_os_features end |
#interface ⇒ String
[Deprecated] Specifies the disk interface to use for attaching this disk,
which is either SCSI or NVME. The default isSCSI.
Corresponds to the JSON property interface
2402 2403 2404 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 2402 def interface @interface end |
#labels ⇒ Hash<String,String>
Labels to apply to this disk. These can be later modified by thedisks.
setLabels method. This field is only applicable for
persistent disks.
Corresponds to the JSON property labels
2409 2410 2411 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 2409 def labels @labels end |
#license_codes ⇒ Array<Fixnum>
Integer license codes indicating which licenses are attached to this
disk.
Corresponds to the JSON property licenseCodes
2415 2416 2417 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 2415 def license_codes @license_codes end |
#licenses ⇒ Array<String>
A list of publicly visible licenses. Reserved for Google's use.
Corresponds to the JSON property licenses
2420 2421 2422 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 2420 def licenses @licenses end |
#multi_writer ⇒ Boolean Also known as: multi_writer?
Indicates whether or not the disk can be read/write attached to
more than one instance.
Corresponds to the JSON property multiWriter
2426 2427 2428 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 2426 def multi_writer @multi_writer end |
#on_update_action ⇒ String
Specifies which action to take on instance update with this disk. Default
is to use the existing disk.
Corresponds to the JSON property onUpdateAction
2433 2434 2435 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 2433 def on_update_action @on_update_action end |
#provisioned_iops ⇒ Fixnum
Indicates how many IOPS to provision for the disk. This sets the number
of I/O operations per second that the disk can handle. Values must be
between 10,000 and 120,000. For more details, see theExtreme persistent
disk documentation.
Corresponds to the JSON property provisionedIops
2441 2442 2443 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 2441 def provisioned_iops @provisioned_iops end |
#provisioned_throughput ⇒ Fixnum
Indicates how much throughput to provision for the disk. This sets the
number of throughput mb per second that the disk can handle. Values must
greater than or equal to 1.
Corresponds to the JSON property provisionedThroughput
2448 2449 2450 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 2448 def provisioned_throughput @provisioned_throughput end |
#replica_zones ⇒ Array<String>
Required for each regional disk associated with the instance. Specify
the URLs of the zones where the disk should be replicated to.
You must provide exactly two replica zones, and one zone must be the same
as the instance zone.
Corresponds to the JSON property replicaZones
2456 2457 2458 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 2456 def replica_zones @replica_zones end |
#resource_manager_tags ⇒ Hash<String,String>
Input only. Resource manager tags to be bound to the disk. Tag keys and values
have the same definition as resource
manager tags. Keys and values can be either in numeric format,
such as tagKeys/tag_key_idand `tagValues/`tag_value_id or in
namespaced format such as org_id|project_id`/`tag_key_short_name and
tag_value_short_name. The field is ignored (both PUT & PATCH) when
empty.
Corresponds to the JSON property resourceManagerTags
2467 2468 2469 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 2467 def @resource_manager_tags end |
#resource_policies ⇒ Array<String>
Resource policies applied to this disk for automatic snapshot creations.
Specified using the full or partial URL. For instance template, specify
only the resource policy name.
Corresponds to the JSON property resourcePolicies
2474 2475 2476 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 2474 def resource_policies @resource_policies end |
#source_image ⇒ String
The source image to create this disk. When creating a new instance boot
disk, one of initializeParams.sourceImage orinitializeParams.sourceSnapshot or
disks.source
is required.
To create a disk with one of the public operating system
images, specify the image by its family name. For example, specifyfamily/
debian-9 to use the latest Debian 9 image:
projects/debian-cloud/global/images/family/debian-9
Alternatively, use a specific version of a public operating system image:
projects/debian-cloud/global/images/debian-9-stretch-vYYYYMMDD
To create a disk with a custom image that you created, specify the
image name in the following format:
global/images/my-custom-image
You can also specify a custom image by its image family, which returns
the latest version of the image in that family. Replace the image name
with family/family-name:
global/images/family/my-image-family
If the source image is deleted later, this field will not be set.
Corresponds to the JSON property sourceImage
2496 2497 2498 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 2496 def source_image @source_image end |
#source_image_encryption_key ⇒ Google::Apis::ComputeAlpha::CustomerEncryptionKey
Thecustomer-supplied
encryption key of the source image. Required if the source image is
protected by a customer-supplied encryption key.
InstanceTemplate and InstancePropertiesPatch do not storecustomer-supplied
encryption keys, so you cannot create disks for instances in a managed
instance group if the
source images are encrypted with your own keys.
Corresponds to the JSON property sourceImageEncryptionKey
2507 2508 2509 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 2507 def source_image_encryption_key @source_image_encryption_key end |
#source_instant_snapshot ⇒ String
The source instant-snapshot to create this disk. When creating a new
instance boot disk, one of initializeParams.sourceSnapshot
or initializeParams.sourceInstantSnapshotinitializeParams.sourceImage or disks.
source
is required.
To create a disk with a snapshot that you created, specify the
snapshot name in the following format:
us-central1-a/instantSnapshots/my-backup
If the source instant-snapshot is deleted later, this field will not be
set.
Corresponds to the JSON property sourceInstantSnapshot
2521 2522 2523 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 2521 def source_instant_snapshot @source_instant_snapshot end |
#source_snapshot ⇒ String
The source snapshot to create this disk. When creating a new instance
boot disk, one of initializeParams.sourceSnapshot orinitializeParams.
sourceImage or disks.source
is required.
To create a disk with a snapshot that you created, specify the
snapshot name in the following format:
global/snapshots/my-backup
If the source snapshot is deleted later, this field will not be set.
Note: You cannot create VMs in bulk using a snapshot as the source. Use
an image instead when you create VMs using
the bulk
insert method.
Corresponds to the JSON property sourceSnapshot
2537 2538 2539 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 2537 def source_snapshot @source_snapshot end |
#source_snapshot_encryption_key ⇒ Google::Apis::ComputeAlpha::CustomerEncryptionKey
Thecustomer-supplied
encryption key of the source snapshot.
Corresponds to the JSON property sourceSnapshotEncryptionKey
2543 2544 2545 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 2543 def source_snapshot_encryption_key @source_snapshot_encryption_key end |
#storage_pool ⇒ String
The storage pool in which the new disk is created. You can provide this as a partial or full URL to the resource. For example, the following are valid values:
- https://www.googleapis.com/compute/v1/projects/project/zones/zone/ storagePools/storagePool
- projects/project/zones/zone/storagePools/storagePool
- zones/zone/storagePools/storagePool
Corresponds to the JSON property
storagePool
2556 2557 2558 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 2556 def storage_pool @storage_pool end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2563 2564 2565 2566 2567 2568 2569 2570 2571 2572 2573 2574 2575 2576 2577 2578 2579 2580 2581 2582 2583 2584 2585 2586 2587 2588 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 2563 def update!(**args) @architecture = args[:architecture] if args.key?(:architecture) @description = args[:description] if args.key?(:description) @disk_name = args[:disk_name] if args.key?(:disk_name) @disk_size_gb = args[:disk_size_gb] if args.key?(:disk_size_gb) @disk_type = args[:disk_type] if args.key?(:disk_type) @enable_confidential_compute = args[:enable_confidential_compute] if args.key?(:enable_confidential_compute) @guest_os_features = args[:guest_os_features] if args.key?(:guest_os_features) @interface = args[:interface] if args.key?(:interface) @labels = args[:labels] if args.key?(:labels) @license_codes = args[:license_codes] if args.key?(:license_codes) @licenses = args[:licenses] if args.key?(:licenses) @multi_writer = args[:multi_writer] if args.key?(:multi_writer) @on_update_action = args[:on_update_action] if args.key?(:on_update_action) @provisioned_iops = args[:provisioned_iops] if args.key?(:provisioned_iops) @provisioned_throughput = args[:provisioned_throughput] if args.key?(:provisioned_throughput) @replica_zones = args[:replica_zones] if args.key?(:replica_zones) @resource_manager_tags = args[:resource_manager_tags] if args.key?(:resource_manager_tags) @resource_policies = args[:resource_policies] if args.key?(:resource_policies) @source_image = args[:source_image] if args.key?(:source_image) @source_image_encryption_key = args[:source_image_encryption_key] if args.key?(:source_image_encryption_key) @source_instant_snapshot = args[:source_instant_snapshot] if args.key?(:source_instant_snapshot) @source_snapshot = args[:source_snapshot] if args.key?(:source_snapshot) @source_snapshot_encryption_key = args[:source_snapshot_encryption_key] if args.key?(:source_snapshot_encryption_key) @storage_pool = args[:storage_pool] if args.key?(:storage_pool) end |