Class: Google::Apis::ComputeAlpha::AttachedDiskInitializeParams

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

[Input Only] Specifies the parameters for a new disk that will be created alongside the new instance. Use initialization parameters to create boot disks or local SSDs attached to the new instance. This field is persisted and returned for instanceTemplate and not returned in the context of instance. This property is mutually exclusive with the source property; you can only define one or the other, but not both.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AttachedDiskInitializeParams

Returns a new instance of AttachedDiskInitializeParams.



2496
2497
2498
# File 'lib/google/apis/compute_alpha/classes.rb', line 2496

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#architectureString

The architecture of the attached disk. Valid values are arm64 or x86_64. Corresponds to the JSON property architecture

Returns:

  • (String)


2291
2292
2293
# File 'lib/google/apis/compute_alpha/classes.rb', line 2291

def architecture
  @architecture
end

#descriptionString

An optional description. Provide this property when creating the disk. Corresponds to the JSON property description

Returns:

  • (String)


2296
2297
2298
# File 'lib/google/apis/compute_alpha/classes.rb', line 2296

def description
  @description
end

#disk_nameString

Specifies the disk name. If not specified, the default is to use the name of the instance. If a disk with the same name already exists in the given region, the existing disk is attached to the new instance and the new disk is not created. Corresponds to the JSON property diskName

Returns:

  • (String)


2304
2305
2306
# File 'lib/google/apis/compute_alpha/classes.rb', line 2304

def disk_name
  @disk_name
end

#disk_size_gbFixnum

Specifies the size of the disk in base-2 GB. The size must be at least 10 GB. If you specify a sourceImage, which is required for boot disks, the default size is the size of the sourceImage. If you do not specify a sourceImage, the default disk size is 500 GB. Corresponds to the JSON property diskSizeGb

Returns:

  • (Fixnum)


2313
2314
2315
# File 'lib/google/apis/compute_alpha/classes.rb', line 2313

def disk_size_gb
  @disk_size_gb
end

#disk_typeString

Corresponds to the JSON property diskType

Returns:

  • (String)


2318
2319
2320
# File 'lib/google/apis/compute_alpha/classes.rb', line 2318

def disk_type
  @disk_type
end

#enable_confidential_computeBoolean Also known as: enable_confidential_compute?

Whether this disk is using confidential compute mode. Corresponds to the JSON property enableConfidentialCompute

Returns:

  • (Boolean)


2323
2324
2325
# File 'lib/google/apis/compute_alpha/classes.rb', line 2323

def enable_confidential_compute
  @enable_confidential_compute
end

#guest_os_featuresArray<Google::Apis::ComputeAlpha::GuestOsFeature>

A list of features to enable on the guest operating system. Applicable only for bootable images. Read Enabling guest operating system features to see a list of available options. Guest OS features are applied by merginginitializeParams.guestOsFeatures anddisks.guestOsFeatures Corresponds to the JSON property guestOsFeatures



2334
2335
2336
# File 'lib/google/apis/compute_alpha/classes.rb', line 2334

def guest_os_features
  @guest_os_features
end

#interfaceString

[Deprecated] Specifies the disk interface to use for attaching this disk, which is either SCSI or NVME. The default isSCSI. Corresponds to the JSON property interface

Returns:

  • (String)


2340
2341
2342
# File 'lib/google/apis/compute_alpha/classes.rb', line 2340

def interface
  @interface
end

#labelsHash<String,String>

Labels to apply to this disk. These can be later modified by thedisks. setLabels method. This field is only applicable for persistent disks. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


2347
2348
2349
# File 'lib/google/apis/compute_alpha/classes.rb', line 2347

def labels
  @labels
end

#license_codesArray<Fixnum>

Integer license codes indicating which licenses are attached to this disk. Corresponds to the JSON property licenseCodes

Returns:

  • (Array<Fixnum>)


2353
2354
2355
# File 'lib/google/apis/compute_alpha/classes.rb', line 2353

def license_codes
  @license_codes
end

#licensesArray<String>

A list of publicly visible licenses. Reserved for Google's use. Corresponds to the JSON property licenses

Returns:

  • (Array<String>)


2358
2359
2360
# File 'lib/google/apis/compute_alpha/classes.rb', line 2358

def licenses
  @licenses
end

#multi_writerBoolean Also known as: multi_writer?

Indicates whether or not the disk can be read/write attached to more than one instance. Corresponds to the JSON property multiWriter

Returns:

  • (Boolean)


2364
2365
2366
# File 'lib/google/apis/compute_alpha/classes.rb', line 2364

def multi_writer
  @multi_writer
end

#on_update_actionString

Specifies which action to take on instance update with this disk. Default is to use the existing disk. Corresponds to the JSON property onUpdateAction

Returns:

  • (String)


2371
2372
2373
# File 'lib/google/apis/compute_alpha/classes.rb', line 2371

def on_update_action
  @on_update_action
end

#provisioned_iopsFixnum

Indicates how many IOPS to provision for the disk. This sets the number of I/O operations per second that the disk can handle. Values must be between 10,000 and 120,000. For more details, see theExtreme persistent disk documentation. Corresponds to the JSON property provisionedIops

Returns:

  • (Fixnum)


2379
2380
2381
# File 'lib/google/apis/compute_alpha/classes.rb', line 2379

def provisioned_iops
  @provisioned_iops
end

#provisioned_throughputFixnum

Indicates how much throughput to provision for the disk. This sets the number of throughput mb per second that the disk can handle. Values must greater than or equal to 1. Corresponds to the JSON property provisionedThroughput

Returns:

  • (Fixnum)


2386
2387
2388
# File 'lib/google/apis/compute_alpha/classes.rb', line 2386

def provisioned_throughput
  @provisioned_throughput
end

#replica_zonesArray<String>

Required for each regional disk associated with the instance. Specify the URLs of the zones where the disk should be replicated to. You must provide exactly two replica zones, and one zone must be the same as the instance zone. Corresponds to the JSON property replicaZones

Returns:

  • (Array<String>)


2394
2395
2396
# File 'lib/google/apis/compute_alpha/classes.rb', line 2394

def replica_zones
  @replica_zones
end

#resource_manager_tagsHash<String,String>

Input only. Resource manager tags to be bound to the disk. Tag keys and values have the same definition as resource manager tags. Keys and values can be either in numeric format, such as tagKeys/tag_key_idand `tagValues/`tag_value_id or in namespaced format such as org_id|project_id`/`tag_key_short_name and tag_value_short_name. The field is ignored (both PUT & PATCH) when empty. Corresponds to the JSON property resourceManagerTags

Returns:

  • (Hash<String,String>)


2405
2406
2407
# File 'lib/google/apis/compute_alpha/classes.rb', line 2405

def resource_manager_tags
  @resource_manager_tags
end

#resource_policiesArray<String>

Resource policies applied to this disk for automatic snapshot creations. Specified using the full or partial URL. For instance template, specify only the resource policy name. Corresponds to the JSON property resourcePolicies

Returns:

  • (Array<String>)


2412
2413
2414
# File 'lib/google/apis/compute_alpha/classes.rb', line 2412

def resource_policies
  @resource_policies
end

#source_imageString

The source image to create this disk. When creating a new instance boot disk, one of initializeParams.sourceImage orinitializeParams.sourceSnapshot or disks.source is required. To create a disk with one of the public operating system images, specify the image by its family name. For example, specifyfamily/ debian-9 to use the latest Debian 9 image: projects/debian-cloud/global/images/family/debian-9 Alternatively, use a specific version of a public operating system image: projects/debian-cloud/global/images/debian-9-stretch-vYYYYMMDD To create a disk with a custom image that you created, specify the image name in the following format: global/images/my-custom-image You can also specify a custom image by its image family, which returns the latest version of the image in that family. Replace the image name with family/family-name: global/images/family/my-image-family If the source image is deleted later, this field will not be set. Corresponds to the JSON property sourceImage

Returns:

  • (String)


2434
2435
2436
# File 'lib/google/apis/compute_alpha/classes.rb', line 2434

def source_image
  @source_image
end

#source_image_encryption_keyGoogle::Apis::ComputeAlpha::CustomerEncryptionKey

Thecustomer-supplied encryption key of the source image. Required if the source image is protected by a customer-supplied encryption key. InstanceTemplate and InstancePropertiesPatch do not storecustomer-supplied encryption keys, so you cannot create disks for instances in a managed instance group if the source images are encrypted with your own keys. Corresponds to the JSON property sourceImageEncryptionKey



2445
2446
2447
# File 'lib/google/apis/compute_alpha/classes.rb', line 2445

def source_image_encryption_key
  @source_image_encryption_key
end

#source_instant_snapshotString

The source instant-snapshot to create this disk. When creating a new instance boot disk, one of initializeParams.sourceSnapshot or initializeParams.sourceInstantSnapshotinitializeParams.sourceImage or disks. source is required. To create a disk with a snapshot that you created, specify the snapshot name in the following format: us-central1-a/instantSnapshots/my-backup If the source instant-snapshot is deleted later, this field will not be set. Corresponds to the JSON property sourceInstantSnapshot

Returns:

  • (String)


2459
2460
2461
# File 'lib/google/apis/compute_alpha/classes.rb', line 2459

def source_instant_snapshot
  @source_instant_snapshot
end

#source_snapshotString

The source snapshot to create this disk. When creating a new instance boot disk, one of initializeParams.sourceSnapshot orinitializeParams. sourceImage or disks.source is required. To create a disk with a snapshot that you created, specify the snapshot name in the following format: global/snapshots/my-backup If the source snapshot is deleted later, this field will not be set. Note: You cannot create VMs in bulk using a snapshot as the source. Use an image instead when you create VMs using the bulk insert method. Corresponds to the JSON property sourceSnapshot

Returns:

  • (String)


2475
2476
2477
# File 'lib/google/apis/compute_alpha/classes.rb', line 2475

def source_snapshot
  @source_snapshot
end

#source_snapshot_encryption_keyGoogle::Apis::ComputeAlpha::CustomerEncryptionKey

Thecustomer-supplied encryption key of the source snapshot. Corresponds to the JSON property sourceSnapshotEncryptionKey



2481
2482
2483
# File 'lib/google/apis/compute_alpha/classes.rb', line 2481

def source_snapshot_encryption_key
  @source_snapshot_encryption_key
end

#storage_poolString

The storage pool in which the new disk is created. You can provide this as a partial or full URL to the resource. For example, the following are valid values:

Returns:

  • (String)


2494
2495
2496
# File 'lib/google/apis/compute_alpha/classes.rb', line 2494

def storage_pool
  @storage_pool
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2501
2502
2503
2504
2505
2506
2507
2508
2509
2510
2511
2512
2513
2514
2515
2516
2517
2518
2519
2520
2521
2522
2523
2524
2525
2526
# File 'lib/google/apis/compute_alpha/classes.rb', line 2501

def update!(**args)
  @architecture = args[:architecture] if args.key?(:architecture)
  @description = args[:description] if args.key?(:description)
  @disk_name = args[:disk_name] if args.key?(:disk_name)
  @disk_size_gb = args[:disk_size_gb] if args.key?(:disk_size_gb)
  @disk_type = args[:disk_type] if args.key?(:disk_type)
  @enable_confidential_compute = args[:enable_confidential_compute] if args.key?(:enable_confidential_compute)
  @guest_os_features = args[:guest_os_features] if args.key?(:guest_os_features)
  @interface = args[:interface] if args.key?(:interface)
  @labels = args[:labels] if args.key?(:labels)
  @license_codes = args[:license_codes] if args.key?(:license_codes)
  @licenses = args[:licenses] if args.key?(:licenses)
  @multi_writer = args[:multi_writer] if args.key?(:multi_writer)
  @on_update_action = args[:on_update_action] if args.key?(:on_update_action)
  @provisioned_iops = args[:provisioned_iops] if args.key?(:provisioned_iops)
  @provisioned_throughput = args[:provisioned_throughput] if args.key?(:provisioned_throughput)
  @replica_zones = args[:replica_zones] if args.key?(:replica_zones)
  @resource_manager_tags = args[:resource_manager_tags] if args.key?(:resource_manager_tags)
  @resource_policies = args[:resource_policies] if args.key?(:resource_policies)
  @source_image = args[:source_image] if args.key?(:source_image)
  @source_image_encryption_key = args[:source_image_encryption_key] if args.key?(:source_image_encryption_key)
  @source_instant_snapshot = args[:source_instant_snapshot] if args.key?(:source_instant_snapshot)
  @source_snapshot = args[:source_snapshot] if args.key?(:source_snapshot)
  @source_snapshot_encryption_key = args[:source_snapshot_encryption_key] if args.key?(:source_snapshot_encryption_key)
  @storage_pool = args[:storage_pool] if args.key?(:storage_pool)
end