Class: Google::Apis::ComputeAlpha::AuthenticationPolicy
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::AuthenticationPolicy
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
[Deprecated] The authentication settings for the backend service. The authentication settings for the backend service.
Instance Attribute Summary collapse
-
#origins ⇒ Array<Google::Apis::ComputeAlpha::OriginAuthenticationMethod>
List of authentication methods that can be used for origin authentication.
-
#peers ⇒ Array<Google::Apis::ComputeAlpha::PeerAuthenticationMethod>
List of authentication methods that can be used for peer authentication.
-
#principal_binding ⇒ String
Define whether peer or origin identity should be used for principal.
-
#server_tls_context ⇒ Google::Apis::ComputeAlpha::TlsContext
[Deprecated] The TLS settings for the client or server.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AuthenticationPolicy
constructor
A new instance of AuthenticationPolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AuthenticationPolicy
Returns a new instance of AuthenticationPolicy.
2772 2773 2774 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 2772 def initialize(**args) update!(**args) end |
Instance Attribute Details
#origins ⇒ Array<Google::Apis::ComputeAlpha::OriginAuthenticationMethod>
List of authentication methods that can be used for origin authentication.
Similar to peers, these will be evaluated in order the first valid one
will be used to set origin identity. If none of these methods pass, the
request will be rejected with authentication failed error (401). Leave the
list empty if origin authentication is not required.
Corresponds to the JSON property origins
2742 2743 2744 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 2742 def origins @origins end |
#peers ⇒ Array<Google::Apis::ComputeAlpha::PeerAuthenticationMethod>
List of authentication methods that can be used for peer authentication.
They will be evaluated in order the first valid one will be used to set
peer identity. If none of these methods pass, the request will be rejected
with authentication failed error (401). Leave the list empty if peer
authentication is not required.
Corresponds to the JSON property peers
2751 2752 2753 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 2751 def peers @peers end |
#principal_binding ⇒ String
Define whether peer or origin identity should be used for principal.
Default value is USE_PEER. If peer (or origin) identity is not available,
either because peer/origin authentication is not defined, or failed,
principal will be left unset. In other words, binding rule does not affect
the decision to accept or reject request. This field can be set to one of
the following:
USE_PEER: Principal will be set to the identity from peer authentication.
USE_ORIGIN: Principal will be set to the identity from origin
authentication.
Corresponds to the JSON property principalBinding
2764 2765 2766 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 2764 def principal_binding @principal_binding end |
#server_tls_context ⇒ Google::Apis::ComputeAlpha::TlsContext
[Deprecated] The TLS settings for the client or server.
The TLS settings for the client or server.
Corresponds to the JSON property serverTlsContext
2770 2771 2772 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 2770 def server_tls_context @server_tls_context end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2777 2778 2779 2780 2781 2782 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 2777 def update!(**args) @origins = args[:origins] if args.key?(:origins) @peers = args[:peers] if args.key?(:peers) @principal_binding = args[:principal_binding] if args.key?(:principal_binding) @server_tls_context = args[:server_tls_context] if args.key?(:server_tls_context) end |