Class: Google::Apis::ComputeAlpha::AutoscalerAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AutoscalerAggregatedList

Returns a new instance of AutoscalerAggregatedList.



3002
3003
3004
# File 'lib/google/apis/compute_alpha/classes.rb', line 3002

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


2962
2963
2964
# File 'lib/google/apis/compute_alpha/classes.rb', line 2962

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::AutoscalersScopedList>

A list of AutoscalersScopedList resources. Corresponds to the JSON property items



2967
2968
2969
# File 'lib/google/apis/compute_alpha/classes.rb', line 2967

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# autoscalerAggregatedList for aggregated lists of autoscalers. Corresponds to the JSON property kind

Returns:

  • (String)


2974
2975
2976
# File 'lib/google/apis/compute_alpha/classes.rb', line 2974

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


2984
2985
2986
# File 'lib/google/apis/compute_alpha/classes.rb', line 2984

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


2989
2990
2991
# File 'lib/google/apis/compute_alpha/classes.rb', line 2989

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


2995
2996
2997
# File 'lib/google/apis/compute_alpha/classes.rb', line 2995

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::AutoscalerAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



3000
3001
3002
# File 'lib/google/apis/compute_alpha/classes.rb', line 3000

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3007
3008
3009
3010
3011
3012
3013
3014
3015
# File 'lib/google/apis/compute_alpha/classes.rb', line 3007

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end