Class: Google::Apis::ComputeAlpha::AutoscalerAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::AutoscalerAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::AutoscalersScopedList>
A list of AutoscalersScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::AutoscalerAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AutoscalerAggregatedList
constructor
A new instance of AutoscalerAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AutoscalerAggregatedList
Returns a new instance of AutoscalerAggregatedList.
2688 2689 2690 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 2688 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
2648 2649 2650 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 2648 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::AutoscalersScopedList>
A list of AutoscalersScopedList resources.
Corresponds to the JSON property items
2653 2654 2655 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 2653 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
autoscalerAggregatedList for aggregated lists of
autoscalers.
Corresponds to the JSON property kind
2660 2661 2662 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 2660 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
2670 2671 2672 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 2670 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
2675 2676 2677 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 2675 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
end_interface: MixerListResponseWithEtagBuilder
Corresponds to the JSON property unreachables
2681 2682 2683 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 2681 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::AutoscalerAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
2686 2687 2688 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 2686 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2693 2694 2695 2696 2697 2698 2699 2700 2701 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 2693 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |