Class: Google::Apis::ComputeAlpha::AutoscalerAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::AutoscalerAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::AutoscalersScopedList>
A list of AutoscalersScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::AutoscalerAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AutoscalerAggregatedList
constructor
A new instance of AutoscalerAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AutoscalerAggregatedList
Returns a new instance of AutoscalerAggregatedList.
2705 2706 2707 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 2705 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
2665 2666 2667 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 2665 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::AutoscalersScopedList>
A list of AutoscalersScopedList resources.
Corresponds to the JSON property items
2670 2671 2672 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 2670 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
autoscalerAggregatedList for aggregated lists of
autoscalers.
Corresponds to the JSON property kind
2677 2678 2679 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 2677 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
2687 2688 2689 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 2687 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
2692 2693 2694 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 2692 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
end_interface: MixerListResponseWithEtagBuilder
Corresponds to the JSON property unreachables
2698 2699 2700 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 2698 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::AutoscalerAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
2703 2704 2705 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 2703 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2710 2711 2712 2713 2714 2715 2716 2717 2718 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 2710 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |