Class: Google::Apis::ComputeAlpha::AutoscalerList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::AutoscalerList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Contains a list of Autoscaler resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::Autoscaler>
A list of Autoscaler resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::AutoscalerList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AutoscalerList
constructor
A new instance of AutoscalerList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AutoscalerList
Returns a new instance of AutoscalerList.
3141 3142 3143 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 3141 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
3108 3109 3110 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 3108 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::Autoscaler>
A list of Autoscaler resources.
Corresponds to the JSON property items
3113 3114 3115 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 3113 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#autoscalerList
for lists of autoscalers.
Corresponds to the JSON property kind
3119 3120 3121 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 3119 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
3129 3130 3131 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 3129 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
3134 3135 3136 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 3134 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::AutoscalerList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
3139 3140 3141 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 3139 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3146 3147 3148 3149 3150 3151 3152 3153 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 3146 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |