Class: Google::Apis::ComputeAlpha::AutoscalerList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::AutoscalerList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Contains a list of Autoscaler resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::Autoscaler>
A list of Autoscaler resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::AutoscalerList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AutoscalerList
constructor
A new instance of AutoscalerList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AutoscalerList
Returns a new instance of AutoscalerList.
3128 3129 3130 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 3128 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
3095 3096 3097 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 3095 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::Autoscaler>
A list of Autoscaler resources.
Corresponds to the JSON property items
3100 3101 3102 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 3100 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#autoscalerList
for lists of autoscalers.
Corresponds to the JSON property kind
3106 3107 3108 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 3106 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
3116 3117 3118 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 3116 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
3121 3122 3123 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 3121 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::AutoscalerList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
3126 3127 3128 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 3126 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3133 3134 3135 3136 3137 3138 3139 3140 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 3133 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |