Class: Google::Apis::ComputeAlpha::AutoscalerList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of Autoscaler resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AutoscalerList

Returns a new instance of AutoscalerList.



3066
3067
3068
# File 'lib/google/apis/compute_alpha/classes.rb', line 3066

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


3033
3034
3035
# File 'lib/google/apis/compute_alpha/classes.rb', line 3033

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::Autoscaler>

A list of Autoscaler resources. Corresponds to the JSON property items



3038
3039
3040
# File 'lib/google/apis/compute_alpha/classes.rb', line 3038

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#autoscalerList for lists of autoscalers. Corresponds to the JSON property kind

Returns:

  • (String)


3044
3045
3046
# File 'lib/google/apis/compute_alpha/classes.rb', line 3044

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


3054
3055
3056
# File 'lib/google/apis/compute_alpha/classes.rb', line 3054

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


3059
3060
3061
# File 'lib/google/apis/compute_alpha/classes.rb', line 3059

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::AutoscalerList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



3064
3065
3066
# File 'lib/google/apis/compute_alpha/classes.rb', line 3064

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3071
3072
3073
3074
3075
3076
3077
3078
# File 'lib/google/apis/compute_alpha/classes.rb', line 3071

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end