Class: Google::Apis::ComputeAlpha::AutoscalerList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::AutoscalerList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Contains a list of Autoscaler resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::Autoscaler>
A list of Autoscaler resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::AutoscalerList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AutoscalerList
constructor
A new instance of AutoscalerList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AutoscalerList
Returns a new instance of AutoscalerList.
2831 2832 2833 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 2831 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
2798 2799 2800 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 2798 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::Autoscaler>
A list of Autoscaler resources.
Corresponds to the JSON property items
2803 2804 2805 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 2803 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#autoscalerList
for lists of autoscalers.
Corresponds to the JSON property kind
2809 2810 2811 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 2809 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
2819 2820 2821 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 2819 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
2824 2825 2826 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 2824 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::AutoscalerList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
2829 2830 2831 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 2829 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2836 2837 2838 2839 2840 2841 2842 2843 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 2836 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |