Class: Google::Apis::ComputeAlpha::AutoscalingPolicyScalingSchedule

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Scaling based on user-defined schedule. The message describes a single scaling schedule. A scaling schedule changes the minimum number of VM instances an autoscaler can recommend, which can trigger scaling out.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AutoscalingPolicyScalingSchedule

Returns a new instance of AutoscalingPolicyScalingSchedule.



3711
3712
3713
# File 'lib/google/apis/compute_alpha/classes.rb', line 3711

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

A description of a scaling schedule. Corresponds to the JSON property description

Returns:

  • (String)


3667
3668
3669
# File 'lib/google/apis/compute_alpha/classes.rb', line 3667

def description
  @description
end

#disabledBoolean Also known as: disabled?

A boolean value that specifies whether a scaling schedule can influence autoscaler recommendations. If set to true, then a scaling schedule has no effect. This field is optional, and its value is false by default. Corresponds to the JSON property disabled

Returns:

  • (Boolean)


3674
3675
3676
# File 'lib/google/apis/compute_alpha/classes.rb', line 3674

def disabled
  @disabled
end

#duration_secFixnum

The duration of time intervals, in seconds, for which this scaling schedule is to run. The minimum allowed value is 300. This field is required. Corresponds to the JSON property durationSec

Returns:

  • (Fixnum)


3682
3683
3684
# File 'lib/google/apis/compute_alpha/classes.rb', line 3682

def duration_sec
  @duration_sec
end

#min_required_replicasFixnum

The minimum number of VM instances that the autoscaler will recommend in time intervals starting according to schedule. This field is required. Corresponds to the JSON property minRequiredReplicas

Returns:

  • (Fixnum)


3689
3690
3691
# File 'lib/google/apis/compute_alpha/classes.rb', line 3689

def min_required_replicas
  @min_required_replicas
end

#scheduleString

The start timestamps of time intervals when this scaling schedule is to provide a scaling signal. This field uses the extended cron format (with an optional year field). The expression can describe a single timestamp if the optional year is set, in which case the scaling schedule runs once. The schedule is interpreted with respect to time_zone. This field is required. Note: These timestamps only describe when autoscaler starts providing the scaling signal. The VMs need additional time to become serving. Corresponds to the JSON property schedule

Returns:

  • (String)


3701
3702
3703
# File 'lib/google/apis/compute_alpha/classes.rb', line 3701

def schedule
  @schedule
end

#time_zoneString

The time zone to use when interpreting the schedule. The value of this field must be a time zone name from the tz database: https://en.wikipedia.org/wiki/Tz_database. This field is assigned a default value of "UTC" if left empty. Corresponds to the JSON property timeZone

Returns:

  • (String)


3709
3710
3711
# File 'lib/google/apis/compute_alpha/classes.rb', line 3709

def time_zone
  @time_zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3716
3717
3718
3719
3720
3721
3722
3723
# File 'lib/google/apis/compute_alpha/classes.rb', line 3716

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @disabled = args[:disabled] if args.key?(:disabled)
  @duration_sec = args[:duration_sec] if args.key?(:duration_sec)
  @min_required_replicas = args[:min_required_replicas] if args.key?(:min_required_replicas)
  @schedule = args[:schedule] if args.key?(:schedule)
  @time_zone = args[:time_zone] if args.key?(:time_zone)
end