Class: Google::Apis::ComputeAlpha::AutoscalingPolicyScalingSchedule
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::AutoscalingPolicyScalingSchedule
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Scaling based on user-defined schedule. The message describes a single scaling schedule. A scaling schedule changes the minimum number of VM instances an autoscaler can recommend, which can trigger scaling out.
Instance Attribute Summary collapse
-
#description ⇒ String
A description of a scaling schedule.
-
#disabled ⇒ Boolean
(also: #disabled?)
A boolean value that specifies whether a scaling schedule can influence autoscaler recommendations.
-
#duration_sec ⇒ Fixnum
The duration of time intervals, in seconds, for which this scaling schedule is to run.
-
#min_required_replicas ⇒ Fixnum
The minimum number of VM instances that the autoscaler will recommend in time intervals starting according to schedule.
-
#schedule ⇒ String
The start timestamps of time intervals when this scaling schedule is to provide a scaling signal.
-
#time_zone ⇒ String
The time zone to use when interpreting the schedule.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AutoscalingPolicyScalingSchedule
constructor
A new instance of AutoscalingPolicyScalingSchedule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AutoscalingPolicyScalingSchedule
Returns a new instance of AutoscalingPolicyScalingSchedule.
3464 3465 3466 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 3464 def initialize(**args) update!(**args) end |
Instance Attribute Details
#description ⇒ String
A description of a scaling schedule.
Corresponds to the JSON property description
3420 3421 3422 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 3420 def description @description end |
#disabled ⇒ Boolean Also known as: disabled?
A boolean value that specifies whether a scaling schedule can influence
autoscaler recommendations. If set to true, then a scaling schedule has
no effect. This field is optional, and its value is false by default.
Corresponds to the JSON property disabled
3427 3428 3429 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 3427 def disabled @disabled end |
#duration_sec ⇒ Fixnum
The duration of time intervals, in seconds, for which this
scaling schedule is to run. The minimum allowed value is 300.
This field is required.
Corresponds to the JSON property durationSec
3435 3436 3437 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 3435 def duration_sec @duration_sec end |
#min_required_replicas ⇒ Fixnum
The minimum number of VM instances that the autoscaler will
recommend in time intervals starting according to schedule. This field is
required.
Corresponds to the JSON property minRequiredReplicas
3442 3443 3444 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 3442 def min_required_replicas @min_required_replicas end |
#schedule ⇒ String
The start timestamps of time intervals when this scaling
schedule is to provide a scaling signal. This field uses the extended
cron format (with an optional year field). The expression can describe a
single timestamp if the optional year is set, in which case the scaling
schedule runs once. The schedule is interpreted with respect to
time_zone. This field is required. Note: These timestamps only describe
when autoscaler starts providing the scaling signal. The VMs
need additional time to become serving.
Corresponds to the JSON property schedule
3454 3455 3456 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 3454 def schedule @schedule end |
#time_zone ⇒ String
The time zone to use when interpreting the schedule.
The value of this field must be a time zone name from the tz database:
https://en.wikipedia.org/wiki/Tz_database. This field is assigned a
default value of "UTC" if left empty.
Corresponds to the JSON property timeZone
3462 3463 3464 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 3462 def time_zone @time_zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3469 3470 3471 3472 3473 3474 3475 3476 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 3469 def update!(**args) @description = args[:description] if args.key?(:description) @disabled = args[:disabled] if args.key?(:disabled) @duration_sec = args[:duration_sec] if args.key?(:duration_sec) @min_required_replicas = args[:min_required_replicas] if args.key?(:min_required_replicas) @schedule = args[:schedule] if args.key?(:schedule) @time_zone = args[:time_zone] if args.key?(:time_zone) end |