Class: Google::Apis::ComputeAlpha::BackendBackendOrchestrationInfo
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::BackendBackendOrchestrationInfo
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
A message containing information about the resource or system that manages the backend.
Instance Attribute Summary collapse
-
#resource_uri ⇒ String
The URI of the resource or system that manages the backend.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BackendBackendOrchestrationInfo
constructor
A new instance of BackendBackendOrchestrationInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BackendBackendOrchestrationInfo
Returns a new instance of BackendBackendOrchestrationInfo.
3707 3708 3709 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 3707 def initialize(**args) update!(**args) end |
Instance Attribute Details
#resource_uri ⇒ String
The URI of the resource or system that manages the backend.
Corresponds to the JSON property resourceUri
3705 3706 3707 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 3705 def resource_uri @resource_uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3712 3713 3714 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 3712 def update!(**args) @resource_uri = args[:resource_uri] if args.key?(:resource_uri) end |