Class: Google::Apis::ComputeAlpha::BackendBucket
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::BackendBucket
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Represents a Cloud Storage Bucket resource. This Cloud Storage bucket resource is referenced by a URL map of a load balancer. For more information, readBackend Buckets.
Instance Attribute Summary collapse
-
#bucket_name ⇒ String
Cloud Storage bucket name.
-
#cdn_policy ⇒ Google::Apis::ComputeAlpha::BackendBucketCdnPolicy
Message containing Cloud CDN configuration for a backend bucket.
-
#compression_mode ⇒ String
Compress text responses using Brotli or gzip compression, based on the client's Accept-Encoding header.
-
#creation_timestamp ⇒ String
[Output Only] Creation timestamp inRFC3339 text format.
-
#custom_response_headers ⇒ Array<String>
Headers that the Application Load Balancer should add to proxied responses.
-
#description ⇒ String
An optional textual description of the resource; provided by the client when the resource is created.
-
#edge_security_policy ⇒ String
[Output Only] The resource URL for the edge security policy associated with this backend bucket.
-
#enable_cdn ⇒ Boolean
(also: #enable_cdn?)
If true, enable Cloud CDN for this BackendBucket.
-
#id ⇒ Fixnum
[Output Only] Unique identifier for the resource; defined by the server.
-
#kind ⇒ String
Output only.
-
#load_balancing_scheme ⇒ String
The value can only be INTERNAL_MANAGED for cross-region internal layer 7 load balancer.
-
#name ⇒ String
Name of the resource.
-
#params ⇒ Google::Apis::ComputeAlpha::BackendBucketParams
Additional Backend Bucket parameters.
-
#region ⇒ String
Output only.
-
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
-
#self_link_with_id ⇒ String
Output only.
-
#used_by ⇒ Array<Google::Apis::ComputeAlpha::BackendBucketUsedBy>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BackendBucket
constructor
A new instance of BackendBucket.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BackendBucket
Returns a new instance of BackendBucket.
4074 4075 4076 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 4074 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bucket_name ⇒ String
Cloud Storage bucket name.
Corresponds to the JSON property bucketName
3973 3974 3975 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 3973 def bucket_name @bucket_name end |
#cdn_policy ⇒ Google::Apis::ComputeAlpha::BackendBucketCdnPolicy
Message containing Cloud CDN configuration for a backend bucket.
Corresponds to the JSON property cdnPolicy
3978 3979 3980 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 3978 def cdn_policy @cdn_policy end |
#compression_mode ⇒ String
Compress text responses using Brotli or gzip compression, based on
the client's Accept-Encoding header.
Corresponds to the JSON property compressionMode
3984 3985 3986 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 3984 def compression_mode @compression_mode end |
#creation_timestamp ⇒ String
[Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
3990 3991 3992 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 3990 def @creation_timestamp end |
#custom_response_headers ⇒ Array<String>
Headers that the Application Load Balancer should add to proxied responses.
Corresponds to the JSON property customResponseHeaders
3995 3996 3997 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 3995 def custom_response_headers @custom_response_headers end |
#description ⇒ String
An optional textual description of the resource; provided by the client
when the resource is created.
Corresponds to the JSON property description
4001 4002 4003 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 4001 def description @description end |
#edge_security_policy ⇒ String
[Output Only] The resource URL for the edge security policy associated with
this backend bucket.
Corresponds to the JSON property edgeSecurityPolicy
4007 4008 4009 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 4007 def edge_security_policy @edge_security_policy end |
#enable_cdn ⇒ Boolean Also known as: enable_cdn?
If true, enable Cloud CDN for this BackendBucket.
Corresponds to the JSON property enableCdn
4012 4013 4014 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 4012 def enable_cdn @enable_cdn end |
#id ⇒ Fixnum
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
4018 4019 4020 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 4018 def id @id end |
#kind ⇒ String
Output only. Type of the resource.
Corresponds to the JSON property kind
4023 4024 4025 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 4023 def kind @kind end |
#load_balancing_scheme ⇒ String
The value can only be INTERNAL_MANAGED for cross-region internal layer 7
load balancer.
If loadBalancingScheme is not specified, the backend bucket can be used by
classic global external load balancers, or global application external load
balancers, or both.
Corresponds to the JSON property loadBalancingScheme
4032 4033 4034 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 4032 def load_balancing_scheme @load_balancing_scheme end |
#name ⇒ String
Name of the resource. Provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must
be a dash, lowercase letter, or digit, except the last character, which
cannot be a dash.
Corresponds to the JSON property name
4043 4044 4045 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 4043 def name @name end |
#params ⇒ Google::Apis::ComputeAlpha::BackendBucketParams
Additional Backend Bucket parameters.
Corresponds to the JSON property params
4048 4049 4050 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 4048 def params @params end |
#region ⇒ String
Output only. [Output Only] URL of the region where the regional backend bucket
resides. This field is not applicable to global backend buckets.
You must specify this field as part of the HTTP request URL. It is
not settable as a field in the request body.
Corresponds to the JSON property region
4056 4057 4058 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 4056 def region @region end |
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
4061 4062 4063 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 4061 def self_link @self_link end |
#self_link_with_id ⇒ String
Output only. [Output Only] Server-defined URL for this resource with the
resource id.
Corresponds to the JSON property selfLinkWithId
4067 4068 4069 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 4067 def self_link_with_id @self_link_with_id end |
#used_by ⇒ Array<Google::Apis::ComputeAlpha::BackendBucketUsedBy>
Output only. [Output Only] List of resources referencing that backend bucket.
Corresponds to the JSON property usedBy
4072 4073 4074 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 4072 def used_by @used_by end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4079 4080 4081 4082 4083 4084 4085 4086 4087 4088 4089 4090 4091 4092 4093 4094 4095 4096 4097 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 4079 def update!(**args) @bucket_name = args[:bucket_name] if args.key?(:bucket_name) @cdn_policy = args[:cdn_policy] if args.key?(:cdn_policy) @compression_mode = args[:compression_mode] if args.key?(:compression_mode) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @custom_response_headers = args[:custom_response_headers] if args.key?(:custom_response_headers) @description = args[:description] if args.key?(:description) @edge_security_policy = args[:edge_security_policy] if args.key?(:edge_security_policy) @enable_cdn = args[:enable_cdn] if args.key?(:enable_cdn) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @load_balancing_scheme = args[:load_balancing_scheme] if args.key?(:load_balancing_scheme) @name = args[:name] if args.key?(:name) @params = args[:params] if args.key?(:params) @region = args[:region] if args.key?(:region) @self_link = args[:self_link] if args.key?(:self_link) @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id) @used_by = args[:used_by] if args.key?(:used_by) end |