Class: Google::Apis::ComputeAlpha::BackendBucketList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of BackendBucket resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BackendBucketList

Returns a new instance of BackendBucketList.



4581
4582
4583
# File 'lib/google/apis/compute_alpha/classes.rb', line 4581

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


4549
4550
4551
# File 'lib/google/apis/compute_alpha/classes.rb', line 4549

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::BackendBucket>

A list of BackendBucket resources. Corresponds to the JSON property items



4554
4555
4556
# File 'lib/google/apis/compute_alpha/classes.rb', line 4554

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


4559
4560
4561
# File 'lib/google/apis/compute_alpha/classes.rb', line 4559

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


4569
4570
4571
# File 'lib/google/apis/compute_alpha/classes.rb', line 4569

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


4574
4575
4576
# File 'lib/google/apis/compute_alpha/classes.rb', line 4574

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::BackendBucketList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



4579
4580
4581
# File 'lib/google/apis/compute_alpha/classes.rb', line 4579

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4586
4587
4588
4589
4590
4591
4592
4593
# File 'lib/google/apis/compute_alpha/classes.rb', line 4586

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end