Class: Google::Apis::ComputeAlpha::BackendBucketList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::BackendBucketList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Contains a list of BackendBucket resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::BackendBucket>
A list of BackendBucket resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::BackendBucketList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BackendBucketList
constructor
A new instance of BackendBucketList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BackendBucketList
Returns a new instance of BackendBucketList.
4272 4273 4274 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 4272 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
4240 4241 4242 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 4240 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::BackendBucket>
A list of BackendBucket resources.
Corresponds to the JSON property items
4245 4246 4247 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 4245 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
4250 4251 4252 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 4250 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
4260 4261 4262 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 4260 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
4265 4266 4267 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 4265 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::BackendBucketList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
4270 4271 4272 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 4270 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4277 4278 4279 4280 4281 4282 4283 4284 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 4277 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |