Class: Google::Apis::ComputeAlpha::BackendBucketListUsable
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::BackendBucketListUsable
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::BackendBucket>
A list of BackendBucket resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::BackendBucketListUsable::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BackendBucketListUsable
constructor
A new instance of BackendBucketListUsable.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BackendBucketListUsable
Returns a new instance of BackendBucketListUsable.
4730 4731 4732 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 4730 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
4696 4697 4698 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 4696 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::BackendBucket>
A list of BackendBucket resources.
Corresponds to the JSON property items
4701 4702 4703 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 4701 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
usableBackendBucketList for lists of usable backend
buckets.
Corresponds to the JSON property kind
4708 4709 4710 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 4708 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
4718 4719 4720 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 4718 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
4723 4724 4725 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 4723 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::BackendBucketListUsable::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
4728 4729 4730 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 4728 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4735 4736 4737 4738 4739 4740 4741 4742 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 4735 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |