Class: Google::Apis::ComputeAlpha::BackendBucketListUsable

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BackendBucketListUsable

Returns a new instance of BackendBucketListUsable.



4707
4708
4709
# File 'lib/google/apis/compute_alpha/classes.rb', line 4707

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


4673
4674
4675
# File 'lib/google/apis/compute_alpha/classes.rb', line 4673

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::BackendBucket>

A list of BackendBucket resources. Corresponds to the JSON property items



4678
4679
4680
# File 'lib/google/apis/compute_alpha/classes.rb', line 4678

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# usableBackendBucketList for lists of usable backend buckets. Corresponds to the JSON property kind

Returns:

  • (String)


4685
4686
4687
# File 'lib/google/apis/compute_alpha/classes.rb', line 4685

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


4695
4696
4697
# File 'lib/google/apis/compute_alpha/classes.rb', line 4695

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


4700
4701
4702
# File 'lib/google/apis/compute_alpha/classes.rb', line 4700

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::BackendBucketListUsable::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



4705
4706
4707
# File 'lib/google/apis/compute_alpha/classes.rb', line 4705

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4712
4713
4714
4715
4716
4717
4718
4719
# File 'lib/google/apis/compute_alpha/classes.rb', line 4712

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end