Class: Google::Apis::ComputeAlpha::BackendBucketListUsable

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BackendBucketListUsable

Returns a new instance of BackendBucketListUsable.



4393
4394
4395
# File 'lib/google/apis/compute_alpha/classes.rb', line 4393

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


4359
4360
4361
# File 'lib/google/apis/compute_alpha/classes.rb', line 4359

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::BackendBucket>

A list of BackendBucket resources. Corresponds to the JSON property items



4364
4365
4366
# File 'lib/google/apis/compute_alpha/classes.rb', line 4364

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# usableBackendBucketList for lists of usable backend buckets. Corresponds to the JSON property kind

Returns:

  • (String)


4371
4372
4373
# File 'lib/google/apis/compute_alpha/classes.rb', line 4371

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


4381
4382
4383
# File 'lib/google/apis/compute_alpha/classes.rb', line 4381

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


4386
4387
4388
# File 'lib/google/apis/compute_alpha/classes.rb', line 4386

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::BackendBucketListUsable::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



4391
4392
4393
# File 'lib/google/apis/compute_alpha/classes.rb', line 4391

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4398
4399
4400
4401
4402
4403
4404
4405
# File 'lib/google/apis/compute_alpha/classes.rb', line 4398

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end