Class: Google::Apis::ComputeAlpha::BackendBucketListUsable
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::BackendBucketListUsable
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::BackendBucket>
A list of BackendBucket resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::BackendBucketListUsable::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BackendBucketListUsable
constructor
A new instance of BackendBucketListUsable.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BackendBucketListUsable
Returns a new instance of BackendBucketListUsable.
4398 4399 4400 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 4398 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
4364 4365 4366 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 4364 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::BackendBucket>
A list of BackendBucket resources.
Corresponds to the JSON property items
4369 4370 4371 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 4369 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
usableBackendBucketList for lists of usable backend
buckets.
Corresponds to the JSON property kind
4376 4377 4378 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 4376 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
4386 4387 4388 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 4386 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
4391 4392 4393 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 4391 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::BackendBucketListUsable::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
4396 4397 4398 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 4396 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4403 4404 4405 4406 4407 4408 4409 4410 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 4403 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |