Class: Google::Apis::ComputeAlpha::BackendServiceAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::BackendServiceAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Contains a list of BackendServicesScopedList.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::BackendServicesScopedList>
A list of BackendServicesScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::BackendServiceAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BackendServiceAggregatedList
constructor
A new instance of BackendServiceAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BackendServiceAggregatedList
Returns a new instance of BackendServiceAggregatedList.
5574 5575 5576 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 5574 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
5537 5538 5539 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 5537 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::BackendServicesScopedList>
A list of BackendServicesScopedList resources.
Corresponds to the JSON property items
5542 5543 5544 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 5542 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
5547 5548 5549 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 5547 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
5557 5558 5559 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 5557 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
5562 5563 5564 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 5562 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
5567 5568 5569 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 5567 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::BackendServiceAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
5572 5573 5574 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 5572 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5579 5580 5581 5582 5583 5584 5585 5586 5587 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 5579 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |