Class: Google::Apis::ComputeAlpha::BackendServiceAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::BackendServiceAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Contains a list of BackendServicesScopedList.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::BackendServicesScopedList>
A list of BackendServicesScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::BackendServiceAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BackendServiceAggregatedList
constructor
A new instance of BackendServiceAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BackendServiceAggregatedList
Returns a new instance of BackendServiceAggregatedList.
5339 5340 5341 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 5339 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
5302 5303 5304 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 5302 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::BackendServicesScopedList>
A list of BackendServicesScopedList resources.
Corresponds to the JSON property items
5307 5308 5309 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 5307 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
5312 5313 5314 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 5312 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
5322 5323 5324 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 5322 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
5327 5328 5329 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 5327 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
5332 5333 5334 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 5332 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::BackendServiceAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
5337 5338 5339 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 5337 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5344 5345 5346 5347 5348 5349 5350 5351 5352 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 5344 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |