Class: Google::Apis::ComputeAlpha::BackendServiceAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of BackendServicesScopedList.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BackendServiceAggregatedList

Returns a new instance of BackendServiceAggregatedList.



5340
5341
5342
# File 'lib/google/apis/compute_alpha/classes.rb', line 5340

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


5303
5304
5305
# File 'lib/google/apis/compute_alpha/classes.rb', line 5303

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::BackendServicesScopedList>

A list of BackendServicesScopedList resources. Corresponds to the JSON property items



5308
5309
5310
# File 'lib/google/apis/compute_alpha/classes.rb', line 5308

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


5313
5314
5315
# File 'lib/google/apis/compute_alpha/classes.rb', line 5313

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


5323
5324
5325
# File 'lib/google/apis/compute_alpha/classes.rb', line 5323

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


5328
5329
5330
# File 'lib/google/apis/compute_alpha/classes.rb', line 5328

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


5333
5334
5335
# File 'lib/google/apis/compute_alpha/classes.rb', line 5333

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::BackendServiceAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



5338
5339
5340
# File 'lib/google/apis/compute_alpha/classes.rb', line 5338

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5345
5346
5347
5348
5349
5350
5351
5352
5353
# File 'lib/google/apis/compute_alpha/classes.rb', line 5345

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end