Class: Google::Apis::ComputeAlpha::BackendServiceDynamicForwarding

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Defines a dynamic forwarding configuration for the backend service.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BackendServiceDynamicForwarding

Returns a new instance of BackendServiceDynamicForwarding.



6023
6024
6025
# File 'lib/google/apis/compute_alpha/classes.rb', line 6023

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#forward_proxyGoogle::Apis::ComputeAlpha::BackendServiceDynamicForwardingForwardProxy

Defines Dynamic Forwarding Proxy configuration. Corresponds to the JSON property forwardProxy



6014
6015
6016
# File 'lib/google/apis/compute_alpha/classes.rb', line 6014

def forward_proxy
  @forward_proxy
end

#ip_port_selectionGoogle::Apis::ComputeAlpha::BackendServiceDynamicForwardingIpPortSelection

Defines a IP:PORT based dynamic forwarding configuration for the backend service. Some ranges are restricted: Restricted ranges. Corresponds to the JSON property ipPortSelection



6021
6022
6023
# File 'lib/google/apis/compute_alpha/classes.rb', line 6021

def ip_port_selection
  @ip_port_selection
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6028
6029
6030
6031
# File 'lib/google/apis/compute_alpha/classes.rb', line 6028

def update!(**args)
  @forward_proxy = args[:forward_proxy] if args.key?(:forward_proxy)
  @ip_port_selection = args[:ip_port_selection] if args.key?(:ip_port_selection)
end