Class: Google::Apis::ComputeAlpha::BackendServiceDynamicForwarding

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Defines a dynamic forwarding configuration for the backend service.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BackendServiceDynamicForwarding

Returns a new instance of BackendServiceDynamicForwarding.



5789
5790
5791
# File 'lib/google/apis/compute_alpha/classes.rb', line 5789

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#forward_proxyGoogle::Apis::ComputeAlpha::BackendServiceDynamicForwardingForwardProxy

Defines Dynamic Forwarding Proxy configuration. Corresponds to the JSON property forwardProxy



5780
5781
5782
# File 'lib/google/apis/compute_alpha/classes.rb', line 5780

def forward_proxy
  @forward_proxy
end

#ip_port_selectionGoogle::Apis::ComputeAlpha::BackendServiceDynamicForwardingIpPortSelection

Defines a IP:PORT based dynamic forwarding configuration for the backend service. Some ranges are restricted: Restricted ranges. Corresponds to the JSON property ipPortSelection



5787
5788
5789
# File 'lib/google/apis/compute_alpha/classes.rb', line 5787

def ip_port_selection
  @ip_port_selection
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5794
5795
5796
5797
# File 'lib/google/apis/compute_alpha/classes.rb', line 5794

def update!(**args)
  @forward_proxy = args[:forward_proxy] if args.key?(:forward_proxy)
  @ip_port_selection = args[:ip_port_selection] if args.key?(:ip_port_selection)
end