Class: Google::Apis::ComputeAlpha::BackendServiceHttpCookie
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::BackendServiceHttpCookie
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
The HTTP cookie used for stateful session affinity.
Instance Attribute Summary collapse
-
#name ⇒ String
Name of the cookie.
-
#path ⇒ String
Path to set for the cookie.
-
#ttl ⇒ Google::Apis::ComputeAlpha::Duration
A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BackendServiceHttpCookie
constructor
A new instance of BackendServiceHttpCookie.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BackendServiceHttpCookie
Returns a new instance of BackendServiceHttpCookie.
6466 6467 6468 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 6466 def initialize(**args) update!(**args) end |
Instance Attribute Details
#name ⇒ String
Name of the cookie.
Corresponds to the JSON property name
6451 6452 6453 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 6451 def name @name end |
#path ⇒ String
Path to set for the cookie.
Corresponds to the JSON property path
6456 6457 6458 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 6456 def path @path end |
#ttl ⇒ Google::Apis::ComputeAlpha::Duration
A Duration represents a fixed-length span of time represented
as a count of seconds and fractions of seconds at nanosecond
resolution. It is independent of any calendar and concepts like "day"
or "month". Range is approximately 10,000 years.
Corresponds to the JSON property ttl
6464 6465 6466 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 6464 def ttl @ttl end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6471 6472 6473 6474 6475 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 6471 def update!(**args) @name = args[:name] if args.key?(:name) @path = args[:path] if args.key?(:path) @ttl = args[:ttl] if args.key?(:ttl) end |