Class: Google::Apis::ComputeAlpha::BackendServiceList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of BackendService resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BackendServiceList

Returns a new instance of BackendServiceList.



6505
6506
6507
# File 'lib/google/apis/compute_alpha/classes.rb', line 6505

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


6472
6473
6474
# File 'lib/google/apis/compute_alpha/classes.rb', line 6472

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::BackendService>

A list of BackendService resources. Corresponds to the JSON property items



6477
6478
6479
# File 'lib/google/apis/compute_alpha/classes.rb', line 6477

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute#backendServiceList for lists of backend services. Corresponds to the JSON property kind

Returns:

  • (String)


6483
6484
6485
# File 'lib/google/apis/compute_alpha/classes.rb', line 6483

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


6493
6494
6495
# File 'lib/google/apis/compute_alpha/classes.rb', line 6493

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


6498
6499
6500
# File 'lib/google/apis/compute_alpha/classes.rb', line 6498

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::BackendServiceList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



6503
6504
6505
# File 'lib/google/apis/compute_alpha/classes.rb', line 6503

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6510
6511
6512
6513
6514
6515
6516
6517
# File 'lib/google/apis/compute_alpha/classes.rb', line 6510

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end