Class: Google::Apis::ComputeAlpha::BackendServiceList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of BackendService resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BackendServiceList

Returns a new instance of BackendServiceList.



6253
6254
6255
# File 'lib/google/apis/compute_alpha/classes.rb', line 6253

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


6220
6221
6222
# File 'lib/google/apis/compute_alpha/classes.rb', line 6220

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::BackendService>

A list of BackendService resources. Corresponds to the JSON property items



6225
6226
6227
# File 'lib/google/apis/compute_alpha/classes.rb', line 6225

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute#backendServiceList for lists of backend services. Corresponds to the JSON property kind

Returns:

  • (String)


6231
6232
6233
# File 'lib/google/apis/compute_alpha/classes.rb', line 6231

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


6241
6242
6243
# File 'lib/google/apis/compute_alpha/classes.rb', line 6241

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


6246
6247
6248
# File 'lib/google/apis/compute_alpha/classes.rb', line 6246

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::BackendServiceList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



6251
6252
6253
# File 'lib/google/apis/compute_alpha/classes.rb', line 6251

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6258
6259
6260
6261
6262
6263
6264
6265
# File 'lib/google/apis/compute_alpha/classes.rb', line 6258

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end