Class: Google::Apis::ComputeAlpha::BackendServiceListUsable

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of usable BackendService resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BackendServiceListUsable

Returns a new instance of BackendServiceListUsable.



6631
6632
6633
# File 'lib/google/apis/compute_alpha/classes.rb', line 6631

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


6597
6598
6599
# File 'lib/google/apis/compute_alpha/classes.rb', line 6597

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::BackendService>

A list of BackendService resources. Corresponds to the JSON property items



6602
6603
6604
# File 'lib/google/apis/compute_alpha/classes.rb', line 6602

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# usableBackendServiceList for lists of usable backend services. Corresponds to the JSON property kind

Returns:

  • (String)


6609
6610
6611
# File 'lib/google/apis/compute_alpha/classes.rb', line 6609

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


6619
6620
6621
# File 'lib/google/apis/compute_alpha/classes.rb', line 6619

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


6624
6625
6626
# File 'lib/google/apis/compute_alpha/classes.rb', line 6624

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::BackendServiceListUsable::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



6629
6630
6631
# File 'lib/google/apis/compute_alpha/classes.rb', line 6629

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6636
6637
6638
6639
6640
6641
6642
6643
# File 'lib/google/apis/compute_alpha/classes.rb', line 6636

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end