Class: Google::Apis::ComputeAlpha::BackendServiceListUsable
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::BackendServiceListUsable
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Contains a list of usable BackendService resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::BackendService>
A list of BackendService resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::BackendServiceListUsable::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BackendServiceListUsable
constructor
A new instance of BackendServiceListUsable.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BackendServiceListUsable
Returns a new instance of BackendServiceListUsable.
6396 6397 6398 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 6396 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
6362 6363 6364 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 6362 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::BackendService>
A list of BackendService resources.
Corresponds to the JSON property items
6367 6368 6369 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 6367 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
usableBackendServiceList for lists of usable backend
services.
Corresponds to the JSON property kind
6374 6375 6376 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 6374 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
6384 6385 6386 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 6384 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
6389 6390 6391 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 6389 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::BackendServiceListUsable::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
6394 6395 6396 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 6394 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6401 6402 6403 6404 6405 6406 6407 6408 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 6401 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |