Class: Google::Apis::ComputeAlpha::BackendServiceListUsable

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of usable BackendService resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BackendServiceListUsable

Returns a new instance of BackendServiceListUsable.



6397
6398
6399
# File 'lib/google/apis/compute_alpha/classes.rb', line 6397

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


6363
6364
6365
# File 'lib/google/apis/compute_alpha/classes.rb', line 6363

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::BackendService>

A list of BackendService resources. Corresponds to the JSON property items



6368
6369
6370
# File 'lib/google/apis/compute_alpha/classes.rb', line 6368

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# usableBackendServiceList for lists of usable backend services. Corresponds to the JSON property kind

Returns:

  • (String)


6375
6376
6377
# File 'lib/google/apis/compute_alpha/classes.rb', line 6375

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


6385
6386
6387
# File 'lib/google/apis/compute_alpha/classes.rb', line 6385

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


6390
6391
6392
# File 'lib/google/apis/compute_alpha/classes.rb', line 6390

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::BackendServiceListUsable::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



6395
6396
6397
# File 'lib/google/apis/compute_alpha/classes.rb', line 6395

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6402
6403
6404
6405
6406
6407
6408
6409
# File 'lib/google/apis/compute_alpha/classes.rb', line 6402

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end