Class: Google::Apis::ComputeAlpha::BackendServiceLocalityLoadBalancingPolicyConfigCustomPolicy
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::BackendServiceLocalityLoadBalancingPolicyConfigCustomPolicy
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
The configuration for a custom policy implemented by the user and deployed with the client.
Instance Attribute Summary collapse
-
#data ⇒ String
An optional, arbitrary JSON object with configuration data, understood by a locally installed custom policy implementation.
-
#name ⇒ String
Identifies the custom policy.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BackendServiceLocalityLoadBalancingPolicyConfigCustomPolicy
constructor
A new instance of BackendServiceLocalityLoadBalancingPolicyConfigCustomPolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BackendServiceLocalityLoadBalancingPolicyConfigCustomPolicy
Returns a new instance of BackendServiceLocalityLoadBalancingPolicyConfigCustomPolicy.
6533 6534 6535 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 6533 def initialize(**args) update!(**args) end |
Instance Attribute Details
#data ⇒ String
An optional, arbitrary JSON object with configuration data, understood
by a locally installed custom policy implementation.
Corresponds to the JSON property data
6518 6519 6520 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 6518 def data @data end |
#name ⇒ String
Identifies the custom policy.
The value should match the name of a custom implementation registered
on the gRPC clients. It should follow protocol buffer message naming
conventions and include the full path (for example,
myorg.CustomLbPolicy). The maximum length is 256 characters.
Do not specify the same custom policy more than once for a
backend. If you do, the configuration is rejected.
For an example of how to use this field, seeUse
a custom policy.
Corresponds to the JSON property name
6531 6532 6533 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 6531 def name @name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6538 6539 6540 6541 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 6538 def update!(**args) @data = args[:data] if args.key?(:data) @name = args[:name] if args.key?(:name) end |