Class: Google::Apis::ComputeAlpha::BackendServiceLogConfig
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::BackendServiceLogConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
The available logging options for the load balancer traffic served by this backend service.
Instance Attribute Summary collapse
-
#enable ⇒ Boolean
(also: #enable?)
Denotes whether to enable logging for the load balancer traffic served by this backend service.
-
#logging_http_request_headers ⇒ Array<Google::Apis::ComputeAlpha::BackendServiceLogConfigLoggingHttpHeader>
The list of request headers that will be logged to Stackdriver.
-
#logging_http_response_headers ⇒ Array<Google::Apis::ComputeAlpha::BackendServiceLogConfigLoggingHttpHeader>
The list of response headers that will be logged to Stackdriver.
-
#optional ⇒ String
Deprecated in favor of optionalMode.
-
#optional_fields ⇒ Array<String>
This field can only be specified if logging is enabled for this backend service and "logConfig.optionalMode" was set to CUSTOM.
-
#optional_mode ⇒ String
This field can only be specified if logging is enabled for this backend service.
-
#sample_rate ⇒ Float
This field can only be specified if logging is enabled for this backend service.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BackendServiceLogConfig
constructor
A new instance of BackendServiceLogConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BackendServiceLogConfig
Returns a new instance of BackendServiceLogConfig.
6955 6956 6957 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 6955 def initialize(**args) update!(**args) end |
Instance Attribute Details
#enable ⇒ Boolean Also known as: enable?
Denotes whether to enable logging for the load balancer
traffic served by this backend service. The default value is false.
Corresponds to the JSON property enable
6907 6908 6909 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 6907 def enable @enable end |
#logging_http_request_headers ⇒ Array<Google::Apis::ComputeAlpha::BackendServiceLogConfigLoggingHttpHeader>
The list of request headers that will be logged to Stackdriver.
Corresponds to the JSON property loggingHttpRequestHeaders
6913 6914 6915 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 6913 def logging_http_request_headers @logging_http_request_headers end |
#logging_http_response_headers ⇒ Array<Google::Apis::ComputeAlpha::BackendServiceLogConfigLoggingHttpHeader>
The list of response headers that will be logged to Stackdriver.
Corresponds to the JSON property loggingHttpResponseHeaders
6918 6919 6920 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 6918 def logging_http_response_headers @logging_http_response_headers end |
#optional ⇒ String
Deprecated in favor of optionalMode.
This field can only be specified if logging is enabled for this backend
service. Configures whether all, none or a subset of optional fields
should be added to the reported logs. One of [INCLUDE_ALL_OPTIONAL,
EXCLUDE_ALL_OPTIONAL, CUSTOM]. Default is EXCLUDE_ALL_OPTIONAL.
Corresponds to the JSON property optional
6927 6928 6929 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 6927 def optional @optional end |
#optional_fields ⇒ Array<String>
This field can only be specified if logging is enabled for this backend
service and "logConfig.optionalMode" was set to CUSTOM. Contains a list
of optional fields you want to include in the logs. For example:
serverInstance, serverGkeDetails.cluster,
serverGkeDetails.pod.podNamespace
Corresponds to the JSON property optionalFields
6936 6937 6938 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 6936 def optional_fields @optional_fields end |
#optional_mode ⇒ String
This field can only be specified if logging is enabled for this backend
service. Configures whether all, none or a subset of optional fields
should be added to the reported logs. One of [INCLUDE_ALL_OPTIONAL,
EXCLUDE_ALL_OPTIONAL, CUSTOM]. Default is EXCLUDE_ALL_OPTIONAL.
Corresponds to the JSON property optionalMode
6944 6945 6946 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 6944 def optional_mode @optional_mode end |
#sample_rate ⇒ Float
This field can only be specified if logging is enabled for this backend
service. The value of the field must be in [0, 1]. This configures the
sampling rate of requests to the load balancer where 1.0 means all logged
requests are reported and 0.0 means no logged requests are reported. The
default value is 1.0.
Corresponds to the JSON property sampleRate
6953 6954 6955 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 6953 def sample_rate @sample_rate end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6960 6961 6962 6963 6964 6965 6966 6967 6968 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 6960 def update!(**args) @enable = args[:enable] if args.key?(:enable) @logging_http_request_headers = args[:logging_http_request_headers] if args.key?(:logging_http_request_headers) @logging_http_response_headers = args[:logging_http_response_headers] if args.key?(:logging_http_response_headers) @optional = args[:optional] if args.key?(:optional) @optional_fields = args[:optional_fields] if args.key?(:optional_fields) @optional_mode = args[:optional_mode] if args.key?(:optional_mode) @sample_rate = args[:sample_rate] if args.key?(:sample_rate) end |