Class: Google::Apis::ComputeAlpha::BackendServiceLogConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

The available logging options for the load balancer traffic served by this backend service.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BackendServiceLogConfig

Returns a new instance of BackendServiceLogConfig.



6924
6925
6926
# File 'lib/google/apis/compute_alpha/classes.rb', line 6924

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enableBoolean Also known as: enable?

Denotes whether to enable logging for the load balancer traffic served by this backend service. The default value is false. Corresponds to the JSON property enable

Returns:

  • (Boolean)


6876
6877
6878
# File 'lib/google/apis/compute_alpha/classes.rb', line 6876

def enable
  @enable
end

#logging_http_request_headersArray<Google::Apis::ComputeAlpha::BackendServiceLogConfigLoggingHttpHeader>

The list of request headers that will be logged to Stackdriver. Corresponds to the JSON property loggingHttpRequestHeaders



6882
6883
6884
# File 'lib/google/apis/compute_alpha/classes.rb', line 6882

def logging_http_request_headers
  @logging_http_request_headers
end

#logging_http_response_headersArray<Google::Apis::ComputeAlpha::BackendServiceLogConfigLoggingHttpHeader>

The list of response headers that will be logged to Stackdriver. Corresponds to the JSON property loggingHttpResponseHeaders



6887
6888
6889
# File 'lib/google/apis/compute_alpha/classes.rb', line 6887

def logging_http_response_headers
  @logging_http_response_headers
end

#optionalString

Deprecated in favor of optionalMode. This field can only be specified if logging is enabled for this backend service. Configures whether all, none or a subset of optional fields should be added to the reported logs. One of [INCLUDE_ALL_OPTIONAL, EXCLUDE_ALL_OPTIONAL, CUSTOM]. Default is EXCLUDE_ALL_OPTIONAL. Corresponds to the JSON property optional

Returns:

  • (String)


6896
6897
6898
# File 'lib/google/apis/compute_alpha/classes.rb', line 6896

def optional
  @optional
end

#optional_fieldsArray<String>

This field can only be specified if logging is enabled for this backend service and "logConfig.optionalMode" was set to CUSTOM. Contains a list of optional fields you want to include in the logs. For example: serverInstance, serverGkeDetails.cluster, serverGkeDetails.pod.podNamespace Corresponds to the JSON property optionalFields

Returns:

  • (Array<String>)


6905
6906
6907
# File 'lib/google/apis/compute_alpha/classes.rb', line 6905

def optional_fields
  @optional_fields
end

#optional_modeString

This field can only be specified if logging is enabled for this backend service. Configures whether all, none or a subset of optional fields should be added to the reported logs. One of [INCLUDE_ALL_OPTIONAL, EXCLUDE_ALL_OPTIONAL, CUSTOM]. Default is EXCLUDE_ALL_OPTIONAL. Corresponds to the JSON property optionalMode

Returns:

  • (String)


6913
6914
6915
# File 'lib/google/apis/compute_alpha/classes.rb', line 6913

def optional_mode
  @optional_mode
end

#sample_rateFloat

This field can only be specified if logging is enabled for this backend service. The value of the field must be in [0, 1]. This configures the sampling rate of requests to the load balancer where 1.0 means all logged requests are reported and 0.0 means no logged requests are reported. The default value is 1.0. Corresponds to the JSON property sampleRate

Returns:

  • (Float)


6922
6923
6924
# File 'lib/google/apis/compute_alpha/classes.rb', line 6922

def sample_rate
  @sample_rate
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6929
6930
6931
6932
6933
6934
6935
6936
6937
# File 'lib/google/apis/compute_alpha/classes.rb', line 6929

def update!(**args)
  @enable = args[:enable] if args.key?(:enable)
  @logging_http_request_headers = args[:logging_http_request_headers] if args.key?(:logging_http_request_headers)
  @logging_http_response_headers = args[:logging_http_response_headers] if args.key?(:logging_http_response_headers)
  @optional = args[:optional] if args.key?(:optional)
  @optional_fields = args[:optional_fields] if args.key?(:optional_fields)
  @optional_mode = args[:optional_mode] if args.key?(:optional_mode)
  @sample_rate = args[:sample_rate] if args.key?(:sample_rate)
end