Class: Google::Apis::ComputeAlpha::BackendServiceNetworkPassThroughLbTrafficPolicy
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::BackendServiceNetworkPassThroughLbTrafficPolicy
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#zonal_affinity ⇒ Google::Apis::ComputeAlpha::BackendServiceNetworkPassThroughLbTrafficPolicyZonalAffinity
When configured, new connections are load balanced across healthy backend endpoints in the local zone.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BackendServiceNetworkPassThroughLbTrafficPolicy
constructor
A new instance of BackendServiceNetworkPassThroughLbTrafficPolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BackendServiceNetworkPassThroughLbTrafficPolicy
Returns a new instance of BackendServiceNetworkPassThroughLbTrafficPolicy.
6638 6639 6640 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 6638 def initialize(**args) update!(**args) end |
Instance Attribute Details
#zonal_affinity ⇒ Google::Apis::ComputeAlpha::BackendServiceNetworkPassThroughLbTrafficPolicyZonalAffinity
When configured, new connections are load balanced across healthy backend
endpoints in the local zone.
Corresponds to the JSON property zonalAffinity
6636 6637 6638 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 6636 def zonal_affinity @zonal_affinity end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6643 6644 6645 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 6643 def update!(**args) @zonal_affinity = args[:zonal_affinity] if args.key?(:zonal_affinity) end |