Class: Google::Apis::ComputeAlpha::BackendServiceNetworkPassThroughLbTrafficPolicyZonalAffinity

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BackendServiceNetworkPassThroughLbTrafficPolicyZonalAffinity

Returns a new instance of BackendServiceNetworkPassThroughLbTrafficPolicyZonalAffinity.



6684
6685
6686
# File 'lib/google/apis/compute_alpha/classes.rb', line 6684

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#spilloverString

This field indicates whether zonal affinity is enabled or not. The possible values are:

  • ZONAL_AFFINITY_DISABLED: Default Value. Zonal Affinity is disabled. The load balancer distributes new connections to all healthy backend endpoints across all zones.
  • ZONAL_AFFINITY_STAY_WITHIN_ZONE: Zonal Affinity is enabled. The load balancer distributes new connections to all healthy backend endpoints in the local zone only. If there are no healthy backend endpoints in the local zone, the load balancer distributes new connections to all backend endpoints in the local zone.
  • ZONAL_AFFINITY_SPILL_CROSS_ZONE: Zonal Affinity is enabled. The load balancer distributes new connections to all healthy backend endpoints in the local zone only. If there aren't enough healthy backend endpoints in the local zone, the load balancer distributes new connections to all healthy backend endpoints across all zones. Corresponds to the JSON property spillover

Returns:

  • (String)


6670
6671
6672
# File 'lib/google/apis/compute_alpha/classes.rb', line 6670

def spillover
  @spillover
end

#spillover_ratioFloat

The value of the field must be in [0, 1]. When the ratio of the count of healthy backend endpoints in a zone to the count of backend endpoints in that same zone is equal to or above this threshold, the load balancer distributes new connections to all healthy endpoints in the local zone only. When the ratio of the count of healthy backend endpoints in a zone to the count of backend endpoints in that same zone is below this threshold, the load balancer distributes all new connections to all healthy endpoints across all zones. Corresponds to the JSON property spilloverRatio

Returns:

  • (Float)


6682
6683
6684
# File 'lib/google/apis/compute_alpha/classes.rb', line 6682

def spillover_ratio
  @spillover_ratio
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6689
6690
6691
6692
# File 'lib/google/apis/compute_alpha/classes.rb', line 6689

def update!(**args)
  @spillover = args[:spillover] if args.key?(:spillover)
  @spillover_ratio = args[:spillover_ratio] if args.key?(:spillover_ratio)
end