Class: Google::Apis::ComputeAlpha::BackendServiceOrchestrationInfo

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

A message containing information about the resource or system that manages the backend service.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BackendServiceOrchestrationInfo

Returns a new instance of BackendServiceOrchestrationInfo.



6707
6708
6709
# File 'lib/google/apis/compute_alpha/classes.rb', line 6707

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#resource_uriString

The resource URI of the resource or system that manages the backend service. Corresponds to the JSON property resourceUri

Returns:

  • (String)


6705
6706
6707
# File 'lib/google/apis/compute_alpha/classes.rb', line 6705

def resource_uri
  @resource_uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6712
6713
6714
# File 'lib/google/apis/compute_alpha/classes.rb', line 6712

def update!(**args)
  @resource_uri = args[:resource_uri] if args.key?(:resource_uri)
end