Class: Google::Apis::ComputeAlpha::BfdPacket

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BfdPacket

Returns a new instance of BfdPacket.



7381
7382
7383
# File 'lib/google/apis/compute_alpha/classes.rb', line 7381

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#authentication_presentBoolean Also known as: authentication_present?

The Authentication Present bit of the BFD packet. This is specified in section 4.1 ofRFC5880 Corresponds to the JSON property authenticationPresent

Returns:

  • (Boolean)


7285
7286
7287
# File 'lib/google/apis/compute_alpha/classes.rb', line 7285

def authentication_present
  @authentication_present
end

#control_plane_independentBoolean Also known as: control_plane_independent?

The Control Plane Independent bit of the BFD packet. This is specified in section 4.1 ofRFC5880 Corresponds to the JSON property controlPlaneIndependent

Returns:

  • (Boolean)


7292
7293
7294
# File 'lib/google/apis/compute_alpha/classes.rb', line 7292

def control_plane_independent
  @control_plane_independent
end

#demandBoolean Also known as: demand?

The demand bit of the BFD packet. This is specified in section 4.1 ofRFC5880 Corresponds to the JSON property demand

Returns:

  • (Boolean)


7298
7299
7300
# File 'lib/google/apis/compute_alpha/classes.rb', line 7298

def demand
  @demand
end

#diagnosticString

The diagnostic code specifies the local system's reason for the last change in session state. This allows remote systems to determine the reason that the previous session failed, for example. These diagnostic codes are specified in section 4.1 ofRFC5880 Corresponds to the JSON property diagnostic

Returns:

  • (String)


7307
7308
7309
# File 'lib/google/apis/compute_alpha/classes.rb', line 7307

def diagnostic
  @diagnostic
end

#finalBoolean Also known as: final?

The Final bit of the BFD packet. This is specified in section 4.1 ofRFC5880 Corresponds to the JSON property final

Returns:

  • (Boolean)


7312
7313
7314
# File 'lib/google/apis/compute_alpha/classes.rb', line 7312

def final
  @final
end

#lengthFixnum

The length of the BFD Control packet in bytes. This is specified in section 4.1 ofRFC5880 Corresponds to the JSON property length

Returns:

  • (Fixnum)


7319
7320
7321
# File 'lib/google/apis/compute_alpha/classes.rb', line 7319

def length
  @length
end

#min_echo_rx_interval_msFixnum

The Required Min Echo RX Interval value in the BFD packet. This is specified in section 4.1 ofRFC5880 Corresponds to the JSON property minEchoRxIntervalMs

Returns:

  • (Fixnum)


7325
7326
7327
# File 'lib/google/apis/compute_alpha/classes.rb', line 7325

def min_echo_rx_interval_ms
  @min_echo_rx_interval_ms
end

#min_rx_interval_msFixnum

The Required Min RX Interval value in the BFD packet. This is specified in section 4.1 ofRFC5880 Corresponds to the JSON property minRxIntervalMs

Returns:

  • (Fixnum)


7331
7332
7333
# File 'lib/google/apis/compute_alpha/classes.rb', line 7331

def min_rx_interval_ms
  @min_rx_interval_ms
end

#min_tx_interval_msFixnum

The Desired Min TX Interval value in the BFD packet. This is specified in section 4.1 ofRFC5880 Corresponds to the JSON property minTxIntervalMs

Returns:

  • (Fixnum)


7337
7338
7339
# File 'lib/google/apis/compute_alpha/classes.rb', line 7337

def min_tx_interval_ms
  @min_tx_interval_ms
end

#multiplierFixnum

The detection time multiplier of the BFD packet. This is specified in section 4.1 ofRFC5880 Corresponds to the JSON property multiplier

Returns:

  • (Fixnum)


7343
7344
7345
# File 'lib/google/apis/compute_alpha/classes.rb', line 7343

def multiplier
  @multiplier
end

#multipointBoolean Also known as: multipoint?

The multipoint bit of the BFD packet. This is specified in section 4.1 ofRFC5880 Corresponds to the JSON property multipoint

Returns:

  • (Boolean)


7349
7350
7351
# File 'lib/google/apis/compute_alpha/classes.rb', line 7349

def multipoint
  @multipoint
end

#my_discriminatorFixnum

The My Discriminator value in the BFD packet. This is specified in section 4.1 ofRFC5880 Corresponds to the JSON property myDiscriminator

Returns:

  • (Fixnum)


7356
7357
7358
# File 'lib/google/apis/compute_alpha/classes.rb', line 7356

def my_discriminator
  @my_discriminator
end

#pollBoolean Also known as: poll?

The Poll bit of the BFD packet. This is specified in section 4.1 ofRFC5880 Corresponds to the JSON property poll

Returns:

  • (Boolean)


7361
7362
7363
# File 'lib/google/apis/compute_alpha/classes.rb', line 7361

def poll
  @poll
end

#stateString

The current BFD session state as seen by the transmitting system. These states are specified in section 4.1 ofRFC5880 Corresponds to the JSON property state

Returns:

  • (String)


7368
7369
7370
# File 'lib/google/apis/compute_alpha/classes.rb', line 7368

def state
  @state
end

#versionFixnum

The version number of the BFD protocol, as specified in section 4.1 ofRFC5880. Corresponds to the JSON property version

Returns:

  • (Fixnum)


7373
7374
7375
# File 'lib/google/apis/compute_alpha/classes.rb', line 7373

def version
  @version
end

#your_discriminatorFixnum

The Your Discriminator value in the BFD packet. This is specified in section 4.1 ofRFC5880 Corresponds to the JSON property yourDiscriminator

Returns:

  • (Fixnum)


7379
7380
7381
# File 'lib/google/apis/compute_alpha/classes.rb', line 7379

def your_discriminator
  @your_discriminator
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7386
7387
7388
7389
7390
7391
7392
7393
7394
7395
7396
7397
7398
7399
7400
7401
7402
7403
# File 'lib/google/apis/compute_alpha/classes.rb', line 7386

def update!(**args)
  @authentication_present = args[:authentication_present] if args.key?(:authentication_present)
  @control_plane_independent = args[:control_plane_independent] if args.key?(:control_plane_independent)
  @demand = args[:demand] if args.key?(:demand)
  @diagnostic = args[:diagnostic] if args.key?(:diagnostic)
  @final = args[:final] if args.key?(:final)
  @length = args[:length] if args.key?(:length)
  @min_echo_rx_interval_ms = args[:min_echo_rx_interval_ms] if args.key?(:min_echo_rx_interval_ms)
  @min_rx_interval_ms = args[:min_rx_interval_ms] if args.key?(:min_rx_interval_ms)
  @min_tx_interval_ms = args[:min_tx_interval_ms] if args.key?(:min_tx_interval_ms)
  @multiplier = args[:multiplier] if args.key?(:multiplier)
  @multipoint = args[:multipoint] if args.key?(:multipoint)
  @my_discriminator = args[:my_discriminator] if args.key?(:my_discriminator)
  @poll = args[:poll] if args.key?(:poll)
  @state = args[:state] if args.key?(:state)
  @version = args[:version] if args.key?(:version)
  @your_discriminator = args[:your_discriminator] if args.key?(:your_discriminator)
end