Class: Google::Apis::ComputeAlpha::BfdPacket

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BfdPacket

Returns a new instance of BfdPacket.



7115
7116
7117
# File 'lib/google/apis/compute_alpha/classes.rb', line 7115

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#authentication_presentBoolean Also known as: authentication_present?

The Authentication Present bit of the BFD packet. This is specified in section 4.1 ofRFC5880 Corresponds to the JSON property authenticationPresent

Returns:

  • (Boolean)


7019
7020
7021
# File 'lib/google/apis/compute_alpha/classes.rb', line 7019

def authentication_present
  @authentication_present
end

#control_plane_independentBoolean Also known as: control_plane_independent?

The Control Plane Independent bit of the BFD packet. This is specified in section 4.1 ofRFC5880 Corresponds to the JSON property controlPlaneIndependent

Returns:

  • (Boolean)


7026
7027
7028
# File 'lib/google/apis/compute_alpha/classes.rb', line 7026

def control_plane_independent
  @control_plane_independent
end

#demandBoolean Also known as: demand?

The demand bit of the BFD packet. This is specified in section 4.1 ofRFC5880 Corresponds to the JSON property demand

Returns:

  • (Boolean)


7032
7033
7034
# File 'lib/google/apis/compute_alpha/classes.rb', line 7032

def demand
  @demand
end

#diagnosticString

The diagnostic code specifies the local system's reason for the last change in session state. This allows remote systems to determine the reason that the previous session failed, for example. These diagnostic codes are specified in section 4.1 ofRFC5880 Corresponds to the JSON property diagnostic

Returns:

  • (String)


7041
7042
7043
# File 'lib/google/apis/compute_alpha/classes.rb', line 7041

def diagnostic
  @diagnostic
end

#finalBoolean Also known as: final?

The Final bit of the BFD packet. This is specified in section 4.1 ofRFC5880 Corresponds to the JSON property final

Returns:

  • (Boolean)


7046
7047
7048
# File 'lib/google/apis/compute_alpha/classes.rb', line 7046

def final
  @final
end

#lengthFixnum

The length of the BFD Control packet in bytes. This is specified in section 4.1 ofRFC5880 Corresponds to the JSON property length

Returns:

  • (Fixnum)


7053
7054
7055
# File 'lib/google/apis/compute_alpha/classes.rb', line 7053

def length
  @length
end

#min_echo_rx_interval_msFixnum

The Required Min Echo RX Interval value in the BFD packet. This is specified in section 4.1 ofRFC5880 Corresponds to the JSON property minEchoRxIntervalMs

Returns:

  • (Fixnum)


7059
7060
7061
# File 'lib/google/apis/compute_alpha/classes.rb', line 7059

def min_echo_rx_interval_ms
  @min_echo_rx_interval_ms
end

#min_rx_interval_msFixnum

The Required Min RX Interval value in the BFD packet. This is specified in section 4.1 ofRFC5880 Corresponds to the JSON property minRxIntervalMs

Returns:

  • (Fixnum)


7065
7066
7067
# File 'lib/google/apis/compute_alpha/classes.rb', line 7065

def min_rx_interval_ms
  @min_rx_interval_ms
end

#min_tx_interval_msFixnum

The Desired Min TX Interval value in the BFD packet. This is specified in section 4.1 ofRFC5880 Corresponds to the JSON property minTxIntervalMs

Returns:

  • (Fixnum)


7071
7072
7073
# File 'lib/google/apis/compute_alpha/classes.rb', line 7071

def min_tx_interval_ms
  @min_tx_interval_ms
end

#multiplierFixnum

The detection time multiplier of the BFD packet. This is specified in section 4.1 ofRFC5880 Corresponds to the JSON property multiplier

Returns:

  • (Fixnum)


7077
7078
7079
# File 'lib/google/apis/compute_alpha/classes.rb', line 7077

def multiplier
  @multiplier
end

#multipointBoolean Also known as: multipoint?

The multipoint bit of the BFD packet. This is specified in section 4.1 ofRFC5880 Corresponds to the JSON property multipoint

Returns:

  • (Boolean)


7083
7084
7085
# File 'lib/google/apis/compute_alpha/classes.rb', line 7083

def multipoint
  @multipoint
end

#my_discriminatorFixnum

The My Discriminator value in the BFD packet. This is specified in section 4.1 ofRFC5880 Corresponds to the JSON property myDiscriminator

Returns:

  • (Fixnum)


7090
7091
7092
# File 'lib/google/apis/compute_alpha/classes.rb', line 7090

def my_discriminator
  @my_discriminator
end

#pollBoolean Also known as: poll?

The Poll bit of the BFD packet. This is specified in section 4.1 ofRFC5880 Corresponds to the JSON property poll

Returns:

  • (Boolean)


7095
7096
7097
# File 'lib/google/apis/compute_alpha/classes.rb', line 7095

def poll
  @poll
end

#stateString

The current BFD session state as seen by the transmitting system. These states are specified in section 4.1 ofRFC5880 Corresponds to the JSON property state

Returns:

  • (String)


7102
7103
7104
# File 'lib/google/apis/compute_alpha/classes.rb', line 7102

def state
  @state
end

#versionFixnum

The version number of the BFD protocol, as specified in section 4.1 ofRFC5880. Corresponds to the JSON property version

Returns:

  • (Fixnum)


7107
7108
7109
# File 'lib/google/apis/compute_alpha/classes.rb', line 7107

def version
  @version
end

#your_discriminatorFixnum

The Your Discriminator value in the BFD packet. This is specified in section 4.1 ofRFC5880 Corresponds to the JSON property yourDiscriminator

Returns:

  • (Fixnum)


7113
7114
7115
# File 'lib/google/apis/compute_alpha/classes.rb', line 7113

def your_discriminator
  @your_discriminator
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7120
7121
7122
7123
7124
7125
7126
7127
7128
7129
7130
7131
7132
7133
7134
7135
7136
7137
# File 'lib/google/apis/compute_alpha/classes.rb', line 7120

def update!(**args)
  @authentication_present = args[:authentication_present] if args.key?(:authentication_present)
  @control_plane_independent = args[:control_plane_independent] if args.key?(:control_plane_independent)
  @demand = args[:demand] if args.key?(:demand)
  @diagnostic = args[:diagnostic] if args.key?(:diagnostic)
  @final = args[:final] if args.key?(:final)
  @length = args[:length] if args.key?(:length)
  @min_echo_rx_interval_ms = args[:min_echo_rx_interval_ms] if args.key?(:min_echo_rx_interval_ms)
  @min_rx_interval_ms = args[:min_rx_interval_ms] if args.key?(:min_rx_interval_ms)
  @min_tx_interval_ms = args[:min_tx_interval_ms] if args.key?(:min_tx_interval_ms)
  @multiplier = args[:multiplier] if args.key?(:multiplier)
  @multipoint = args[:multipoint] if args.key?(:multipoint)
  @my_discriminator = args[:my_discriminator] if args.key?(:my_discriminator)
  @poll = args[:poll] if args.key?(:poll)
  @state = args[:state] if args.key?(:state)
  @version = args[:version] if args.key?(:version)
  @your_discriminator = args[:your_discriminator] if args.key?(:your_discriminator)
end