Class: Google::Apis::ComputeAlpha::BfdPacket
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::BfdPacket
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#authentication_present ⇒ Boolean
(also: #authentication_present?)
The Authentication Present bit of the BFD packet.
-
#control_plane_independent ⇒ Boolean
(also: #control_plane_independent?)
The Control Plane Independent bit of the BFD packet.
-
#demand ⇒ Boolean
(also: #demand?)
The demand bit of the BFD packet.
-
#diagnostic ⇒ String
The diagnostic code specifies the local system's reason for the last change in session state.
-
#final ⇒ Boolean
(also: #final?)
The Final bit of the BFD packet.
-
#length ⇒ Fixnum
The length of the BFD Control packet in bytes.
-
#min_echo_rx_interval_ms ⇒ Fixnum
The Required Min Echo RX Interval value in the BFD packet.
-
#min_rx_interval_ms ⇒ Fixnum
The Required Min RX Interval value in the BFD packet.
-
#min_tx_interval_ms ⇒ Fixnum
The Desired Min TX Interval value in the BFD packet.
-
#multiplier ⇒ Fixnum
The detection time multiplier of the BFD packet.
-
#multipoint ⇒ Boolean
(also: #multipoint?)
The multipoint bit of the BFD packet.
-
#my_discriminator ⇒ Fixnum
The My Discriminator value in the BFD packet.
-
#poll ⇒ Boolean
(also: #poll?)
The Poll bit of the BFD packet.
-
#state ⇒ String
The current BFD session state as seen by the transmitting system.
-
#version ⇒ Fixnum
The version number of the BFD protocol, as specified in section 4.1 ofRFC5880.
-
#your_discriminator ⇒ Fixnum
The Your Discriminator value in the BFD packet.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BfdPacket
constructor
A new instance of BfdPacket.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BfdPacket
Returns a new instance of BfdPacket.
7116 7117 7118 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 7116 def initialize(**args) update!(**args) end |
Instance Attribute Details
#authentication_present ⇒ Boolean Also known as: authentication_present?
The Authentication Present bit of the BFD packet. This is specified in
section 4.1 ofRFC5880
Corresponds to the JSON property authenticationPresent
7020 7021 7022 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 7020 def authentication_present @authentication_present end |
#control_plane_independent ⇒ Boolean Also known as: control_plane_independent?
The Control Plane Independent bit of the BFD packet. This is specified in
section 4.1 ofRFC5880
Corresponds to the JSON property controlPlaneIndependent
7027 7028 7029 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 7027 def control_plane_independent @control_plane_independent end |
#demand ⇒ Boolean Also known as: demand?
The demand bit of the BFD packet. This is specified in section 4.1 ofRFC5880
Corresponds to the JSON property demand
7033 7034 7035 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 7033 def demand @demand end |
#diagnostic ⇒ String
The diagnostic code specifies the local system's reason for the last change
in session state. This allows remote systems to determine the reason that
the previous session failed, for example. These diagnostic codes are
specified in section 4.1 ofRFC5880
Corresponds to the JSON property diagnostic
7042 7043 7044 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 7042 def diagnostic @diagnostic end |
#final ⇒ Boolean Also known as: final?
The Final bit of the BFD packet. This is specified in section 4.1 ofRFC5880
Corresponds to the JSON property final
7047 7048 7049 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 7047 def final @final end |
#length ⇒ Fixnum
The length of the BFD Control packet in bytes. This is specified in section
4.1 ofRFC5880
Corresponds to the JSON property length
7054 7055 7056 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 7054 def length @length end |
#min_echo_rx_interval_ms ⇒ Fixnum
The Required Min Echo RX Interval value in the BFD packet. This is
specified in section 4.1 ofRFC5880
Corresponds to the JSON property minEchoRxIntervalMs
7060 7061 7062 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 7060 def min_echo_rx_interval_ms @min_echo_rx_interval_ms end |
#min_rx_interval_ms ⇒ Fixnum
The Required Min RX Interval value in the BFD packet. This is specified in
section 4.1 ofRFC5880
Corresponds to the JSON property minRxIntervalMs
7066 7067 7068 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 7066 def min_rx_interval_ms @min_rx_interval_ms end |
#min_tx_interval_ms ⇒ Fixnum
The Desired Min TX Interval value in the BFD packet. This is specified in
section 4.1 ofRFC5880
Corresponds to the JSON property minTxIntervalMs
7072 7073 7074 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 7072 def min_tx_interval_ms @min_tx_interval_ms end |
#multiplier ⇒ Fixnum
The detection time multiplier of the BFD packet. This is specified in
section 4.1 ofRFC5880
Corresponds to the JSON property multiplier
7078 7079 7080 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 7078 def multiplier @multiplier end |
#multipoint ⇒ Boolean Also known as: multipoint?
The multipoint bit of the BFD packet. This is specified in section 4.1
ofRFC5880
Corresponds to the JSON property multipoint
7084 7085 7086 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 7084 def multipoint @multipoint end |
#my_discriminator ⇒ Fixnum
The My Discriminator value in the BFD packet. This is specified in section
4.1 ofRFC5880
Corresponds to the JSON property myDiscriminator
7091 7092 7093 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 7091 def my_discriminator @my_discriminator end |
#poll ⇒ Boolean Also known as: poll?
The Poll bit of the BFD packet. This is specified in section 4.1 ofRFC5880
Corresponds to the JSON property poll
7096 7097 7098 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 7096 def poll @poll end |
#state ⇒ String
The current BFD session state as seen by the transmitting system. These
states are specified in section 4.1 ofRFC5880
Corresponds to the JSON property state
7103 7104 7105 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 7103 def state @state end |
#version ⇒ Fixnum
The version number of the BFD protocol, as specified in section 4.1 ofRFC5880.
Corresponds to the JSON property version
7108 7109 7110 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 7108 def version @version end |
#your_discriminator ⇒ Fixnum
The Your Discriminator value in the BFD packet. This is specified in
section 4.1 ofRFC5880
Corresponds to the JSON property yourDiscriminator
7114 7115 7116 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 7114 def your_discriminator @your_discriminator end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7121 7122 7123 7124 7125 7126 7127 7128 7129 7130 7131 7132 7133 7134 7135 7136 7137 7138 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 7121 def update!(**args) @authentication_present = args[:authentication_present] if args.key?(:authentication_present) @control_plane_independent = args[:control_plane_independent] if args.key?(:control_plane_independent) @demand = args[:demand] if args.key?(:demand) @diagnostic = args[:diagnostic] if args.key?(:diagnostic) @final = args[:final] if args.key?(:final) @length = args[:length] if args.key?(:length) @min_echo_rx_interval_ms = args[:min_echo_rx_interval_ms] if args.key?(:min_echo_rx_interval_ms) @min_rx_interval_ms = args[:min_rx_interval_ms] if args.key?(:min_rx_interval_ms) @min_tx_interval_ms = args[:min_tx_interval_ms] if args.key?(:min_tx_interval_ms) @multiplier = args[:multiplier] if args.key?(:multiplier) @multipoint = args[:multipoint] if args.key?(:multipoint) @my_discriminator = args[:my_discriminator] if args.key?(:my_discriminator) @poll = args[:poll] if args.key?(:poll) @state = args[:state] if args.key?(:state) @version = args[:version] if args.key?(:version) @your_discriminator = args[:your_discriminator] if args.key?(:your_discriminator) end |