Class: Google::Apis::ComputeAlpha::BfdStatus

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Next free: 15

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BfdStatus

Returns a new instance of BfdStatus.



7555
7556
7557
# File 'lib/google/apis/compute_alpha/classes.rb', line 7555

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bfd_session_initialization_modeString

The BFD session initialization mode for this BGP peer. If set to ACTIVE, the Cloud Router will initiate the BFD session for this BGP peer. If set to PASSIVE, the Cloud Router will wait for the peer router to initiate the BFD session for this BGP peer. If set to DISABLED, BFD is disabled for this BGP peer. Corresponds to the JSON property bfdSessionInitializationMode

Returns:

  • (String)


7483
7484
7485
# File 'lib/google/apis/compute_alpha/classes.rb', line 7483

def bfd_session_initialization_mode
  @bfd_session_initialization_mode
end

#config_update_timestamp_microsFixnum

Unix timestamp of the most recent config update. Corresponds to the JSON property configUpdateTimestampMicros

Returns:

  • (Fixnum)


7488
7489
7490
# File 'lib/google/apis/compute_alpha/classes.rb', line 7488

def config_update_timestamp_micros
  @config_update_timestamp_micros
end

#control_packet_countsGoogle::Apis::ComputeAlpha::BfdStatusPacketCounts

Control packet counts for the current BFD session. Corresponds to the JSON property controlPacketCounts



7493
7494
7495
# File 'lib/google/apis/compute_alpha/classes.rb', line 7493

def control_packet_counts
  @control_packet_counts
end

#control_packet_intervalsArray<Google::Apis::ComputeAlpha::PacketIntervals>

Inter-packet time interval statistics for control packets. Corresponds to the JSON property controlPacketIntervals



7498
7499
7500
# File 'lib/google/apis/compute_alpha/classes.rb', line 7498

def control_packet_intervals
  @control_packet_intervals
end

#echo_packet_countsGoogle::Apis::ComputeAlpha::BfdStatusPacketCounts

Echo packet counts for the current BFD session. Corresponds to the JSON property echoPacketCounts



7503
7504
7505
# File 'lib/google/apis/compute_alpha/classes.rb', line 7503

def echo_packet_counts
  @echo_packet_counts
end

#echo_packet_intervalsArray<Google::Apis::ComputeAlpha::PacketIntervals>

Inter-packet time interval statistics for echo packets. Corresponds to the JSON property echoPacketIntervals



7508
7509
7510
# File 'lib/google/apis/compute_alpha/classes.rb', line 7508

def echo_packet_intervals
  @echo_packet_intervals
end

#local_diagnosticString

The diagnostic code specifies the local system's reason for the last change in session state. This allows remote systems to determine the reason that the previous session failed, for example. These diagnostic codes are specified in section 4.1 ofRFC5880 Corresponds to the JSON property localDiagnostic

Returns:

  • (String)


7516
7517
7518
# File 'lib/google/apis/compute_alpha/classes.rb', line 7516

def local_diagnostic
  @local_diagnostic
end

#local_stateString

The current BFD session state as seen by the transmitting system. These states are specified in section 4.1 ofRFC5880 Corresponds to the JSON property localState

Returns:

  • (String)


7522
7523
7524
# File 'lib/google/apis/compute_alpha/classes.rb', line 7522

def local_state
  @local_state
end

#negotiated_local_control_tx_interval_msFixnum

Negotiated transmit interval for control packets. Corresponds to the JSON property negotiatedLocalControlTxIntervalMs

Returns:

  • (Fixnum)


7527
7528
7529
# File 'lib/google/apis/compute_alpha/classes.rb', line 7527

def negotiated_local_control_tx_interval_ms
  @negotiated_local_control_tx_interval_ms
end

#negotiated_local_echo_tx_interval_msFixnum

Negotiated transmit interval for echo packets. Corresponds to the JSON property negotiatedLocalEchoTxIntervalMs

Returns:

  • (Fixnum)


7532
7533
7534
# File 'lib/google/apis/compute_alpha/classes.rb', line 7532

def negotiated_local_echo_tx_interval_ms
  @negotiated_local_echo_tx_interval_ms
end

#rx_packetGoogle::Apis::ComputeAlpha::BfdPacket

The most recent Rx control packet for this BFD session. Corresponds to the JSON property rxPacket



7537
7538
7539
# File 'lib/google/apis/compute_alpha/classes.rb', line 7537

def rx_packet
  @rx_packet
end

#tx_packetGoogle::Apis::ComputeAlpha::BfdPacket

The most recent Tx control packet for this BFD session. Corresponds to the JSON property txPacket



7542
7543
7544
# File 'lib/google/apis/compute_alpha/classes.rb', line 7542

def tx_packet
  @tx_packet
end

#uptime_msFixnum

Session uptime in milliseconds. Value will be 0 if session is not up. Corresponds to the JSON property uptimeMs

Returns:

  • (Fixnum)


7547
7548
7549
# File 'lib/google/apis/compute_alpha/classes.rb', line 7547

def uptime_ms
  @uptime_ms
end

#using_echo_modeBoolean Also known as: using_echo_mode?

Indicates if echo mode is currently being used. Corresponds to the JSON property usingEchoMode

Returns:

  • (Boolean)


7552
7553
7554
# File 'lib/google/apis/compute_alpha/classes.rb', line 7552

def using_echo_mode
  @using_echo_mode
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7560
7561
7562
7563
7564
7565
7566
7567
7568
7569
7570
7571
7572
7573
7574
7575
# File 'lib/google/apis/compute_alpha/classes.rb', line 7560

def update!(**args)
  @bfd_session_initialization_mode = args[:bfd_session_initialization_mode] if args.key?(:bfd_session_initialization_mode)
  @config_update_timestamp_micros = args[:config_update_timestamp_micros] if args.key?(:config_update_timestamp_micros)
  @control_packet_counts = args[:control_packet_counts] if args.key?(:control_packet_counts)
  @control_packet_intervals = args[:control_packet_intervals] if args.key?(:control_packet_intervals)
  @echo_packet_counts = args[:echo_packet_counts] if args.key?(:echo_packet_counts)
  @echo_packet_intervals = args[:echo_packet_intervals] if args.key?(:echo_packet_intervals)
  @local_diagnostic = args[:local_diagnostic] if args.key?(:local_diagnostic)
  @local_state = args[:local_state] if args.key?(:local_state)
  @negotiated_local_control_tx_interval_ms = args[:negotiated_local_control_tx_interval_ms] if args.key?(:negotiated_local_control_tx_interval_ms)
  @negotiated_local_echo_tx_interval_ms = args[:negotiated_local_echo_tx_interval_ms] if args.key?(:negotiated_local_echo_tx_interval_ms)
  @rx_packet = args[:rx_packet] if args.key?(:rx_packet)
  @tx_packet = args[:tx_packet] if args.key?(:tx_packet)
  @uptime_ms = args[:uptime_ms] if args.key?(:uptime_ms)
  @using_echo_mode = args[:using_echo_mode] if args.key?(:using_echo_mode)
end