Class: Google::Apis::ComputeAlpha::BfdStatus
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::BfdStatus
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Next free: 15
Instance Attribute Summary collapse
-
#bfd_session_initialization_mode ⇒ String
The BFD session initialization mode for this BGP peer.
-
#config_update_timestamp_micros ⇒ Fixnum
Unix timestamp of the most recent config update.
-
#control_packet_counts ⇒ Google::Apis::ComputeAlpha::BfdStatusPacketCounts
Control packet counts for the current BFD session.
-
#control_packet_intervals ⇒ Array<Google::Apis::ComputeAlpha::PacketIntervals>
Inter-packet time interval statistics for control packets.
-
#echo_packet_counts ⇒ Google::Apis::ComputeAlpha::BfdStatusPacketCounts
Echo packet counts for the current BFD session.
-
#echo_packet_intervals ⇒ Array<Google::Apis::ComputeAlpha::PacketIntervals>
Inter-packet time interval statistics for echo packets.
-
#local_diagnostic ⇒ String
The diagnostic code specifies the local system's reason for the last change in session state.
-
#local_state ⇒ String
The current BFD session state as seen by the transmitting system.
-
#negotiated_local_control_tx_interval_ms ⇒ Fixnum
Negotiated transmit interval for control packets.
-
#negotiated_local_echo_tx_interval_ms ⇒ Fixnum
Negotiated transmit interval for echo packets.
-
#rx_packet ⇒ Google::Apis::ComputeAlpha::BfdPacket
The most recent Rx control packet for this BFD session.
-
#tx_packet ⇒ Google::Apis::ComputeAlpha::BfdPacket
The most recent Tx control packet for this BFD session.
-
#uptime_ms ⇒ Fixnum
Session uptime in milliseconds.
-
#using_echo_mode ⇒ Boolean
(also: #using_echo_mode?)
Indicates if echo mode is currently being used.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BfdStatus
constructor
A new instance of BfdStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BfdStatus
Returns a new instance of BfdStatus.
7489 7490 7491 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 7489 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bfd_session_initialization_mode ⇒ String
The BFD session initialization mode for this BGP peer.
If set to ACTIVE, the Cloud Router will initiate the BFD session for
this BGP peer. If set to PASSIVE, the Cloud Router will wait for the
peer router to initiate the BFD session for this BGP peer. If set to
DISABLED, BFD is disabled for this BGP peer.
Corresponds to the JSON property bfdSessionInitializationMode
7417 7418 7419 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 7417 def bfd_session_initialization_mode @bfd_session_initialization_mode end |
#config_update_timestamp_micros ⇒ Fixnum
Unix timestamp of the most recent config update.
Corresponds to the JSON property configUpdateTimestampMicros
7422 7423 7424 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 7422 def @config_update_timestamp_micros end |
#control_packet_counts ⇒ Google::Apis::ComputeAlpha::BfdStatusPacketCounts
Control packet counts for the current BFD session.
Corresponds to the JSON property controlPacketCounts
7427 7428 7429 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 7427 def control_packet_counts @control_packet_counts end |
#control_packet_intervals ⇒ Array<Google::Apis::ComputeAlpha::PacketIntervals>
Inter-packet time interval statistics for control packets.
Corresponds to the JSON property controlPacketIntervals
7432 7433 7434 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 7432 def control_packet_intervals @control_packet_intervals end |
#echo_packet_counts ⇒ Google::Apis::ComputeAlpha::BfdStatusPacketCounts
Echo packet counts for the current BFD session.
Corresponds to the JSON property echoPacketCounts
7437 7438 7439 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 7437 def echo_packet_counts @echo_packet_counts end |
#echo_packet_intervals ⇒ Array<Google::Apis::ComputeAlpha::PacketIntervals>
Inter-packet time interval statistics for echo packets.
Corresponds to the JSON property echoPacketIntervals
7442 7443 7444 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 7442 def echo_packet_intervals @echo_packet_intervals end |
#local_diagnostic ⇒ String
The diagnostic code specifies the local system's reason for the last change
in session state. This allows remote systems to determine the reason that
the previous session failed, for example. These diagnostic codes are
specified in section 4.1 ofRFC5880
Corresponds to the JSON property localDiagnostic
7450 7451 7452 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 7450 def local_diagnostic @local_diagnostic end |
#local_state ⇒ String
The current BFD session state as seen by the transmitting system. These
states are specified in section 4.1 ofRFC5880
Corresponds to the JSON property localState
7456 7457 7458 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 7456 def local_state @local_state end |
#negotiated_local_control_tx_interval_ms ⇒ Fixnum
Negotiated transmit interval for control packets.
Corresponds to the JSON property negotiatedLocalControlTxIntervalMs
7461 7462 7463 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 7461 def negotiated_local_control_tx_interval_ms @negotiated_local_control_tx_interval_ms end |
#negotiated_local_echo_tx_interval_ms ⇒ Fixnum
Negotiated transmit interval for echo packets.
Corresponds to the JSON property negotiatedLocalEchoTxIntervalMs
7466 7467 7468 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 7466 def negotiated_local_echo_tx_interval_ms @negotiated_local_echo_tx_interval_ms end |
#rx_packet ⇒ Google::Apis::ComputeAlpha::BfdPacket
The most recent Rx control packet for this BFD session.
Corresponds to the JSON property rxPacket
7471 7472 7473 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 7471 def rx_packet @rx_packet end |
#tx_packet ⇒ Google::Apis::ComputeAlpha::BfdPacket
The most recent Tx control packet for this BFD session.
Corresponds to the JSON property txPacket
7476 7477 7478 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 7476 def tx_packet @tx_packet end |
#uptime_ms ⇒ Fixnum
Session uptime in milliseconds. Value will be 0 if session is not up.
Corresponds to the JSON property uptimeMs
7481 7482 7483 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 7481 def uptime_ms @uptime_ms end |
#using_echo_mode ⇒ Boolean Also known as: using_echo_mode?
Indicates if echo mode is currently being used.
Corresponds to the JSON property usingEchoMode
7486 7487 7488 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 7486 def using_echo_mode @using_echo_mode end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7494 7495 7496 7497 7498 7499 7500 7501 7502 7503 7504 7505 7506 7507 7508 7509 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 7494 def update!(**args) @bfd_session_initialization_mode = args[:bfd_session_initialization_mode] if args.key?(:bfd_session_initialization_mode) @config_update_timestamp_micros = args[:config_update_timestamp_micros] if args.key?(:config_update_timestamp_micros) @control_packet_counts = args[:control_packet_counts] if args.key?(:control_packet_counts) @control_packet_intervals = args[:control_packet_intervals] if args.key?(:control_packet_intervals) @echo_packet_counts = args[:echo_packet_counts] if args.key?(:echo_packet_counts) @echo_packet_intervals = args[:echo_packet_intervals] if args.key?(:echo_packet_intervals) @local_diagnostic = args[:local_diagnostic] if args.key?(:local_diagnostic) @local_state = args[:local_state] if args.key?(:local_state) @negotiated_local_control_tx_interval_ms = args[:negotiated_local_control_tx_interval_ms] if args.key?(:negotiated_local_control_tx_interval_ms) @negotiated_local_echo_tx_interval_ms = args[:negotiated_local_echo_tx_interval_ms] if args.key?(:negotiated_local_echo_tx_interval_ms) @rx_packet = args[:rx_packet] if args.key?(:rx_packet) @tx_packet = args[:tx_packet] if args.key?(:tx_packet) @uptime_ms = args[:uptime_ms] if args.key?(:uptime_ms) @using_echo_mode = args[:using_echo_mode] if args.key?(:using_echo_mode) end |