Class: Google::Apis::ComputeAlpha::BfdStatus

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Next free: 15

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BfdStatus

Returns a new instance of BfdStatus.



7237
7238
7239
# File 'lib/google/apis/compute_alpha/classes.rb', line 7237

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bfd_session_initialization_modeString

The BFD session initialization mode for this BGP peer. If set to ACTIVE, the Cloud Router will initiate the BFD session for this BGP peer. If set to PASSIVE, the Cloud Router will wait for the peer router to initiate the BFD session for this BGP peer. If set to DISABLED, BFD is disabled for this BGP peer. Corresponds to the JSON property bfdSessionInitializationMode

Returns:

  • (String)


7165
7166
7167
# File 'lib/google/apis/compute_alpha/classes.rb', line 7165

def bfd_session_initialization_mode
  @bfd_session_initialization_mode
end

#config_update_timestamp_microsFixnum

Unix timestamp of the most recent config update. Corresponds to the JSON property configUpdateTimestampMicros

Returns:

  • (Fixnum)


7170
7171
7172
# File 'lib/google/apis/compute_alpha/classes.rb', line 7170

def config_update_timestamp_micros
  @config_update_timestamp_micros
end

#control_packet_countsGoogle::Apis::ComputeAlpha::BfdStatusPacketCounts

Control packet counts for the current BFD session. Corresponds to the JSON property controlPacketCounts



7175
7176
7177
# File 'lib/google/apis/compute_alpha/classes.rb', line 7175

def control_packet_counts
  @control_packet_counts
end

#control_packet_intervalsArray<Google::Apis::ComputeAlpha::PacketIntervals>

Inter-packet time interval statistics for control packets. Corresponds to the JSON property controlPacketIntervals



7180
7181
7182
# File 'lib/google/apis/compute_alpha/classes.rb', line 7180

def control_packet_intervals
  @control_packet_intervals
end

#echo_packet_countsGoogle::Apis::ComputeAlpha::BfdStatusPacketCounts

Echo packet counts for the current BFD session. Corresponds to the JSON property echoPacketCounts



7185
7186
7187
# File 'lib/google/apis/compute_alpha/classes.rb', line 7185

def echo_packet_counts
  @echo_packet_counts
end

#echo_packet_intervalsArray<Google::Apis::ComputeAlpha::PacketIntervals>

Inter-packet time interval statistics for echo packets. Corresponds to the JSON property echoPacketIntervals



7190
7191
7192
# File 'lib/google/apis/compute_alpha/classes.rb', line 7190

def echo_packet_intervals
  @echo_packet_intervals
end

#local_diagnosticString

The diagnostic code specifies the local system's reason for the last change in session state. This allows remote systems to determine the reason that the previous session failed, for example. These diagnostic codes are specified in section 4.1 ofRFC5880 Corresponds to the JSON property localDiagnostic

Returns:

  • (String)


7198
7199
7200
# File 'lib/google/apis/compute_alpha/classes.rb', line 7198

def local_diagnostic
  @local_diagnostic
end

#local_stateString

The current BFD session state as seen by the transmitting system. These states are specified in section 4.1 ofRFC5880 Corresponds to the JSON property localState

Returns:

  • (String)


7204
7205
7206
# File 'lib/google/apis/compute_alpha/classes.rb', line 7204

def local_state
  @local_state
end

#negotiated_local_control_tx_interval_msFixnum

Negotiated transmit interval for control packets. Corresponds to the JSON property negotiatedLocalControlTxIntervalMs

Returns:

  • (Fixnum)


7209
7210
7211
# File 'lib/google/apis/compute_alpha/classes.rb', line 7209

def negotiated_local_control_tx_interval_ms
  @negotiated_local_control_tx_interval_ms
end

#negotiated_local_echo_tx_interval_msFixnum

Negotiated transmit interval for echo packets. Corresponds to the JSON property negotiatedLocalEchoTxIntervalMs

Returns:

  • (Fixnum)


7214
7215
7216
# File 'lib/google/apis/compute_alpha/classes.rb', line 7214

def negotiated_local_echo_tx_interval_ms
  @negotiated_local_echo_tx_interval_ms
end

#rx_packetGoogle::Apis::ComputeAlpha::BfdPacket

The most recent Rx control packet for this BFD session. Corresponds to the JSON property rxPacket



7219
7220
7221
# File 'lib/google/apis/compute_alpha/classes.rb', line 7219

def rx_packet
  @rx_packet
end

#tx_packetGoogle::Apis::ComputeAlpha::BfdPacket

The most recent Tx control packet for this BFD session. Corresponds to the JSON property txPacket



7224
7225
7226
# File 'lib/google/apis/compute_alpha/classes.rb', line 7224

def tx_packet
  @tx_packet
end

#uptime_msFixnum

Session uptime in milliseconds. Value will be 0 if session is not up. Corresponds to the JSON property uptimeMs

Returns:

  • (Fixnum)


7229
7230
7231
# File 'lib/google/apis/compute_alpha/classes.rb', line 7229

def uptime_ms
  @uptime_ms
end

#using_echo_modeBoolean Also known as: using_echo_mode?

Indicates if echo mode is currently being used. Corresponds to the JSON property usingEchoMode

Returns:

  • (Boolean)


7234
7235
7236
# File 'lib/google/apis/compute_alpha/classes.rb', line 7234

def using_echo_mode
  @using_echo_mode
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7242
7243
7244
7245
7246
7247
7248
7249
7250
7251
7252
7253
7254
7255
7256
7257
# File 'lib/google/apis/compute_alpha/classes.rb', line 7242

def update!(**args)
  @bfd_session_initialization_mode = args[:bfd_session_initialization_mode] if args.key?(:bfd_session_initialization_mode)
  @config_update_timestamp_micros = args[:config_update_timestamp_micros] if args.key?(:config_update_timestamp_micros)
  @control_packet_counts = args[:control_packet_counts] if args.key?(:control_packet_counts)
  @control_packet_intervals = args[:control_packet_intervals] if args.key?(:control_packet_intervals)
  @echo_packet_counts = args[:echo_packet_counts] if args.key?(:echo_packet_counts)
  @echo_packet_intervals = args[:echo_packet_intervals] if args.key?(:echo_packet_intervals)
  @local_diagnostic = args[:local_diagnostic] if args.key?(:local_diagnostic)
  @local_state = args[:local_state] if args.key?(:local_state)
  @negotiated_local_control_tx_interval_ms = args[:negotiated_local_control_tx_interval_ms] if args.key?(:negotiated_local_control_tx_interval_ms)
  @negotiated_local_echo_tx_interval_ms = args[:negotiated_local_echo_tx_interval_ms] if args.key?(:negotiated_local_echo_tx_interval_ms)
  @rx_packet = args[:rx_packet] if args.key?(:rx_packet)
  @tx_packet = args[:tx_packet] if args.key?(:tx_packet)
  @uptime_ms = args[:uptime_ms] if args.key?(:uptime_ms)
  @using_echo_mode = args[:using_echo_mode] if args.key?(:using_echo_mode)
end