Class: Google::Apis::ComputeAlpha::BfdStatus
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::BfdStatus
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Next free: 15
Instance Attribute Summary collapse
-
#bfd_session_initialization_mode ⇒ String
The BFD session initialization mode for this BGP peer.
-
#config_update_timestamp_micros ⇒ Fixnum
Unix timestamp of the most recent config update.
-
#control_packet_counts ⇒ Google::Apis::ComputeAlpha::BfdStatusPacketCounts
Control packet counts for the current BFD session.
-
#control_packet_intervals ⇒ Array<Google::Apis::ComputeAlpha::PacketIntervals>
Inter-packet time interval statistics for control packets.
-
#echo_packet_counts ⇒ Google::Apis::ComputeAlpha::BfdStatusPacketCounts
Echo packet counts for the current BFD session.
-
#echo_packet_intervals ⇒ Array<Google::Apis::ComputeAlpha::PacketIntervals>
Inter-packet time interval statistics for echo packets.
-
#local_diagnostic ⇒ String
The diagnostic code specifies the local system's reason for the last change in session state.
-
#local_state ⇒ String
The current BFD session state as seen by the transmitting system.
-
#negotiated_local_control_tx_interval_ms ⇒ Fixnum
Negotiated transmit interval for control packets.
-
#negotiated_local_echo_tx_interval_ms ⇒ Fixnum
Negotiated transmit interval for echo packets.
-
#rx_packet ⇒ Google::Apis::ComputeAlpha::BfdPacket
The most recent Rx control packet for this BFD session.
-
#tx_packet ⇒ Google::Apis::ComputeAlpha::BfdPacket
The most recent Tx control packet for this BFD session.
-
#uptime_ms ⇒ Fixnum
Session uptime in milliseconds.
-
#using_echo_mode ⇒ Boolean
(also: #using_echo_mode?)
Indicates if echo mode is currently being used.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BfdStatus
constructor
A new instance of BfdStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BfdStatus
Returns a new instance of BfdStatus.
7223 7224 7225 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 7223 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bfd_session_initialization_mode ⇒ String
The BFD session initialization mode for this BGP peer.
If set to ACTIVE, the Cloud Router will initiate the BFD session for
this BGP peer. If set to PASSIVE, the Cloud Router will wait for the
peer router to initiate the BFD session for this BGP peer. If set to
DISABLED, BFD is disabled for this BGP peer.
Corresponds to the JSON property bfdSessionInitializationMode
7151 7152 7153 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 7151 def bfd_session_initialization_mode @bfd_session_initialization_mode end |
#config_update_timestamp_micros ⇒ Fixnum
Unix timestamp of the most recent config update.
Corresponds to the JSON property configUpdateTimestampMicros
7156 7157 7158 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 7156 def @config_update_timestamp_micros end |
#control_packet_counts ⇒ Google::Apis::ComputeAlpha::BfdStatusPacketCounts
Control packet counts for the current BFD session.
Corresponds to the JSON property controlPacketCounts
7161 7162 7163 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 7161 def control_packet_counts @control_packet_counts end |
#control_packet_intervals ⇒ Array<Google::Apis::ComputeAlpha::PacketIntervals>
Inter-packet time interval statistics for control packets.
Corresponds to the JSON property controlPacketIntervals
7166 7167 7168 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 7166 def control_packet_intervals @control_packet_intervals end |
#echo_packet_counts ⇒ Google::Apis::ComputeAlpha::BfdStatusPacketCounts
Echo packet counts for the current BFD session.
Corresponds to the JSON property echoPacketCounts
7171 7172 7173 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 7171 def echo_packet_counts @echo_packet_counts end |
#echo_packet_intervals ⇒ Array<Google::Apis::ComputeAlpha::PacketIntervals>
Inter-packet time interval statistics for echo packets.
Corresponds to the JSON property echoPacketIntervals
7176 7177 7178 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 7176 def echo_packet_intervals @echo_packet_intervals end |
#local_diagnostic ⇒ String
The diagnostic code specifies the local system's reason for the last change
in session state. This allows remote systems to determine the reason that
the previous session failed, for example. These diagnostic codes are
specified in section 4.1 ofRFC5880
Corresponds to the JSON property localDiagnostic
7184 7185 7186 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 7184 def local_diagnostic @local_diagnostic end |
#local_state ⇒ String
The current BFD session state as seen by the transmitting system. These
states are specified in section 4.1 ofRFC5880
Corresponds to the JSON property localState
7190 7191 7192 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 7190 def local_state @local_state end |
#negotiated_local_control_tx_interval_ms ⇒ Fixnum
Negotiated transmit interval for control packets.
Corresponds to the JSON property negotiatedLocalControlTxIntervalMs
7195 7196 7197 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 7195 def negotiated_local_control_tx_interval_ms @negotiated_local_control_tx_interval_ms end |
#negotiated_local_echo_tx_interval_ms ⇒ Fixnum
Negotiated transmit interval for echo packets.
Corresponds to the JSON property negotiatedLocalEchoTxIntervalMs
7200 7201 7202 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 7200 def negotiated_local_echo_tx_interval_ms @negotiated_local_echo_tx_interval_ms end |
#rx_packet ⇒ Google::Apis::ComputeAlpha::BfdPacket
The most recent Rx control packet for this BFD session.
Corresponds to the JSON property rxPacket
7205 7206 7207 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 7205 def rx_packet @rx_packet end |
#tx_packet ⇒ Google::Apis::ComputeAlpha::BfdPacket
The most recent Tx control packet for this BFD session.
Corresponds to the JSON property txPacket
7210 7211 7212 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 7210 def tx_packet @tx_packet end |
#uptime_ms ⇒ Fixnum
Session uptime in milliseconds. Value will be 0 if session is not up.
Corresponds to the JSON property uptimeMs
7215 7216 7217 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 7215 def uptime_ms @uptime_ms end |
#using_echo_mode ⇒ Boolean Also known as: using_echo_mode?
Indicates if echo mode is currently being used.
Corresponds to the JSON property usingEchoMode
7220 7221 7222 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 7220 def using_echo_mode @using_echo_mode end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7228 7229 7230 7231 7232 7233 7234 7235 7236 7237 7238 7239 7240 7241 7242 7243 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 7228 def update!(**args) @bfd_session_initialization_mode = args[:bfd_session_initialization_mode] if args.key?(:bfd_session_initialization_mode) @config_update_timestamp_micros = args[:config_update_timestamp_micros] if args.key?(:config_update_timestamp_micros) @control_packet_counts = args[:control_packet_counts] if args.key?(:control_packet_counts) @control_packet_intervals = args[:control_packet_intervals] if args.key?(:control_packet_intervals) @echo_packet_counts = args[:echo_packet_counts] if args.key?(:echo_packet_counts) @echo_packet_intervals = args[:echo_packet_intervals] if args.key?(:echo_packet_intervals) @local_diagnostic = args[:local_diagnostic] if args.key?(:local_diagnostic) @local_state = args[:local_state] if args.key?(:local_state) @negotiated_local_control_tx_interval_ms = args[:negotiated_local_control_tx_interval_ms] if args.key?(:negotiated_local_control_tx_interval_ms) @negotiated_local_echo_tx_interval_ms = args[:negotiated_local_echo_tx_interval_ms] if args.key?(:negotiated_local_echo_tx_interval_ms) @rx_packet = args[:rx_packet] if args.key?(:rx_packet) @tx_packet = args[:tx_packet] if args.key?(:tx_packet) @uptime_ms = args[:uptime_ms] if args.key?(:uptime_ms) @using_echo_mode = args[:using_echo_mode] if args.key?(:using_echo_mode) end |