Class: Google::Apis::ComputeAlpha::BfdStatus
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::BfdStatus
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Next free: 15
Instance Attribute Summary collapse
-
#bfd_session_initialization_mode ⇒ String
The BFD session initialization mode for this BGP peer.
-
#config_update_timestamp_micros ⇒ Fixnum
Unix timestamp of the most recent config update.
-
#control_packet_counts ⇒ Google::Apis::ComputeAlpha::BfdStatusPacketCounts
Control packet counts for the current BFD session.
-
#control_packet_intervals ⇒ Array<Google::Apis::ComputeAlpha::PacketIntervals>
Inter-packet time interval statistics for control packets.
-
#echo_packet_counts ⇒ Google::Apis::ComputeAlpha::BfdStatusPacketCounts
Echo packet counts for the current BFD session.
-
#echo_packet_intervals ⇒ Array<Google::Apis::ComputeAlpha::PacketIntervals>
Inter-packet time interval statistics for echo packets.
-
#local_diagnostic ⇒ String
The diagnostic code specifies the local system's reason for the last change in session state.
-
#local_state ⇒ String
The current BFD session state as seen by the transmitting system.
-
#negotiated_local_control_tx_interval_ms ⇒ Fixnum
Negotiated transmit interval for control packets.
-
#negotiated_local_echo_tx_interval_ms ⇒ Fixnum
Negotiated transmit interval for echo packets.
-
#rx_packet ⇒ Google::Apis::ComputeAlpha::BfdPacket
The most recent Rx control packet for this BFD session.
-
#tx_packet ⇒ Google::Apis::ComputeAlpha::BfdPacket
The most recent Tx control packet for this BFD session.
-
#uptime_ms ⇒ Fixnum
Session uptime in milliseconds.
-
#using_echo_mode ⇒ Boolean
(also: #using_echo_mode?)
Indicates if echo mode is currently being used.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BfdStatus
constructor
A new instance of BfdStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BfdStatus
Returns a new instance of BfdStatus.
7224 7225 7226 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 7224 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bfd_session_initialization_mode ⇒ String
The BFD session initialization mode for this BGP peer.
If set to ACTIVE, the Cloud Router will initiate the BFD session for
this BGP peer. If set to PASSIVE, the Cloud Router will wait for the
peer router to initiate the BFD session for this BGP peer. If set to
DISABLED, BFD is disabled for this BGP peer.
Corresponds to the JSON property bfdSessionInitializationMode
7152 7153 7154 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 7152 def bfd_session_initialization_mode @bfd_session_initialization_mode end |
#config_update_timestamp_micros ⇒ Fixnum
Unix timestamp of the most recent config update.
Corresponds to the JSON property configUpdateTimestampMicros
7157 7158 7159 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 7157 def @config_update_timestamp_micros end |
#control_packet_counts ⇒ Google::Apis::ComputeAlpha::BfdStatusPacketCounts
Control packet counts for the current BFD session.
Corresponds to the JSON property controlPacketCounts
7162 7163 7164 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 7162 def control_packet_counts @control_packet_counts end |
#control_packet_intervals ⇒ Array<Google::Apis::ComputeAlpha::PacketIntervals>
Inter-packet time interval statistics for control packets.
Corresponds to the JSON property controlPacketIntervals
7167 7168 7169 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 7167 def control_packet_intervals @control_packet_intervals end |
#echo_packet_counts ⇒ Google::Apis::ComputeAlpha::BfdStatusPacketCounts
Echo packet counts for the current BFD session.
Corresponds to the JSON property echoPacketCounts
7172 7173 7174 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 7172 def echo_packet_counts @echo_packet_counts end |
#echo_packet_intervals ⇒ Array<Google::Apis::ComputeAlpha::PacketIntervals>
Inter-packet time interval statistics for echo packets.
Corresponds to the JSON property echoPacketIntervals
7177 7178 7179 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 7177 def echo_packet_intervals @echo_packet_intervals end |
#local_diagnostic ⇒ String
The diagnostic code specifies the local system's reason for the last change
in session state. This allows remote systems to determine the reason that
the previous session failed, for example. These diagnostic codes are
specified in section 4.1 ofRFC5880
Corresponds to the JSON property localDiagnostic
7185 7186 7187 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 7185 def local_diagnostic @local_diagnostic end |
#local_state ⇒ String
The current BFD session state as seen by the transmitting system. These
states are specified in section 4.1 ofRFC5880
Corresponds to the JSON property localState
7191 7192 7193 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 7191 def local_state @local_state end |
#negotiated_local_control_tx_interval_ms ⇒ Fixnum
Negotiated transmit interval for control packets.
Corresponds to the JSON property negotiatedLocalControlTxIntervalMs
7196 7197 7198 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 7196 def negotiated_local_control_tx_interval_ms @negotiated_local_control_tx_interval_ms end |
#negotiated_local_echo_tx_interval_ms ⇒ Fixnum
Negotiated transmit interval for echo packets.
Corresponds to the JSON property negotiatedLocalEchoTxIntervalMs
7201 7202 7203 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 7201 def negotiated_local_echo_tx_interval_ms @negotiated_local_echo_tx_interval_ms end |
#rx_packet ⇒ Google::Apis::ComputeAlpha::BfdPacket
The most recent Rx control packet for this BFD session.
Corresponds to the JSON property rxPacket
7206 7207 7208 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 7206 def rx_packet @rx_packet end |
#tx_packet ⇒ Google::Apis::ComputeAlpha::BfdPacket
The most recent Tx control packet for this BFD session.
Corresponds to the JSON property txPacket
7211 7212 7213 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 7211 def tx_packet @tx_packet end |
#uptime_ms ⇒ Fixnum
Session uptime in milliseconds. Value will be 0 if session is not up.
Corresponds to the JSON property uptimeMs
7216 7217 7218 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 7216 def uptime_ms @uptime_ms end |
#using_echo_mode ⇒ Boolean Also known as: using_echo_mode?
Indicates if echo mode is currently being used.
Corresponds to the JSON property usingEchoMode
7221 7222 7223 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 7221 def using_echo_mode @using_echo_mode end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7229 7230 7231 7232 7233 7234 7235 7236 7237 7238 7239 7240 7241 7242 7243 7244 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 7229 def update!(**args) @bfd_session_initialization_mode = args[:bfd_session_initialization_mode] if args.key?(:bfd_session_initialization_mode) @config_update_timestamp_micros = args[:config_update_timestamp_micros] if args.key?(:config_update_timestamp_micros) @control_packet_counts = args[:control_packet_counts] if args.key?(:control_packet_counts) @control_packet_intervals = args[:control_packet_intervals] if args.key?(:control_packet_intervals) @echo_packet_counts = args[:echo_packet_counts] if args.key?(:echo_packet_counts) @echo_packet_intervals = args[:echo_packet_intervals] if args.key?(:echo_packet_intervals) @local_diagnostic = args[:local_diagnostic] if args.key?(:local_diagnostic) @local_state = args[:local_state] if args.key?(:local_state) @negotiated_local_control_tx_interval_ms = args[:negotiated_local_control_tx_interval_ms] if args.key?(:negotiated_local_control_tx_interval_ms) @negotiated_local_echo_tx_interval_ms = args[:negotiated_local_echo_tx_interval_ms] if args.key?(:negotiated_local_echo_tx_interval_ms) @rx_packet = args[:rx_packet] if args.key?(:rx_packet) @tx_packet = args[:tx_packet] if args.key?(:tx_packet) @uptime_ms = args[:uptime_ms] if args.key?(:uptime_ms) @using_echo_mode = args[:using_echo_mode] if args.key?(:using_echo_mode) end |