Class: Google::Apis::ComputeAlpha::BulkInsertInstanceResource

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

A transient resource used in compute.instances.bulkInsert and compute.regionInstances.bulkInsert . This resource is not persisted anywhere, it is used only for processing the requests.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BulkInsertInstanceResource

Returns a new instance of BulkInsertInstanceResource.



7642
7643
7644
# File 'lib/google/apis/compute_alpha/classes.rb', line 7642

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#countFixnum

The maximum number of instances to create. Corresponds to the JSON property count

Returns:

  • (Fixnum)


7572
7573
7574
# File 'lib/google/apis/compute_alpha/classes.rb', line 7572

def count
  @count
end

#instance_flexibility_policyGoogle::Apis::ComputeAlpha::InstanceFlexibilityPolicy

A flexible specification of machine types for instances to create. Corresponds to the JSON property instanceFlexibilityPolicy



7577
7578
7579
# File 'lib/google/apis/compute_alpha/classes.rb', line 7577

def instance_flexibility_policy
  @instance_flexibility_policy
end

#instance_propertiesGoogle::Apis::ComputeAlpha::InstanceProperties

The instance properties defining the VM instances to be created. Required if sourceInstanceTemplate is not provided. Corresponds to the JSON property instanceProperties



7583
7584
7585
# File 'lib/google/apis/compute_alpha/classes.rb', line 7583

def instance_properties
  @instance_properties
end

#location_policyGoogle::Apis::ComputeAlpha::LocationPolicy

Configuration for location policy among multiple possible locations (e.g. preferences for zone selection among zones in a single region). Corresponds to the JSON property locationPolicy



7589
7590
7591
# File 'lib/google/apis/compute_alpha/classes.rb', line 7589

def location_policy
  @location_policy
end

#min_countFixnum

The minimum number of instances to create. If no min_count is specified then count is used as the default value. Ifmin_count instances cannot be created, then no instances will be created and instances already created will be deleted. Corresponds to the JSON property minCount

Returns:

  • (Fixnum)


7597
7598
7599
# File 'lib/google/apis/compute_alpha/classes.rb', line 7597

def min_count
  @min_count
end

#name_patternString

The string pattern used for the names of the VMs. Either name_pattern or per_instance_properties must be set. The pattern must contain one continuous sequence of placeholder hash characters (#) with each character corresponding to one digit of the generated instance name. Example: a name_pattern of inst-#### generates instance names such asinst-0001 and inst-0002. If existing instances in the same project and zone have names that match the name pattern then the generated instance numbers start after the biggest existing number. For example, if there exists an instance with nameinst-0050, then instance names generated using the patterninst-#### begin with inst-0051. The name pattern placeholder #...# can contain up to 18 characters. Corresponds to the JSON property namePattern

Returns:

  • (String)


7614
7615
7616
# File 'lib/google/apis/compute_alpha/classes.rb', line 7614

def name_pattern
  @name_pattern
end

#per_instance_propertiesHash<String,Google::Apis::ComputeAlpha::BulkInsertInstanceResourcePerInstanceProperties>

Per-instance properties to be set on individual instances. Keys of this map specify requested instance names. Can be empty if name_pattern is used. Corresponds to the JSON property perInstanceProperties



7621
7622
7623
# File 'lib/google/apis/compute_alpha/classes.rb', line 7621

def per_instance_properties
  @per_instance_properties
end

#source_instance_templateString

Specifies the instance template from which to create instances. You may combine sourceInstanceTemplate withinstanceProperties to override specific values from an existing instance template. Bulk API follows the semantics of JSON Merge Patch described by RFC 7396. It can be a full or partial URL. For example, the following are all valid URLs to an instance template:

Returns:

  • (String)


7640
7641
7642
# File 'lib/google/apis/compute_alpha/classes.rb', line 7640

def source_instance_template
  @source_instance_template
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7647
7648
7649
7650
7651
7652
7653
7654
7655
7656
# File 'lib/google/apis/compute_alpha/classes.rb', line 7647

def update!(**args)
  @count = args[:count] if args.key?(:count)
  @instance_flexibility_policy = args[:instance_flexibility_policy] if args.key?(:instance_flexibility_policy)
  @instance_properties = args[:instance_properties] if args.key?(:instance_properties)
  @location_policy = args[:location_policy] if args.key?(:location_policy)
  @min_count = args[:min_count] if args.key?(:min_count)
  @name_pattern = args[:name_pattern] if args.key?(:name_pattern)
  @per_instance_properties = args[:per_instance_properties] if args.key?(:per_instance_properties)
  @source_instance_template = args[:source_instance_template] if args.key?(:source_instance_template)
end