Class: Google::Apis::ComputeAlpha::CacheInvalidationRule
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::CacheInvalidationRule
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#backend_service ⇒ String
If set, this invalidation rule will only apply to requests routed to the given backend service or backend bucket.
-
#cache_tags ⇒ Array<String>
A list of cache tags used to identify cached objects.
-
#content_type ⇒ String
If set, this invalidation rule will only apply to responses with the given content-type.
-
#host ⇒ String
If set, this invalidation rule will only apply to requests with a Host header matching host.
-
#http_status ⇒ Fixnum
If set, this invalidation rule will only apply to responses with the given HTTP status.
-
#path ⇒ String
Corresponds to the JSON property
path.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CacheInvalidationRule
constructor
A new instance of CacheInvalidationRule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CacheInvalidationRule
Returns a new instance of CacheInvalidationRule.
7841 7842 7843 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 7841 def initialize(**args) update!(**args) end |
Instance Attribute Details
#backend_service ⇒ String
If set, this invalidation rule will only apply to requests routed to the
given backend service or backend bucket.
For example, for a backend bucket bb1 in the same scope as the URL map,
the path would be projects/my-project/global/backendBuckets/bb1; and
for a backend service bs1 in the same scope as the URL map, the path
would be projects/my-project/global/backendServices/bs1.
Corresponds to the JSON property backendService
7802 7803 7804 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 7802 def backend_service @backend_service end |
#cache_tags ⇒ Array<String>
A list of cache tags used to identify cached objects.
- Cache tags are specified when the response is first cached, by setting
the
Cache-Tagresponse header at the origin. - Multiple cache tags in the same invalidation request are treated as
Boolean
OR- for example,tag1 OR tag2 OR tag3. - If other fields are also specified, these are treated as Boolean
ANDwith any tags. Up to 10 tags can be specified in a single invalidation request. Corresponds to the JSON propertycacheTags
7815 7816 7817 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 7815 def @cache_tags end |
#content_type ⇒ String
If set, this invalidation rule will only apply to responses with the given
content-type. Parameters are not allowed and are ignored from the response
when matching. Wildcards are not allowed.
Corresponds to the JSON property contentType
7822 7823 7824 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 7822 def content_type @content_type end |
#host ⇒ String
If set, this invalidation rule will only apply to requests with a Host
header matching host.
Corresponds to the JSON property host
7828 7829 7830 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 7828 def host @host end |
#http_status ⇒ Fixnum
If set, this invalidation rule will only apply to responses with the
given HTTP status. Valid range is 200-599.
Corresponds to the JSON property httpStatus
7834 7835 7836 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 7834 def http_status @http_status end |
#path ⇒ String
Corresponds to the JSON property path
7839 7840 7841 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 7839 def path @path end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7846 7847 7848 7849 7850 7851 7852 7853 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 7846 def update!(**args) @backend_service = args[:backend_service] if args.key?(:backend_service) @cache_tags = args[:cache_tags] if args.key?(:cache_tags) @content_type = args[:content_type] if args.key?(:content_type) @host = args[:host] if args.key?(:host) @http_status = args[:http_status] if args.key?(:http_status) @path = args[:path] if args.key?(:path) end |