Class: Google::Apis::ComputeAlpha::CachePolicyCacheKeyPolicy
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::CachePolicyCacheKeyPolicy
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Message containing what to include in the cache key for a request for Cache Policy defined on Route Action.
Instance Attribute Summary collapse
-
#excluded_query_parameters ⇒ Array<String>
Names of query string parameters to exclude in cache keys.
-
#include_host ⇒ Boolean
(also: #include_host?)
If true, requests to different hosts will be cached separately.
-
#include_protocol ⇒ Boolean
(also: #include_protocol?)
If true, http and https requests will be cached separately.
-
#include_query_string ⇒ Boolean
(also: #include_query_string?)
If true, include query string parameters in the cache key according to
includedQueryParametersandexcludedQueryParameters. -
#included_cookie_names ⇒ Array<String>
Allows HTTP cookies (by name) to be used in the cache key.
-
#included_header_names ⇒ Array<String>
Allows HTTP request headers (by name) to be used in the cache key.
-
#included_query_parameters ⇒ Array<String>
Names of query string parameters to include in cache keys.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CachePolicyCacheKeyPolicy
constructor
A new instance of CachePolicyCacheKeyPolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CachePolicyCacheKeyPolicy
Returns a new instance of CachePolicyCacheKeyPolicy.
8135 8136 8137 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 8135 def initialize(**args) update!(**args) end |
Instance Attribute Details
#excluded_query_parameters ⇒ Array<String>
Names of query string parameters to exclude in cache keys. All other
parameters will be included. Either specify excludedQueryParameters
or includedQueryParameters, not both. '&' and '=' will be percent
encoded and not treated as delimiters.
Note: This field applies to routes that use backend services. Attempting
to set it on a route that points exclusively to Backend Buckets will
result in a configuration error. For routes that point to a Backend
Bucket, use includedQueryParameters to define which parameters should
be part of the cache key.
Corresponds to the JSON property excludedQueryParameters
8073 8074 8075 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 8073 def excluded_query_parameters @excluded_query_parameters end |
#include_host ⇒ Boolean Also known as: include_host?
If true, requests to different hosts will be cached separately.
Note: This setting is only applicable to routes that use a Backend
Service. It does not affect requests served by a Backend Bucket, as the
host is never included in a Backend Bucket's cache key. Attempting to set
it on a route that points exclusively to Backend Buckets will result in a
configuration error.
Corresponds to the JSON property includeHost
8083 8084 8085 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 8083 def include_host @include_host end |
#include_protocol ⇒ Boolean Also known as: include_protocol?
If true, http and https requests will be cached separately.
Note: This setting is only applicable to routes that use a Backend
Service. It does not affect requests served by a Backend Bucket, as the
protocol is never included in a Backend Bucket's cache key. Attempting to
set on a route that points exclusively to Backend Buckets will result in
a configuration error.
Corresponds to the JSON property includeProtocol
8094 8095 8096 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 8094 def include_protocol @include_protocol end |
#include_query_string ⇒ Boolean Also known as: include_query_string?
If true, include query string parameters in the cache key according to
includedQueryParameters and excludedQueryParameters. If neither
is set, the entire query string will be included. If false, the query
string will be excluded from the cache key entirely.
Note: This field applies to routes that use backend services. Attempting
to set it on a route that points exclusively to Backend Buckets will
result in a configuration error. For routes that point to a Backend
Bucket, use includedQueryParameters to define which parameters should
be part of the cache key.
Corresponds to the JSON property includeQueryString
8108 8109 8110 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 8108 def include_query_string @include_query_string end |
#included_cookie_names ⇒ Array<String>
Allows HTTP cookies (by name) to be used in the cache key.
The name=value pair will be used in the cache key Cloud CDN generates.
Note: This setting is only applicable to routes that use a Backend
Service. It does not affect requests served by a Backend Bucket.
Attempting to set it on a route that points exclusively to Backend
Buckets will result in a configuration error. Up to 5 cookie names can be
specified.
Corresponds to the JSON property includedCookieNames
8120 8121 8122 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 8120 def @included_cookie_names end |
#included_header_names ⇒ Array<String>
Allows HTTP request headers (by name) to be used in the cache key.
Corresponds to the JSON property includedHeaderNames
8125 8126 8127 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 8125 def included_header_names @included_header_names end |
#included_query_parameters ⇒ Array<String>
Names of query string parameters to include in cache keys. All other
parameters will be excluded. Either specify includedQueryParameters
or excludedQueryParameters, not both. '&' and '=' will be percent
encoded and not treated as delimiters.
Corresponds to the JSON property includedQueryParameters
8133 8134 8135 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 8133 def included_query_parameters @included_query_parameters end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8140 8141 8142 8143 8144 8145 8146 8147 8148 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 8140 def update!(**args) @excluded_query_parameters = args[:excluded_query_parameters] if args.key?(:excluded_query_parameters) @include_host = args[:include_host] if args.key?(:include_host) @include_protocol = args[:include_protocol] if args.key?(:include_protocol) @include_query_string = args[:include_query_string] if args.key?(:include_query_string) @included_cookie_names = args[:included_cookie_names] if args.key?(:included_cookie_names) @included_header_names = args[:included_header_names] if args.key?(:included_header_names) @included_query_parameters = args[:included_query_parameters] if args.key?(:included_query_parameters) end |