Class: Google::Apis::ComputeAlpha::CachePolicyNegativeCachingPolicy

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Specify CDN TTLs for response error codes.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CachePolicyNegativeCachingPolicy

Returns a new instance of CachePolicyNegativeCachingPolicy.



8172
8173
8174
# File 'lib/google/apis/compute_alpha/classes.rb', line 8172

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#codeFixnum

The HTTP status code to define a TTL against. Only HTTP status codes 300, 301, 302, 307, 308, 404, 405, 410, 421, 451 and 501 can be specified as values, and you cannot specify a status code more than once. Corresponds to the JSON property code

Returns:

  • (Fixnum)


8162
8163
8164
# File 'lib/google/apis/compute_alpha/classes.rb', line 8162

def code
  @code
end

#ttlGoogle::Apis::ComputeAlpha::Duration

A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution. It is independent of any calendar and concepts like "day" or "month". Range is approximately 10,000 years. Corresponds to the JSON property ttl



8170
8171
8172
# File 'lib/google/apis/compute_alpha/classes.rb', line 8170

def ttl
  @ttl
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8177
8178
8179
8180
# File 'lib/google/apis/compute_alpha/classes.rb', line 8177

def update!(**args)
  @code = args[:code] if args.key?(:code)
  @ttl = args[:ttl] if args.key?(:ttl)
end