Class: Google::Apis::ComputeAlpha::CalendarModeAdviceRequest
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::CalendarModeAdviceRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
A request to recommend the best way to consume the specified resources in the future.
Instance Attribute Summary collapse
-
#future_resources_specs ⇒ Hash<String,Google::Apis::ComputeAlpha::FutureResourcesSpec>
Specification of resources to create in the future.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CalendarModeAdviceRequest
constructor
A new instance of CalendarModeAdviceRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CalendarModeAdviceRequest
Returns a new instance of CalendarModeAdviceRequest.
8196 8197 8198 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 8196 def initialize(**args) update!(**args) end |
Instance Attribute Details
#future_resources_specs ⇒ Hash<String,Google::Apis::ComputeAlpha::FutureResourcesSpec>
Specification of resources to create in the future.
The key of the map is an arbitrary string specified by the caller.
Value of the map is a specification of required resources and their
constraints. Currently only one value is allowed in this map.
Corresponds to the JSON property futureResourcesSpecs
8194 8195 8196 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 8194 def future_resources_specs @future_resources_specs end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8201 8202 8203 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 8201 def update!(**args) @future_resources_specs = args[:future_resources_specs] if args.key?(:future_resources_specs) end |