Class: Google::Apis::ComputeAlpha::CalendarModeAdviceResponse
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::CalendarModeAdviceResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
A response containing the recommended way of creating the specified resources in the future. It contains (will contain) multiple recommendations that can be analyzed by the customer and the best one can be picked.
Instance Attribute Summary collapse
-
#recommendations ⇒ Array<Google::Apis::ComputeAlpha::CalendarModeRecommendation>
Recommendations where, how and when to create the requested resources in order to maximize their obtainability and minimize cost.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CalendarModeAdviceResponse
constructor
A new instance of CalendarModeAdviceResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CalendarModeAdviceResponse
Returns a new instance of CalendarModeAdviceResponse.
8217 8218 8219 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 8217 def initialize(**args) update!(**args) end |
Instance Attribute Details
#recommendations ⇒ Array<Google::Apis::ComputeAlpha::CalendarModeRecommendation>
Recommendations where, how and when to create the requested resources
in order to maximize their obtainability and minimize cost.
Corresponds to the JSON property recommendations
8215 8216 8217 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 8215 def recommendations @recommendations end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8222 8223 8224 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 8222 def update!(**args) @recommendations = args[:recommendations] if args.key?(:recommendations) end |