Class: Google::Apis::ComputeAlpha::CalendarModeExtensionAdviceRequest
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::CalendarModeExtensionAdviceRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
A request to recommend the best duration for extending an existing Future Reservation in CALENDAR mode, that is equal or less than the specified extension duration.
Instance Attribute Summary collapse
-
#end_time_not_later_than ⇒ String
Required.
-
#future_reservation ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CalendarModeExtensionAdviceRequest
constructor
A new instance of CalendarModeExtensionAdviceRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CalendarModeExtensionAdviceRequest
Returns a new instance of CalendarModeExtensionAdviceRequest.
8578 8579 8580 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 8578 def initialize(**args) update!(**args) end |
Instance Attribute Details
#end_time_not_later_than ⇒ String
Required. The desired end time after the Future Reservation is extended.
Corresponds to the JSON property endTimeNotLaterThan
8568 8569 8570 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 8568 def end_time_not_later_than @end_time_not_later_than end |
#future_reservation ⇒ String
Required. Reference to the Future Reservation, in the format:
projects/project/zones/zone/futureReservations/name
Full URIs that include hostnames (like compute.googleapis.com or
www.googleapis.com) are also supported.
Corresponds to the JSON property futureReservation
8576 8577 8578 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 8576 def future_reservation @future_reservation end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8583 8584 8585 8586 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 8583 def update!(**args) @end_time_not_later_than = args[:end_time_not_later_than] if args.key?(:end_time_not_later_than) @future_reservation = args[:future_reservation] if args.key?(:future_reservation) end |