Class: Google::Apis::ComputeAlpha::CapacityAdviceResponseRecommendationScores
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::CapacityAdviceResponseRecommendationScores
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Groups information about a shard of capacity.
Instance Attribute Summary collapse
-
#estimated_uptime ⇒ String
The estimated run time of the majority of Spot VMs in the request before preemption.
-
#estimated_wait_duration ⇒ String
Output only.
-
#obtainability ⇒ Float
The obtainability score indicates the likelihood of successfully obtaining (provisioning) the requested number of VMs.
-
#uptime_score ⇒ Float
The uptime score indicates the likelihood that your Spot VMs will continue to run without preemption within the next few hours.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CapacityAdviceResponseRecommendationScores
constructor
A new instance of CapacityAdviceResponseRecommendationScores.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CapacityAdviceResponseRecommendationScores
Returns a new instance of CapacityAdviceResponseRecommendationScores.
9001 9002 9003 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 9001 def initialize(**args) update!(**args) end |
Instance Attribute Details
#estimated_uptime ⇒ String
The estimated run time of the majority of Spot VMs in the request
before preemption. The estimate is best-effort only. It is based on
historical data and current conditions.
Corresponds to the JSON property estimatedUptime
8977 8978 8979 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 8977 def estimated_uptime @estimated_uptime end |
#estimated_wait_duration ⇒ String
Output only. The likely maximum time that you will have to wait until
Compute Engine provisions your instances.
Corresponds to the JSON property estimatedWaitDuration
8983 8984 8985 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 8983 def estimated_wait_duration @estimated_wait_duration end |
#obtainability ⇒ Float
The obtainability score indicates the likelihood of successfully
obtaining (provisioning) the requested number of VMs.
The score range is 0.0 through 1.0. Higher is better.
Corresponds to the JSON property obtainability
8990 8991 8992 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 8990 def obtainability @obtainability end |
#uptime_score ⇒ Float
The uptime score indicates the likelihood that your Spot VMs will
continue to run without preemption within the next few hours. For more
information about the preemption process, see Preemption
of Spot VMs.
The score range is 0.0 through 1.0. Higher is better.
Corresponds to the JSON property uptimeScore
8999 9000 9001 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 8999 def uptime_score @uptime_score end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9006 9007 9008 9009 9010 9011 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 9006 def update!(**args) @estimated_uptime = args[:estimated_uptime] if args.key?(:estimated_uptime) @estimated_wait_duration = args[:estimated_wait_duration] if args.key?(:estimated_wait_duration) @obtainability = args[:obtainability] if args.key?(:obtainability) @uptime_score = args[:uptime_score] if args.key?(:uptime_score) end |