Class: Google::Apis::ComputeAlpha::CapacityAdviceResponseRecommendationScores

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Groups information about a shard of capacity.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CapacityAdviceResponseRecommendationScores

Returns a new instance of CapacityAdviceResponseRecommendationScores.



8589
8590
8591
# File 'lib/google/apis/compute_alpha/classes.rb', line 8589

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#estimated_uptimeString

The estimated run time of the majority of Spot VMs in the request before preemption. The estimate is best-effort only. It is based on historical data and current conditions. Corresponds to the JSON property estimatedUptime

Returns:

  • (String)


8565
8566
8567
# File 'lib/google/apis/compute_alpha/classes.rb', line 8565

def estimated_uptime
  @estimated_uptime
end

#estimated_wait_durationString

Output only. The likely maximum time that you will have to wait until Compute Engine provisions your instances. Corresponds to the JSON property estimatedWaitDuration

Returns:

  • (String)


8571
8572
8573
# File 'lib/google/apis/compute_alpha/classes.rb', line 8571

def estimated_wait_duration
  @estimated_wait_duration
end

#obtainabilityFloat

The obtainability score indicates the likelihood of successfully obtaining (provisioning) the requested number of VMs. The score range is 0.0 through 1.0. Higher is better. Corresponds to the JSON property obtainability

Returns:

  • (Float)


8578
8579
8580
# File 'lib/google/apis/compute_alpha/classes.rb', line 8578

def obtainability
  @obtainability
end

#uptime_scoreFloat

The uptime score indicates the likelihood that your Spot VMs will continue to run without preemption within the next few hours. For more information about the preemption process, see Preemption of Spot VMs. The score range is 0.0 through 1.0. Higher is better. Corresponds to the JSON property uptimeScore

Returns:

  • (Float)


8587
8588
8589
# File 'lib/google/apis/compute_alpha/classes.rb', line 8587

def uptime_score
  @uptime_score
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8594
8595
8596
8597
8598
8599
# File 'lib/google/apis/compute_alpha/classes.rb', line 8594

def update!(**args)
  @estimated_uptime = args[:estimated_uptime] if args.key?(:estimated_uptime)
  @estimated_wait_duration = args[:estimated_wait_duration] if args.key?(:estimated_wait_duration)
  @obtainability = args[:obtainability] if args.key?(:obtainability)
  @uptime_score = args[:uptime_score] if args.key?(:uptime_score)
end