Class: Google::Apis::ComputeAlpha::CapacityAdviceResponseRecommendationShard

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Shards represent blocks of uniform capacity in recommendations. Each shard is for a single zone and a single machine shape. Each shard defines a size expressed as the number of VMs.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CapacityAdviceResponseRecommendationShard

Returns a new instance of CapacityAdviceResponseRecommendationShard.



9040
9041
9042
# File 'lib/google/apis/compute_alpha/classes.rb', line 9040

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#instance_countFixnum

The number of instances. Corresponds to the JSON property instanceCount

Returns:

  • (Fixnum)


9023
9024
9025
# File 'lib/google/apis/compute_alpha/classes.rb', line 9023

def instance_count
  @instance_count
end

#machine_typeString

The machine type corresponds to the instance selection in the request. Corresponds to the JSON property machineType

Returns:

  • (String)


9028
9029
9030
# File 'lib/google/apis/compute_alpha/classes.rb', line 9028

def machine_type
  @machine_type
end

#provisioning_modelString

The provisioning model that you want to view recommendations for. Corresponds to the JSON property provisioningModel

Returns:

  • (String)


9033
9034
9035
# File 'lib/google/apis/compute_alpha/classes.rb', line 9033

def provisioning_model
  @provisioning_model
end

#zoneString

Output only. The zone name for this shard. Corresponds to the JSON property zone

Returns:

  • (String)


9038
9039
9040
# File 'lib/google/apis/compute_alpha/classes.rb', line 9038

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9045
9046
9047
9048
9049
9050
# File 'lib/google/apis/compute_alpha/classes.rb', line 9045

def update!(**args)
  @instance_count = args[:instance_count] if args.key?(:instance_count)
  @machine_type = args[:machine_type] if args.key?(:machine_type)
  @provisioning_model = args[:provisioning_model] if args.key?(:provisioning_model)
  @zone = args[:zone] if args.key?(:zone)
end