Class: Google::Apis::ComputeAlpha::CapacityAdviceResponseRecommendationShard

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Shards represent blocks of uniform capacity in recommendations. Each shard is for a single zone and a single machine shape. Each shard defines a size expressed as the number of VMs.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CapacityAdviceResponseRecommendationShard

Returns a new instance of CapacityAdviceResponseRecommendationShard.



8628
8629
8630
# File 'lib/google/apis/compute_alpha/classes.rb', line 8628

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#instance_countFixnum

The number of instances. Corresponds to the JSON property instanceCount

Returns:

  • (Fixnum)


8611
8612
8613
# File 'lib/google/apis/compute_alpha/classes.rb', line 8611

def instance_count
  @instance_count
end

#machine_typeString

The machine type corresponds to the instance selection in the request. Corresponds to the JSON property machineType

Returns:

  • (String)


8616
8617
8618
# File 'lib/google/apis/compute_alpha/classes.rb', line 8616

def machine_type
  @machine_type
end

#provisioning_modelString

The provisioning model that you want to view recommendations for. Corresponds to the JSON property provisioningModel

Returns:

  • (String)


8621
8622
8623
# File 'lib/google/apis/compute_alpha/classes.rb', line 8621

def provisioning_model
  @provisioning_model
end

#zoneString

Output only. The zone name for this shard. Corresponds to the JSON property zone

Returns:

  • (String)


8626
8627
8628
# File 'lib/google/apis/compute_alpha/classes.rb', line 8626

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8633
8634
8635
8636
8637
8638
# File 'lib/google/apis/compute_alpha/classes.rb', line 8633

def update!(**args)
  @instance_count = args[:instance_count] if args.key?(:instance_count)
  @machine_type = args[:machine_type] if args.key?(:machine_type)
  @provisioning_model = args[:provisioning_model] if args.key?(:provisioning_model)
  @zone = args[:zone] if args.key?(:zone)
end