Class: Google::Apis::ComputeAlpha::CapacityAdviceResponseRecommendationShard

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Shards represent blocks of uniform capacity in recommendations. Each shard is for a single zone, single instance selection, and a single machine shape. Each shard defines a size expressed as the number of VMs.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CapacityAdviceResponseRecommendationShard

Returns a new instance of CapacityAdviceResponseRecommendationShard.



8580
8581
8582
# File 'lib/google/apis/compute_alpha/classes.rb', line 8580

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#instance_countFixnum

Corresponds to the JSON property instanceCount

Returns:

  • (Fixnum)


8560
8561
8562
# File 'lib/google/apis/compute_alpha/classes.rb', line 8560

def instance_count
  @instance_count
end

#machine_typeString

The machine type corresponds to the instance selection in the request. Corresponds to the JSON property machineType

Returns:

  • (String)


8565
8566
8567
# File 'lib/google/apis/compute_alpha/classes.rb', line 8565

def machine_type
  @machine_type
end

#provisioning_modelString

The provisioning model that you want to view recommendations for. Set to: SPOT. For more information, see Compute Engine instances provisioning models. Corresponds to the JSON property provisioningModel

Returns:

  • (String)


8573
8574
8575
# File 'lib/google/apis/compute_alpha/classes.rb', line 8573

def provisioning_model
  @provisioning_model
end

#zoneString

Output only. The zone name for this shard. Corresponds to the JSON property zone

Returns:

  • (String)


8578
8579
8580
# File 'lib/google/apis/compute_alpha/classes.rb', line 8578

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8585
8586
8587
8588
8589
8590
# File 'lib/google/apis/compute_alpha/classes.rb', line 8585

def update!(**args)
  @instance_count = args[:instance_count] if args.key?(:instance_count)
  @machine_type = args[:machine_type] if args.key?(:machine_type)
  @provisioning_model = args[:provisioning_model] if args.key?(:provisioning_model)
  @zone = args[:zone] if args.key?(:zone)
end