Class: Google::Apis::ComputeAlpha::CapacityHistoryRequest
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::CapacityHistoryRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
A request to get the capacity history.
Instance Attribute Summary collapse
-
#instance_properties ⇒ Google::Apis::ComputeAlpha::CapacityHistoryRequestInstanceProperties
Instance properties for this request.
-
#location_policy ⇒ Google::Apis::ComputeAlpha::CapacityHistoryRequestLocationPolicy
Location policy for this request.
-
#types ⇒ Array<String>
List of history types to get capacity history for.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CapacityHistoryRequest
constructor
A new instance of CapacityHistoryRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CapacityHistoryRequest
Returns a new instance of CapacityHistoryRequest.
8660 8661 8662 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 8660 def initialize(**args) update!(**args) end |
Instance Attribute Details
#instance_properties ⇒ Google::Apis::ComputeAlpha::CapacityHistoryRequestInstanceProperties
Instance properties for this request.
Corresponds to the JSON property instanceProperties
8648 8649 8650 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 8648 def instance_properties @instance_properties end |
#location_policy ⇒ Google::Apis::ComputeAlpha::CapacityHistoryRequestLocationPolicy
Location policy for this request.
Corresponds to the JSON property locationPolicy
8653 8654 8655 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 8653 def location_policy @location_policy end |
#types ⇒ Array<String>
List of history types to get capacity history for.
Corresponds to the JSON property types
8658 8659 8660 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 8658 def types @types end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8665 8666 8667 8668 8669 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 8665 def update!(**args) @instance_properties = args[:instance_properties] if args.key?(:instance_properties) @location_policy = args[:location_policy] if args.key?(:location_policy) @types = args[:types] if args.key?(:types) end |