Class: Google::Apis::ComputeAlpha::CapacityHistoryRequest
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::CapacityHistoryRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
A request to get the capacity history.
Instance Attribute Summary collapse
-
#instance_properties ⇒ Google::Apis::ComputeAlpha::CapacityHistoryRequestInstanceProperties
Instance properties for this request.
-
#location_policy ⇒ Google::Apis::ComputeAlpha::CapacityHistoryRequestLocationPolicy
Location policy for this request.
-
#types ⇒ Array<String>
List of history types to get capacity history for.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CapacityHistoryRequest
constructor
A new instance of CapacityHistoryRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CapacityHistoryRequest
Returns a new instance of CapacityHistoryRequest.
8646 8647 8648 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 8646 def initialize(**args) update!(**args) end |
Instance Attribute Details
#instance_properties ⇒ Google::Apis::ComputeAlpha::CapacityHistoryRequestInstanceProperties
Instance properties for this request.
Corresponds to the JSON property instanceProperties
8634 8635 8636 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 8634 def instance_properties @instance_properties end |
#location_policy ⇒ Google::Apis::ComputeAlpha::CapacityHistoryRequestLocationPolicy
Location policy for this request.
Corresponds to the JSON property locationPolicy
8639 8640 8641 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 8639 def location_policy @location_policy end |
#types ⇒ Array<String>
List of history types to get capacity history for.
Corresponds to the JSON property types
8644 8645 8646 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 8644 def types @types end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8651 8652 8653 8654 8655 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 8651 def update!(**args) @instance_properties = args[:instance_properties] if args.key?(:instance_properties) @location_policy = args[:location_policy] if args.key?(:location_policy) @types = args[:types] if args.key?(:types) end |