Class: Google::Apis::ComputeAlpha::CapacityHistoryRequestLocationPolicy
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::CapacityHistoryRequestLocationPolicy
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#location ⇒ String
The region or zone to get capacity history for.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CapacityHistoryRequestLocationPolicy
constructor
A new instance of CapacityHistoryRequestLocationPolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CapacityHistoryRequestLocationPolicy
Returns a new instance of CapacityHistoryRequestLocationPolicy.
8727 8728 8729 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 8727 def initialize(**args) update!(**args) end |
Instance Attribute Details
#location ⇒ String
The region or zone to get capacity history for. It can be a partial or full URL. For example, the following are valid values:
- https://www.googleapis.com/compute/v1/projects/project/zones/zone
- projects/project/zones/zone
- zones/zone
This field is optional.
Corresponds to the JSON property
location
8725 8726 8727 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 8725 def location @location end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8732 8733 8734 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 8732 def update!(**args) @location = args[:location] if args.key?(:location) end |