Class: Google::Apis::ComputeAlpha::CapacityHistoryResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains the capacity history.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CapacityHistoryResponse

Returns a new instance of CapacityHistoryResponse.



9185
9186
9187
# File 'lib/google/apis/compute_alpha/classes.rb', line 9185

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#locationString

Output only. The location (region or zone) for which the capacity history is returned. It is returned as a URL - For example,https://www.googleapis.com/compute/v1/ projects/project/zones/zone. Corresponds to the JSON property location

Returns:

  • (String)


9168
9169
9170
# File 'lib/google/apis/compute_alpha/classes.rb', line 9168

def location
  @location
end

#machine_typeString

The machine type for which the capacity history is returned. Corresponds to the JSON property machineType

Returns:

  • (String)


9173
9174
9175
# File 'lib/google/apis/compute_alpha/classes.rb', line 9173

def machine_type
  @machine_type
end

#preemption_historyArray<Google::Apis::ComputeAlpha::CapacityHistoryResponsePreemptionRecord>

The preemption history for the requested machine type and location. Corresponds to the JSON property preemptionHistory



9178
9179
9180
# File 'lib/google/apis/compute_alpha/classes.rb', line 9178

def preemption_history
  @preemption_history
end

#price_historyArray<Google::Apis::ComputeAlpha::CapacityHistoryResponsePriceRecord>

The price history for the requested machine type and location. Corresponds to the JSON property priceHistory



9183
9184
9185
# File 'lib/google/apis/compute_alpha/classes.rb', line 9183

def price_history
  @price_history
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9190
9191
9192
9193
9194
9195
# File 'lib/google/apis/compute_alpha/classes.rb', line 9190

def update!(**args)
  @location = args[:location] if args.key?(:location)
  @machine_type = args[:machine_type] if args.key?(:machine_type)
  @preemption_history = args[:preemption_history] if args.key?(:preemption_history)
  @price_history = args[:price_history] if args.key?(:price_history)
end