Class: Google::Apis::ComputeAlpha::CapacityHistoryResponsePreemptionRecord

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CapacityHistoryResponsePreemptionRecord

Returns a new instance of CapacityHistoryResponsePreemptionRecord.



8770
8771
8772
# File 'lib/google/apis/compute_alpha/classes.rb', line 8770

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#intervalGoogle::Apis::ComputeAlpha::Interval

Represents a time interval, encoded as a Timestamp start (inclusive) and a Timestamp end (exclusive). The start must be less than or equal to the end. When the start equals the end, the interval is empty (matches no time). When both start and end are unspecified, the interval matches any time. Corresponds to the JSON property interval



8763
8764
8765
# File 'lib/google/apis/compute_alpha/classes.rb', line 8763

def interval
  @interval
end

#preemption_rateFloat

Corresponds to the JSON property preemptionRate

Returns:

  • (Float)


8768
8769
8770
# File 'lib/google/apis/compute_alpha/classes.rb', line 8768

def preemption_rate
  @preemption_rate
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8775
8776
8777
8778
# File 'lib/google/apis/compute_alpha/classes.rb', line 8775

def update!(**args)
  @interval = args[:interval] if args.key?(:interval)
  @preemption_rate = args[:preemption_rate] if args.key?(:preemption_rate)
end