Class: Google::Apis::ComputeAlpha::CapacityHistoryResponsePreemptionRecord
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::CapacityHistoryResponsePreemptionRecord
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#interval ⇒ Google::Apis::ComputeAlpha::Interval
Represents a time interval, encoded as a Timestamp start (inclusive) and a Timestamp end (exclusive).
-
#preemption_rate ⇒ Float
Corresponds to the JSON property
preemptionRate.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CapacityHistoryResponsePreemptionRecord
constructor
A new instance of CapacityHistoryResponsePreemptionRecord.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CapacityHistoryResponsePreemptionRecord
Returns a new instance of CapacityHistoryResponsePreemptionRecord.
8787 8788 8789 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 8787 def initialize(**args) update!(**args) end |
Instance Attribute Details
#interval ⇒ Google::Apis::ComputeAlpha::Interval
Represents a time interval, encoded as a Timestamp start (inclusive) and a
Timestamp end (exclusive).
The start must be less than or equal to the end.
When the start equals the end, the interval is empty (matches no time).
When both start and end are unspecified, the interval matches any time.
Corresponds to the JSON property interval
8780 8781 8782 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 8780 def interval @interval end |
#preemption_rate ⇒ Float
Corresponds to the JSON property preemptionRate
8785 8786 8787 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 8785 def preemption_rate @preemption_rate end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8792 8793 8794 8795 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 8792 def update!(**args) @interval = args[:interval] if args.key?(:interval) @preemption_rate = args[:preemption_rate] if args.key?(:preemption_rate) end |