Class: Google::Apis::ComputeAlpha::CapacityHistoryResponsePriceRecord

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

A record of price history.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CapacityHistoryResponsePriceRecord

Returns a new instance of CapacityHistoryResponsePriceRecord.



9248
9249
9250
# File 'lib/google/apis/compute_alpha/classes.rb', line 9248

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#intervalGoogle::Apis::ComputeAlpha::Interval

Represents a time interval, encoded as a Timestamp start (inclusive) and a Timestamp end (exclusive). The start must be less than or equal to the end. When the start equals the end, the interval is empty (matches no time). When both start and end are unspecified, the interval matches any time. Corresponds to the JSON property interval



9241
9242
9243
# File 'lib/google/apis/compute_alpha/classes.rb', line 9241

def interval
  @interval
end

#list_priceGoogle::Apis::ComputeAlpha::Money

Represents an amount of money with its currency type. Corresponds to the JSON property listPrice



9246
9247
9248
# File 'lib/google/apis/compute_alpha/classes.rb', line 9246

def list_price
  @list_price
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9253
9254
9255
9256
# File 'lib/google/apis/compute_alpha/classes.rb', line 9253

def update!(**args)
  @interval = args[:interval] if args.key?(:interval)
  @list_price = args[:list_price] if args.key?(:list_price)
end