Class: Google::Apis::ComputeAlpha::CapacityHistoryResponsePriceRecord

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CapacityHistoryResponsePriceRecord

Returns a new instance of CapacityHistoryResponsePriceRecord.



8799
8800
8801
# File 'lib/google/apis/compute_alpha/classes.rb', line 8799

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#intervalGoogle::Apis::ComputeAlpha::Interval

Represents a time interval, encoded as a Timestamp start (inclusive) and a Timestamp end (exclusive). The start must be less than or equal to the end. When the start equals the end, the interval is empty (matches no time). When both start and end are unspecified, the interval matches any time. Corresponds to the JSON property interval



8792
8793
8794
# File 'lib/google/apis/compute_alpha/classes.rb', line 8792

def interval
  @interval
end

#list_priceGoogle::Apis::ComputeAlpha::Money

Represents an amount of money with its currency type. Corresponds to the JSON property listPrice



8797
8798
8799
# File 'lib/google/apis/compute_alpha/classes.rb', line 8797

def list_price
  @list_price
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8804
8805
8806
8807
# File 'lib/google/apis/compute_alpha/classes.rb', line 8804

def update!(**args)
  @interval = args[:interval] if args.key?(:interval)
  @list_price = args[:list_price] if args.key?(:list_price)
end