Class: Google::Apis::ComputeAlpha::CapacityHistoryResponsePriceRecord
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::CapacityHistoryResponsePriceRecord
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#interval ⇒ Google::Apis::ComputeAlpha::Interval
Represents a time interval, encoded as a Timestamp start (inclusive) and a Timestamp end (exclusive).
-
#list_price ⇒ Google::Apis::ComputeAlpha::Money
Represents an amount of money with its currency type.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CapacityHistoryResponsePriceRecord
constructor
A new instance of CapacityHistoryResponsePriceRecord.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CapacityHistoryResponsePriceRecord
Returns a new instance of CapacityHistoryResponsePriceRecord.
8821 8822 8823 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 8821 def initialize(**args) update!(**args) end |
Instance Attribute Details
#interval ⇒ Google::Apis::ComputeAlpha::Interval
Represents a time interval, encoded as a Timestamp start (inclusive) and a
Timestamp end (exclusive).
The start must be less than or equal to the end.
When the start equals the end, the interval is empty (matches no time).
When both start and end are unspecified, the interval matches any time.
Corresponds to the JSON property interval
8814 8815 8816 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 8814 def interval @interval end |
#list_price ⇒ Google::Apis::ComputeAlpha::Money
Represents an amount of money with its currency type.
Corresponds to the JSON property listPrice
8819 8820 8821 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 8819 def list_price @list_price end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8826 8827 8828 8829 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 8826 def update!(**args) @interval = args[:interval] if args.key?(:interval) @list_price = args[:list_price] if args.key?(:list_price) end |