Class: Google::Apis::ComputeAlpha::CircuitBreakers

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Settings controlling the volume of requests, connections and retries to this backend service.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CircuitBreakers

Returns a new instance of CircuitBreakers.



8910
8911
8912
# File 'lib/google/apis/compute_alpha/classes.rb', line 8910

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#connect_timeoutGoogle::Apis::ComputeAlpha::Duration

A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution. It is independent of any calendar and concepts like "day" or "month". Range is approximately 10,000 years. Corresponds to the JSON property connectTimeout



8868
8869
8870
# File 'lib/google/apis/compute_alpha/classes.rb', line 8868

def connect_timeout
  @connect_timeout
end

#max_connectionsFixnum

The maximum number of connections to the backend service. If not specified, there is no limit. Not supported when the backend service is referenced by a URL map that is bound to target gRPC proxy that has validateForProxyless field set to true. Corresponds to the JSON property maxConnections

Returns:

  • (Fixnum)


8876
8877
8878
# File 'lib/google/apis/compute_alpha/classes.rb', line 8876

def max_connections
  @max_connections
end

#max_pending_requestsFixnum

The maximum number of pending requests allowed to the backend service. If not specified, there is no limit. Not supported when the backend service is referenced by a URL map that is bound to target gRPC proxy that has validateForProxyless field set to true. Corresponds to the JSON property maxPendingRequests

Returns:

  • (Fixnum)


8884
8885
8886
# File 'lib/google/apis/compute_alpha/classes.rb', line 8884

def max_pending_requests
  @max_pending_requests
end

#max_requestsFixnum

The maximum number of parallel requests that allowed to the backend service. If not specified, there is no limit. Corresponds to the JSON property maxRequests

Returns:

  • (Fixnum)


8890
8891
8892
# File 'lib/google/apis/compute_alpha/classes.rb', line 8890

def max_requests
  @max_requests
end

#max_requests_per_connectionFixnum

Maximum requests for a single connection to the backend service. This parameter is respected by both the HTTP/1.1 and HTTP/2 implementations. If not specified, there is no limit. Setting this parameter to 1 will effectively disable keep alive. Not supported when the backend service is referenced by a URL map that is bound to target gRPC proxy that has validateForProxyless field set to true. Corresponds to the JSON property maxRequestsPerConnection

Returns:

  • (Fixnum)


8900
8901
8902
# File 'lib/google/apis/compute_alpha/classes.rb', line 8900

def max_requests_per_connection
  @max_requests_per_connection
end

#max_retriesFixnum

The maximum number of parallel retries allowed to the backend cluster. If not specified, the default is 1. Not supported when the backend service is referenced by a URL map that is bound to target gRPC proxy that has validateForProxyless field set to true. Corresponds to the JSON property maxRetries

Returns:

  • (Fixnum)


8908
8909
8910
# File 'lib/google/apis/compute_alpha/classes.rb', line 8908

def max_retries
  @max_retries
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8915
8916
8917
8918
8919
8920
8921
8922
# File 'lib/google/apis/compute_alpha/classes.rb', line 8915

def update!(**args)
  @connect_timeout = args[:connect_timeout] if args.key?(:connect_timeout)
  @max_connections = args[:max_connections] if args.key?(:max_connections)
  @max_pending_requests = args[:max_pending_requests] if args.key?(:max_pending_requests)
  @max_requests = args[:max_requests] if args.key?(:max_requests)
  @max_requests_per_connection = args[:max_requests_per_connection] if args.key?(:max_requests_per_connection)
  @max_retries = args[:max_retries] if args.key?(:max_retries)
end