Class: Google::Apis::ComputeAlpha::CircuitBreakers
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::CircuitBreakers
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Settings controlling the volume of requests, connections and retries to this backend service.
Instance Attribute Summary collapse
-
#connect_timeout ⇒ Google::Apis::ComputeAlpha::Duration
A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution.
-
#max_connections ⇒ Fixnum
The maximum number of connections to the backend service.
-
#max_pending_requests ⇒ Fixnum
The maximum number of pending requests allowed to the backend service.
-
#max_requests ⇒ Fixnum
The maximum number of parallel requests that allowed to the backend service.
-
#max_requests_per_connection ⇒ Fixnum
Maximum requests for a single connection to the backend service.
-
#max_retries ⇒ Fixnum
The maximum number of parallel retries allowed to the backend cluster.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CircuitBreakers
constructor
A new instance of CircuitBreakers.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CircuitBreakers
Returns a new instance of CircuitBreakers.
8915 8916 8917 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 8915 def initialize(**args) update!(**args) end |
Instance Attribute Details
#connect_timeout ⇒ Google::Apis::ComputeAlpha::Duration
A Duration represents a fixed-length span of time represented
as a count of seconds and fractions of seconds at nanosecond
resolution. It is independent of any calendar and concepts like "day"
or "month". Range is approximately 10,000 years.
Corresponds to the JSON property connectTimeout
8873 8874 8875 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 8873 def connect_timeout @connect_timeout end |
#max_connections ⇒ Fixnum
The maximum number of connections to the backend service. If not specified,
there is no limit.
Not supported when the backend service is referenced by a URL map that is
bound to target gRPC proxy that has validateForProxyless field set to true.
Corresponds to the JSON property maxConnections
8881 8882 8883 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 8881 def max_connections @max_connections end |
#max_pending_requests ⇒ Fixnum
The maximum number of pending requests allowed to the backend service. If
not specified, there is no limit.
Not supported when the backend service is referenced by a URL map that is
bound to target gRPC proxy that has validateForProxyless field set to true.
Corresponds to the JSON property maxPendingRequests
8889 8890 8891 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 8889 def max_pending_requests @max_pending_requests end |
#max_requests ⇒ Fixnum
The maximum number of parallel requests that allowed to the backend
service. If not specified, there is no limit.
Corresponds to the JSON property maxRequests
8895 8896 8897 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 8895 def max_requests @max_requests end |
#max_requests_per_connection ⇒ Fixnum
Maximum requests for a single connection to the backend service.
This parameter is respected by both the HTTP/1.1 and HTTP/2
implementations. If not specified, there is no limit. Setting this
parameter to 1 will effectively disable keep alive.
Not supported when the backend service is referenced by a URL map that is
bound to target gRPC proxy that has validateForProxyless field set to true.
Corresponds to the JSON property maxRequestsPerConnection
8905 8906 8907 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 8905 def max_requests_per_connection @max_requests_per_connection end |
#max_retries ⇒ Fixnum
The maximum number of parallel retries allowed to the backend cluster. If
not specified, the default is 1.
Not supported when the backend service is referenced by a URL map that is
bound to target gRPC proxy that has validateForProxyless field set to true.
Corresponds to the JSON property maxRetries
8913 8914 8915 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 8913 def max_retries @max_retries end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8920 8921 8922 8923 8924 8925 8926 8927 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 8920 def update!(**args) @connect_timeout = args[:connect_timeout] if args.key?(:connect_timeout) @max_connections = args[:max_connections] if args.key?(:max_connections) @max_pending_requests = args[:max_pending_requests] if args.key?(:max_pending_requests) @max_requests = args[:max_requests] if args.key?(:max_requests) @max_requests_per_connection = args[:max_requests_per_connection] if args.key?(:max_requests_per_connection) @max_retries = args[:max_retries] if args.key?(:max_retries) end |