Class: Google::Apis::ComputeAlpha::ClientTlsSettings

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

[Deprecated] The client side authentication settings for connection originating from the backend service. the backend service.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ClientTlsSettings

Returns a new instance of ClientTlsSettings.



9395
9396
9397
# File 'lib/google/apis/compute_alpha/classes.rb', line 9395

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#client_tls_contextGoogle::Apis::ComputeAlpha::TlsContext

[Deprecated] The TLS settings for the client or server. The TLS settings for the client or server. Corresponds to the JSON property clientTlsContext



9367
9368
9369
# File 'lib/google/apis/compute_alpha/classes.rb', line 9367

def client_tls_context
  @client_tls_context
end

#modeString

Indicates whether connections to this port should be secured using TLS. The value of this field determines how TLS is enforced. This can be set to one of the following values: DISABLE: Do not setup a TLS connection to the backends. SIMPLE: Originate a TLS connection to the backends. MUTUAL: Secure connections to the backends using mutual TLS by presenting client certificates for authentication. Corresponds to the JSON property mode

Returns:

  • (String)


9378
9379
9380
# File 'lib/google/apis/compute_alpha/classes.rb', line 9378

def mode
  @mode
end

#sniString

SNI string to present to the server during TLS handshake. This field is applicable only when mode is SIMPLE or MUTUAL. Corresponds to the JSON property sni

Returns:

  • (String)


9384
9385
9386
# File 'lib/google/apis/compute_alpha/classes.rb', line 9384

def sni
  @sni
end

#subject_alt_namesArray<String>

A list of alternate names to verify the subject identity in the certificate.If specified, the proxy will verify that the server certificate's subject alt name matches one of the specified values. This field is applicable only when mode is SIMPLE or MUTUAL. Corresponds to the JSON property subjectAltNames

Returns:

  • (Array<String>)


9393
9394
9395
# File 'lib/google/apis/compute_alpha/classes.rb', line 9393

def subject_alt_names
  @subject_alt_names
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9400
9401
9402
9403
9404
9405
# File 'lib/google/apis/compute_alpha/classes.rb', line 9400

def update!(**args)
  @client_tls_context = args[:client_tls_context] if args.key?(:client_tls_context)
  @mode = args[:mode] if args.key?(:mode)
  @sni = args[:sni] if args.key?(:sni)
  @subject_alt_names = args[:subject_alt_names] if args.key?(:subject_alt_names)
end