Class: Google::Apis::ComputeAlpha::ClientTlsSettings

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

[Deprecated] The client side authentication settings for connection originating from the backend service. the backend service.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ClientTlsSettings

Returns a new instance of ClientTlsSettings.



8977
8978
8979
# File 'lib/google/apis/compute_alpha/classes.rb', line 8977

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#client_tls_contextGoogle::Apis::ComputeAlpha::TlsContext

[Deprecated] The TLS settings for the client or server. The TLS settings for the client or server. Corresponds to the JSON property clientTlsContext



8949
8950
8951
# File 'lib/google/apis/compute_alpha/classes.rb', line 8949

def client_tls_context
  @client_tls_context
end

#modeString

Indicates whether connections to this port should be secured using TLS. The value of this field determines how TLS is enforced. This can be set to one of the following values: DISABLE: Do not setup a TLS connection to the backends. SIMPLE: Originate a TLS connection to the backends. MUTUAL: Secure connections to the backends using mutual TLS by presenting client certificates for authentication. Corresponds to the JSON property mode

Returns:

  • (String)


8960
8961
8962
# File 'lib/google/apis/compute_alpha/classes.rb', line 8960

def mode
  @mode
end

#sniString

SNI string to present to the server during TLS handshake. This field is applicable only when mode is SIMPLE or MUTUAL. Corresponds to the JSON property sni

Returns:

  • (String)


8966
8967
8968
# File 'lib/google/apis/compute_alpha/classes.rb', line 8966

def sni
  @sni
end

#subject_alt_namesArray<String>

A list of alternate names to verify the subject identity in the certificate.If specified, the proxy will verify that the server certificate's subject alt name matches one of the specified values. This field is applicable only when mode is SIMPLE or MUTUAL. Corresponds to the JSON property subjectAltNames

Returns:

  • (Array<String>)


8975
8976
8977
# File 'lib/google/apis/compute_alpha/classes.rb', line 8975

def subject_alt_names
  @subject_alt_names
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8982
8983
8984
8985
8986
8987
# File 'lib/google/apis/compute_alpha/classes.rb', line 8982

def update!(**args)
  @client_tls_context = args[:client_tls_context] if args.key?(:client_tls_context)
  @mode = args[:mode] if args.key?(:mode)
  @sni = args[:sni] if args.key?(:sni)
  @subject_alt_names = args[:subject_alt_names] if args.key?(:subject_alt_names)
end