Class: Google::Apis::ComputeAlpha::ClientTlsSettings
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::ClientTlsSettings
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
[Deprecated] The client side authentication settings for connection originating from the backend service. the backend service.
Instance Attribute Summary collapse
-
#client_tls_context ⇒ Google::Apis::ComputeAlpha::TlsContext
[Deprecated] The TLS settings for the client or server.
-
#mode ⇒ String
Indicates whether connections to this port should be secured using TLS.
-
#sni ⇒ String
SNI string to present to the server during TLS handshake.
-
#subject_alt_names ⇒ Array<String>
A list of alternate names to verify the subject identity in the certificate.If specified, the proxy will verify that the server certificate's subject alt name matches one of the specified values.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ClientTlsSettings
constructor
A new instance of ClientTlsSettings.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ClientTlsSettings
Returns a new instance of ClientTlsSettings.
8963 8964 8965 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 8963 def initialize(**args) update!(**args) end |
Instance Attribute Details
#client_tls_context ⇒ Google::Apis::ComputeAlpha::TlsContext
[Deprecated] The TLS settings for the client or server.
The TLS settings for the client or server.
Corresponds to the JSON property clientTlsContext
8935 8936 8937 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 8935 def client_tls_context @client_tls_context end |
#mode ⇒ String
Indicates whether connections to this port should be secured using TLS.
The value of this field determines how TLS is enforced. This can be set
to one of the following values: DISABLE: Do not setup a TLS connection to
the backends.
SIMPLE: Originate a TLS connection to the backends.
MUTUAL: Secure connections to the backends using mutual TLS by presenting
client certificates for authentication.
Corresponds to the JSON property mode
8946 8947 8948 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 8946 def mode @mode end |
#sni ⇒ String
SNI string to present to the server during TLS handshake. This field is
applicable only when mode is SIMPLE or MUTUAL.
Corresponds to the JSON property sni
8952 8953 8954 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 8952 def sni @sni end |
#subject_alt_names ⇒ Array<String>
A list of alternate names to verify the subject identity in the
certificate.If specified,
the proxy will verify that the server certificate's subject alt name
matches one of the specified values. This field is applicable only when
mode is SIMPLE or MUTUAL.
Corresponds to the JSON property subjectAltNames
8961 8962 8963 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 8961 def subject_alt_names @subject_alt_names end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8968 8969 8970 8971 8972 8973 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 8968 def update!(**args) @client_tls_context = args[:client_tls_context] if args.key?(:client_tls_context) @mode = args[:mode] if args.key?(:mode) @sni = args[:sni] if args.key?(:sni) @subject_alt_names = args[:subject_alt_names] if args.key?(:subject_alt_names) end |