Class: Google::Apis::ComputeAlpha::Commitment
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::Commitment
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Represents a regional resource-based commitment resource. Creating this commitment resource means that you are purchasing a resource-based committed use contract, with an explicit start and end time. You can purchase resource-based commitments for both hardware and software resources. For more information, read Resource-based committed use discounts
Instance Attribute Summary collapse
-
#auto_renew ⇒ Boolean
(also: #auto_renew?)
Specifies whether to automatically renew the commitment at the end of its current term.
-
#category ⇒ String
The category of the commitment; specifies whether the commitment is for hardware or software resources.
-
#creation_timestamp ⇒ String
Output only.
-
#custom_end_timestamp ⇒ String
[Input Only] Optional, specifies the requested commitment end time inRFC3339 text format.
-
#description ⇒ String
An optional description of the commitment.
-
#end_timestamp ⇒ String
Output only.
-
#existing_reservations ⇒ Array<String>
Corresponds to the JSON property
existingReservations. -
#id ⇒ Fixnum
Output only.
-
#kind ⇒ String
Output only.
-
#license_resource ⇒ Google::Apis::ComputeAlpha::LicenseResourceCommitment
Commitment for a particular license resource.
-
#merge_source_commitments ⇒ Array<String>
The list of source commitments that you are merging to create the new merged commitment.
-
#name ⇒ String
Name of the commitment.
-
#params ⇒ Google::Apis::ComputeAlpha::CommitmentParams
Additional commitment params.
-
#plan ⇒ String
The minimum time duration that you commit to purchasing resources.
-
#region ⇒ String
Output only.
-
#reservations ⇒ Array<Google::Apis::ComputeAlpha::Reservation>
The list of new reservations that you want to create and attach to this commitment.
-
#resource_status ⇒ Google::Apis::ComputeAlpha::CommitmentResourceStatus
[Output Only] Contains output only fields.
-
#resources ⇒ Array<Google::Apis::ComputeAlpha::ResourceCommitment>
The list of all the hardware resources, with their types and amounts, that you want to commit to.
-
#self_link ⇒ String
Output only.
-
#self_link_with_id ⇒ String
Output only.
-
#split_source_commitment ⇒ String
The source commitment from which you are transferring resources to create the new split commitment.
-
#start_timestamp ⇒ String
Output only.
-
#status ⇒ String
Output only.
-
#status_message ⇒ String
Output only.
-
#type ⇒ String
The type of commitment; specifies the machine series for which you want to commit to purchasing resources.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Commitment
constructor
A new instance of Commitment.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Commitment
Returns a new instance of Commitment.
9163 9164 9165 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 9163 def initialize(**args) update!(**args) end |
Instance Attribute Details
#auto_renew ⇒ Boolean Also known as: auto_renew?
Specifies whether to automatically renew the commitment at the end of its
current term. The default value is false. If you set the field
to true, each time your commitment reaches the end of its
term, Compute Engine automatically renews it for another term. You can
update this field anytime before the commitment expires. For example, if
the commitment is set to expire at 12 AM UTC-8 on January 3, 2027, you can
update this field until 11:59 PM UTC-8 on January 2, 2027.
Corresponds to the JSON property autoRenew
8977 8978 8979 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 8977 def auto_renew @auto_renew end |
#category ⇒ String
The category of the commitment; specifies whether the commitment is for
hardware or software resources. Category MACHINE specifies
that you are committing to hardware machine resources such asVCPU or MEMORY,
listed in resources.
Category LICENSE specifies that you are committing to software
licenses, listed in licenseResources.
Note that if you specify MACHINE commitments, then you must
also specify a type to indicate the machine series of the
hardware resource that you are committing to.
Corresponds to the JSON property category
8991 8992 8993 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 8991 def category @category end |
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
8997 8998 8999 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 8997 def @creation_timestamp end |
#custom_end_timestamp ⇒ String
[Input Only] Optional, specifies the requested commitment end time inRFC3339
text format. Use this option when the desired
commitment's end date is later than the start date + term duration.
Corresponds to the JSON property customEndTimestamp
9004 9005 9006 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 9004 def @custom_end_timestamp end |
#description ⇒ String
An optional description of the commitment. You can provide this property
when you create the resource.
Corresponds to the JSON property description
9010 9011 9012 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 9010 def description @description end |
#end_timestamp ⇒ String
Output only. [Output Only] Commitment end time inRFC3339
text format.
Corresponds to the JSON property endTimestamp
9016 9017 9018 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 9016 def @end_timestamp end |
#existing_reservations ⇒ Array<String>
Corresponds to the JSON property existingReservations
9021 9022 9023 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 9021 def existing_reservations @existing_reservations end |
#id ⇒ Fixnum
Output only. [Output Only] The unique identifier for the resource. This
identifier is
defined by the server.
Corresponds to the JSON property id
9028 9029 9030 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 9028 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Always compute#commitment
for commitments.
Corresponds to the JSON property kind
9034 9035 9036 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 9034 def kind @kind end |
#license_resource ⇒ Google::Apis::ComputeAlpha::LicenseResourceCommitment
Commitment for a particular license resource.
Corresponds to the JSON property licenseResource
9039 9040 9041 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 9039 def license_resource @license_resource end |
#merge_source_commitments ⇒ Array<String>
The list of source commitments that you are merging to create the new
merged commitment. For more information, see
Merging commitments.
Corresponds to the JSON property mergeSourceCommitments
9046 9047 9048 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 9046 def merge_source_commitments @merge_source_commitments end |
#name ⇒ String
Name of the commitment. You must specify a name when you purchase the
commitment. The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must
be a dash, lowercase letter, or digit, except the last character, which
cannot be a dash.
Corresponds to the JSON property name
9057 9058 9059 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 9057 def name @name end |
#params ⇒ Google::Apis::ComputeAlpha::CommitmentParams
Additional commitment params.
Corresponds to the JSON property params
9062 9063 9064 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 9062 def params @params end |
#plan ⇒ String
The minimum time duration that you commit to purchasing resources.
The plan that you choose determines the preset term length of the
commitment (which is 1 year or 3 years) and affects the discount rate that
you receive for your resources. Committing to a longer time duration
typically gives you a higher discount rate. The supported values for this
field are TWELVE_MONTH (1 year), andTHIRTY_SIX_MONTH (3 years).
Corresponds to the JSON property plan
9072 9073 9074 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 9072 def plan @plan end |
#region ⇒ String
Output only. [Output Only] URL of the region where the commitment and
committed
resources are located.
Corresponds to the JSON property region
9079 9080 9081 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 9079 def region @region end |
#reservations ⇒ Array<Google::Apis::ComputeAlpha::Reservation>
The list of new reservations that you want to create and attach to this
commitment.
You must attach reservations to your commitment if your commitment
specifies any GPUs or Local SSD disks. For more information, see
Attach reservations to resource-based commitments.
Specify this property only if you want to create new
reservations to attach. To attach existing reservations, specify
theexistingReservations property instead.
Corresponds to the JSON property reservations
9091 9092 9093 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 9091 def reservations @reservations end |
#resource_status ⇒ Google::Apis::ComputeAlpha::CommitmentResourceStatus
[Output Only] Contains output only fields.
Corresponds to the JSON property resourceStatus
9096 9097 9098 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 9096 def resource_status @resource_status end |
#resources ⇒ Array<Google::Apis::ComputeAlpha::ResourceCommitment>
The list of all the hardware resources, with their types and amounts, that
you want to commit to. Specify as a separate entry in the list for each
individual resource type.
Corresponds to the JSON property resources
9103 9104 9105 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 9103 def resources @resources end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
9108 9109 9110 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 9108 def self_link @self_link end |
#self_link_with_id ⇒ String
Output only. [Output Only] Server-defined URL for this resource with the
resource id.
Corresponds to the JSON property selfLinkWithId
9114 9115 9116 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 9114 def self_link_with_id @self_link_with_id end |
#split_source_commitment ⇒ String
The source commitment from which you are transferring resources to create
the new split commitment. For more information, see
Split commitments.
Corresponds to the JSON property splitSourceCommitment
9121 9122 9123 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 9121 def split_source_commitment @split_source_commitment end |
#start_timestamp ⇒ String
Output only. [Output Only] Commitment start time inRFC3339
text format.
Corresponds to the JSON property startTimestamp
9127 9128 9129 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 9127 def @start_timestamp end |
#status ⇒ String
Output only. [Output Only] Status of the commitment with regards to eventual
expiration
(each commitment has an end date defined). Status can be one of the
following values: NOT_YET_ACTIVE, ACTIVE, orEXPIRED.
Corresponds to the JSON property status
9135 9136 9137 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 9135 def status @status end |
#status_message ⇒ String
Output only. [Output Only] An optional, human-readable explanation of the
status.
Corresponds to the JSON property statusMessage
9141 9142 9143 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 9141 def @status_message end |
#type ⇒ String
The type of commitment; specifies the
machine series for which you want to commit to purchasing resources.
The choice of machine series affects the discount rate and the eligible
resource types.
The type must be one of the following:ACCELERATOR_OPTIMIZED,
ACCELERATOR_OPTIMIZED_A3,ACCELERATOR_OPTIMIZED_A3_MEGA,COMPUTE_OPTIMIZED,
COMPUTE_OPTIMIZED_C2D,
COMPUTE_OPTIMIZED_C3, COMPUTE_OPTIMIZED_C3D,COMPUTE_OPTIMIZED_H3,
GENERAL_PURPOSE,GENERAL_PURPOSE_C4, GENERAL_PURPOSE_E2,GENERAL_PURPOSE_N2,
GENERAL_PURPOSE_N2D,GENERAL_PURPOSE_N4, GENERAL_PURPOSE_T2D,GRAPHICS_OPTIMIZED,
GRAPHICS_OPTIMIZED_G4,GRAPHICS_OPTIMIZED_G4_VGPU,MEMORY_OPTIMIZED,
MEMORY_OPTIMIZED_M3,MEMORY_OPTIMIZED_X4, STORAGE_OPTIMIZED_Z3. For
example, type MEMORY_OPTIMIZED specifies a commitment that
applies only to eligible resources of memory optimized M1 and M2 machine
series. Type GENERAL_PURPOSE specifies a commitment that
applies only to eligible resources of general purpose N1 machine series.
Corresponds to the JSON property type
9161 9162 9163 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 9161 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9168 9169 9170 9171 9172 9173 9174 9175 9176 9177 9178 9179 9180 9181 9182 9183 9184 9185 9186 9187 9188 9189 9190 9191 9192 9193 9194 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 9168 def update!(**args) @auto_renew = args[:auto_renew] if args.key?(:auto_renew) @category = args[:category] if args.key?(:category) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @custom_end_timestamp = args[:custom_end_timestamp] if args.key?(:custom_end_timestamp) @description = args[:description] if args.key?(:description) @end_timestamp = args[:end_timestamp] if args.key?(:end_timestamp) @existing_reservations = args[:existing_reservations] if args.key?(:existing_reservations) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @license_resource = args[:license_resource] if args.key?(:license_resource) @merge_source_commitments = args[:merge_source_commitments] if args.key?(:merge_source_commitments) @name = args[:name] if args.key?(:name) @params = args[:params] if args.key?(:params) @plan = args[:plan] if args.key?(:plan) @region = args[:region] if args.key?(:region) @reservations = args[:reservations] if args.key?(:reservations) @resource_status = args[:resource_status] if args.key?(:resource_status) @resources = args[:resources] if args.key?(:resources) @self_link = args[:self_link] if args.key?(:self_link) @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id) @split_source_commitment = args[:split_source_commitment] if args.key?(:split_source_commitment) @start_timestamp = args[:start_timestamp] if args.key?(:start_timestamp) @status = args[:status] if args.key?(:status) @status_message = args[:status_message] if args.key?(:status_message) @type = args[:type] if args.key?(:type) end |