Class: Google::Apis::ComputeAlpha::Commitment
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::Commitment
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Represents a regional resource-based commitment resource. Creating this commitment resource means that you are purchasing a resource-based committed use contract, with an explicit start and end time. You can purchase resource-based commitments for both hardware and software resources. For more information, read Resource-based committed use discounts
Instance Attribute Summary collapse
-
#auto_renew ⇒ Boolean
(also: #auto_renew?)
Specifies whether to automatically renew the commitment at the end of its current term.
-
#category ⇒ String
The category of the commitment; specifies whether the commitment is for hardware or software resources.
-
#creation_timestamp ⇒ String
Output only.
-
#custom_end_timestamp ⇒ String
[Input Only] Optional, specifies the requested commitment end time inRFC3339 text format.
-
#description ⇒ String
An optional description of the commitment.
-
#end_timestamp ⇒ String
Output only.
-
#existing_reservations ⇒ Array<String>
Corresponds to the JSON property
existingReservations. -
#id ⇒ Fixnum
Output only.
-
#kind ⇒ String
Output only.
-
#license_resource ⇒ Google::Apis::ComputeAlpha::LicenseResourceCommitment
Commitment for a particular license resource.
-
#merge_source_commitments ⇒ Array<String>
The list of source commitments that you are merging to create the new merged commitment.
-
#name ⇒ String
Name of the commitment.
-
#plan ⇒ String
The minimum time duration that you commit to purchasing resources.
-
#region ⇒ String
Output only.
-
#reservations ⇒ Array<Google::Apis::ComputeAlpha::Reservation>
The list of new reservations that you want to create and attach to this commitment.
-
#resource_status ⇒ Google::Apis::ComputeAlpha::CommitmentResourceStatus
[Output Only] Contains output only fields.
-
#resources ⇒ Array<Google::Apis::ComputeAlpha::ResourceCommitment>
The list of all the hardware resources, with their types and amounts, that you want to commit to.
-
#self_link ⇒ String
Output only.
-
#self_link_with_id ⇒ String
Output only.
-
#split_source_commitment ⇒ String
The source commitment from which you are transferring resources to create the new split commitment.
-
#start_timestamp ⇒ String
Output only.
-
#status ⇒ String
Output only.
-
#status_message ⇒ String
Output only.
-
#type ⇒ String
The type of commitment; specifies the machine series for which you want to commit to purchasing resources.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Commitment
constructor
A new instance of Commitment.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Commitment
Returns a new instance of Commitment.
8941 8942 8943 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 8941 def initialize(**args) update!(**args) end |
Instance Attribute Details
#auto_renew ⇒ Boolean Also known as: auto_renew?
Specifies whether to automatically renew the commitment at the end of its
current term. The default value is false. If you set the field
to true, each time your commitment reaches the end of its
term, Compute Engine automatically renews it for another term. You can
update this field anytime before the commitment expires. For example, if
the commitment is set to expire at 12 AM UTC-8 on January 3, 2027, you can
update this field until 11:59 PM UTC-8 on January 2, 2027.
Corresponds to the JSON property autoRenew
8760 8761 8762 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 8760 def auto_renew @auto_renew end |
#category ⇒ String
The category of the commitment; specifies whether the commitment is for
hardware or software resources. Category MACHINE specifies
that you are committing to hardware machine resources such asVCPU or MEMORY,
listed in resources.
Category LICENSE specifies that you are committing to software
licenses, listed in licenseResources.
Note that if you specify MACHINE commitments, then you must
also specify a type to indicate the machine series of the
hardware resource that you are committing to.
Corresponds to the JSON property category
8774 8775 8776 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 8774 def category @category end |
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
8780 8781 8782 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 8780 def @creation_timestamp end |
#custom_end_timestamp ⇒ String
[Input Only] Optional, specifies the requested commitment end time inRFC3339
text format. Use this option when the desired
commitment's end date is later than the start date + term duration.
Corresponds to the JSON property customEndTimestamp
8787 8788 8789 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 8787 def @custom_end_timestamp end |
#description ⇒ String
An optional description of the commitment. You can provide this property
when you create the resource.
Corresponds to the JSON property description
8793 8794 8795 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 8793 def description @description end |
#end_timestamp ⇒ String
Output only. [Output Only] Commitment end time inRFC3339
text format.
Corresponds to the JSON property endTimestamp
8799 8800 8801 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 8799 def @end_timestamp end |
#existing_reservations ⇒ Array<String>
Corresponds to the JSON property existingReservations
8804 8805 8806 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 8804 def existing_reservations @existing_reservations end |
#id ⇒ Fixnum
Output only. [Output Only] The unique identifier for the resource. This
identifier is
defined by the server.
Corresponds to the JSON property id
8811 8812 8813 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 8811 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Always compute#commitment
for commitments.
Corresponds to the JSON property kind
8817 8818 8819 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 8817 def kind @kind end |
#license_resource ⇒ Google::Apis::ComputeAlpha::LicenseResourceCommitment
Commitment for a particular license resource.
Corresponds to the JSON property licenseResource
8822 8823 8824 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 8822 def license_resource @license_resource end |
#merge_source_commitments ⇒ Array<String>
The list of source commitments that you are merging to create the new
merged commitment. For more information, see
Merging commitments.
Corresponds to the JSON property mergeSourceCommitments
8829 8830 8831 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 8829 def merge_source_commitments @merge_source_commitments end |
#name ⇒ String
Name of the commitment. You must specify a name when you purchase the
commitment. The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must
be a dash, lowercase letter, or digit, except the last character, which
cannot be a dash.
Corresponds to the JSON property name
8840 8841 8842 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 8840 def name @name end |
#plan ⇒ String
The minimum time duration that you commit to purchasing resources.
The plan that you choose determines the preset term length of the
commitment (which is 1 year or 3 years) and affects the discount rate that
you receive for your resources. Committing to a longer time duration
typically gives you a higher discount rate. The supported values for this
field are TWELVE_MONTH (1 year), andTHIRTY_SIX_MONTH (3 years).
Corresponds to the JSON property plan
8850 8851 8852 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 8850 def plan @plan end |
#region ⇒ String
Output only. [Output Only] URL of the region where the commitment and
committed
resources are located.
Corresponds to the JSON property region
8857 8858 8859 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 8857 def region @region end |
#reservations ⇒ Array<Google::Apis::ComputeAlpha::Reservation>
The list of new reservations that you want to create and attach to this
commitment.
You must attach reservations to your commitment if your commitment
specifies any GPUs or Local SSD disks. For more information, see
Attach reservations to resource-based commitments.
Specify this property only if you want to create new
reservations to attach. To attach existing reservations, specify
theexistingReservations property instead.
Corresponds to the JSON property reservations
8869 8870 8871 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 8869 def reservations @reservations end |
#resource_status ⇒ Google::Apis::ComputeAlpha::CommitmentResourceStatus
[Output Only] Contains output only fields.
Corresponds to the JSON property resourceStatus
8874 8875 8876 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 8874 def resource_status @resource_status end |
#resources ⇒ Array<Google::Apis::ComputeAlpha::ResourceCommitment>
The list of all the hardware resources, with their types and amounts, that
you want to commit to. Specify as a separate entry in the list for each
individual resource type.
Corresponds to the JSON property resources
8881 8882 8883 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 8881 def resources @resources end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
8886 8887 8888 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 8886 def self_link @self_link end |
#self_link_with_id ⇒ String
Output only. [Output Only] Server-defined URL for this resource with the
resource id.
Corresponds to the JSON property selfLinkWithId
8892 8893 8894 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 8892 def self_link_with_id @self_link_with_id end |
#split_source_commitment ⇒ String
The source commitment from which you are transferring resources to create
the new split commitment. For more information, see
Split commitments.
Corresponds to the JSON property splitSourceCommitment
8899 8900 8901 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 8899 def split_source_commitment @split_source_commitment end |
#start_timestamp ⇒ String
Output only. [Output Only] Commitment start time inRFC3339
text format.
Corresponds to the JSON property startTimestamp
8905 8906 8907 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 8905 def @start_timestamp end |
#status ⇒ String
Output only. [Output Only] Status of the commitment with regards to eventual
expiration
(each commitment has an end date defined). Status can be one of the
following values: NOT_YET_ACTIVE, ACTIVE, orEXPIRED.
Corresponds to the JSON property status
8913 8914 8915 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 8913 def status @status end |
#status_message ⇒ String
Output only. [Output Only] An optional, human-readable explanation of the
status.
Corresponds to the JSON property statusMessage
8919 8920 8921 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 8919 def @status_message end |
#type ⇒ String
The type of commitment; specifies the
machine series for which you want to commit to purchasing resources.
The choice of machine series affects the discount rate and the eligible
resource types.
The type must be one of the following:ACCELERATOR_OPTIMIZED,
ACCELERATOR_OPTIMIZED_A3,ACCELERATOR_OPTIMIZED_A3_MEGA,COMPUTE_OPTIMIZED,
COMPUTE_OPTIMIZED_C2D,
COMPUTE_OPTIMIZED_C3, COMPUTE_OPTIMIZED_C3D,COMPUTE_OPTIMIZED_H3,
GENERAL_PURPOSE,GENERAL_PURPOSE_C4, GENERAL_PURPOSE_E2,GENERAL_PURPOSE_N2,
GENERAL_PURPOSE_N2D,GENERAL_PURPOSE_N4, GENERAL_PURPOSE_T2D,GRAPHICS_OPTIMIZED,
GRAPHICS_OPTIMIZED_G4,MEMORY_OPTIMIZED, MEMORY_OPTIMIZED_M3,
MEMORY_OPTIMIZED_X4, STORAGE_OPTIMIZED_Z3. For
example, type MEMORY_OPTIMIZED specifies a commitment that
applies only to eligible resources of memory optimized M1 and M2 machine
series. Type GENERAL_PURPOSE specifies a commitment that
applies only to eligible resources of general purpose N1 machine series.
Corresponds to the JSON property type
8939 8940 8941 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 8939 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8946 8947 8948 8949 8950 8951 8952 8953 8954 8955 8956 8957 8958 8959 8960 8961 8962 8963 8964 8965 8966 8967 8968 8969 8970 8971 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 8946 def update!(**args) @auto_renew = args[:auto_renew] if args.key?(:auto_renew) @category = args[:category] if args.key?(:category) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @custom_end_timestamp = args[:custom_end_timestamp] if args.key?(:custom_end_timestamp) @description = args[:description] if args.key?(:description) @end_timestamp = args[:end_timestamp] if args.key?(:end_timestamp) @existing_reservations = args[:existing_reservations] if args.key?(:existing_reservations) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @license_resource = args[:license_resource] if args.key?(:license_resource) @merge_source_commitments = args[:merge_source_commitments] if args.key?(:merge_source_commitments) @name = args[:name] if args.key?(:name) @plan = args[:plan] if args.key?(:plan) @region = args[:region] if args.key?(:region) @reservations = args[:reservations] if args.key?(:reservations) @resource_status = args[:resource_status] if args.key?(:resource_status) @resources = args[:resources] if args.key?(:resources) @self_link = args[:self_link] if args.key?(:self_link) @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id) @split_source_commitment = args[:split_source_commitment] if args.key?(:split_source_commitment) @start_timestamp = args[:start_timestamp] if args.key?(:start_timestamp) @status = args[:status] if args.key?(:status) @status_message = args[:status_message] if args.key?(:status_message) @type = args[:type] if args.key?(:type) end |