Class: Google::Apis::ComputeAlpha::CommitmentList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of Commitment resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CommitmentList

Returns a new instance of CommitmentList.



9369
9370
9371
# File 'lib/google/apis/compute_alpha/classes.rb', line 9369

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


9336
9337
9338
# File 'lib/google/apis/compute_alpha/classes.rb', line 9336

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::Commitment>

A list of Commitment resources. Corresponds to the JSON property items



9341
9342
9343
# File 'lib/google/apis/compute_alpha/classes.rb', line 9341

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#commitmentList for lists of commitments. Corresponds to the JSON property kind

Returns:

  • (String)


9347
9348
9349
# File 'lib/google/apis/compute_alpha/classes.rb', line 9347

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


9357
9358
9359
# File 'lib/google/apis/compute_alpha/classes.rb', line 9357

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


9362
9363
9364
# File 'lib/google/apis/compute_alpha/classes.rb', line 9362

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::CommitmentList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



9367
9368
9369
# File 'lib/google/apis/compute_alpha/classes.rb', line 9367

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9374
9375
9376
9377
9378
9379
9380
9381
# File 'lib/google/apis/compute_alpha/classes.rb', line 9374

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end