Class: Google::Apis::ComputeAlpha::CommitmentList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::CommitmentList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Contains a list of Commitment resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::Commitment>
A list of Commitment resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::CommitmentList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CommitmentList
constructor
A new instance of CommitmentList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CommitmentList
Returns a new instance of CommitmentList.
9386 9387 9388 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 9386 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
9353 9354 9355 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 9353 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::Commitment>
A list of Commitment resources.
Corresponds to the JSON property items
9358 9359 9360 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 9358 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#commitmentList
for lists of commitments.
Corresponds to the JSON property kind
9364 9365 9366 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 9364 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
9374 9375 9376 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 9374 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
9379 9380 9381 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 9379 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::CommitmentList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
9384 9385 9386 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 9384 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9391 9392 9393 9394 9395 9396 9397 9398 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 9391 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |