Class: Google::Apis::ComputeAlpha::CommitmentList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of Commitment resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CommitmentList

Returns a new instance of CommitmentList.



9391
9392
9393
# File 'lib/google/apis/compute_alpha/classes.rb', line 9391

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


9358
9359
9360
# File 'lib/google/apis/compute_alpha/classes.rb', line 9358

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::Commitment>

A list of Commitment resources. Corresponds to the JSON property items



9363
9364
9365
# File 'lib/google/apis/compute_alpha/classes.rb', line 9363

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#commitmentList for lists of commitments. Corresponds to the JSON property kind

Returns:

  • (String)


9369
9370
9371
# File 'lib/google/apis/compute_alpha/classes.rb', line 9369

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


9379
9380
9381
# File 'lib/google/apis/compute_alpha/classes.rb', line 9379

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


9384
9385
9386
# File 'lib/google/apis/compute_alpha/classes.rb', line 9384

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::CommitmentList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



9389
9390
9391
# File 'lib/google/apis/compute_alpha/classes.rb', line 9389

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9396
9397
9398
9399
9400
9401
9402
9403
# File 'lib/google/apis/compute_alpha/classes.rb', line 9396

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end