Class: Google::Apis::ComputeAlpha::CommitmentParams
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::CommitmentParams
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Additional commitment params.
Instance Attribute Summary collapse
-
#resource_manager_tags ⇒ Hash<String,String>
Input only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CommitmentParams
constructor
A new instance of CommitmentParams.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CommitmentParams
Returns a new instance of CommitmentParams.
9469 9470 9471 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 9469 def initialize(**args) update!(**args) end |
Instance Attribute Details
#resource_manager_tags ⇒ Hash<String,String>
Input only. Resource manager tags to be bound to the commitment. Tag keys and
values have the same definition as resource
manager tags. Keys and values can be either in numeric format,
such as tagKeys/tag_key_idand `tagValues/`tag_value_id or in
namespaced format such as org_id|project_id`/`tag_key_short_name and
tag_value_short_name. The field is ignored (both PUT &
PATCH) when empty.
Corresponds to the JSON property resourceManagerTags
9467 9468 9469 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 9467 def @resource_manager_tags end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9474 9475 9476 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 9474 def update!(**args) @resource_manager_tags = args[:resource_manager_tags] if args.key?(:resource_manager_tags) end |