Class: Google::Apis::ComputeAlpha::CommitmentResourceStatusCancellationInformation
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::CommitmentResourceStatusCancellationInformation
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#canceled_commitment ⇒ Google::Apis::ComputeAlpha::Money
Represents an amount of money with its currency type.
-
#canceled_commitment_last_updated_timestamp ⇒ String
Output only.
-
#cancellation_cap ⇒ Google::Apis::ComputeAlpha::Money
Represents an amount of money with its currency type.
-
#cancellation_fee ⇒ Google::Apis::ComputeAlpha::Money
Represents an amount of money with its currency type.
-
#cancellation_fee_expiration_timestamp ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CommitmentResourceStatusCancellationInformation
constructor
A new instance of CommitmentResourceStatusCancellationInformation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CommitmentResourceStatusCancellationInformation
Returns a new instance of CommitmentResourceStatusCancellationInformation.
9836 9837 9838 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 9836 def initialize(**args) update!(**args) end |
Instance Attribute Details
#canceled_commitment ⇒ Google::Apis::ComputeAlpha::Money
Represents an amount of money with its currency type.
Corresponds to the JSON property canceledCommitment
9812 9813 9814 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 9812 def canceled_commitment @canceled_commitment end |
#canceled_commitment_last_updated_timestamp ⇒ String
Output only. [Output Only] An optional last update time of canceled_commitment.
RFC3339 text format.
Corresponds to the JSON property canceledCommitmentLastUpdatedTimestamp
9818 9819 9820 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 9818 def @canceled_commitment_last_updated_timestamp end |
#cancellation_cap ⇒ Google::Apis::ComputeAlpha::Money
Represents an amount of money with its currency type.
Corresponds to the JSON property cancellationCap
9823 9824 9825 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 9823 def cancellation_cap @cancellation_cap end |
#cancellation_fee ⇒ Google::Apis::ComputeAlpha::Money
Represents an amount of money with its currency type.
Corresponds to the JSON property cancellationFee
9828 9829 9830 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 9828 def cancellation_fee @cancellation_fee end |
#cancellation_fee_expiration_timestamp ⇒ String
Output only. [Output Only] An optional, cancellation fee expiration time.
RFC3339 text format.
Corresponds to the JSON property cancellationFeeExpirationTimestamp
9834 9835 9836 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 9834 def @cancellation_fee_expiration_timestamp end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9841 9842 9843 9844 9845 9846 9847 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 9841 def update!(**args) @canceled_commitment = args[:canceled_commitment] if args.key?(:canceled_commitment) @canceled_commitment_last_updated_timestamp = args[:canceled_commitment_last_updated_timestamp] if args.key?(:canceled_commitment_last_updated_timestamp) @cancellation_cap = args[:cancellation_cap] if args.key?(:cancellation_cap) @cancellation_fee = args[:cancellation_fee] if args.key?(:cancellation_fee) @cancellation_fee_expiration_timestamp = args[:cancellation_fee_expiration_timestamp] if args.key?(:cancellation_fee_expiration_timestamp) end |