Class: Google::Apis::ComputeAlpha::CommitmentResourceStatusCancellationInformation
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::CommitmentResourceStatusCancellationInformation
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#canceled_commitment ⇒ Google::Apis::ComputeAlpha::Money
Represents an amount of money with its currency type.
-
#canceled_commitment_last_updated_timestamp ⇒ String
Output only.
-
#cancellation_cap ⇒ Google::Apis::ComputeAlpha::Money
Represents an amount of money with its currency type.
-
#cancellation_fee ⇒ Google::Apis::ComputeAlpha::Money
Represents an amount of money with its currency type.
-
#cancellation_fee_expiration_timestamp ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CommitmentResourceStatusCancellationInformation
constructor
A new instance of CommitmentResourceStatusCancellationInformation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CommitmentResourceStatusCancellationInformation
Returns a new instance of CommitmentResourceStatusCancellationInformation.
9539 9540 9541 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 9539 def initialize(**args) update!(**args) end |
Instance Attribute Details
#canceled_commitment ⇒ Google::Apis::ComputeAlpha::Money
Represents an amount of money with its currency type.
Corresponds to the JSON property canceledCommitment
9515 9516 9517 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 9515 def canceled_commitment @canceled_commitment end |
#canceled_commitment_last_updated_timestamp ⇒ String
Output only. [Output Only] An optional last update time of canceled_commitment.
RFC3339 text format.
Corresponds to the JSON property canceledCommitmentLastUpdatedTimestamp
9521 9522 9523 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 9521 def @canceled_commitment_last_updated_timestamp end |
#cancellation_cap ⇒ Google::Apis::ComputeAlpha::Money
Represents an amount of money with its currency type.
Corresponds to the JSON property cancellationCap
9526 9527 9528 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 9526 def cancellation_cap @cancellation_cap end |
#cancellation_fee ⇒ Google::Apis::ComputeAlpha::Money
Represents an amount of money with its currency type.
Corresponds to the JSON property cancellationFee
9531 9532 9533 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 9531 def cancellation_fee @cancellation_fee end |
#cancellation_fee_expiration_timestamp ⇒ String
Output only. [Output Only] An optional, cancellation fee expiration time.
RFC3339 text format.
Corresponds to the JSON property cancellationFeeExpirationTimestamp
9537 9538 9539 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 9537 def @cancellation_fee_expiration_timestamp end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9544 9545 9546 9547 9548 9549 9550 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 9544 def update!(**args) @canceled_commitment = args[:canceled_commitment] if args.key?(:canceled_commitment) @canceled_commitment_last_updated_timestamp = args[:canceled_commitment_last_updated_timestamp] if args.key?(:canceled_commitment_last_updated_timestamp) @cancellation_cap = args[:cancellation_cap] if args.key?(:cancellation_cap) @cancellation_fee = args[:cancellation_fee] if args.key?(:cancellation_fee) @cancellation_fee_expiration_timestamp = args[:cancellation_fee_expiration_timestamp] if args.key?(:cancellation_fee_expiration_timestamp) end |