Class: Google::Apis::ComputeAlpha::CommitmentResourceStatusCancellationInformation
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::CommitmentResourceStatusCancellationInformation
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#canceled_commitment ⇒ Google::Apis::ComputeAlpha::Money
Represents an amount of money with its currency type.
-
#canceled_commitment_last_updated_timestamp ⇒ String
Output only.
-
#cancellation_cap ⇒ Google::Apis::ComputeAlpha::Money
Represents an amount of money with its currency type.
-
#cancellation_fee ⇒ Google::Apis::ComputeAlpha::Money
Represents an amount of money with its currency type.
-
#cancellation_fee_expiration_timestamp ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CommitmentResourceStatusCancellationInformation
constructor
A new instance of CommitmentResourceStatusCancellationInformation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CommitmentResourceStatusCancellationInformation
Returns a new instance of CommitmentResourceStatusCancellationInformation.
9291 9292 9293 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 9291 def initialize(**args) update!(**args) end |
Instance Attribute Details
#canceled_commitment ⇒ Google::Apis::ComputeAlpha::Money
Represents an amount of money with its currency type.
Corresponds to the JSON property canceledCommitment
9267 9268 9269 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 9267 def canceled_commitment @canceled_commitment end |
#canceled_commitment_last_updated_timestamp ⇒ String
Output only. [Output Only] An optional last update time of canceled_commitment.
RFC3339 text format.
Corresponds to the JSON property canceledCommitmentLastUpdatedTimestamp
9273 9274 9275 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 9273 def @canceled_commitment_last_updated_timestamp end |
#cancellation_cap ⇒ Google::Apis::ComputeAlpha::Money
Represents an amount of money with its currency type.
Corresponds to the JSON property cancellationCap
9278 9279 9280 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 9278 def cancellation_cap @cancellation_cap end |
#cancellation_fee ⇒ Google::Apis::ComputeAlpha::Money
Represents an amount of money with its currency type.
Corresponds to the JSON property cancellationFee
9283 9284 9285 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 9283 def cancellation_fee @cancellation_fee end |
#cancellation_fee_expiration_timestamp ⇒ String
Output only. [Output Only] An optional, cancellation fee expiration time.
RFC3339 text format.
Corresponds to the JSON property cancellationFeeExpirationTimestamp
9289 9290 9291 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 9289 def @cancellation_fee_expiration_timestamp end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9296 9297 9298 9299 9300 9301 9302 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 9296 def update!(**args) @canceled_commitment = args[:canceled_commitment] if args.key?(:canceled_commitment) @canceled_commitment_last_updated_timestamp = args[:canceled_commitment_last_updated_timestamp] if args.key?(:canceled_commitment_last_updated_timestamp) @cancellation_cap = args[:cancellation_cap] if args.key?(:cancellation_cap) @cancellation_fee = args[:cancellation_fee] if args.key?(:cancellation_fee) @cancellation_fee_expiration_timestamp = args[:cancellation_fee_expiration_timestamp] if args.key?(:cancellation_fee_expiration_timestamp) end |