Class: Google::Apis::ComputeAlpha::CompositeHealthCheckAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of CompositeHealthChecksScopedList.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CompositeHealthCheckAggregatedList

Returns a new instance of CompositeHealthCheckAggregatedList.



10104
10105
10106
# File 'lib/google/apis/compute_alpha/classes.rb', line 10104

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


10067
10068
10069
# File 'lib/google/apis/compute_alpha/classes.rb', line 10067

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::CompositeHealthChecksScopedList>

A list of CompositeHealthChecksScopedList resources. Corresponds to the JSON property items



10072
10073
10074
# File 'lib/google/apis/compute_alpha/classes.rb', line 10072

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


10077
10078
10079
# File 'lib/google/apis/compute_alpha/classes.rb', line 10077

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


10087
10088
10089
# File 'lib/google/apis/compute_alpha/classes.rb', line 10087

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


10092
10093
10094
# File 'lib/google/apis/compute_alpha/classes.rb', line 10092

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


10097
10098
10099
# File 'lib/google/apis/compute_alpha/classes.rb', line 10097

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::CompositeHealthCheckAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



10102
10103
10104
# File 'lib/google/apis/compute_alpha/classes.rb', line 10102

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10109
10110
10111
10112
10113
10114
10115
10116
10117
# File 'lib/google/apis/compute_alpha/classes.rb', line 10109

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end