Class: Google::Apis::ComputeAlpha::CompositeHealthCheckAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of CompositeHealthChecksScopedList.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CompositeHealthCheckAggregatedList

Returns a new instance of CompositeHealthCheckAggregatedList.



9846
9847
9848
# File 'lib/google/apis/compute_alpha/classes.rb', line 9846

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


9809
9810
9811
# File 'lib/google/apis/compute_alpha/classes.rb', line 9809

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::CompositeHealthChecksScopedList>

A list of CompositeHealthChecksScopedList resources. Corresponds to the JSON property items



9814
9815
9816
# File 'lib/google/apis/compute_alpha/classes.rb', line 9814

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


9819
9820
9821
# File 'lib/google/apis/compute_alpha/classes.rb', line 9819

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


9829
9830
9831
# File 'lib/google/apis/compute_alpha/classes.rb', line 9829

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


9834
9835
9836
# File 'lib/google/apis/compute_alpha/classes.rb', line 9834

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


9839
9840
9841
# File 'lib/google/apis/compute_alpha/classes.rb', line 9839

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::CompositeHealthCheckAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



9844
9845
9846
# File 'lib/google/apis/compute_alpha/classes.rb', line 9844

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9851
9852
9853
9854
9855
9856
9857
9858
9859
# File 'lib/google/apis/compute_alpha/classes.rb', line 9851

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end