Class: Google::Apis::ComputeAlpha::CompositeHealthCheckAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::CompositeHealthCheckAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Contains a list of CompositeHealthChecksScopedList.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::CompositeHealthChecksScopedList>
A list of CompositeHealthChecksScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::CompositeHealthCheckAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CompositeHealthCheckAggregatedList
constructor
A new instance of CompositeHealthCheckAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CompositeHealthCheckAggregatedList
Returns a new instance of CompositeHealthCheckAggregatedList.
9559 9560 9561 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 9559 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
9522 9523 9524 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 9522 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::CompositeHealthChecksScopedList>
A list of CompositeHealthChecksScopedList resources.
Corresponds to the JSON property items
9527 9528 9529 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 9527 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
9532 9533 9534 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 9532 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
9542 9543 9544 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 9542 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
9547 9548 9549 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 9547 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
9552 9553 9554 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 9552 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::CompositeHealthCheckAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
9557 9558 9559 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 9557 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9564 9565 9566 9567 9568 9569 9570 9571 9572 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 9564 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |