Class: Google::Apis::ComputeAlpha::CompositeHealthCheckList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::CompositeHealthCheckList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::CompositeHealthCheck>
A list of CompositeHealthCheck resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
-
#warning ⇒ Google::Apis::ComputeAlpha::CompositeHealthCheckList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CompositeHealthCheckList
constructor
A new instance of CompositeHealthCheckList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CompositeHealthCheckList
Returns a new instance of CompositeHealthCheckList.
10423 10424 10425 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 10423 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
10390 10391 10392 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 10390 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::CompositeHealthCheck>
A list of CompositeHealthCheck resources.
Corresponds to the JSON property items
10395 10396 10397 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 10395 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#
compositeHealthCheck for composite health checks.
Corresponds to the JSON property kind
10401 10402 10403 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 10401 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
10411 10412 10413 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 10411 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
10416 10417 10418 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 10416 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::CompositeHealthCheckList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
10421 10422 10423 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 10421 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10428 10429 10430 10431 10432 10433 10434 10435 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 10428 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |