Class: Google::Apis::ComputeAlpha::CompositeHealthCheckList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CompositeHealthCheckList

Returns a new instance of CompositeHealthCheckList.



9966
9967
9968
# File 'lib/google/apis/compute_alpha/classes.rb', line 9966

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


9933
9934
9935
# File 'lib/google/apis/compute_alpha/classes.rb', line 9933

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::CompositeHealthCheck>

A list of CompositeHealthCheck resources. Corresponds to the JSON property items



9938
9939
9940
# File 'lib/google/apis/compute_alpha/classes.rb', line 9938

def items
  @items
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# compositeHealthCheck for composite health checks. Corresponds to the JSON property kind

Returns:

  • (String)


9944
9945
9946
# File 'lib/google/apis/compute_alpha/classes.rb', line 9944

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


9954
9955
9956
# File 'lib/google/apis/compute_alpha/classes.rb', line 9954

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


9959
9960
9961
# File 'lib/google/apis/compute_alpha/classes.rb', line 9959

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::CompositeHealthCheckList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



9964
9965
9966
# File 'lib/google/apis/compute_alpha/classes.rb', line 9964

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9971
9972
9973
9974
9975
9976
9977
9978
# File 'lib/google/apis/compute_alpha/classes.rb', line 9971

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end