Class: Google::Apis::ComputeAlpha::CompositeHealthCheckList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CompositeHealthCheckList

Returns a new instance of CompositeHealthCheckList.



9988
9989
9990
# File 'lib/google/apis/compute_alpha/classes.rb', line 9988

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


9955
9956
9957
# File 'lib/google/apis/compute_alpha/classes.rb', line 9955

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::CompositeHealthCheck>

A list of CompositeHealthCheck resources. Corresponds to the JSON property items



9960
9961
9962
# File 'lib/google/apis/compute_alpha/classes.rb', line 9960

def items
  @items
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# compositeHealthCheck for composite health checks. Corresponds to the JSON property kind

Returns:

  • (String)


9966
9967
9968
# File 'lib/google/apis/compute_alpha/classes.rb', line 9966

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


9976
9977
9978
# File 'lib/google/apis/compute_alpha/classes.rb', line 9976

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


9981
9982
9983
# File 'lib/google/apis/compute_alpha/classes.rb', line 9981

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::CompositeHealthCheckList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



9986
9987
9988
# File 'lib/google/apis/compute_alpha/classes.rb', line 9986

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9993
9994
9995
9996
9997
9998
9999
10000
# File 'lib/google/apis/compute_alpha/classes.rb', line 9993

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end