Class: Google::Apis::ComputeAlpha::CompositeHealthCheckList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CompositeHealthCheckList

Returns a new instance of CompositeHealthCheckList.



9718
9719
9720
# File 'lib/google/apis/compute_alpha/classes.rb', line 9718

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


9685
9686
9687
# File 'lib/google/apis/compute_alpha/classes.rb', line 9685

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::CompositeHealthCheck>

A list of CompositeHealthCheck resources. Corresponds to the JSON property items



9690
9691
9692
# File 'lib/google/apis/compute_alpha/classes.rb', line 9690

def items
  @items
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# compositeHealthCheck for composite health checks. Corresponds to the JSON property kind

Returns:

  • (String)


9696
9697
9698
# File 'lib/google/apis/compute_alpha/classes.rb', line 9696

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


9706
9707
9708
# File 'lib/google/apis/compute_alpha/classes.rb', line 9706

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


9711
9712
9713
# File 'lib/google/apis/compute_alpha/classes.rb', line 9711

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::CompositeHealthCheckList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



9716
9717
9718
# File 'lib/google/apis/compute_alpha/classes.rb', line 9716

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9723
9724
9725
9726
9727
9728
9729
9730
# File 'lib/google/apis/compute_alpha/classes.rb', line 9723

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end