Class: Google::Apis::ComputeAlpha::ConsistentHashLoadBalancerSettings
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::ConsistentHashLoadBalancerSettings
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
This message defines settings for a consistent hash style load balancer.
Instance Attribute Summary collapse
-
#http_cookie ⇒ Google::Apis::ComputeAlpha::ConsistentHashLoadBalancerSettingsHttpCookie
The information about the HTTP Cookie on which the hash function is based for load balancing policies that use a consistent hash.
-
#http_header_name ⇒ String
The hash based on the value of the specified header field.
-
#minimum_ring_size ⇒ Fixnum
The minimum number of virtual nodes to use for the hash ring.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ConsistentHashLoadBalancerSettings
constructor
A new instance of ConsistentHashLoadBalancerSettings.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ConsistentHashLoadBalancerSettings
Returns a new instance of ConsistentHashLoadBalancerSettings.
10732 10733 10734 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 10732 def initialize(**args) update!(**args) end |
Instance Attribute Details
#http_cookie ⇒ Google::Apis::ComputeAlpha::ConsistentHashLoadBalancerSettingsHttpCookie
The information about the HTTP Cookie on which the hash function is based
for load balancing policies that use a consistent hash.
Corresponds to the JSON property httpCookie
10716 10717 10718 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 10716 def @http_cookie end |
#http_header_name ⇒ String
The hash based on the value of the specified header field. This field is
applicable if the sessionAffinity is set toHEADER_FIELD.
Corresponds to the JSON property httpHeaderName
10722 10723 10724 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 10722 def http_header_name @http_header_name end |
#minimum_ring_size ⇒ Fixnum
The minimum number of virtual nodes to use for the hash ring. Defaults to
- Larger ring sizes result in more granular load distributions. If the
number of hosts in the load balancing pool is larger than the ring size,
each host will be assigned a single virtual node.
Corresponds to the JSON property
minimumRingSize
10730 10731 10732 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 10730 def minimum_ring_size @minimum_ring_size end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10737 10738 10739 10740 10741 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 10737 def update!(**args) @http_cookie = args[:http_cookie] if args.key?(:http_cookie) @http_header_name = args[:http_header_name] if args.key?(:http_header_name) @minimum_ring_size = args[:minimum_ring_size] if args.key?(:minimum_ring_size) end |