Class: Google::Apis::ComputeAlpha::ConsistentHashLoadBalancerSettingsHttpCookie
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::ConsistentHashLoadBalancerSettingsHttpCookie
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
The information about the HTTP Cookie on which the hash function is based for load balancing policies that use a consistent hash.
Instance Attribute Summary collapse
-
#name ⇒ String
Name of the cookie.
-
#path ⇒ String
Path to set for the cookie.
-
#ttl ⇒ Google::Apis::ComputeAlpha::Duration
A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ConsistentHashLoadBalancerSettingsHttpCookie
constructor
A new instance of ConsistentHashLoadBalancerSettingsHttpCookie.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ConsistentHashLoadBalancerSettingsHttpCookie
Returns a new instance of ConsistentHashLoadBalancerSettingsHttpCookie.
10797 10798 10799 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 10797 def initialize(**args) update!(**args) end |
Instance Attribute Details
#name ⇒ String
Name of the cookie.
Corresponds to the JSON property name
10782 10783 10784 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 10782 def name @name end |
#path ⇒ String
Path to set for the cookie.
Corresponds to the JSON property path
10787 10788 10789 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 10787 def path @path end |
#ttl ⇒ Google::Apis::ComputeAlpha::Duration
A Duration represents a fixed-length span of time represented
as a count of seconds and fractions of seconds at nanosecond
resolution. It is independent of any calendar and concepts like "day"
or "month". Range is approximately 10,000 years.
Corresponds to the JSON property ttl
10795 10796 10797 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 10795 def ttl @ttl end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10802 10803 10804 10805 10806 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 10802 def update!(**args) @name = args[:name] if args.key?(:name) @path = args[:path] if args.key?(:path) @ttl = args[:ttl] if args.key?(:ttl) end |