Class: Google::Apis::ComputeAlpha::ConsistentHashLoadBalancerSettingsHttpCookie

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

The information about the HTTP Cookie on which the hash function is based for load balancing policies that use a consistent hash.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ConsistentHashLoadBalancerSettingsHttpCookie

Returns a new instance of ConsistentHashLoadBalancerSettingsHttpCookie.



10767
10768
10769
# File 'lib/google/apis/compute_alpha/classes.rb', line 10767

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nameString

Name of the cookie. Corresponds to the JSON property name

Returns:

  • (String)


10752
10753
10754
# File 'lib/google/apis/compute_alpha/classes.rb', line 10752

def name
  @name
end

#pathString

Path to set for the cookie. Corresponds to the JSON property path

Returns:

  • (String)


10757
10758
10759
# File 'lib/google/apis/compute_alpha/classes.rb', line 10757

def path
  @path
end

#ttlGoogle::Apis::ComputeAlpha::Duration

A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution. It is independent of any calendar and concepts like "day" or "month". Range is approximately 10,000 years. Corresponds to the JSON property ttl



10765
10766
10767
# File 'lib/google/apis/compute_alpha/classes.rb', line 10765

def ttl
  @ttl
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10772
10773
10774
10775
10776
# File 'lib/google/apis/compute_alpha/classes.rb', line 10772

def update!(**args)
  @name = args[:name] if args.key?(:name)
  @path = args[:path] if args.key?(:path)
  @ttl = args[:ttl] if args.key?(:ttl)
end