Class: Google::Apis::ComputeAlpha::CorsPolicy
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::CorsPolicy
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
The specification for allowing client-side cross-origin requests. For more information about the W3C recommendation for cross-origin resource sharing (CORS), see Fetch API Living Standard.
Instance Attribute Summary collapse
-
#allow_credentials ⇒ Boolean
(also: #allow_credentials?)
In response to a preflight request, setting this to true indicates that the actual request can include user credentials.
-
#allow_headers ⇒ Array<String>
Specifies the content for the Access-Control-Allow-Headers header.
-
#allow_methods ⇒ Array<String>
Specifies the content for the Access-Control-Allow-Methods header.
-
#allow_origin_regexes ⇒ Array<String>
Specifies a regular expression that matches allowed origins.
-
#allow_origins ⇒ Array<String>
Specifies the list of origins that is allowed to do CORS requests.
-
#disabled ⇒ Boolean
(also: #disabled?)
If true, disables the CORS policy.
-
#expose_headers ⇒ Array<String>
Specifies the content for the Access-Control-Expose-Headers header.
-
#max_age ⇒ Fixnum
Specifies how long results of a preflight request can be cached in seconds.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CorsPolicy
constructor
A new instance of CorsPolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CorsPolicy
Returns a new instance of CorsPolicy.
10141 10142 10143 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 10141 def initialize(**args) update!(**args) end |
Instance Attribute Details
#allow_credentials ⇒ Boolean Also known as: allow_credentials?
In response to a preflight request, setting this to true
indicates that
the actual request can include user credentials. This field translates to
the Access-Control-Allow-Credentials header.
Default is false.
Corresponds to the JSON property allowCredentials
10088 10089 10090 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 10088 def allow_credentials @allow_credentials end |
#allow_headers ⇒ Array<String>
Specifies the content for the Access-Control-Allow-Headers
header.
Corresponds to the JSON property allowHeaders
10095 10096 10097 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 10095 def allow_headers @allow_headers end |
#allow_methods ⇒ Array<String>
Specifies the content for the Access-Control-Allow-Methods
header.
Corresponds to the JSON property allowMethods
10101 10102 10103 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 10101 def allow_methods @allow_methods end |
#allow_origin_regexes ⇒ Array<String>
Specifies a regular expression that matches allowed origins. For
more information, see regular expression syntax.
An origin is allowed if it matches either an item inallowOrigins or an item
inallowOriginRegexes.
Regular expressions can only be used when the loadBalancingScheme is
set to INTERNAL_SELF_MANAGED.
Corresponds to the JSON property allowOriginRegexes
10111 10112 10113 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 10111 def allow_origin_regexes @allow_origin_regexes end |
#allow_origins ⇒ Array<String>
Specifies the list of origins that is allowed to do CORS requests.
An origin is allowed if it matches either an item inallowOrigins or an item
inallowOriginRegexes.
Corresponds to the JSON property allowOrigins
10118 10119 10120 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 10118 def allow_origins @allow_origins end |
#disabled ⇒ Boolean Also known as: disabled?
If true, disables the CORS policy.
The default value is false, which indicates that the CORS
policy is in effect.
Corresponds to the JSON property disabled
10125 10126 10127 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 10125 def disabled @disabled end |
#expose_headers ⇒ Array<String>
Specifies the content for the Access-Control-Expose-Headers
header.
Corresponds to the JSON property exposeHeaders
10132 10133 10134 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 10132 def expose_headers @expose_headers end |
#max_age ⇒ Fixnum
Specifies how long results of a preflight request can be cached in
seconds. This field translates to the Access-Control-Max-Age
header.
Corresponds to the JSON property maxAge
10139 10140 10141 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 10139 def max_age @max_age end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10146 10147 10148 10149 10150 10151 10152 10153 10154 10155 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 10146 def update!(**args) @allow_credentials = args[:allow_credentials] if args.key?(:allow_credentials) @allow_headers = args[:allow_headers] if args.key?(:allow_headers) @allow_methods = args[:allow_methods] if args.key?(:allow_methods) @allow_origin_regexes = args[:allow_origin_regexes] if args.key?(:allow_origin_regexes) @allow_origins = args[:allow_origins] if args.key?(:allow_origins) @disabled = args[:disabled] if args.key?(:disabled) @expose_headers = args[:expose_headers] if args.key?(:expose_headers) @max_age = args[:max_age] if args.key?(:max_age) end |