Class: Google::Apis::ComputeAlpha::CrossSiteNetwork

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

A resource that represents a cross-site network. You can use cross-site networks to connect your on-premises networks to each other through Interconnect connections.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CrossSiteNetwork

Returns a new instance of CrossSiteNetwork.



10210
10211
10212
# File 'lib/google/apis/compute_alpha/classes.rb', line 10210

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


10168
10169
10170
# File 'lib/google/apis/compute_alpha/classes.rb', line 10168

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of the cross-site network. Corresponds to the JSON property description

Returns:

  • (String)


10173
10174
10175
# File 'lib/google/apis/compute_alpha/classes.rb', line 10173

def description
  @description
end

#idFixnum

Output only. [Output Only] The unique identifier for the resource type. The server generates this identifier. Corresponds to the JSON property id

Returns:

  • (Fixnum)


10180
10181
10182
# File 'lib/google/apis/compute_alpha/classes.rb', line 10180

def id
  @id
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# crossSiteNetwork for cross-site networks. Corresponds to the JSON property kind

Returns:

  • (String)


10186
10187
10188
# File 'lib/google/apis/compute_alpha/classes.rb', line 10186

def kind
  @kind
end

#nameString

Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


10197
10198
10199
# File 'lib/google/apis/compute_alpha/classes.rb', line 10197

def name
  @name
end

Output only. [Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


10202
10203
10204
# File 'lib/google/apis/compute_alpha/classes.rb', line 10202

def self_link
  @self_link
end

Output only. [Output Only] Server-defined URL for this resource with the resource id. Corresponds to the JSON property selfLinkWithId

Returns:

  • (String)


10208
10209
10210
# File 'lib/google/apis/compute_alpha/classes.rb', line 10208

def self_link_with_id
  @self_link_with_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10215
10216
10217
10218
10219
10220
10221
10222
10223
# File 'lib/google/apis/compute_alpha/classes.rb', line 10215

def update!(**args)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @self_link = args[:self_link] if args.key?(:self_link)
  @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id)
end