Class: Google::Apis::ComputeAlpha::CrossSiteNetworkList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Response to the list request that contains a list of cross-site networks.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CrossSiteNetworkList

Returns a new instance of CrossSiteNetworkList.



10822
10823
10824
# File 'lib/google/apis/compute_alpha/classes.rb', line 10822

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


10778
10779
10780
# File 'lib/google/apis/compute_alpha/classes.rb', line 10778

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


10783
10784
10785
# File 'lib/google/apis/compute_alpha/classes.rb', line 10783

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::CrossSiteNetwork>

A list of CrossSiteNetwork resources. Corresponds to the JSON property items



10788
10789
10790
# File 'lib/google/apis/compute_alpha/classes.rb', line 10788

def items
  @items
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# crossSiteNetwork for cross-site networks. Corresponds to the JSON property kind

Returns:

  • (String)


10794
10795
10796
# File 'lib/google/apis/compute_alpha/classes.rb', line 10794

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


10804
10805
10806
# File 'lib/google/apis/compute_alpha/classes.rb', line 10804

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


10809
10810
10811
# File 'lib/google/apis/compute_alpha/classes.rb', line 10809

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


10815
10816
10817
# File 'lib/google/apis/compute_alpha/classes.rb', line 10815

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::CrossSiteNetworkList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



10820
10821
10822
# File 'lib/google/apis/compute_alpha/classes.rb', line 10820

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10827
10828
10829
10830
10831
10832
10833
10834
10835
10836
# File 'lib/google/apis/compute_alpha/classes.rb', line 10827

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end