Class: Google::Apis::ComputeAlpha::CrossSiteNetworkList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::CrossSiteNetworkList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Response to the list request that contains a list of cross-site networks.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::CrossSiteNetwork>
A list of CrossSiteNetwork resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::CrossSiteNetworkList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CrossSiteNetworkList
constructor
A new instance of CrossSiteNetworkList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CrossSiteNetworkList
Returns a new instance of CrossSiteNetworkList.
10525 10526 10527 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 10525 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
10481 10482 10483 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 10481 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
10486 10487 10488 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 10486 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::CrossSiteNetwork>
A list of CrossSiteNetwork resources.
Corresponds to the JSON property items
10491 10492 10493 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 10491 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#
crossSiteNetwork for cross-site networks.
Corresponds to the JSON property kind
10497 10498 10499 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 10497 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
10507 10508 10509 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 10507 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
10512 10513 10514 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 10512 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
end_interface: MixerListResponseWithEtagBuilder
Corresponds to the JSON property unreachables
10518 10519 10520 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 10518 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::CrossSiteNetworkList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
10523 10524 10525 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 10523 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10530 10531 10532 10533 10534 10535 10536 10537 10538 10539 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 10530 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |