Class: Google::Apis::ComputeAlpha::CrossSiteNetworkList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Response to the list request that contains a list of cross-site networks.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CrossSiteNetworkList

Returns a new instance of CrossSiteNetworkList.



10547
10548
10549
# File 'lib/google/apis/compute_alpha/classes.rb', line 10547

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


10503
10504
10505
# File 'lib/google/apis/compute_alpha/classes.rb', line 10503

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


10508
10509
10510
# File 'lib/google/apis/compute_alpha/classes.rb', line 10508

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::CrossSiteNetwork>

A list of CrossSiteNetwork resources. Corresponds to the JSON property items



10513
10514
10515
# File 'lib/google/apis/compute_alpha/classes.rb', line 10513

def items
  @items
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# crossSiteNetwork for cross-site networks. Corresponds to the JSON property kind

Returns:

  • (String)


10519
10520
10521
# File 'lib/google/apis/compute_alpha/classes.rb', line 10519

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


10529
10530
10531
# File 'lib/google/apis/compute_alpha/classes.rb', line 10529

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


10534
10535
10536
# File 'lib/google/apis/compute_alpha/classes.rb', line 10534

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


10540
10541
10542
# File 'lib/google/apis/compute_alpha/classes.rb', line 10540

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::CrossSiteNetworkList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



10545
10546
10547
# File 'lib/google/apis/compute_alpha/classes.rb', line 10545

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10552
10553
10554
10555
10556
10557
10558
10559
10560
10561
# File 'lib/google/apis/compute_alpha/classes.rb', line 10552

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end