Class: Google::Apis::ComputeAlpha::CrossSiteNetworkList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Response to the list request that contains a list of cross-site networks.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CrossSiteNetworkList

Returns a new instance of CrossSiteNetworkList.



10277
10278
10279
# File 'lib/google/apis/compute_alpha/classes.rb', line 10277

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


10233
10234
10235
# File 'lib/google/apis/compute_alpha/classes.rb', line 10233

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


10238
10239
10240
# File 'lib/google/apis/compute_alpha/classes.rb', line 10238

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::CrossSiteNetwork>

A list of CrossSiteNetwork resources. Corresponds to the JSON property items



10243
10244
10245
# File 'lib/google/apis/compute_alpha/classes.rb', line 10243

def items
  @items
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# crossSiteNetwork for cross-site networks. Corresponds to the JSON property kind

Returns:

  • (String)


10249
10250
10251
# File 'lib/google/apis/compute_alpha/classes.rb', line 10249

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


10259
10260
10261
# File 'lib/google/apis/compute_alpha/classes.rb', line 10259

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


10264
10265
10266
# File 'lib/google/apis/compute_alpha/classes.rb', line 10264

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


10270
10271
10272
# File 'lib/google/apis/compute_alpha/classes.rb', line 10270

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::CrossSiteNetworkList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



10275
10276
10277
# File 'lib/google/apis/compute_alpha/classes.rb', line 10275

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10282
10283
10284
10285
10286
10287
10288
10289
10290
10291
# File 'lib/google/apis/compute_alpha/classes.rb', line 10282

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end