Class: Google::Apis::ComputeAlpha::DeprecationStatus
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::DeprecationStatus
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Deprecation status for a public resource.
Instance Attribute Summary collapse
-
#deleted ⇒ String
An optional RFC3339 timestamp on or after which the state of this resource is intended to change to DELETED.
-
#deprecated ⇒ String
An optional RFC3339 timestamp on or after which the state of this resource is intended to change to DEPRECATED.
-
#obsolete ⇒ String
An optional RFC3339 timestamp on or after which the state of this resource is intended to change to OBSOLETE.
-
#replacement ⇒ String
The URL of the suggested replacement for a deprecated resource.
-
#state ⇒ String
The deprecation state of this resource.
-
#state_override ⇒ Google::Apis::ComputeAlpha::RolloutPolicy
A rollout policy configuration.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DeprecationStatus
constructor
A new instance of DeprecationStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DeprecationStatus
Returns a new instance of DeprecationStatus.
11482 11483 11484 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 11482 def initialize(**args) update!(**args) end |
Instance Attribute Details
#deleted ⇒ String
An optional RFC3339 timestamp on or after which the state of this
resource is intended to change to DELETED. This is only
informational and the status will not change unless the client explicitly
changes it.
Corresponds to the JSON property deleted
11440 11441 11442 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 11440 def deleted @deleted end |
#deprecated ⇒ String
An optional RFC3339 timestamp on or after which the state of this
resource is intended to change to DEPRECATED. This is only
informational and the status will not change unless the client explicitly
changes it.
Corresponds to the JSON property deprecated
11448 11449 11450 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 11448 def deprecated @deprecated end |
#obsolete ⇒ String
An optional RFC3339 timestamp on or after which the state of this
resource is intended to change to OBSOLETE. This is only
informational and the status will not change unless the client explicitly
changes it.
Corresponds to the JSON property obsolete
11456 11457 11458 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 11456 def obsolete @obsolete end |
#replacement ⇒ String
The URL of the suggested replacement for a deprecated resource.
The suggested replacement resource must be the same kind of resource as the
deprecated resource.
Corresponds to the JSON property replacement
11463 11464 11465 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 11463 def replacement @replacement end |
#state ⇒ String
The deprecation state of this resource. This can be ACTIVE,DEPRECATED,
OBSOLETE, or DELETED.
Operations which communicate the end of life date for an image, can useACTIVE.
Operations which create a new resource using aDEPRECATED resource will return
successfully, but with a
warning indicating the deprecated resource and recommending its
replacement. Operations which use OBSOLETE orDELETED resources will be
rejected and result in an error.
Corresponds to the JSON property state
11475 11476 11477 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 11475 def state @state end |
#state_override ⇒ Google::Apis::ComputeAlpha::RolloutPolicy
A rollout policy configuration.
Corresponds to the JSON property stateOverride
11480 11481 11482 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 11480 def state_override @state_override end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11487 11488 11489 11490 11491 11492 11493 11494 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 11487 def update!(**args) @deleted = args[:deleted] if args.key?(:deleted) @deprecated = args[:deprecated] if args.key?(:deprecated) @obsolete = args[:obsolete] if args.key?(:obsolete) @replacement = args[:replacement] if args.key?(:replacement) @state = args[:state] if args.key?(:state) @state_override = args[:state_override] if args.key?(:state_override) end |