Class: Google::Apis::ComputeAlpha::DeprecationStatus

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Deprecation status for a public resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DeprecationStatus

Returns a new instance of DeprecationStatus.



11319
11320
11321
# File 'lib/google/apis/compute_alpha/classes.rb', line 11319

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#deletedString

An optional RFC3339 timestamp on or after which the state of this resource is intended to change to DELETED. This is only informational and the status will not change unless the client explicitly changes it. Corresponds to the JSON property deleted

Returns:

  • (String)


11277
11278
11279
# File 'lib/google/apis/compute_alpha/classes.rb', line 11277

def deleted
  @deleted
end

#deprecatedString

An optional RFC3339 timestamp on or after which the state of this resource is intended to change to DEPRECATED. This is only informational and the status will not change unless the client explicitly changes it. Corresponds to the JSON property deprecated

Returns:

  • (String)


11285
11286
11287
# File 'lib/google/apis/compute_alpha/classes.rb', line 11285

def deprecated
  @deprecated
end

#obsoleteString

An optional RFC3339 timestamp on or after which the state of this resource is intended to change to OBSOLETE. This is only informational and the status will not change unless the client explicitly changes it. Corresponds to the JSON property obsolete

Returns:

  • (String)


11293
11294
11295
# File 'lib/google/apis/compute_alpha/classes.rb', line 11293

def obsolete
  @obsolete
end

#replacementString

The URL of the suggested replacement for a deprecated resource. The suggested replacement resource must be the same kind of resource as the deprecated resource. Corresponds to the JSON property replacement

Returns:

  • (String)


11300
11301
11302
# File 'lib/google/apis/compute_alpha/classes.rb', line 11300

def replacement
  @replacement
end

#stateString

The deprecation state of this resource. This can be ACTIVE,DEPRECATED, OBSOLETE, or DELETED. Operations which communicate the end of life date for an image, can useACTIVE. Operations which create a new resource using aDEPRECATED resource will return successfully, but with a warning indicating the deprecated resource and recommending its replacement. Operations which use OBSOLETE orDELETED resources will be rejected and result in an error. Corresponds to the JSON property state

Returns:

  • (String)


11312
11313
11314
# File 'lib/google/apis/compute_alpha/classes.rb', line 11312

def state
  @state
end

#state_overrideGoogle::Apis::ComputeAlpha::RolloutPolicy

A rollout policy configuration. Corresponds to the JSON property stateOverride



11317
11318
11319
# File 'lib/google/apis/compute_alpha/classes.rb', line 11317

def state_override
  @state_override
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11324
11325
11326
11327
11328
11329
11330
11331
# File 'lib/google/apis/compute_alpha/classes.rb', line 11324

def update!(**args)
  @deleted = args[:deleted] if args.key?(:deleted)
  @deprecated = args[:deprecated] if args.key?(:deprecated)
  @obsolete = args[:obsolete] if args.key?(:obsolete)
  @replacement = args[:replacement] if args.key?(:replacement)
  @state = args[:state] if args.key?(:state)
  @state_override = args[:state_override] if args.key?(:state_override)
end