Class: Google::Apis::ComputeAlpha::DeprecationStatus
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::DeprecationStatus
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Deprecation status for a public resource.
Instance Attribute Summary collapse
-
#deleted ⇒ String
An optional RFC3339 timestamp on or after which the state of this resource is intended to change to DELETED.
-
#deprecated ⇒ String
An optional RFC3339 timestamp on or after which the state of this resource is intended to change to DEPRECATED.
-
#obsolete ⇒ String
An optional RFC3339 timestamp on or after which the state of this resource is intended to change to OBSOLETE.
-
#replacement ⇒ String
The URL of the suggested replacement for a deprecated resource.
-
#state ⇒ String
The deprecation state of this resource.
-
#state_override ⇒ Google::Apis::ComputeAlpha::RolloutPolicy
A rollout policy configuration.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DeprecationStatus
constructor
A new instance of DeprecationStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DeprecationStatus
Returns a new instance of DeprecationStatus.
11061 11062 11063 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 11061 def initialize(**args) update!(**args) end |
Instance Attribute Details
#deleted ⇒ String
An optional RFC3339 timestamp on or after which the state of this
resource is intended to change to DELETED. This is only
informational and the status will not change unless the client explicitly
changes it.
Corresponds to the JSON property deleted
11019 11020 11021 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 11019 def deleted @deleted end |
#deprecated ⇒ String
An optional RFC3339 timestamp on or after which the state of this
resource is intended to change to DEPRECATED. This is only
informational and the status will not change unless the client explicitly
changes it.
Corresponds to the JSON property deprecated
11027 11028 11029 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 11027 def deprecated @deprecated end |
#obsolete ⇒ String
An optional RFC3339 timestamp on or after which the state of this
resource is intended to change to OBSOLETE. This is only
informational and the status will not change unless the client explicitly
changes it.
Corresponds to the JSON property obsolete
11035 11036 11037 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 11035 def obsolete @obsolete end |
#replacement ⇒ String
The URL of the suggested replacement for a deprecated resource.
The suggested replacement resource must be the same kind of resource as the
deprecated resource.
Corresponds to the JSON property replacement
11042 11043 11044 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 11042 def replacement @replacement end |
#state ⇒ String
The deprecation state of this resource. This can be ACTIVE,DEPRECATED,
OBSOLETE, or DELETED.
Operations which communicate the end of life date for an image, can useACTIVE.
Operations which create a new resource using aDEPRECATED resource will return
successfully, but with a
warning indicating the deprecated resource and recommending its
replacement. Operations which use OBSOLETE orDELETED resources will be
rejected and result in an error.
Corresponds to the JSON property state
11054 11055 11056 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 11054 def state @state end |
#state_override ⇒ Google::Apis::ComputeAlpha::RolloutPolicy
A rollout policy configuration.
Corresponds to the JSON property stateOverride
11059 11060 11061 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 11059 def state_override @state_override end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11066 11067 11068 11069 11070 11071 11072 11073 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 11066 def update!(**args) @deleted = args[:deleted] if args.key?(:deleted) @deprecated = args[:deprecated] if args.key?(:deprecated) @obsolete = args[:obsolete] if args.key?(:obsolete) @replacement = args[:replacement] if args.key?(:replacement) @state = args[:state] if args.key?(:state) @state_override = args[:state_override] if args.key?(:state_override) end |