Class: Google::Apis::ComputeAlpha::DhcpOptionsConfigList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::DhcpOptionsConfigList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Server-defined ETag for optimistic concurrency control.
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::DhcpOptionsConfig>
A list of DhcpOptionsConfig resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::DhcpOptionsConfigList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DhcpOptionsConfigList
constructor
A new instance of DhcpOptionsConfigList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DhcpOptionsConfigList
Returns a new instance of DhcpOptionsConfigList.
11762 11763 11764 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 11762 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Server-defined ETag for optimistic concurrency control.
Corresponds to the JSON property etag
11717 11718 11719 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 11717 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
11722 11723 11724 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 11722 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::DhcpOptionsConfig>
A list of DhcpOptionsConfig resources.
Corresponds to the JSON property items
11727 11728 11729 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 11727 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#
dhcpOptionsConfigList for a list of dhcp options
configs.
Corresponds to the JSON property kind
11734 11735 11736 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 11734 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
11744 11745 11746 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 11744 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
11749 11750 11751 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 11749 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
end_interface: MixerListResponseWithEtagBuilder
Corresponds to the JSON property unreachables
11755 11756 11757 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 11755 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::DhcpOptionsConfigList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
11760 11761 11762 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 11760 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11767 11768 11769 11770 11771 11772 11773 11774 11775 11776 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 11767 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |