Class: Google::Apis::ComputeAlpha::DhcpOptionsConfigList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DhcpOptionsConfigList

Returns a new instance of DhcpOptionsConfigList.



11599
11600
11601
# File 'lib/google/apis/compute_alpha/classes.rb', line 11599

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Server-defined ETag for optimistic concurrency control. Corresponds to the JSON property etag

Returns:

  • (String)


11554
11555
11556
# File 'lib/google/apis/compute_alpha/classes.rb', line 11554

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


11559
11560
11561
# File 'lib/google/apis/compute_alpha/classes.rb', line 11559

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::DhcpOptionsConfig>

A list of DhcpOptionsConfig resources. Corresponds to the JSON property items



11564
11565
11566
# File 'lib/google/apis/compute_alpha/classes.rb', line 11564

def items
  @items
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# dhcpOptionsConfigList for a list of dhcp options configs. Corresponds to the JSON property kind

Returns:

  • (String)


11571
11572
11573
# File 'lib/google/apis/compute_alpha/classes.rb', line 11571

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


11581
11582
11583
# File 'lib/google/apis/compute_alpha/classes.rb', line 11581

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


11586
11587
11588
# File 'lib/google/apis/compute_alpha/classes.rb', line 11586

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


11592
11593
11594
# File 'lib/google/apis/compute_alpha/classes.rb', line 11592

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::DhcpOptionsConfigList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



11597
11598
11599
# File 'lib/google/apis/compute_alpha/classes.rb', line 11597

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11604
11605
11606
11607
11608
11609
11610
11611
11612
11613
# File 'lib/google/apis/compute_alpha/classes.rb', line 11604

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end