Class: Google::Apis::ComputeAlpha::DiskAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DiskAggregatedList

Returns a new instance of DiskAggregatedList.



12351
12352
12353
# File 'lib/google/apis/compute_alpha/classes.rb', line 12351

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


12312
12313
12314
# File 'lib/google/apis/compute_alpha/classes.rb', line 12312

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::DisksScopedList>

A list of DisksScopedList resources. Corresponds to the JSON property items



12317
12318
12319
# File 'lib/google/apis/compute_alpha/classes.rb', line 12317

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute#diskAggregatedList for aggregated lists of persistent disks. Corresponds to the JSON property kind

Returns:

  • (String)


12324
12325
12326
# File 'lib/google/apis/compute_alpha/classes.rb', line 12324

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


12334
12335
12336
# File 'lib/google/apis/compute_alpha/classes.rb', line 12334

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


12339
12340
12341
# File 'lib/google/apis/compute_alpha/classes.rb', line 12339

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


12344
12345
12346
# File 'lib/google/apis/compute_alpha/classes.rb', line 12344

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::DiskAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



12349
12350
12351
# File 'lib/google/apis/compute_alpha/classes.rb', line 12349

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12356
12357
12358
12359
12360
12361
12362
12363
12364
# File 'lib/google/apis/compute_alpha/classes.rb', line 12356

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end