Class: Google::Apis::ComputeAlpha::DiskAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DiskAggregatedList

Returns a new instance of DiskAggregatedList.



11702
11703
11704
# File 'lib/google/apis/compute_alpha/classes.rb', line 11702

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


11663
11664
11665
# File 'lib/google/apis/compute_alpha/classes.rb', line 11663

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::DisksScopedList>

A list of DisksScopedList resources. Corresponds to the JSON property items



11668
11669
11670
# File 'lib/google/apis/compute_alpha/classes.rb', line 11668

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute#diskAggregatedList for aggregated lists of persistent disks. Corresponds to the JSON property kind

Returns:

  • (String)


11675
11676
11677
# File 'lib/google/apis/compute_alpha/classes.rb', line 11675

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


11685
11686
11687
# File 'lib/google/apis/compute_alpha/classes.rb', line 11685

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


11690
11691
11692
# File 'lib/google/apis/compute_alpha/classes.rb', line 11690

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


11695
11696
11697
# File 'lib/google/apis/compute_alpha/classes.rb', line 11695

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::DiskAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



11700
11701
11702
# File 'lib/google/apis/compute_alpha/classes.rb', line 11700

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11707
11708
11709
11710
11711
11712
11713
11714
11715
# File 'lib/google/apis/compute_alpha/classes.rb', line 11707

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end