Class: Google::Apis::ComputeAlpha::DiskAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DiskAggregatedList

Returns a new instance of DiskAggregatedList.



11724
11725
11726
# File 'lib/google/apis/compute_alpha/classes.rb', line 11724

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


11685
11686
11687
# File 'lib/google/apis/compute_alpha/classes.rb', line 11685

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::DisksScopedList>

A list of DisksScopedList resources. Corresponds to the JSON property items



11690
11691
11692
# File 'lib/google/apis/compute_alpha/classes.rb', line 11690

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute#diskAggregatedList for aggregated lists of persistent disks. Corresponds to the JSON property kind

Returns:

  • (String)


11697
11698
11699
# File 'lib/google/apis/compute_alpha/classes.rb', line 11697

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


11707
11708
11709
# File 'lib/google/apis/compute_alpha/classes.rb', line 11707

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


11712
11713
11714
# File 'lib/google/apis/compute_alpha/classes.rb', line 11712

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


11717
11718
11719
# File 'lib/google/apis/compute_alpha/classes.rb', line 11717

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::DiskAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



11722
11723
11724
# File 'lib/google/apis/compute_alpha/classes.rb', line 11722

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11729
11730
11731
11732
11733
11734
11735
11736
11737
# File 'lib/google/apis/compute_alpha/classes.rb', line 11729

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end