Class: Google::Apis::ComputeAlpha::DiskAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::DiskAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::DisksScopedList>
A list of DisksScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::DiskAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DiskAggregatedList
constructor
A new instance of DiskAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DiskAggregatedList
Returns a new instance of DiskAggregatedList.
11454 11455 11456 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 11454 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
11415 11416 11417 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 11415 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::DisksScopedList>
A list of DisksScopedList resources.
Corresponds to the JSON property items
11420 11421 11422 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 11420 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#diskAggregatedList
for aggregated lists of persistent
disks.
Corresponds to the JSON property kind
11427 11428 11429 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 11427 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
11437 11438 11439 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 11437 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
11442 11443 11444 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 11442 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
11447 11448 11449 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 11447 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::DiskAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
11452 11453 11454 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 11452 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11459 11460 11461 11462 11463 11464 11465 11466 11467 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 11459 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |