Class: Google::Apis::ComputeAlpha::DiskAsyncReplication
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::DiskAsyncReplication
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#consistency_group_policy ⇒ String
Output only.
-
#consistency_group_policy_id ⇒ String
Output only.
-
#disk ⇒ String
The other disk asynchronously replicated to or from the current disk.
-
#disk_id ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DiskAsyncReplication
constructor
A new instance of DiskAsyncReplication.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DiskAsyncReplication
Returns a new instance of DiskAsyncReplication.
11830 11831 11832 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 11830 def initialize(**args) update!(**args) end |
Instance Attribute Details
#consistency_group_policy ⇒ String
Output only. [Output Only] URL of the DiskConsistencyGroupPolicy if
replication was
started on the disk as a member of a group.
Corresponds to the JSON property consistencyGroupPolicy
11797 11798 11799 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 11797 def consistency_group_policy @consistency_group_policy end |
#consistency_group_policy_id ⇒ String
Output only. [Output Only] ID of the DiskConsistencyGroupPolicy if replication
was
started on the disk as a member of a group.
Corresponds to the JSON property consistencyGroupPolicyId
11804 11805 11806 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 11804 def consistency_group_policy_id @consistency_group_policy_id end |
#disk ⇒ String
The other disk asynchronously replicated to or from the current disk. You can provide this as a partial or full URL to the resource. For example, the following are valid values:
- https://www.googleapis.com/compute/v1/projects/project/zones/zone/disks/ disk
- projects/project/zones/zone/disks/disk
- zones/zone/disks/disk
Corresponds to the JSON property
disk
11817 11818 11819 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 11817 def disk @disk end |
#disk_id ⇒ String
Output only. [Output Only] The unique ID of the other disk asynchronously
replicated
to or from the current disk. This value identifies the exact disk that
was used to create this replication. For example, if you started
replicating the persistent disk from a disk that was later deleted and
recreated under the same name, the disk ID would identify the exact
version of the disk that was used.
Corresponds to the JSON property diskId
11828 11829 11830 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 11828 def disk_id @disk_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11835 11836 11837 11838 11839 11840 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 11835 def update!(**args) @consistency_group_policy = args[:consistency_group_policy] if args.key?(:consistency_group_policy) @consistency_group_policy_id = args[:consistency_group_policy_id] if args.key?(:consistency_group_policy_id) @disk = args[:disk] if args.key?(:disk) @disk_id = args[:disk_id] if args.key?(:disk_id) end |