Class: Google::Apis::ComputeAlpha::DiskAsyncReplication

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DiskAsyncReplication

Returns a new instance of DiskAsyncReplication.



11852
11853
11854
# File 'lib/google/apis/compute_alpha/classes.rb', line 11852

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#consistency_group_policyString

Output only. [Output Only] URL of the DiskConsistencyGroupPolicy if replication was started on the disk as a member of a group. Corresponds to the JSON property consistencyGroupPolicy

Returns:

  • (String)


11819
11820
11821
# File 'lib/google/apis/compute_alpha/classes.rb', line 11819

def consistency_group_policy
  @consistency_group_policy
end

#consistency_group_policy_idString

Output only. [Output Only] ID of the DiskConsistencyGroupPolicy if replication was started on the disk as a member of a group. Corresponds to the JSON property consistencyGroupPolicyId

Returns:

  • (String)


11826
11827
11828
# File 'lib/google/apis/compute_alpha/classes.rb', line 11826

def consistency_group_policy_id
  @consistency_group_policy_id
end

#diskString

The other disk asynchronously replicated to or from the current disk. You can provide this as a partial or full URL to the resource. For example, the following are valid values:

Returns:

  • (String)


11839
11840
11841
# File 'lib/google/apis/compute_alpha/classes.rb', line 11839

def disk
  @disk
end

#disk_idString

Output only. [Output Only] The unique ID of the other disk asynchronously replicated to or from the current disk. This value identifies the exact disk that was used to create this replication. For example, if you started replicating the persistent disk from a disk that was later deleted and recreated under the same name, the disk ID would identify the exact version of the disk that was used. Corresponds to the JSON property diskId

Returns:

  • (String)


11850
11851
11852
# File 'lib/google/apis/compute_alpha/classes.rb', line 11850

def disk_id
  @disk_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11857
11858
11859
11860
11861
11862
# File 'lib/google/apis/compute_alpha/classes.rb', line 11857

def update!(**args)
  @consistency_group_policy = args[:consistency_group_policy] if args.key?(:consistency_group_policy)
  @consistency_group_policy_id = args[:consistency_group_policy_id] if args.key?(:consistency_group_policy_id)
  @disk = args[:disk] if args.key?(:disk)
  @disk_id = args[:disk_id] if args.key?(:disk_id)
end