Class: Google::Apis::ComputeAlpha::DiskList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

A list of Disk resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DiskList

Returns a new instance of DiskList.



12661
12662
12663
# File 'lib/google/apis/compute_alpha/classes.rb', line 12661

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


12628
12629
12630
# File 'lib/google/apis/compute_alpha/classes.rb', line 12628

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::Disk>

A list of Disk resources. Corresponds to the JSON property items



12633
12634
12635
# File 'lib/google/apis/compute_alpha/classes.rb', line 12633

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#diskList for lists of disks. Corresponds to the JSON property kind

Returns:

  • (String)


12639
12640
12641
# File 'lib/google/apis/compute_alpha/classes.rb', line 12639

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


12649
12650
12651
# File 'lib/google/apis/compute_alpha/classes.rb', line 12649

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


12654
12655
12656
# File 'lib/google/apis/compute_alpha/classes.rb', line 12654

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::DiskList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



12659
12660
12661
# File 'lib/google/apis/compute_alpha/classes.rb', line 12659

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12666
12667
12668
12669
12670
12671
12672
12673
# File 'lib/google/apis/compute_alpha/classes.rb', line 12666

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end