Class: Google::Apis::ComputeAlpha::DiskList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::DiskList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
A list of Disk resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::Disk>
A list of Disk resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::DiskList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DiskList
constructor
A new instance of DiskList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DiskList
Returns a new instance of DiskList.
12012 12013 12014 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 12012 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
11979 11980 11981 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 11979 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::Disk>
A list of Disk resources.
Corresponds to the JSON property items
11984 11985 11986 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 11984 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#diskList for
lists of disks.
Corresponds to the JSON property kind
11990 11991 11992 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 11990 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
12000 12001 12002 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 12000 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
12005 12006 12007 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 12005 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::DiskList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
12010 12011 12012 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 12010 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12017 12018 12019 12020 12021 12022 12023 12024 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 12017 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |