Class: Google::Apis::ComputeAlpha::DiskList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::DiskList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
A list of Disk resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::Disk>
A list of Disk resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::DiskList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DiskList
constructor
A new instance of DiskList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DiskList
Returns a new instance of DiskList.
12029 12030 12031 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 12029 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
11996 11997 11998 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 11996 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::Disk>
A list of Disk resources.
Corresponds to the JSON property items
12001 12002 12003 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 12001 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#diskList for
lists of disks.
Corresponds to the JSON property kind
12007 12008 12009 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 12007 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
12017 12018 12019 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 12017 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
12022 12023 12024 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 12022 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::DiskList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
12027 12028 12029 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 12027 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12034 12035 12036 12037 12038 12039 12040 12041 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 12034 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |