Class: Google::Apis::ComputeAlpha::DiskList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

A list of Disk resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DiskList

Returns a new instance of DiskList.



11764
11765
11766
# File 'lib/google/apis/compute_alpha/classes.rb', line 11764

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


11731
11732
11733
# File 'lib/google/apis/compute_alpha/classes.rb', line 11731

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::Disk>

A list of Disk resources. Corresponds to the JSON property items



11736
11737
11738
# File 'lib/google/apis/compute_alpha/classes.rb', line 11736

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#diskList for lists of disks. Corresponds to the JSON property kind

Returns:

  • (String)


11742
11743
11744
# File 'lib/google/apis/compute_alpha/classes.rb', line 11742

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


11752
11753
11754
# File 'lib/google/apis/compute_alpha/classes.rb', line 11752

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


11757
11758
11759
# File 'lib/google/apis/compute_alpha/classes.rb', line 11757

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::DiskList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



11762
11763
11764
# File 'lib/google/apis/compute_alpha/classes.rb', line 11762

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11769
11770
11771
11772
11773
11774
11775
11776
# File 'lib/google/apis/compute_alpha/classes.rb', line 11769

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end