Class: Google::Apis::ComputeAlpha::DiskPairReplicationState

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DiskPairReplicationState

Returns a new instance of DiskPairReplicationState.



12178
12179
12180
# File 'lib/google/apis/compute_alpha/classes.rb', line 12178

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#data_replication_stateString

Output only. [Output Only] The status of disk creation.

  • ASYNC_REPLICATION_STATE_INITIALIZING: The device is doing the initial replication after starting the replication.

  • ASYNC_REPLICATION_STATE_REPLICATING_HEALTHY: The primary disk is healthily replicating to the secondary device i.e. last_replication_time is within RPO.

  • ASYNC_REPLICATION_STATE_REPLICATING_BEHIND_HIGH_CHURN: The replication is lagging above the SLO limit due to the disk's change rate being above the supported limit.

  • ASYNC_REPLICATION_STATE_REPLICATING_BEHIND_SYSTEM_LAGGING: The replication is lagging, and the RPO is not being met due to some internal issue.

  • ASYNC_REPLICATION_STATE_REPLICATION_STUCK: The replication is completely stuck due to some internal error.

  • ASYNC_REPLICATION_STATE_STOPPING: The replication is under the process of being stopped. This is a transient state.

  • ASYNC_REPLICATION_STATE_STOPPED: The replication between the disk-pairs have stopped.

  • ASYNC_REPLICATION_STATE_REPLICATING_BEHIND_CG_HIGH_CHURN: The replication is lagging above the SLO limit for the disk in the consistency group due to disk's change rate being above the supported limit. Corresponds to the JSON property dataReplicationState

Returns:

  • (String)


12171
12172
12173
# File 'lib/google/apis/compute_alpha/classes.rb', line 12171

def data_replication_state
  @data_replication_state
end

#replication_disk_pairGoogle::Apis::ComputeAlpha::ReplicationDiskPair

Corresponds to the JSON property replicationDiskPair



12176
12177
12178
# File 'lib/google/apis/compute_alpha/classes.rb', line 12176

def replication_disk_pair
  @replication_disk_pair
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12183
12184
12185
12186
# File 'lib/google/apis/compute_alpha/classes.rb', line 12183

def update!(**args)
  @data_replication_state = args[:data_replication_state] if args.key?(:data_replication_state)
  @replication_disk_pair = args[:replication_disk_pair] if args.key?(:replication_disk_pair)
end