Class: Google::Apis::ComputeAlpha::DiskParams

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Additional disk params.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DiskParams

Returns a new instance of DiskParams.



11956
11957
11958
# File 'lib/google/apis/compute_alpha/classes.rb', line 11956

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#resource_manager_tagsHash<String,String>

Input only. Resource manager tags to be bound to the disk. Tag keys and values have the same definition as resource manager tags. Keys and values can be either in numeric format, such as tagKeys/tag_key_idand `tagValues/456` or in namespaced format such asorg_id|project_id/tag_key_short_nameand tag_value_short_name`. The field is ignored (both PUT & PATCH) when empty. Corresponds to the JSON propertyresourceManagerTags`

Returns:

  • (Hash<String,String>)


11954
11955
11956
# File 'lib/google/apis/compute_alpha/classes.rb', line 11954

def resource_manager_tags
  @resource_manager_tags
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11961
11962
11963
# File 'lib/google/apis/compute_alpha/classes.rb', line 11961

def update!(**args)
  @resource_manager_tags = args[:resource_manager_tags] if args.key?(:resource_manager_tags)
end