Class: Google::Apis::ComputeAlpha::DiskSettingsResourcePolicyDetails

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

This is the object for storing the detail information about the Resource Policy that will be set as default ones for the Disks that is using the DiskSettings. It contains:

  • one target Resource Policy referenced by its Fully-Qualified URL,
  • [output only] Disk Types that will be excluded from using this Resource Policy,
  • Other filtering support (e.g. Label filtering) for Default Resource Policy can be added here as well

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DiskSettingsResourcePolicyDetails

Returns a new instance of DiskSettingsResourcePolicyDetails.



12411
12412
12413
# File 'lib/google/apis/compute_alpha/classes.rb', line 12411

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#excluded_disk_typesArray<String>

Output only. [Output Only] A list of Disk Types that will be excluded from applying the Resource Policy referenced here. If absent, Disks created in any DiskType can use the referenced default Resource Policy. Corresponds to the JSON property excludedDiskTypes

Returns:

  • (Array<String>)


12404
12405
12406
# File 'lib/google/apis/compute_alpha/classes.rb', line 12404

def excluded_disk_types
  @excluded_disk_types
end

#resource_policyString

The target Resource Policies identified by their Fully-Qualified URL. Corresponds to the JSON property resourcePolicy

Returns:

  • (String)


12409
12410
12411
# File 'lib/google/apis/compute_alpha/classes.rb', line 12409

def resource_policy
  @resource_policy
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12416
12417
12418
12419
# File 'lib/google/apis/compute_alpha/classes.rb', line 12416

def update!(**args)
  @excluded_disk_types = args[:excluded_disk_types] if args.key?(:excluded_disk_types)
  @resource_policy = args[:resource_policy] if args.key?(:resource_policy)
end