Class: Google::Apis::ComputeAlpha::DiskSettingsResourcePolicyDetails
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::DiskSettingsResourcePolicyDetails
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
This is the object for storing the detail information about the Resource Policy that will be set as default ones for the Disks that is using the DiskSettings. It contains:
- one target Resource Policy referenced by its Fully-Qualified URL,
- [output only] Disk Types that will be excluded from using this Resource Policy,
- Other filtering support (e.g. Label filtering) for Default Resource Policy can be added here as well
Instance Attribute Summary collapse
-
#excluded_disk_types ⇒ Array<String>
Output only.
-
#resource_policy ⇒ String
The target Resource Policies identified by their Fully-Qualified URL.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DiskSettingsResourcePolicyDetails
constructor
A new instance of DiskSettingsResourcePolicyDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DiskSettingsResourcePolicyDetails
Returns a new instance of DiskSettingsResourcePolicyDetails.
12416 12417 12418 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 12416 def initialize(**args) update!(**args) end |
Instance Attribute Details
#excluded_disk_types ⇒ Array<String>
Output only. [Output Only] A list of Disk Types that will be excluded from
applying
the Resource Policy referenced here.
If absent, Disks created in any DiskType can use the referenced
default Resource Policy.
Corresponds to the JSON property excludedDiskTypes
12409 12410 12411 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 12409 def excluded_disk_types @excluded_disk_types end |
#resource_policy ⇒ String
The target Resource Policies identified by their Fully-Qualified URL.
Corresponds to the JSON property resourcePolicy
12414 12415 12416 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 12414 def resource_policy @resource_policy end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12421 12422 12423 12424 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 12421 def update!(**args) @excluded_disk_types = args[:excluded_disk_types] if args.key?(:excluded_disk_types) @resource_policy = args[:resource_policy] if args.key?(:resource_policy) end |