Class: Google::Apis::ComputeAlpha::DiskType
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::DiskType
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Represents a Disk Type resource. Google Compute Engine has two Disk Type resources:
- Regional
- Zonal You can choose from a variety of disk types based on your needs. For more information, readStorage options. The diskTypes resource represents disk types for a zonal persistent disk. For more information, readZonal persistent disks. The regionDiskTypes resource represents disk types for a regional persistent disk. For more information, read Regional persistent disks.
Instance Attribute Summary collapse
-
#creation_timestamp ⇒ String
[Output Only] Creation timestamp inRFC3339 text format.
-
#default_disk_size_gb ⇒ Fixnum
[Output Only] Server-defined default disk size in GB.
-
#deprecated ⇒ Google::Apis::ComputeAlpha::DeprecationStatus
Deprecation status for a public resource.
-
#description ⇒ String
[Output Only] An optional description of this resource.
-
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
[Output Only] Name of the resource.
-
#region ⇒ String
[Output Only] URL of the region where the disk type resides.
-
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
-
#self_link_with_id ⇒ String
Output only.
-
#valid_disk_size ⇒ String
[Output Only] An optional textual description of the valid disk size, such as "10GB-10TB".
-
#zone ⇒ String
[Output Only] URL of the zone where the disk type resides.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DiskType
constructor
A new instance of DiskType.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DiskType
Returns a new instance of DiskType.
13331 13332 13333 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 13331 def initialize(**args) update!(**args) end |
Instance Attribute Details
#creation_timestamp ⇒ String
[Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
13265 13266 13267 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 13265 def @creation_timestamp end |
#default_disk_size_gb ⇒ Fixnum
[Output Only] Server-defined default disk size in GB.
Corresponds to the JSON property defaultDiskSizeGb
13270 13271 13272 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 13270 def default_disk_size_gb @default_disk_size_gb end |
#deprecated ⇒ Google::Apis::ComputeAlpha::DeprecationStatus
Deprecation status for a public resource.
Corresponds to the JSON property deprecated
13275 13276 13277 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 13275 def deprecated @deprecated end |
#description ⇒ String
[Output Only] An optional description of this resource.
Corresponds to the JSON property description
13280 13281 13282 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 13280 def description @description end |
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
13286 13287 13288 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 13286 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Always compute#diskType
for disk types.
Corresponds to the JSON property kind
13292 13293 13294 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 13292 def kind @kind end |
#name ⇒ String
[Output Only] Name of the resource.
Corresponds to the JSON property name
13297 13298 13299 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 13297 def name @name end |
#region ⇒ String
[Output Only] URL of the region where the disk type resides. Only
applicable for regional resources.
You must specify this field as part of the HTTP request URL. It is
not settable as a field in the request body.
Corresponds to the JSON property region
13305 13306 13307 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 13305 def region @region end |
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
13310 13311 13312 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 13310 def self_link @self_link end |
#self_link_with_id ⇒ String
Output only. [Output Only] Server-defined URL for this resource with the
resource id.
Corresponds to the JSON property selfLinkWithId
13316 13317 13318 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 13316 def self_link_with_id @self_link_with_id end |
#valid_disk_size ⇒ String
[Output Only] An optional textual description of the valid disk size,
such as "10GB-10TB".
Corresponds to the JSON property validDiskSize
13322 13323 13324 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 13322 def valid_disk_size @valid_disk_size end |
#zone ⇒ String
[Output Only] URL of the zone where the disk type resides.
You must specify this field as part of the HTTP request URL. It is
not settable as a field in the request body.
Corresponds to the JSON property zone
13329 13330 13331 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 13329 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
13336 13337 13338 13339 13340 13341 13342 13343 13344 13345 13346 13347 13348 13349 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 13336 def update!(**args) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @default_disk_size_gb = args[:default_disk_size_gb] if args.key?(:default_disk_size_gb) @deprecated = args[:deprecated] if args.key?(:deprecated) @description = args[:description] if args.key?(:description) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @region = args[:region] if args.key?(:region) @self_link = args[:self_link] if args.key?(:self_link) @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id) @valid_disk_size = args[:valid_disk_size] if args.key?(:valid_disk_size) @zone = args[:zone] if args.key?(:zone) end |