Class: Google::Apis::ComputeAlpha::DiskType

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Represents a Disk Type resource. Google Compute Engine has two Disk Type resources:

  • Regional
  • Zonal You can choose from a variety of disk types based on your needs. For more information, readStorage options. The diskTypes resource represents disk types for a zonal persistent disk. For more information, readZonal persistent disks. The regionDiskTypes resource represents disk types for a regional persistent disk. For more information, read Regional persistent disks.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DiskType

Returns a new instance of DiskType.



12528
12529
12530
# File 'lib/google/apis/compute_alpha/classes.rb', line 12528

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#creation_timestampString

[Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


12462
12463
12464
# File 'lib/google/apis/compute_alpha/classes.rb', line 12462

def creation_timestamp
  @creation_timestamp
end

#default_disk_size_gbFixnum

[Output Only] Server-defined default disk size in GB. Corresponds to the JSON property defaultDiskSizeGb

Returns:

  • (Fixnum)


12467
12468
12469
# File 'lib/google/apis/compute_alpha/classes.rb', line 12467

def default_disk_size_gb
  @default_disk_size_gb
end

#deprecatedGoogle::Apis::ComputeAlpha::DeprecationStatus

Deprecation status for a public resource. Corresponds to the JSON property deprecated



12472
12473
12474
# File 'lib/google/apis/compute_alpha/classes.rb', line 12472

def deprecated
  @deprecated
end

#descriptionString

[Output Only] An optional description of this resource. Corresponds to the JSON property description

Returns:

  • (String)


12477
12478
12479
# File 'lib/google/apis/compute_alpha/classes.rb', line 12477

def description
  @description
end

#idFixnum

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


12483
12484
12485
# File 'lib/google/apis/compute_alpha/classes.rb', line 12483

def id
  @id
end

#kindString

Output only. [Output Only] Type of the resource. Always compute#diskType for disk types. Corresponds to the JSON property kind

Returns:

  • (String)


12489
12490
12491
# File 'lib/google/apis/compute_alpha/classes.rb', line 12489

def kind
  @kind
end

#nameString

[Output Only] Name of the resource. Corresponds to the JSON property name

Returns:

  • (String)


12494
12495
12496
# File 'lib/google/apis/compute_alpha/classes.rb', line 12494

def name
  @name
end

#regionString

[Output Only] URL of the region where the disk type resides. Only applicable for regional resources. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body. Corresponds to the JSON property region

Returns:

  • (String)


12502
12503
12504
# File 'lib/google/apis/compute_alpha/classes.rb', line 12502

def region
  @region
end

[Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


12507
12508
12509
# File 'lib/google/apis/compute_alpha/classes.rb', line 12507

def self_link
  @self_link
end

Output only. [Output Only] Server-defined URL for this resource with the resource id. Corresponds to the JSON property selfLinkWithId

Returns:

  • (String)


12513
12514
12515
# File 'lib/google/apis/compute_alpha/classes.rb', line 12513

def self_link_with_id
  @self_link_with_id
end

#valid_disk_sizeString

[Output Only] An optional textual description of the valid disk size, such as "10GB-10TB". Corresponds to the JSON property validDiskSize

Returns:

  • (String)


12519
12520
12521
# File 'lib/google/apis/compute_alpha/classes.rb', line 12519

def valid_disk_size
  @valid_disk_size
end

#zoneString

[Output Only] URL of the zone where the disk type resides. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body. Corresponds to the JSON property zone

Returns:

  • (String)


12526
12527
12528
# File 'lib/google/apis/compute_alpha/classes.rb', line 12526

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12533
12534
12535
12536
12537
12538
12539
12540
12541
12542
12543
12544
12545
12546
# File 'lib/google/apis/compute_alpha/classes.rb', line 12533

def update!(**args)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @default_disk_size_gb = args[:default_disk_size_gb] if args.key?(:default_disk_size_gb)
  @deprecated = args[:deprecated] if args.key?(:deprecated)
  @description = args[:description] if args.key?(:description)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @region = args[:region] if args.key?(:region)
  @self_link = args[:self_link] if args.key?(:self_link)
  @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id)
  @valid_disk_size = args[:valid_disk_size] if args.key?(:valid_disk_size)
  @zone = args[:zone] if args.key?(:zone)
end