Class: Google::Apis::ComputeAlpha::DiskType

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Represents a Disk Type resource. Google Compute Engine has two Disk Type resources:

  • Regional
  • Zonal You can choose from a variety of disk types based on your needs. For more information, readStorage options. The diskTypes resource represents disk types for a zonal persistent disk. For more information, readZonal persistent disks. The regionDiskTypes resource represents disk types for a regional persistent disk. For more information, read Regional persistent disks.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DiskType

Returns a new instance of DiskType.



12506
12507
12508
# File 'lib/google/apis/compute_alpha/classes.rb', line 12506

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#creation_timestampString

[Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


12440
12441
12442
# File 'lib/google/apis/compute_alpha/classes.rb', line 12440

def creation_timestamp
  @creation_timestamp
end

#default_disk_size_gbFixnum

[Output Only] Server-defined default disk size in GB. Corresponds to the JSON property defaultDiskSizeGb

Returns:

  • (Fixnum)


12445
12446
12447
# File 'lib/google/apis/compute_alpha/classes.rb', line 12445

def default_disk_size_gb
  @default_disk_size_gb
end

#deprecatedGoogle::Apis::ComputeAlpha::DeprecationStatus

Deprecation status for a public resource. Corresponds to the JSON property deprecated



12450
12451
12452
# File 'lib/google/apis/compute_alpha/classes.rb', line 12450

def deprecated
  @deprecated
end

#descriptionString

[Output Only] An optional description of this resource. Corresponds to the JSON property description

Returns:

  • (String)


12455
12456
12457
# File 'lib/google/apis/compute_alpha/classes.rb', line 12455

def description
  @description
end

#idFixnum

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


12461
12462
12463
# File 'lib/google/apis/compute_alpha/classes.rb', line 12461

def id
  @id
end

#kindString

Output only. [Output Only] Type of the resource. Always compute#diskType for disk types. Corresponds to the JSON property kind

Returns:

  • (String)


12467
12468
12469
# File 'lib/google/apis/compute_alpha/classes.rb', line 12467

def kind
  @kind
end

#nameString

[Output Only] Name of the resource. Corresponds to the JSON property name

Returns:

  • (String)


12472
12473
12474
# File 'lib/google/apis/compute_alpha/classes.rb', line 12472

def name
  @name
end

#regionString

[Output Only] URL of the region where the disk type resides. Only applicable for regional resources. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body. Corresponds to the JSON property region

Returns:

  • (String)


12480
12481
12482
# File 'lib/google/apis/compute_alpha/classes.rb', line 12480

def region
  @region
end

[Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


12485
12486
12487
# File 'lib/google/apis/compute_alpha/classes.rb', line 12485

def self_link
  @self_link
end

Output only. [Output Only] Server-defined URL for this resource with the resource id. Corresponds to the JSON property selfLinkWithId

Returns:

  • (String)


12491
12492
12493
# File 'lib/google/apis/compute_alpha/classes.rb', line 12491

def self_link_with_id
  @self_link_with_id
end

#valid_disk_sizeString

[Output Only] An optional textual description of the valid disk size, such as "10GB-10TB". Corresponds to the JSON property validDiskSize

Returns:

  • (String)


12497
12498
12499
# File 'lib/google/apis/compute_alpha/classes.rb', line 12497

def valid_disk_size
  @valid_disk_size
end

#zoneString

[Output Only] URL of the zone where the disk type resides. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body. Corresponds to the JSON property zone

Returns:

  • (String)


12504
12505
12506
# File 'lib/google/apis/compute_alpha/classes.rb', line 12504

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12511
12512
12513
12514
12515
12516
12517
12518
12519
12520
12521
12522
12523
12524
# File 'lib/google/apis/compute_alpha/classes.rb', line 12511

def update!(**args)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @default_disk_size_gb = args[:default_disk_size_gb] if args.key?(:default_disk_size_gb)
  @deprecated = args[:deprecated] if args.key?(:deprecated)
  @description = args[:description] if args.key?(:description)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @region = args[:region] if args.key?(:region)
  @self_link = args[:self_link] if args.key?(:self_link)
  @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id)
  @valid_disk_size = args[:valid_disk_size] if args.key?(:valid_disk_size)
  @zone = args[:zone] if args.key?(:zone)
end