Class: Google::Apis::ComputeAlpha::DiskType
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::DiskType
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Represents a Disk Type resource. Google Compute Engine has two Disk Type resources:
- Regional
- Zonal You can choose from a variety of disk types based on your needs. For more information, readStorage options. The diskTypes resource represents disk types for a zonal persistent disk. For more information, readZonal persistent disks. The regionDiskTypes resource represents disk types for a regional persistent disk. For more information, read Regional persistent disks.
Instance Attribute Summary collapse
-
#creation_timestamp ⇒ String
[Output Only] Creation timestamp inRFC3339 text format.
-
#default_disk_size_gb ⇒ Fixnum
[Output Only] Server-defined default disk size in GB.
-
#deprecated ⇒ Google::Apis::ComputeAlpha::DeprecationStatus
Deprecation status for a public resource.
-
#description ⇒ String
[Output Only] An optional description of this resource.
-
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
[Output Only] Name of the resource.
-
#region ⇒ String
[Output Only] URL of the region where the disk type resides.
-
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
-
#self_link_with_id ⇒ String
Output only.
-
#valid_disk_size ⇒ String
[Output Only] An optional textual description of the valid disk size, such as "10GB-10TB".
-
#zone ⇒ String
[Output Only] URL of the zone where the disk type resides.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DiskType
constructor
A new instance of DiskType.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DiskType
Returns a new instance of DiskType.
12241 12242 12243 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 12241 def initialize(**args) update!(**args) end |
Instance Attribute Details
#creation_timestamp ⇒ String
[Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
12175 12176 12177 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 12175 def @creation_timestamp end |
#default_disk_size_gb ⇒ Fixnum
[Output Only] Server-defined default disk size in GB.
Corresponds to the JSON property defaultDiskSizeGb
12180 12181 12182 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 12180 def default_disk_size_gb @default_disk_size_gb end |
#deprecated ⇒ Google::Apis::ComputeAlpha::DeprecationStatus
Deprecation status for a public resource.
Corresponds to the JSON property deprecated
12185 12186 12187 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 12185 def deprecated @deprecated end |
#description ⇒ String
[Output Only] An optional description of this resource.
Corresponds to the JSON property description
12190 12191 12192 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 12190 def description @description end |
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
12196 12197 12198 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 12196 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Always compute#diskType
for disk types.
Corresponds to the JSON property kind
12202 12203 12204 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 12202 def kind @kind end |
#name ⇒ String
[Output Only] Name of the resource.
Corresponds to the JSON property name
12207 12208 12209 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 12207 def name @name end |
#region ⇒ String
[Output Only] URL of the region where the disk type resides. Only
applicable for regional resources.
You must specify this field as part of the HTTP request URL. It is
not settable as a field in the request body.
Corresponds to the JSON property region
12215 12216 12217 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 12215 def region @region end |
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
12220 12221 12222 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 12220 def self_link @self_link end |
#self_link_with_id ⇒ String
Output only. [Output Only] Server-defined URL for this resource with the
resource id.
Corresponds to the JSON property selfLinkWithId
12226 12227 12228 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 12226 def self_link_with_id @self_link_with_id end |
#valid_disk_size ⇒ String
[Output Only] An optional textual description of the valid disk size,
such as "10GB-10TB".
Corresponds to the JSON property validDiskSize
12232 12233 12234 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 12232 def valid_disk_size @valid_disk_size end |
#zone ⇒ String
[Output Only] URL of the zone where the disk type resides.
You must specify this field as part of the HTTP request URL. It is
not settable as a field in the request body.
Corresponds to the JSON property zone
12239 12240 12241 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 12239 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12246 12247 12248 12249 12250 12251 12252 12253 12254 12255 12256 12257 12258 12259 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 12246 def update!(**args) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @default_disk_size_gb = args[:default_disk_size_gb] if args.key?(:default_disk_size_gb) @deprecated = args[:deprecated] if args.key?(:deprecated) @description = args[:description] if args.key?(:description) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @region = args[:region] if args.key?(:region) @self_link = args[:self_link] if args.key?(:self_link) @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id) @valid_disk_size = args[:valid_disk_size] if args.key?(:valid_disk_size) @zone = args[:zone] if args.key?(:zone) end |