Class: Google::Apis::ComputeAlpha::DiskUpdateKmsKeyRequest
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::DiskUpdateKmsKeyRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#kms_key_name ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DiskUpdateKmsKeyRequest
constructor
A new instance of DiskUpdateKmsKeyRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DiskUpdateKmsKeyRequest
Returns a new instance of DiskUpdateKmsKeyRequest.
12903 12904 12905 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 12903 def initialize(**args) update!(**args) end |
Instance Attribute Details
#kms_key_name ⇒ String
Optional. The new KMS key to replace the current one on the disk. If empty, the disk will be re-encrypted using the primary version of the disk's current KMS key. The KMS key can be provided in the following formats:
- projects/project_id/locations/location/keyRings/key_ring/cryptoKeys/key
Where project is the project ID or
project number.
Corresponds to the JSON property
kmsKeyName
12901 12902 12903 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 12901 def kms_key_name @kms_key_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12908 12909 12910 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 12908 def update!(**args) @kms_key_name = args[:kms_key_name] if args.key?(:kms_key_name) end |