Class: Google::Apis::ComputeAlpha::DistributionPolicy

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DistributionPolicy

Returns a new instance of DistributionPolicy.



13204
13205
13206
# File 'lib/google/apis/compute_alpha/classes.rb', line 13204

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#target_shapeString

The distribution shape to which the group converges either proactively or on resize events (depending on the value set inupdatePolicy. instanceRedistributionType). Corresponds to the JSON property targetShape

Returns:

  • (String)


13191
13192
13193
# File 'lib/google/apis/compute_alpha/classes.rb', line 13191

def target_shape
  @target_shape
end

#zonesArray<Google::Apis::ComputeAlpha::DistributionPolicyZoneConfiguration>

Zones where the regional managed instance group will create and manage its instances. By default, a regional MIG doesn't automatically select an AI zone to create instances, even if an AI zone is available in the specified region. To create instances in an AI zone in the selected region, you must explicitly specify it in the distribution policy together with the other preferred zones. Corresponds to the JSON property zones



13202
13203
13204
# File 'lib/google/apis/compute_alpha/classes.rb', line 13202

def zones
  @zones
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13209
13210
13211
13212
# File 'lib/google/apis/compute_alpha/classes.rb', line 13209

def update!(**args)
  @target_shape = args[:target_shape] if args.key?(:target_shape)
  @zones = args[:zones] if args.key?(:zones)
end