Class: Google::Apis::ComputeAlpha::DistributionPolicy
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::DistributionPolicy
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#target_shape ⇒ String
The distribution shape to which the group converges either proactively or on resize events (depending on the value set inupdatePolicy. instanceRedistributionType).
-
#zones ⇒ Array<Google::Apis::ComputeAlpha::DistributionPolicyZoneConfiguration>
Zones where the regional managed instance group will create and manage its instances.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DistributionPolicy
constructor
A new instance of DistributionPolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DistributionPolicy
Returns a new instance of DistributionPolicy.
12901 12902 12903 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 12901 def initialize(**args) update!(**args) end |
Instance Attribute Details
#target_shape ⇒ String
The distribution shape to which the group converges either proactively or
on resize events (depending on the value set inupdatePolicy.
instanceRedistributionType).
Corresponds to the JSON property targetShape
12893 12894 12895 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 12893 def target_shape @target_shape end |
#zones ⇒ Array<Google::Apis::ComputeAlpha::DistributionPolicyZoneConfiguration>
Zones where the regional managed instance group will create and manage
its instances.
Corresponds to the JSON property zones
12899 12900 12901 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 12899 def zones @zones end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12906 12907 12908 12909 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 12906 def update!(**args) @target_shape = args[:target_shape] if args.key?(:target_shape) @zones = args[:zones] if args.key?(:zones) end |