Class: Google::Apis::ComputeAlpha::Duration
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::Duration
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution. It is independent of any calendar and concepts like "day" or "month". Range is approximately 10,000 years.
Instance Attribute Summary collapse
-
#nanos ⇒ Fixnum
Span of time that's a fraction of a second at nanosecond resolution.
-
#seconds ⇒ Fixnum
Span of time at a resolution of a second.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Duration
constructor
A new instance of Duration.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Duration
Returns a new instance of Duration.
13885 13886 13887 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 13885 def initialize(**args) update!(**args) end |
Instance Attribute Details
#nanos ⇒ Fixnum
Span of time that's a fraction of a second at nanosecond resolution.
Durations less than one second are represented with a 0
seconds field and a positive nanos field. Must be from 0
to 999,999,999 inclusive.
Corresponds to the JSON property nanos
13876 13877 13878 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 13876 def nanos @nanos end |
#seconds ⇒ Fixnum
Span of time at a resolution of a second. Must be from 0
to 315,576,000,000 inclusive. Note: these bounds are computed from:
60 sec/min * 60 min/hr * 24 hr/day * 365.25 days/year * 10000 years
Corresponds to the JSON property seconds
13883 13884 13885 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 13883 def seconds @seconds end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
13890 13891 13892 13893 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 13890 def update!(**args) @nanos = args[:nanos] if args.key?(:nanos) @seconds = args[:seconds] if args.key?(:seconds) end |