Class: Google::Apis::ComputeAlpha::ExchangedPeeringRoutesList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ExchangedPeeringRoutesList

Returns a new instance of ExchangedPeeringRoutesList.



14213
14214
14215
# File 'lib/google/apis/compute_alpha/classes.rb', line 14213

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


14179
14180
14181
# File 'lib/google/apis/compute_alpha/classes.rb', line 14179

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::ExchangedPeeringRoute>

A list of ExchangedPeeringRoute resources. Corresponds to the JSON property items



14184
14185
14186
# File 'lib/google/apis/compute_alpha/classes.rb', line 14184

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# exchangedPeeringRoutesList for exchanged peering routes lists. Corresponds to the JSON property kind

Returns:

  • (String)


14191
14192
14193
# File 'lib/google/apis/compute_alpha/classes.rb', line 14191

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


14201
14202
14203
# File 'lib/google/apis/compute_alpha/classes.rb', line 14201

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


14206
14207
14208
# File 'lib/google/apis/compute_alpha/classes.rb', line 14206

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::ExchangedPeeringRoutesList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



14211
14212
14213
# File 'lib/google/apis/compute_alpha/classes.rb', line 14211

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



14218
14219
14220
14221
14222
14223
14224
14225
# File 'lib/google/apis/compute_alpha/classes.rb', line 14218

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end