Class: Google::Apis::ComputeAlpha::ExchangedPeeringRoutesList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ExchangedPeeringRoutesList

Returns a new instance of ExchangedPeeringRoutesList.



13120
13121
13122
# File 'lib/google/apis/compute_alpha/classes.rb', line 13120

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


13086
13087
13088
# File 'lib/google/apis/compute_alpha/classes.rb', line 13086

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::ExchangedPeeringRoute>

A list of ExchangedPeeringRoute resources. Corresponds to the JSON property items



13091
13092
13093
# File 'lib/google/apis/compute_alpha/classes.rb', line 13091

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# exchangedPeeringRoutesList for exchanged peering routes lists. Corresponds to the JSON property kind

Returns:

  • (String)


13098
13099
13100
# File 'lib/google/apis/compute_alpha/classes.rb', line 13098

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


13108
13109
13110
# File 'lib/google/apis/compute_alpha/classes.rb', line 13108

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


13113
13114
13115
# File 'lib/google/apis/compute_alpha/classes.rb', line 13113

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::ExchangedPeeringRoutesList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



13118
13119
13120
# File 'lib/google/apis/compute_alpha/classes.rb', line 13118

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13125
13126
13127
13128
13129
13130
13131
13132
# File 'lib/google/apis/compute_alpha/classes.rb', line 13125

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end