Class: Google::Apis::ComputeAlpha::ExternalVpnGateway

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Represents an external VPN gateway. External VPN gateway is the on-premises VPN gateway(s) or another cloud provider's VPN gateway that connects to your Google Cloud VPN gateway. To create a highly available VPN from Google Cloud Platform to your VPN gateway or another cloud provider's VPN gateway, you must create a external VPN gateway resource with information about the other gateway. For more information about using external VPN gateways, see Creating an HA VPN gateway and tunnel pair to a peer VPN.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ExternalVpnGateway

Returns a new instance of ExternalVpnGateway.



13642
13643
13644
# File 'lib/google/apis/compute_alpha/classes.rb', line 13642

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


13564
13565
13566
# File 'lib/google/apis/compute_alpha/classes.rb', line 13564

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


13570
13571
13572
# File 'lib/google/apis/compute_alpha/classes.rb', line 13570

def description
  @description
end

#idFixnum

Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


13577
13578
13579
# File 'lib/google/apis/compute_alpha/classes.rb', line 13577

def id
  @id
end

#interfacesArray<Google::Apis::ComputeAlpha::ExternalVpnGatewayInterface>

A list of interfaces for this external VPN gateway. If your peer-side gateway is an on-premises gateway and non-AWS cloud providers' gateway, at most two interfaces can be provided for an external VPN gateway. If your peer side is an AWS virtual private gateway, four interfaces should be provided for an external VPN gateway. Corresponds to the JSON property interfaces



13586
13587
13588
# File 'lib/google/apis/compute_alpha/classes.rb', line 13586

def interfaces
  @interfaces
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# externalVpnGateway for externalVpnGateways. Corresponds to the JSON property kind

Returns:

  • (String)


13592
13593
13594
# File 'lib/google/apis/compute_alpha/classes.rb', line 13592

def kind
  @kind
end

#label_fingerprintString

A fingerprint for the labels being applied to this ExternalVpnGateway, which is essentially a hash of the labels set used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update labels. You must always provide an up-to-date fingerprint hash in order to update or change labels, otherwise the request will fail with error412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve an ExternalVpnGateway. Corresponds to the JSON property labelFingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


13605
13606
13607
# File 'lib/google/apis/compute_alpha/classes.rb', line 13605

def label_fingerprint
  @label_fingerprint
end

#labelsHash<String,String>

Labels for this resource. These can only be added or modified by thesetLabels method. Each label key/value pair must comply withRFC1035. Label values may be empty. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


13612
13613
13614
# File 'lib/google/apis/compute_alpha/classes.rb', line 13612

def labels
  @labels
end

#nameString

Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


13623
13624
13625
# File 'lib/google/apis/compute_alpha/classes.rb', line 13623

def name
  @name
end

#paramsGoogle::Apis::ComputeAlpha::ExternalVpnGatewayParams

Input only. [Input Only] Additional params passed with the request, but not persisted as part of resource payload. Corresponds to the JSON property params



13630
13631
13632
# File 'lib/google/apis/compute_alpha/classes.rb', line 13630

def params
  @params
end

#redundancy_typeString

Indicates the user-supplied redundancy type of this external VPN gateway. Corresponds to the JSON property redundancyType

Returns:

  • (String)


13635
13636
13637
# File 'lib/google/apis/compute_alpha/classes.rb', line 13635

def redundancy_type
  @redundancy_type
end

Output only. [Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


13640
13641
13642
# File 'lib/google/apis/compute_alpha/classes.rb', line 13640

def self_link
  @self_link
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13647
13648
13649
13650
13651
13652
13653
13654
13655
13656
13657
13658
13659
# File 'lib/google/apis/compute_alpha/classes.rb', line 13647

def update!(**args)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @id = args[:id] if args.key?(:id)
  @interfaces = args[:interfaces] if args.key?(:interfaces)
  @kind = args[:kind] if args.key?(:kind)
  @label_fingerprint = args[:label_fingerprint] if args.key?(:label_fingerprint)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @params = args[:params] if args.key?(:params)
  @redundancy_type = args[:redundancy_type] if args.key?(:redundancy_type)
  @self_link = args[:self_link] if args.key?(:self_link)
end