Class: Google::Apis::ComputeAlpha::ExternalVpnGatewayList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::ExternalVpnGatewayList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Response to the list request, and contains a list of externalVpnGateways.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::ExternalVpnGateway>
A list of ExternalVpnGateway resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::ExternalVpnGatewayList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ExternalVpnGatewayList
constructor
A new instance of ExternalVpnGatewayList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ExternalVpnGatewayList
Returns a new instance of ExternalVpnGatewayList.
14594 14595 14596 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 14594 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
14556 14557 14558 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 14556 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
14561 14562 14563 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 14561 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::ExternalVpnGateway>
A list of ExternalVpnGateway resources.
Corresponds to the JSON property items
14566 14567 14568 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 14566 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#
externalVpnGatewayList for lists of externalVpnGateways.
Corresponds to the JSON property kind
14572 14573 14574 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 14572 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
14582 14583 14584 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 14582 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
14587 14588 14589 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 14587 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::ExternalVpnGatewayList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
14592 14593 14594 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 14592 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
14599 14600 14601 14602 14603 14604 14605 14606 14607 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 14599 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |