Class: Google::Apis::ComputeAlpha::ExternalVpnGatewayList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::ExternalVpnGatewayList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Response to the list request, and contains a list of externalVpnGateways.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::ExternalVpnGateway>
A list of ExternalVpnGateway resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::ExternalVpnGatewayList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ExternalVpnGatewayList
constructor
A new instance of ExternalVpnGatewayList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ExternalVpnGatewayList
Returns a new instance of ExternalVpnGatewayList.
14401 14402 14403 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 14401 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
14363 14364 14365 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 14363 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
14368 14369 14370 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 14368 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::ExternalVpnGateway>
A list of ExternalVpnGateway resources.
Corresponds to the JSON property items
14373 14374 14375 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 14373 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#
externalVpnGatewayList for lists of externalVpnGateways.
Corresponds to the JSON property kind
14379 14380 14381 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 14379 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
14389 14390 14391 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 14389 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
14394 14395 14396 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 14394 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::ExternalVpnGatewayList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
14399 14400 14401 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 14399 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
14406 14407 14408 14409 14410 14411 14412 14413 14414 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 14406 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |