Class: Google::Apis::ComputeAlpha::ExternalVpnGatewayList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Response to the list request, and contains a list of externalVpnGateways.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ExternalVpnGatewayList

Returns a new instance of ExternalVpnGatewayList.



13769
13770
13771
# File 'lib/google/apis/compute_alpha/classes.rb', line 13769

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


13731
13732
13733
# File 'lib/google/apis/compute_alpha/classes.rb', line 13731

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


13736
13737
13738
# File 'lib/google/apis/compute_alpha/classes.rb', line 13736

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::ExternalVpnGateway>

A list of ExternalVpnGateway resources. Corresponds to the JSON property items



13741
13742
13743
# File 'lib/google/apis/compute_alpha/classes.rb', line 13741

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute# externalVpnGatewayList for lists of externalVpnGateways. Corresponds to the JSON property kind

Returns:

  • (String)


13747
13748
13749
# File 'lib/google/apis/compute_alpha/classes.rb', line 13747

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


13757
13758
13759
# File 'lib/google/apis/compute_alpha/classes.rb', line 13757

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


13762
13763
13764
# File 'lib/google/apis/compute_alpha/classes.rb', line 13762

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::ExternalVpnGatewayList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



13767
13768
13769
# File 'lib/google/apis/compute_alpha/classes.rb', line 13767

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13774
13775
13776
13777
13778
13779
13780
13781
13782
# File 'lib/google/apis/compute_alpha/classes.rb', line 13774

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end