Class: Google::Apis::ComputeAlpha::ExternalVpnGatewayList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::ExternalVpnGatewayList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Response to the list request, and contains a list of externalVpnGateways.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::ExternalVpnGateway>
A list of ExternalVpnGateway resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::ExternalVpnGatewayList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ExternalVpnGatewayList
constructor
A new instance of ExternalVpnGatewayList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ExternalVpnGatewayList
Returns a new instance of ExternalVpnGatewayList.
13774 13775 13776 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 13774 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
13736 13737 13738 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 13736 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
13741 13742 13743 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 13741 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::ExternalVpnGateway>
A list of ExternalVpnGateway resources.
Corresponds to the JSON property items
13746 13747 13748 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 13746 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#
externalVpnGatewayList for lists of externalVpnGateways.
Corresponds to the JSON property kind
13752 13753 13754 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 13752 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
13762 13763 13764 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 13762 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
13767 13768 13769 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 13767 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::ExternalVpnGatewayList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
13772 13773 13774 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 13772 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
13779 13780 13781 13782 13783 13784 13785 13786 13787 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 13779 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |