Class: Google::Apis::ComputeAlpha::Firewall

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Represents a Firewall Rule resource. Firewall rules allow or deny ingress traffic to, and egress traffic from your instances. For more information, readFirewall rules.

Defined Under Namespace

Classes: Allowed, Denied

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Firewall

Returns a new instance of Firewall.



13817
13818
13819
# File 'lib/google/apis/compute_alpha/classes.rb', line 13817

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allowedArray<Google::Apis::ComputeAlpha::Firewall::Allowed>

The list of ALLOW rules specified by this firewall. Each rule specifies a protocol and port-range tuple that describes a permitted connection. Corresponds to the JSON property allowed



13625
13626
13627
# File 'lib/google/apis/compute_alpha/classes.rb', line 13625

def allowed
  @allowed
end

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


13631
13632
13633
# File 'lib/google/apis/compute_alpha/classes.rb', line 13631

def creation_timestamp
  @creation_timestamp
end

#deniedArray<Google::Apis::ComputeAlpha::Firewall::Denied>

The list of DENY rules specified by this firewall. Each rule specifies a protocol and port-range tuple that describes a denied connection. Corresponds to the JSON property denied



13637
13638
13639
# File 'lib/google/apis/compute_alpha/classes.rb', line 13637

def denied
  @denied
end

#descriptionString

An optional description of this resource. Provide this field when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


13643
13644
13645
# File 'lib/google/apis/compute_alpha/classes.rb', line 13643

def description
  @description
end

#destination_rangesArray<String>

If destination ranges are specified, the firewall rule applies only to traffic that has destination IP address in these ranges. These ranges must be expressed inCIDR format. Both IPv4 and IPv6 are supported. Corresponds to the JSON property destinationRanges

Returns:

  • (Array<String>)


13650
13651
13652
# File 'lib/google/apis/compute_alpha/classes.rb', line 13650

def destination_ranges
  @destination_ranges
end

#directionString

Direction of traffic to which this firewall applies, either INGRESS or EGRESS. The default is INGRESS. For EGRESS traffic, you cannot specify the sourceTags fields. Corresponds to the JSON property direction

Returns:

  • (String)


13657
13658
13659
# File 'lib/google/apis/compute_alpha/classes.rb', line 13657

def direction
  @direction
end

#disabledBoolean Also known as: disabled?

Denotes whether the firewall rule is disabled. When set to true, the firewall rule is not enforced and the network behaves as if it did not exist. If this is unspecified, the firewall rule will be enabled. Corresponds to the JSON property disabled

Returns:

  • (Boolean)


13664
13665
13666
# File 'lib/google/apis/compute_alpha/classes.rb', line 13664

def disabled
  @disabled
end

#enable_loggingBoolean Also known as: enable_logging?

Deprecated in favor of enable in LogConfig. This field denotes whether to enable logging for a particular firewall rule. If logging is enabled, logs will be exported t Cloud Logging. Corresponds to the JSON property enableLogging

Returns:

  • (Boolean)


13673
13674
13675
# File 'lib/google/apis/compute_alpha/classes.rb', line 13673

def enable_logging
  @enable_logging
end

#idFixnum

Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


13681
13682
13683
# File 'lib/google/apis/compute_alpha/classes.rb', line 13681

def id
  @id
end

#kindString

Output only. [Output Only] Type of the resource. Always compute#firewall for firewall rules. Corresponds to the JSON property kind

Returns:

  • (String)


13687
13688
13689
# File 'lib/google/apis/compute_alpha/classes.rb', line 13687

def kind
  @kind
end

#log_configGoogle::Apis::ComputeAlpha::FirewallLogConfig

The available logging options for a firewall rule. Corresponds to the JSON property logConfig



13692
13693
13694
# File 'lib/google/apis/compute_alpha/classes.rb', line 13692

def log_config
  @log_config
end

#nameString

Name of the resource; provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])?. The first character must be a lowercase letter, and all following characters (except for the last character) must be a dash, lowercase letter, or digit. The last character must be a lowercase letter or digit. Corresponds to the JSON property name

Returns:

  • (String)


13703
13704
13705
# File 'lib/google/apis/compute_alpha/classes.rb', line 13703

def name
  @name
end

#networkString

URL of the network resource for this firewall rule. If not specified when creating a firewall rule, the default network is used: global/networks/default If you choose to specify this field, you can specify the network as a full or partial URL. For example, the following are all valid URLs:

- https://www.googleapis.com/compute/v1/projects/myproject/global/networks/my- network

  • projects/myproject/global/networks/my-network
  • global/networks/default Corresponds to the JSON property network

Returns:

  • (String)


13719
13720
13721
# File 'lib/google/apis/compute_alpha/classes.rb', line 13719

def network
  @network
end

#paramsGoogle::Apis::ComputeAlpha::FirewallParams

Additional firewall parameters. Corresponds to the JSON property params



13724
13725
13726
# File 'lib/google/apis/compute_alpha/classes.rb', line 13724

def params
  @params
end

#priorityFixnum

Priority for this rule. This is an integer between 0 and 65535, both inclusive. The default value is 1000. Relative priorities determine which rule takes effect if multiple rules apply. Lower values indicate higher priority. For example, a rule with priority 0 has higher precedence than a rule with priority 1. DENY rules take precedence over ALLOW rules if they have equal priority. Note that VPC networks have implied rules with a priority of 65535. To avoid conflicts with the implied rules, use a priority number less than 65535. Corresponds to the JSON property priority

Returns:

  • (Fixnum)


13738
13739
13740
# File 'lib/google/apis/compute_alpha/classes.rb', line 13738

def priority
  @priority
end

[Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


13743
13744
13745
# File 'lib/google/apis/compute_alpha/classes.rb', line 13743

def self_link
  @self_link
end

Output only. [Output Only] Server-defined URL for this resource with the resource id. Corresponds to the JSON property selfLinkWithId

Returns:

  • (String)


13749
13750
13751
# File 'lib/google/apis/compute_alpha/classes.rb', line 13749

def self_link_with_id
  @self_link_with_id
end

#source_rangesArray<String>

If source ranges are specified, the firewall rule applies only to traffic that has a source IP address in these ranges. These ranges must be expressed inCIDR format. One or both of sourceRanges and sourceTags may be set. If both fields are set, the rule applies to traffic that has a source IP address within sourceRanges OR a source IP from a resource with a matching tag listed in thesourceTags field. The connection does not need to match both fields for the rule to apply. Both IPv4 and IPv6 are supported. Corresponds to the JSON property sourceRanges

Returns:

  • (Array<String>)


13763
13764
13765
# File 'lib/google/apis/compute_alpha/classes.rb', line 13763

def source_ranges
  @source_ranges
end

#source_service_accountsArray<String>

If source service accounts are specified, the firewall rules apply only to traffic originating from an instance with a service account in this list. Source service accounts cannot be used to control traffic to an instance's external IP address because service accounts are associated with an instance, not an IP address.sourceRanges can be set at the same time assourceServiceAccounts. If both are set, the firewall applies to traffic that has a source IP address within the sourceRanges OR a source IP that belongs to an instance with service account listed insourceServiceAccount. The connection does not need to match both fields for the firewall to apply.sourceServiceAccounts cannot be used at the same time assourceTags or targetTags. Corresponds to the JSON property sourceServiceAccounts

Returns:

  • (Array<String>)


13779
13780
13781
# File 'lib/google/apis/compute_alpha/classes.rb', line 13779

def source_service_accounts
  @source_service_accounts
end

#source_tagsArray<String>

If source tags are specified, the firewall rule applies only to traffic with source IPs that match the primary network interfaces of VM instances that have the tag and are in the same VPC network. Source tags cannot be used to control traffic to an instance's external IP address, it only applies to traffic between instances in the same virtual network. Because tags are associated with instances, not IP addresses. One or both of sourceRanges and sourceTags may be set. If both fields are set, the firewall applies to traffic that has a source IP address within sourceRanges OR a source IP from a resource with a matching tag listed in the sourceTags field. The connection does not need to match both fields for the firewall to apply. Corresponds to the JSON property sourceTags

Returns:

  • (Array<String>)


13795
13796
13797
# File 'lib/google/apis/compute_alpha/classes.rb', line 13795

def source_tags
  @source_tags
end

#target_service_accountsArray<String>

A list of service accounts indicating sets of instances located in the network that may make network connections as specified inallowed[]. targetServiceAccounts cannot be used at the same time astargetTags or sourceTags. If neither targetServiceAccounts nor targetTags are specified, the firewall rule applies to all instances on the specified network. Corresponds to the JSON property targetServiceAccounts

Returns:

  • (Array<String>)


13806
13807
13808
# File 'lib/google/apis/compute_alpha/classes.rb', line 13806

def target_service_accounts
  @target_service_accounts
end

#target_tagsArray<String>

A list of tags that controls which instances the firewall rule applies to. If targetTags are specified, then the firewall rule applies only to instances in the VPC network that have one of those tags. If no targetTags are specified, the firewall rule applies to all instances on the specified network. Corresponds to the JSON property targetTags

Returns:

  • (Array<String>)


13815
13816
13817
# File 'lib/google/apis/compute_alpha/classes.rb', line 13815

def target_tags
  @target_tags
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13822
13823
13824
13825
13826
13827
13828
13829
13830
13831
13832
13833
13834
13835
13836
13837
13838
13839
13840
13841
13842
13843
13844
13845
# File 'lib/google/apis/compute_alpha/classes.rb', line 13822

def update!(**args)
  @allowed = args[:allowed] if args.key?(:allowed)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @denied = args[:denied] if args.key?(:denied)
  @description = args[:description] if args.key?(:description)
  @destination_ranges = args[:destination_ranges] if args.key?(:destination_ranges)
  @direction = args[:direction] if args.key?(:direction)
  @disabled = args[:disabled] if args.key?(:disabled)
  @enable_logging = args[:enable_logging] if args.key?(:enable_logging)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @log_config = args[:log_config] if args.key?(:log_config)
  @name = args[:name] if args.key?(:name)
  @network = args[:network] if args.key?(:network)
  @params = args[:params] if args.key?(:params)
  @priority = args[:priority] if args.key?(:priority)
  @self_link = args[:self_link] if args.key?(:self_link)
  @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id)
  @source_ranges = args[:source_ranges] if args.key?(:source_ranges)
  @source_service_accounts = args[:source_service_accounts] if args.key?(:source_service_accounts)
  @source_tags = args[:source_tags] if args.key?(:source_tags)
  @target_service_accounts = args[:target_service_accounts] if args.key?(:target_service_accounts)
  @target_tags = args[:target_tags] if args.key?(:target_tags)
end