Class: Google::Apis::ComputeAlpha::Firewall::Allowed
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::Firewall::Allowed
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#ip_protocol ⇒ String
The IP protocol to which this rule applies.
-
#ports ⇒ Array<String>
An optional list of ports to which this rule applies.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Allowed
constructor
A new instance of Allowed.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Allowed
Returns a new instance of Allowed.
13869 13870 13871 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 13869 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ip_protocol ⇒ String
The IP protocol to which this rule applies. The protocol type is
required when creating a firewall rule. This value can either be one of the
following well known protocol strings (tcp, udp,icmp, esp, ah, ipip,sctp) or
the IP protocol number.
Corresponds to the JSON property IPProtocol
13857 13858 13859 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 13857 def ip_protocol @ip_protocol end |
#ports ⇒ Array<String>
An optional list of ports to which this rule applies.
This field is only applicable for the UDP or TCP protocol.
Each entry must be either an integer or a range.
If not specified, this rule applies to connections through any port.
Example inputs include: ["22"], ["80","443"],
and ["12345-12349"].
Corresponds to the JSON property ports
13867 13868 13869 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 13867 def ports @ports end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
13874 13875 13876 13877 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 13874 def update!(**args) @ip_protocol = args[:ip_protocol] if args.key?(:ip_protocol) @ports = args[:ports] if args.key?(:ports) end |