Class: Google::Apis::ComputeAlpha::FirewallList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::FirewallList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Contains a list of firewalls.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::Firewall>
A list of Firewall resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::FirewallList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FirewallList
constructor
A new instance of FirewallList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FirewallList
Returns a new instance of FirewallList.
15047 15048 15049 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 15047 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
15014 15015 15016 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 15014 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::Firewall>
A list of Firewall resources.
Corresponds to the JSON property items
15019 15020 15021 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 15019 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#firewallList
for lists of firewalls.
Corresponds to the JSON property kind
15025 15026 15027 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 15025 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
15035 15036 15037 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 15035 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
15040 15041 15042 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 15040 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::FirewallList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
15045 15046 15047 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 15045 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
15052 15053 15054 15055 15056 15057 15058 15059 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 15052 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |