Class: Google::Apis::ComputeAlpha::FirewallList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of firewalls.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FirewallList

Returns a new instance of FirewallList.



14884
14885
14886
# File 'lib/google/apis/compute_alpha/classes.rb', line 14884

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


14851
14852
14853
# File 'lib/google/apis/compute_alpha/classes.rb', line 14851

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::Firewall>

A list of Firewall resources. Corresponds to the JSON property items



14856
14857
14858
# File 'lib/google/apis/compute_alpha/classes.rb', line 14856

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#firewallList for lists of firewalls. Corresponds to the JSON property kind

Returns:

  • (String)


14862
14863
14864
# File 'lib/google/apis/compute_alpha/classes.rb', line 14862

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


14872
14873
14874
# File 'lib/google/apis/compute_alpha/classes.rb', line 14872

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


14877
14878
14879
# File 'lib/google/apis/compute_alpha/classes.rb', line 14877

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::FirewallList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



14882
14883
14884
# File 'lib/google/apis/compute_alpha/classes.rb', line 14882

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



14889
14890
14891
14892
14893
14894
14895
14896
# File 'lib/google/apis/compute_alpha/classes.rb', line 14889

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end