Class: Google::Apis::ComputeAlpha::FirewallList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of firewalls.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FirewallList

Returns a new instance of FirewallList.



14274
14275
14276
# File 'lib/google/apis/compute_alpha/classes.rb', line 14274

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


14241
14242
14243
# File 'lib/google/apis/compute_alpha/classes.rb', line 14241

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::Firewall>

A list of Firewall resources. Corresponds to the JSON property items



14246
14247
14248
# File 'lib/google/apis/compute_alpha/classes.rb', line 14246

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#firewallList for lists of firewalls. Corresponds to the JSON property kind

Returns:

  • (String)


14252
14253
14254
# File 'lib/google/apis/compute_alpha/classes.rb', line 14252

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


14262
14263
14264
# File 'lib/google/apis/compute_alpha/classes.rb', line 14262

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


14267
14268
14269
# File 'lib/google/apis/compute_alpha/classes.rb', line 14267

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::FirewallList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



14272
14273
14274
# File 'lib/google/apis/compute_alpha/classes.rb', line 14272

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



14279
14280
14281
14282
14283
14284
14285
14286
# File 'lib/google/apis/compute_alpha/classes.rb', line 14279

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end