Class: Google::Apis::ComputeAlpha::FirewallList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of firewalls.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FirewallList

Returns a new instance of FirewallList.



14235
14236
14237
# File 'lib/google/apis/compute_alpha/classes.rb', line 14235

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


14202
14203
14204
# File 'lib/google/apis/compute_alpha/classes.rb', line 14202

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::Firewall>

A list of Firewall resources. Corresponds to the JSON property items



14207
14208
14209
# File 'lib/google/apis/compute_alpha/classes.rb', line 14207

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#firewallList for lists of firewalls. Corresponds to the JSON property kind

Returns:

  • (String)


14213
14214
14215
# File 'lib/google/apis/compute_alpha/classes.rb', line 14213

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


14223
14224
14225
# File 'lib/google/apis/compute_alpha/classes.rb', line 14223

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


14228
14229
14230
# File 'lib/google/apis/compute_alpha/classes.rb', line 14228

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::FirewallList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



14233
14234
14235
# File 'lib/google/apis/compute_alpha/classes.rb', line 14233

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



14240
14241
14242
14243
14244
14245
14246
14247
# File 'lib/google/apis/compute_alpha/classes.rb', line 14240

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end