Class: Google::Apis::ComputeAlpha::FirewallLogConfig
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::FirewallLogConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
The available logging options for a firewall rule.
Instance Attribute Summary collapse
-
#enable ⇒ Boolean
(also: #enable?)
This field denotes whether to enable logging for a particular firewall rule.
-
#metadata ⇒ String
This field can only be specified for a particular firewall rule if logging is enabled for that rule.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FirewallLogConfig
constructor
A new instance of FirewallLogConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FirewallLogConfig
Returns a new instance of FirewallLogConfig.
14377 14378 14379 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 14377 def initialize(**args) update!(**args) end |
Instance Attribute Details
#enable ⇒ Boolean Also known as: enable?
This field denotes whether to enable logging for a particular firewall
rule.
Corresponds to the JSON property enable
14367 14368 14369 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 14367 def enable @enable end |
#metadata ⇒ String
This field can only be specified for a particular firewall rule if
logging is enabled for that rule. This field denotes whether to include
or exclude metadata for firewall logs.
Corresponds to the JSON property metadata
14375 14376 14377 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 14375 def @metadata end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
14382 14383 14384 14385 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 14382 def update!(**args) @enable = args[:enable] if args.key?(:enable) @metadata = args[:metadata] if args.key?(:metadata) end |