Class: Google::Apis::ComputeAlpha::FirewallPoliciesScopedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::FirewallPoliciesScopedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#firewall_policies ⇒ Array<Google::Apis::ComputeAlpha::FirewallPolicy>
A list of firewall policies contained in this scope.
-
#warning ⇒ Google::Apis::ComputeAlpha::FirewallPoliciesScopedList::Warning
Informational warning which replaces the list of firewall policies when the list is empty.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FirewallPoliciesScopedList
constructor
A new instance of FirewallPoliciesScopedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FirewallPoliciesScopedList
Returns a new instance of FirewallPoliciesScopedList.
14421 14422 14423 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 14421 def initialize(**args) update!(**args) end |
Instance Attribute Details
#firewall_policies ⇒ Array<Google::Apis::ComputeAlpha::FirewallPolicy>
A list of firewall policies contained in this scope.
Corresponds to the JSON property firewallPolicies
14413 14414 14415 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 14413 def firewall_policies @firewall_policies end |
#warning ⇒ Google::Apis::ComputeAlpha::FirewallPoliciesScopedList::Warning
Informational warning which replaces the list of firewall policies when
the list is empty.
Corresponds to the JSON property warning
14419 14420 14421 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 14419 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
14426 14427 14428 14429 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 14426 def update!(**args) @firewall_policies = args[:firewall_policies] if args.key?(:firewall_policies) @warning = args[:warning] if args.key?(:warning) end |