Class: Google::Apis::ComputeAlpha::FirewallPoliciesScopedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FirewallPoliciesScopedList

Returns a new instance of FirewallPoliciesScopedList.



14443
14444
14445
# File 'lib/google/apis/compute_alpha/classes.rb', line 14443

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#firewall_policiesArray<Google::Apis::ComputeAlpha::FirewallPolicy>

A list of firewall policies contained in this scope. Corresponds to the JSON property firewallPolicies



14435
14436
14437
# File 'lib/google/apis/compute_alpha/classes.rb', line 14435

def firewall_policies
  @firewall_policies
end

#warningGoogle::Apis::ComputeAlpha::FirewallPoliciesScopedList::Warning

Informational warning which replaces the list of firewall policies when the list is empty. Corresponds to the JSON property warning



14441
14442
14443
# File 'lib/google/apis/compute_alpha/classes.rb', line 14441

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



14448
14449
14450
14451
# File 'lib/google/apis/compute_alpha/classes.rb', line 14448

def update!(**args)
  @firewall_policies = args[:firewall_policies] if args.key?(:firewall_policies)
  @warning = args[:warning] if args.key?(:warning)
end