Class: Google::Apis::ComputeAlpha::FirewallPoliciesScopedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::FirewallPoliciesScopedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#firewall_policies ⇒ Array<Google::Apis::ComputeAlpha::FirewallPolicy>
A list of firewall policies contained in this scope.
-
#warning ⇒ Google::Apis::ComputeAlpha::FirewallPoliciesScopedList::Warning
Informational warning which replaces the list of firewall policies when the list is empty.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FirewallPoliciesScopedList
constructor
A new instance of FirewallPoliciesScopedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FirewallPoliciesScopedList
Returns a new instance of FirewallPoliciesScopedList.
14443 14444 14445 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 14443 def initialize(**args) update!(**args) end |
Instance Attribute Details
#firewall_policies ⇒ Array<Google::Apis::ComputeAlpha::FirewallPolicy>
A list of firewall policies contained in this scope.
Corresponds to the JSON property firewallPolicies
14435 14436 14437 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 14435 def firewall_policies @firewall_policies end |
#warning ⇒ Google::Apis::ComputeAlpha::FirewallPoliciesScopedList::Warning
Informational warning which replaces the list of firewall policies when
the list is empty.
Corresponds to the JSON property warning
14441 14442 14443 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 14441 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
14448 14449 14450 14451 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 14448 def update!(**args) @firewall_policies = args[:firewall_policies] if args.key?(:firewall_policies) @warning = args[:warning] if args.key?(:warning) end |