Class: Google::Apis::ComputeAlpha::FirewallPolicy

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Represents a Firewall Policy resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FirewallPolicy

Returns a new instance of FirewallPolicy.



14689
14690
14691
# File 'lib/google/apis/compute_alpha/classes.rb', line 14689

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#associationsArray<Google::Apis::ComputeAlpha::FirewallPolicyAssociation>

A list of associations that belong to this firewall policy. Corresponds to the JSON property associations



14532
14533
14534
# File 'lib/google/apis/compute_alpha/classes.rb', line 14532

def associations
  @associations
end

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


14538
14539
14540
# File 'lib/google/apis/compute_alpha/classes.rb', line 14538

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


14544
14545
14546
# File 'lib/google/apis/compute_alpha/classes.rb', line 14544

def description
  @description
end

#display_nameString

Deprecated, please use short name instead. User-provided name of the Organization firewall policy. The name should be unique in the organization in which the firewall policy is created. This field is not applicable to network firewall policies. This name must be set on creation and cannot be changed. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property displayName

Returns:

  • (String)


14559
14560
14561
# File 'lib/google/apis/compute_alpha/classes.rb', line 14559

def display_name
  @display_name
end

#fingerprintString

Specifies a fingerprint for this resource, which is essentially a hash of the metadata's contents and used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update metadata. You must always provide an up-to-date fingerprint hash in order to update or change metadata, otherwise the request will fail with error412 conditionNotMet. To see the latest fingerprint, make get() request to the firewall policy. Corresponds to the JSON property fingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


14572
14573
14574
# File 'lib/google/apis/compute_alpha/classes.rb', line 14572

def fingerprint
  @fingerprint
end

#idFixnum

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


14578
14579
14580
# File 'lib/google/apis/compute_alpha/classes.rb', line 14578

def id
  @id
end

#kindString

Output only. [Output only] Type of the resource. Alwayscompute# firewallPolicyfor firewall policies Corresponds to the JSON property kind

Returns:

  • (String)


14584
14585
14586
# File 'lib/google/apis/compute_alpha/classes.rb', line 14584

def kind
  @kind
end

#nameString

Name of the resource. For Organization Firewall Policies it's a [Output Only] numeric ID allocated by Google Cloud which uniquely identifies the Organization Firewall Policy. Corresponds to the JSON property name

Returns:

  • (String)


14591
14592
14593
# File 'lib/google/apis/compute_alpha/classes.rb', line 14591

def name
  @name
end

#packet_mirroring_rulesArray<Google::Apis::ComputeAlpha::FirewallPolicyRule>

A list of packet mirroring rules that belong to this policy. Corresponds to the JSON property packetMirroringRules



14596
14597
14598
# File 'lib/google/apis/compute_alpha/classes.rb', line 14596

def packet_mirroring_rules
  @packet_mirroring_rules
end

#parentString

Output only. [Output Only] The parent of the firewall policy. This field is not applicable to network firewall policies. Corresponds to the JSON property parent

Returns:

  • (String)


14602
14603
14604
# File 'lib/google/apis/compute_alpha/classes.rb', line 14602

def parent
  @parent
end

#policy_sourceString

Indicates the source of this Firewall Policy. This field is optional on creation and defaults to USER_DEFINED. The USER_DEFINED value indicates a regular firewall policy. The SYSTEM value indicates a system-level policy managed by an internal service like GKE. This SYSTEM value is reserved for internal services and cannot be set by users during policy creation. Policies with a SYSTEM source cannot be modified or deleted by users. Corresponds to the JSON property policySource

Returns:

  • (String)


14614
14615
14616
# File 'lib/google/apis/compute_alpha/classes.rb', line 14614

def policy_source
  @policy_source
end

#policy_typeString

The type of the firewall policy. This field can be eitherVPC_POLICY or RDMA_ROCE_POLICY. Note: if not specified then VPC_POLICY will be used. Corresponds to the JSON property policyType

Returns:

  • (String)


14621
14622
14623
# File 'lib/google/apis/compute_alpha/classes.rb', line 14621

def policy_type
  @policy_type
end

#regionString

Output only. [Output Only] URL of the region where the regional firewall policy resides. This field is not applicable to global firewall policies. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body. Corresponds to the JSON property region

Returns:

  • (String)


14630
14631
14632
# File 'lib/google/apis/compute_alpha/classes.rb', line 14630

def region
  @region
end

#rollout_operationGoogle::Apis::ComputeAlpha::FirewallPolicyRolloutOperation

Represents progressive rollout input parameters and current status. Corresponds to the JSON property rolloutOperation



14635
14636
14637
# File 'lib/google/apis/compute_alpha/classes.rb', line 14635

def rollout_operation
  @rollout_operation
end

#rule_tuple_countFixnum

Output only. [Output Only] Total count of all firewall policy rule tuples. A firewall policy can not exceed a set number of tuples. Corresponds to the JSON property ruleTupleCount

Returns:

  • (Fixnum)


14642
14643
14644
# File 'lib/google/apis/compute_alpha/classes.rb', line 14642

def rule_tuple_count
  @rule_tuple_count
end

#rulesArray<Google::Apis::ComputeAlpha::FirewallPolicyRule>

A list of rules that belong to this policy. There must always be a default rule (rule with priority 2147483647 and match "*"). If no rules are provided when creating a firewall policy, a default rule with action "allow" will be added. Corresponds to the JSON property rules



14650
14651
14652
# File 'lib/google/apis/compute_alpha/classes.rb', line 14650

def rules
  @rules
end

[Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


14655
14656
14657
# File 'lib/google/apis/compute_alpha/classes.rb', line 14655

def self_link
  @self_link
end

Output only. [Output Only] Server-defined URL for this resource with the resource id. Corresponds to the JSON property selfLinkWithId

Returns:

  • (String)


14661
14662
14663
# File 'lib/google/apis/compute_alpha/classes.rb', line 14661

def self_link_with_id
  @self_link_with_id
end

#short_nameString

User-provided name of the Organization firewall policy. The name should be unique in the organization in which the firewall policy is created. This field is not applicable to network firewall policies. This name must be set on creation and cannot be changed. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property shortName

Returns:

  • (String)


14675
14676
14677
# File 'lib/google/apis/compute_alpha/classes.rb', line 14675

def short_name
  @short_name
end

#vpc_network_scopeString

The scope of networks allowed to be associated with the firewall policy. This field can be either GLOBAL_VPC_NETWORK orREGIONAL_VPC_NETWORK. A firewall policy with the VPC scope set to GLOBAL_VPC_NETWORK is allowed to be attached only to global networks. When the VPC scope is set to REGIONAL_VPC_NETWORK the firewall policy is allowed to be attached only to regional networks in the same scope as the firewall policy. Note: if not specified then GLOBAL_VPC_NETWORK will be used. Corresponds to the JSON property vpcNetworkScope

Returns:

  • (String)


14687
14688
14689
# File 'lib/google/apis/compute_alpha/classes.rb', line 14687

def vpc_network_scope
  @vpc_network_scope
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



14694
14695
14696
14697
14698
14699
14700
14701
14702
14703
14704
14705
14706
14707
14708
14709
14710
14711
14712
14713
14714
14715
# File 'lib/google/apis/compute_alpha/classes.rb', line 14694

def update!(**args)
  @associations = args[:associations] if args.key?(:associations)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @fingerprint = args[:fingerprint] if args.key?(:fingerprint)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @packet_mirroring_rules = args[:packet_mirroring_rules] if args.key?(:packet_mirroring_rules)
  @parent = args[:parent] if args.key?(:parent)
  @policy_source = args[:policy_source] if args.key?(:policy_source)
  @policy_type = args[:policy_type] if args.key?(:policy_type)
  @region = args[:region] if args.key?(:region)
  @rollout_operation = args[:rollout_operation] if args.key?(:rollout_operation)
  @rule_tuple_count = args[:rule_tuple_count] if args.key?(:rule_tuple_count)
  @rules = args[:rules] if args.key?(:rules)
  @self_link = args[:self_link] if args.key?(:self_link)
  @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id)
  @short_name = args[:short_name] if args.key?(:short_name)
  @vpc_network_scope = args[:vpc_network_scope] if args.key?(:vpc_network_scope)
end