Class: Google::Apis::ComputeAlpha::FirewallPolicyAssociation

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FirewallPolicyAssociation

Returns a new instance of FirewallPolicyAssociation.



14776
14777
14778
# File 'lib/google/apis/compute_alpha/classes.rb', line 14776

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#attachment_targetString

The target that the firewall policy is attached to. Corresponds to the JSON property attachmentTarget

Returns:

  • (String)


14742
14743
14744
# File 'lib/google/apis/compute_alpha/classes.rb', line 14742

def attachment_target
  @attachment_target
end

#display_nameString

[Output Only] Deprecated, please use short name instead. The display name of the firewall policy of the association. Corresponds to the JSON property displayName

Returns:

  • (String)


14748
14749
14750
# File 'lib/google/apis/compute_alpha/classes.rb', line 14748

def display_name
  @display_name
end

#firewall_policy_idString

Output only. [Output Only] The firewall policy ID of the association. Corresponds to the JSON property firewallPolicyId

Returns:

  • (String)


14753
14754
14755
# File 'lib/google/apis/compute_alpha/classes.rb', line 14753

def firewall_policy_id
  @firewall_policy_id
end

#nameString

The name for an association. Corresponds to the JSON property name

Returns:

  • (String)


14758
14759
14760
# File 'lib/google/apis/compute_alpha/classes.rb', line 14758

def name
  @name
end

#priorityFixnum

An integer indicating the priority of an association. The priority must be a positive value between 1 and 2147483647. Firewall Policies are evaluated from highest to lowest priority where 1 is the highest priority and 2147483647 is the lowest priority. The default value is 1000. If two associations have the same priority then lexicographical order on association names is applied. Corresponds to the JSON property priority

Returns:

  • (Fixnum)


14768
14769
14770
# File 'lib/google/apis/compute_alpha/classes.rb', line 14768

def priority
  @priority
end

#short_nameString

Output only. [Output Only] The short name of the firewall policy of the association. Corresponds to the JSON property shortName

Returns:

  • (String)


14774
14775
14776
# File 'lib/google/apis/compute_alpha/classes.rb', line 14774

def short_name
  @short_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



14781
14782
14783
14784
14785
14786
14787
14788
# File 'lib/google/apis/compute_alpha/classes.rb', line 14781

def update!(**args)
  @attachment_target = args[:attachment_target] if args.key?(:attachment_target)
  @display_name = args[:display_name] if args.key?(:display_name)
  @firewall_policy_id = args[:firewall_policy_id] if args.key?(:firewall_policy_id)
  @name = args[:name] if args.key?(:name)
  @priority = args[:priority] if args.key?(:priority)
  @short_name = args[:short_name] if args.key?(:short_name)
end