Class: Google::Apis::ComputeAlpha::FirewallPolicyAssociation
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::FirewallPolicyAssociation
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#attachment_target ⇒ String
The target that the firewall policy is attached to.
-
#display_name ⇒ String
[Output Only] Deprecated, please use short name instead.
-
#firewall_policy_id ⇒ String
Output only.
-
#name ⇒ String
The name for an association.
-
#priority ⇒ Fixnum
An integer indicating the priority of an association.
-
#short_name ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FirewallPolicyAssociation
constructor
A new instance of FirewallPolicyAssociation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FirewallPolicyAssociation
Returns a new instance of FirewallPolicyAssociation.
14754 14755 14756 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 14754 def initialize(**args) update!(**args) end |
Instance Attribute Details
#attachment_target ⇒ String
The target that the firewall policy is attached to.
Corresponds to the JSON property attachmentTarget
14720 14721 14722 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 14720 def @attachment_target end |
#display_name ⇒ String
[Output Only] Deprecated, please use short name instead. The display name
of the firewall policy of the association.
Corresponds to the JSON property displayName
14726 14727 14728 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 14726 def display_name @display_name end |
#firewall_policy_id ⇒ String
Output only. [Output Only] The firewall policy ID of the association.
Corresponds to the JSON property firewallPolicyId
14731 14732 14733 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 14731 def firewall_policy_id @firewall_policy_id end |
#name ⇒ String
The name for an association.
Corresponds to the JSON property name
14736 14737 14738 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 14736 def name @name end |
#priority ⇒ Fixnum
An integer indicating the priority of an association. The priority
must be a positive value between 1 and 2147483647.
Firewall Policies are evaluated from highest to lowest priority where 1
is the highest priority and 2147483647 is the lowest priority.
The default value is 1000. If two associations have the same priority
then lexicographical order on association names is applied.
Corresponds to the JSON property priority
14746 14747 14748 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 14746 def priority @priority end |
#short_name ⇒ String
Output only. [Output Only] The short name of the firewall policy of the
association.
Corresponds to the JSON property shortName
14752 14753 14754 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 14752 def short_name @short_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
14759 14760 14761 14762 14763 14764 14765 14766 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 14759 def update!(**args) @attachment_target = args[:attachment_target] if args.key?(:attachment_target) @display_name = args[:display_name] if args.key?(:display_name) @firewall_policy_id = args[:firewall_policy_id] if args.key?(:firewall_policy_id) @name = args[:name] if args.key?(:name) @priority = args[:priority] if args.key?(:priority) @short_name = args[:short_name] if args.key?(:short_name) end |