Class: Google::Apis::ComputeAlpha::FirewallPolicyList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::FirewallPolicyList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::FirewallPolicy>
A list of FirewallPolicy resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#warning ⇒ Google::Apis::ComputeAlpha::FirewallPolicyList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FirewallPolicyList
constructor
A new instance of FirewallPolicyList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FirewallPolicyList
Returns a new instance of FirewallPolicyList.
15436 15437 15438 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 15436 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
15408 15409 15410 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 15408 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::FirewallPolicy>
A list of FirewallPolicy resources.
Corresponds to the JSON property items
15413 15414 15415 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 15413 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#firewallPolicyList
for listsof FirewallPolicies
Corresponds to the JSON property kind
15419 15420 15421 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 15419 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
15429 15430 15431 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 15429 def next_page_token @next_page_token end |
#warning ⇒ Google::Apis::ComputeAlpha::FirewallPolicyList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
15434 15435 15436 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 15434 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
15441 15442 15443 15444 15445 15446 15447 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 15441 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @warning = args[:warning] if args.key?(:warning) end |