Class: Google::Apis::ComputeAlpha::FirewallPolicyList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FirewallPolicyList

Returns a new instance of FirewallPolicyList.



14804
14805
14806
# File 'lib/google/apis/compute_alpha/classes.rb', line 14804

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


14776
14777
14778
# File 'lib/google/apis/compute_alpha/classes.rb', line 14776

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::FirewallPolicy>

A list of FirewallPolicy resources. Corresponds to the JSON property items



14781
14782
14783
# File 'lib/google/apis/compute_alpha/classes.rb', line 14781

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute#firewallPolicyList for listsof FirewallPolicies Corresponds to the JSON property kind

Returns:

  • (String)


14787
14788
14789
# File 'lib/google/apis/compute_alpha/classes.rb', line 14787

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


14797
14798
14799
# File 'lib/google/apis/compute_alpha/classes.rb', line 14797

def next_page_token
  @next_page_token
end

#warningGoogle::Apis::ComputeAlpha::FirewallPolicyList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



14802
14803
14804
# File 'lib/google/apis/compute_alpha/classes.rb', line 14802

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



14809
14810
14811
14812
14813
14814
14815
# File 'lib/google/apis/compute_alpha/classes.rb', line 14809

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @warning = args[:warning] if args.key?(:warning)
end