Class: Google::Apis::ComputeAlpha::FirewallPolicyRolloutOperationRolloutInput

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Represents progressive rollout input parameters.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FirewallPolicyRolloutOperationRolloutInput

Returns a new instance of FirewallPolicyRolloutOperationRolloutInput.



15567
15568
15569
# File 'lib/google/apis/compute_alpha/classes.rb', line 15567

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nameString

The name of the rollout plan. Ex. organizations//locations/global/rolloutPlans/. Corresponds to the JSON property name

Returns:

  • (String)


15553
15554
15555
# File 'lib/google/apis/compute_alpha/classes.rb', line 15553

def name
  @name
end

#predefined_rollout_planString

Predefined rollout plan. Corresponds to the JSON property predefinedRolloutPlan

Returns:

  • (String)


15558
15559
15560
# File 'lib/google/apis/compute_alpha/classes.rb', line 15558

def predefined_rollout_plan
  @predefined_rollout_plan
end

#retry_uuidString

The UUID of the retry action. Only needed if this is a retry for an existing rollout. This can be used after the user canceled a rollout and want to retry it with no changes. Corresponds to the JSON property retryUuid

Returns:

  • (String)


15565
15566
15567
# File 'lib/google/apis/compute_alpha/classes.rb', line 15565

def retry_uuid
  @retry_uuid
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



15572
15573
15574
15575
15576
# File 'lib/google/apis/compute_alpha/classes.rb', line 15572

def update!(**args)
  @name = args[:name] if args.key?(:name)
  @predefined_rollout_plan = args[:predefined_rollout_plan] if args.key?(:predefined_rollout_plan)
  @retry_uuid = args[:retry_uuid] if args.key?(:retry_uuid)
end