Class: Google::Apis::ComputeAlpha::FirewallPolicyRolloutOperationRolloutInput

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Represents progressive rollout input parameters.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FirewallPolicyRolloutOperationRolloutInput

Returns a new instance of FirewallPolicyRolloutOperationRolloutInput.



14957
14958
14959
# File 'lib/google/apis/compute_alpha/classes.rb', line 14957

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nameString

The name of the rollout plan. Ex. organizations//locations/global/rolloutPlans/. Corresponds to the JSON property name

Returns:

  • (String)


14943
14944
14945
# File 'lib/google/apis/compute_alpha/classes.rb', line 14943

def name
  @name
end

#predefined_rollout_planString

Predefined rollout plan. Corresponds to the JSON property predefinedRolloutPlan

Returns:

  • (String)


14948
14949
14950
# File 'lib/google/apis/compute_alpha/classes.rb', line 14948

def predefined_rollout_plan
  @predefined_rollout_plan
end

#retry_uuidString

The UUID of the retry action. Only needed if this is a retry for an existing rollout. This can be used after the user canceled a rollout and want to retry it with no changes. Corresponds to the JSON property retryUuid

Returns:

  • (String)


14955
14956
14957
# File 'lib/google/apis/compute_alpha/classes.rb', line 14955

def retry_uuid
  @retry_uuid
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



14962
14963
14964
14965
14966
# File 'lib/google/apis/compute_alpha/classes.rb', line 14962

def update!(**args)
  @name = args[:name] if args.key?(:name)
  @predefined_rollout_plan = args[:predefined_rollout_plan] if args.key?(:predefined_rollout_plan)
  @retry_uuid = args[:retry_uuid] if args.key?(:retry_uuid)
end