Class: Google::Apis::ComputeAlpha::FirewallPolicyRolloutOperationRolloutInput
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::FirewallPolicyRolloutOperationRolloutInput
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Represents progressive rollout input parameters.
Instance Attribute Summary collapse
-
#name ⇒ String
The name of the rollout plan.
-
#predefined_rollout_plan ⇒ String
Predefined rollout plan.
-
#retry_uuid ⇒ String
The UUID of the retry action.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FirewallPolicyRolloutOperationRolloutInput
constructor
A new instance of FirewallPolicyRolloutOperationRolloutInput.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FirewallPolicyRolloutOperationRolloutInput
Returns a new instance of FirewallPolicyRolloutOperationRolloutInput.
14935 14936 14937 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 14935 def initialize(**args) update!(**args) end |
Instance Attribute Details
#name ⇒ String
The name of the rollout plan. Ex.
organizations//locations/global/rolloutPlans/.
Corresponds to the JSON property name
14921 14922 14923 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 14921 def name @name end |
#predefined_rollout_plan ⇒ String
Predefined rollout plan.
Corresponds to the JSON property predefinedRolloutPlan
14926 14927 14928 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 14926 def predefined_rollout_plan @predefined_rollout_plan end |
#retry_uuid ⇒ String
The UUID of the retry action. Only needed if this is a retry for an
existing rollout. This can be used after the user canceled a rollout
and want to retry it with no changes.
Corresponds to the JSON property retryUuid
14933 14934 14935 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 14933 def retry_uuid @retry_uuid end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
14940 14941 14942 14943 14944 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 14940 def update!(**args) @name = args[:name] if args.key?(:name) @predefined_rollout_plan = args[:predefined_rollout_plan] if args.key?(:predefined_rollout_plan) @retry_uuid = args[:retry_uuid] if args.key?(:retry_uuid) end |