Class: Google::Apis::ComputeAlpha::FirewallPolicyRolloutOperationRolloutInput
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::FirewallPolicyRolloutOperationRolloutInput
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Represents progressive rollout input parameters.
Instance Attribute Summary collapse
-
#name ⇒ String
The name of the rollout plan.
-
#predefined_rollout_plan ⇒ String
Predefined rollout plan.
-
#retry_uuid ⇒ String
The UUID of the retry action.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FirewallPolicyRolloutOperationRolloutInput
constructor
A new instance of FirewallPolicyRolloutOperationRolloutInput.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FirewallPolicyRolloutOperationRolloutInput
Returns a new instance of FirewallPolicyRolloutOperationRolloutInput.
14637 14638 14639 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 14637 def initialize(**args) update!(**args) end |
Instance Attribute Details
#name ⇒ String
The name of the rollout plan. Ex.
organizations//locations/global/rolloutPlans/.
Corresponds to the JSON property name
14623 14624 14625 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 14623 def name @name end |
#predefined_rollout_plan ⇒ String
Predefined rollout plan.
Corresponds to the JSON property predefinedRolloutPlan
14628 14629 14630 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 14628 def predefined_rollout_plan @predefined_rollout_plan end |
#retry_uuid ⇒ String
The UUID of the retry action. Only needed if this is a retry for an
existing rollout. This can be used after the user canceled a rollout
and want to retry it with no changes.
Corresponds to the JSON property retryUuid
14635 14636 14637 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 14635 def retry_uuid @retry_uuid end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
14642 14643 14644 14645 14646 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 14642 def update!(**args) @name = args[:name] if args.key?(:name) @predefined_rollout_plan = args[:predefined_rollout_plan] if args.key?(:predefined_rollout_plan) @retry_uuid = args[:retry_uuid] if args.key?(:retry_uuid) end |