Class: Google::Apis::ComputeAlpha::FirewallPolicyRolloutOperationRolloutStatusNextRollout
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::FirewallPolicyRolloutOperationRolloutStatusNextRollout
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#rollout_id ⇒ String
Output only.
-
#rollout_plan ⇒ String
The name of the rollout plan to be used by the next not yet started rollout.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FirewallPolicyRolloutOperationRolloutStatusNextRollout
constructor
A new instance of FirewallPolicyRolloutOperationRolloutStatusNextRollout.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FirewallPolicyRolloutOperationRolloutStatusNextRollout
Returns a new instance of FirewallPolicyRolloutOperationRolloutStatusNextRollout.
14981 14982 14983 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 14981 def initialize(**args) update!(**args) end |
Instance Attribute Details
#rollout_id ⇒ String
Output only. [Output only] The id of the next rollout.
Corresponds to the JSON property rolloutId
14969 14970 14971 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 14969 def rollout_id @rollout_id end |
#rollout_plan ⇒ String
The name of the rollout plan to be used by the next not yet started
rollout. This field is auto populated based on RolloutInput when a
new rollout is scheduled. This can be manually changed before the
scheduled rollout starts.
Ex.
organizations//locations/global/rolloutPlans/
Corresponds to the JSON property rolloutPlan
14979 14980 14981 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 14979 def rollout_plan @rollout_plan end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
14986 14987 14988 14989 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 14986 def update!(**args) @rollout_id = args[:rollout_id] if args.key?(:rollout_id) @rollout_plan = args[:rollout_plan] if args.key?(:rollout_plan) end |