Class: Google::Apis::ComputeAlpha::FirewallPolicyRolloutOperationRolloutStatusNextRollout

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FirewallPolicyRolloutOperationRolloutStatusNextRollout

Returns a new instance of FirewallPolicyRolloutOperationRolloutStatusNextRollout.



14700
14701
14702
# File 'lib/google/apis/compute_alpha/classes.rb', line 14700

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#rollout_idString

Output only. [Output only] The id of the next rollout. Corresponds to the JSON property rolloutId

Returns:

  • (String)


14688
14689
14690
# File 'lib/google/apis/compute_alpha/classes.rb', line 14688

def rollout_id
  @rollout_id
end

#rollout_planString

The name of the rollout plan to be used by the next not yet started rollout. This field is auto populated based on RolloutInput when a new rollout is scheduled. This can be manually changed before the scheduled rollout starts. Ex. organizations//locations/global/rolloutPlans/ Corresponds to the JSON property rolloutPlan

Returns:

  • (String)


14698
14699
14700
# File 'lib/google/apis/compute_alpha/classes.rb', line 14698

def rollout_plan
  @rollout_plan
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



14705
14706
14707
14708
# File 'lib/google/apis/compute_alpha/classes.rb', line 14705

def update!(**args)
  @rollout_id = args[:rollout_id] if args.key?(:rollout_id)
  @rollout_plan = args[:rollout_plan] if args.key?(:rollout_plan)
end