Class: Google::Apis::ComputeAlpha::FirewallPolicyRolloutOperationRolloutStatusRolloutMetadata

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Represents the status of the progressive rollout instance, either completed or ongoing.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FirewallPolicyRolloutOperationRolloutStatusRolloutMetadata

Returns a new instance of FirewallPolicyRolloutOperationRolloutStatusRolloutMetadata.



15014
15015
15016
# File 'lib/google/apis/compute_alpha/classes.rb', line 15014

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#rolloutString

Output only. [Output only] The name of the rollout organizations//locations/global/rollouts/ Corresponds to the JSON property rollout

Returns:

  • (String)


15001
15002
15003
# File 'lib/google/apis/compute_alpha/classes.rb', line 15001

def rollout
  @rollout
end

#rollout_planString

Output only. [Output only] The name of the rollout plan used by this rollout organizations//locations/global/rolloutPlans/ Corresponds to the JSON property rolloutPlan

Returns:

  • (String)


15007
15008
15009
# File 'lib/google/apis/compute_alpha/classes.rb', line 15007

def rollout_plan
  @rollout_plan
end

#stateString

Output only. [Output only] The state of the rollout. Corresponds to the JSON property state

Returns:

  • (String)


15012
15013
15014
# File 'lib/google/apis/compute_alpha/classes.rb', line 15012

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



15019
15020
15021
15022
15023
# File 'lib/google/apis/compute_alpha/classes.rb', line 15019

def update!(**args)
  @rollout = args[:rollout] if args.key?(:rollout)
  @rollout_plan = args[:rollout_plan] if args.key?(:rollout_plan)
  @state = args[:state] if args.key?(:state)
end