Class: Google::Apis::ComputeAlpha::FirewallPolicyRolloutOperationRolloutStatusRolloutMetadata
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::FirewallPolicyRolloutOperationRolloutStatusRolloutMetadata
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Represents the status of the progressive rollout instance, either completed or ongoing.
Instance Attribute Summary collapse
-
#rollout ⇒ String
Output only.
-
#rollout_plan ⇒ String
Output only.
-
#state ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FirewallPolicyRolloutOperationRolloutStatusRolloutMetadata
constructor
A new instance of FirewallPolicyRolloutOperationRolloutStatusRolloutMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FirewallPolicyRolloutOperationRolloutStatusRolloutMetadata
Returns a new instance of FirewallPolicyRolloutOperationRolloutStatusRolloutMetadata.
14733 14734 14735 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 14733 def initialize(**args) update!(**args) end |
Instance Attribute Details
#rollout ⇒ String
Output only. [Output only] The name of the rollout
organizations//locations/global/rollouts/
Corresponds to the JSON property rollout
14720 14721 14722 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 14720 def rollout @rollout end |
#rollout_plan ⇒ String
Output only. [Output only] The name of the rollout plan used by this rollout
organizations//locations/global/rolloutPlans/
Corresponds to the JSON property rolloutPlan
14726 14727 14728 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 14726 def rollout_plan @rollout_plan end |
#state ⇒ String
Output only. [Output only] The state of the rollout.
Corresponds to the JSON property state
14731 14732 14733 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 14731 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
14738 14739 14740 14741 14742 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 14738 def update!(**args) @rollout = args[:rollout] if args.key?(:rollout) @rollout_plan = args[:rollout_plan] if args.key?(:rollout_plan) @state = args[:state] if args.key?(:state) end |