Class: Google::Apis::ComputeAlpha::FirewallPolicyRuleMatcher
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::FirewallPolicyRuleMatcher
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Represents a match condition that incoming traffic is evaluated against. Exactly one field must be specified.
Instance Attribute Summary collapse
-
#dest_address_groups ⇒ Array<String>
Address groups which should be matched against the traffic destination.
-
#dest_fqdns ⇒ Array<String>
Fully Qualified Domain Name (FQDN) which should be matched against traffic destination.
-
#dest_ip_ranges ⇒ Array<String>
CIDR IP address range.
-
#dest_network_context ⇒ String
Network context of the traffic destination.
-
#dest_network_scope ⇒ String
Network scope of the traffic destination.
-
#dest_network_type ⇒ String
Network type of the traffic destination.
-
#dest_region_codes ⇒ Array<String>
Region codes whose IP addresses will be used to match for destination of traffic.
-
#dest_threat_intelligences ⇒ Array<String>
Names of Network Threat Intelligence lists.
-
#layer4_configs ⇒ Array<Google::Apis::ComputeAlpha::FirewallPolicyRuleMatcherLayer4Config>
Pairs of IP protocols and ports that the rule should match.
-
#src_address_groups ⇒ Array<String>
Address groups which should be matched against the traffic source.
-
#src_fqdns ⇒ Array<String>
Fully Qualified Domain Name (FQDN) which should be matched against traffic source.
-
#src_ip_ranges ⇒ Array<String>
CIDR IP address range.
-
#src_network_context ⇒ String
Network context of the traffic source.
-
#src_network_scope ⇒ String
Network scope of the traffic source.
-
#src_network_type ⇒ String
Network type of the traffic source.
-
#src_networks ⇒ Array<String>
Networks of the traffic source.
-
#src_region_codes ⇒ Array<String>
Region codes whose IP addresses will be used to match for source of traffic.
-
#src_secure_tags ⇒ Array<Google::Apis::ComputeAlpha::FirewallPolicyRuleSecureTag>
List of secure tag values, which should be matched at the source of the traffic.
-
#src_threat_intelligences ⇒ Array<String>
Names of Network Threat Intelligence lists.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FirewallPolicyRuleMatcher
constructor
A new instance of FirewallPolicyRuleMatcher.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FirewallPolicyRuleMatcher
Returns a new instance of FirewallPolicyRuleMatcher.
15357 15358 15359 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 15357 def initialize(**args) update!(**args) end |
Instance Attribute Details
#dest_address_groups ⇒ Array<String>
Address groups which should be matched against the traffic destination.
Maximum number of destination address groups is 10.
Corresponds to the JSON property destAddressGroups
15222 15223 15224 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 15222 def dest_address_groups @dest_address_groups end |
#dest_fqdns ⇒ Array<String>
Fully Qualified Domain Name (FQDN) which should be matched against
traffic destination.
Maximum number of destination fqdn allowed is 100.
Corresponds to the JSON property destFqdns
15229 15230 15231 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 15229 def dest_fqdns @dest_fqdns end |
#dest_ip_ranges ⇒ Array<String>
CIDR IP address range.
Maximum number of destination CIDR IP ranges allowed is 5000.
Corresponds to the JSON property destIpRanges
15235 15236 15237 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 15235 def dest_ip_ranges @dest_ip_ranges end |
#dest_network_context ⇒ String
Network context of the traffic destination. Allowed values are:
- UNSPECIFIED
- INTERNET
- NON_INTERNET
Corresponds to the JSON property
destNetworkContext
15245 15246 15247 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 15245 def dest_network_context @dest_network_context end |
#dest_network_scope ⇒ String
Network scope of the traffic destination.
Corresponds to the JSON property destNetworkScope
15250 15251 15252 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 15250 def dest_network_scope @dest_network_scope end |
#dest_network_type ⇒ String
Network type of the traffic destination. Allowed values are:
- UNSPECIFIED
- INTERNET
- NON_INTERNET
Corresponds to the JSON property
destNetworkType
15260 15261 15262 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 15260 def dest_network_type @dest_network_type end |
#dest_region_codes ⇒ Array<String>
Region codes whose IP addresses will be used to match for destination
of traffic. Should be specified as 2 letter country code defined as per
ISO 3166 alpha-2 country codes. ex."US"
Maximum number of dest region codes allowed is 5000.
Corresponds to the JSON property destRegionCodes
15268 15269 15270 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 15268 def dest_region_codes @dest_region_codes end |
#dest_threat_intelligences ⇒ Array<String>
Names of Network Threat Intelligence lists.
The IPs in these lists will be matched against traffic destination.
Corresponds to the JSON property destThreatIntelligences
15274 15275 15276 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 15274 def dest_threat_intelligences @dest_threat_intelligences end |
#layer4_configs ⇒ Array<Google::Apis::ComputeAlpha::FirewallPolicyRuleMatcherLayer4Config>
Pairs of IP protocols and ports that the rule should match.
Corresponds to the JSON property layer4Configs
15279 15280 15281 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 15279 def layer4_configs @layer4_configs end |
#src_address_groups ⇒ Array<String>
Address groups which should be matched against the traffic source.
Maximum number of source address groups is 10.
Corresponds to the JSON property srcAddressGroups
15285 15286 15287 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 15285 def src_address_groups @src_address_groups end |
#src_fqdns ⇒ Array<String>
Fully Qualified Domain Name (FQDN) which should be matched against
traffic source.
Maximum number of source fqdn allowed is 100.
Corresponds to the JSON property srcFqdns
15292 15293 15294 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 15292 def src_fqdns @src_fqdns end |
#src_ip_ranges ⇒ Array<String>
CIDR IP address range.
Maximum number of source CIDR IP ranges allowed is 5000.
Corresponds to the JSON property srcIpRanges
15298 15299 15300 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 15298 def src_ip_ranges @src_ip_ranges end |
#src_network_context ⇒ String
Network context of the traffic source. Allowed values are:
- UNSPECIFIED
- INTERNET
- INTRA_VPC
- NON_INTERNET
- VPC_NETWORKS
Corresponds to the JSON property
srcNetworkContext
15310 15311 15312 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 15310 def src_network_context @src_network_context end |
#src_network_scope ⇒ String
Network scope of the traffic source.
Corresponds to the JSON property srcNetworkScope
15315 15316 15317 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 15315 def src_network_scope @src_network_scope end |
#src_network_type ⇒ String
Network type of the traffic source. Allowed values are:
- UNSPECIFIED
- INTERNET
- INTRA_VPC
- NON_INTERNET
- VPC_NETWORKS
Corresponds to the JSON property
srcNetworkType
15327 15328 15329 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 15327 def src_network_type @src_network_type end |
#src_networks ⇒ Array<String>
Networks of the traffic source. It can be either a full or partial url.
Corresponds to the JSON property srcNetworks
15332 15333 15334 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 15332 def src_networks @src_networks end |
#src_region_codes ⇒ Array<String>
Region codes whose IP addresses will be used to match for source
of traffic. Should be specified as 2 letter country code defined as per
ISO 3166 alpha-2 country codes. ex."US"
Maximum number of source region codes allowed is 5000.
Corresponds to the JSON property srcRegionCodes
15340 15341 15342 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 15340 def src_region_codes @src_region_codes end |
#src_secure_tags ⇒ Array<Google::Apis::ComputeAlpha::FirewallPolicyRuleSecureTag>
List of secure tag values, which should be matched at the source
of the traffic.
For INGRESS rule, if all the srcSecureTag are INEFFECTIVE,
and there is no srcIpRange, this rule will be ignored.
Maximum number of source tag values allowed is 256.
Corresponds to the JSON property srcSecureTags
15349 15350 15351 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 15349 def @src_secure_tags end |
#src_threat_intelligences ⇒ Array<String>
Names of Network Threat Intelligence lists.
The IPs in these lists will be matched against traffic source.
Corresponds to the JSON property srcThreatIntelligences
15355 15356 15357 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 15355 def src_threat_intelligences @src_threat_intelligences end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
15362 15363 15364 15365 15366 15367 15368 15369 15370 15371 15372 15373 15374 15375 15376 15377 15378 15379 15380 15381 15382 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 15362 def update!(**args) @dest_address_groups = args[:dest_address_groups] if args.key?(:dest_address_groups) @dest_fqdns = args[:dest_fqdns] if args.key?(:dest_fqdns) @dest_ip_ranges = args[:dest_ip_ranges] if args.key?(:dest_ip_ranges) @dest_network_context = args[:dest_network_context] if args.key?(:dest_network_context) @dest_network_scope = args[:dest_network_scope] if args.key?(:dest_network_scope) @dest_network_type = args[:dest_network_type] if args.key?(:dest_network_type) @dest_region_codes = args[:dest_region_codes] if args.key?(:dest_region_codes) @dest_threat_intelligences = args[:dest_threat_intelligences] if args.key?(:dest_threat_intelligences) @layer4_configs = args[:layer4_configs] if args.key?(:layer4_configs) @src_address_groups = args[:src_address_groups] if args.key?(:src_address_groups) @src_fqdns = args[:src_fqdns] if args.key?(:src_fqdns) @src_ip_ranges = args[:src_ip_ranges] if args.key?(:src_ip_ranges) @src_network_context = args[:src_network_context] if args.key?(:src_network_context) @src_network_scope = args[:src_network_scope] if args.key?(:src_network_scope) @src_network_type = args[:src_network_type] if args.key?(:src_network_type) @src_networks = args[:src_networks] if args.key?(:src_networks) @src_region_codes = args[:src_region_codes] if args.key?(:src_region_codes) @src_secure_tags = args[:src_secure_tags] if args.key?(:src_secure_tags) @src_threat_intelligences = args[:src_threat_intelligences] if args.key?(:src_threat_intelligences) end |