Class: Google::Apis::ComputeAlpha::FirewallPolicyRuleMatcherLayer4Config

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FirewallPolicyRuleMatcherLayer4Config

Returns a new instance of FirewallPolicyRuleMatcherLayer4Config.



16205
16206
16207
# File 'lib/google/apis/compute_alpha/classes.rb', line 16205

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ip_protocolString

The IP protocol to which this rule applies. The protocol type is required when creating a firewall rule. This value can either be one of the following well known protocol strings (tcp,udp, icmp, esp,ah, ipip, sctp), or the IP protocol number. Corresponds to the JSON property ipProtocol

Returns:

  • (String)


16194
16195
16196
# File 'lib/google/apis/compute_alpha/classes.rb', line 16194

def ip_protocol
  @ip_protocol
end

#portsArray<String>

An optional list of ports to which this rule applies. This field is only applicable for UDP or TCP protocol. Each entry must be either an integer or a range. If not specified, this rule applies to connections through any port. Example inputs include: ["22"],["80","443"], and ["12345-12349"]. Corresponds to the JSON property ports

Returns:

  • (Array<String>)


16203
16204
16205
# File 'lib/google/apis/compute_alpha/classes.rb', line 16203

def ports
  @ports
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



16210
16211
16212
16213
# File 'lib/google/apis/compute_alpha/classes.rb', line 16210

def update!(**args)
  @ip_protocol = args[:ip_protocol] if args.key?(:ip_protocol)
  @ports = args[:ports] if args.key?(:ports)
end