Class: Google::Apis::ComputeAlpha::FixedOrPercent

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Encapsulates numeric value that can be either absolute or relative.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FixedOrPercent

Returns a new instance of FixedOrPercent.



15459
15460
15461
# File 'lib/google/apis/compute_alpha/classes.rb', line 15459

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#calculatedFixnum

Output only. Absolute value of VM instances calculated based on the specific mode.

  • If the value is fixed, then the calculated value is equal to the fixed value.
  • If the value is a percent, then the calculated value is percent/100 * targetSize. For example, the calculated value of a 80% of a managed instance group with 150 instances would be (80/100 * 150) = 120 VM instances. If there is a remainder, the number is rounded. Corresponds to the JSON property calculated

Returns:

  • (Fixnum)


15446
15447
15448
# File 'lib/google/apis/compute_alpha/classes.rb', line 15446

def calculated
  @calculated
end

#fixedFixnum

Specifies a fixed number of VM instances. This must be a positive integer. Corresponds to the JSON property fixed

Returns:

  • (Fixnum)


15451
15452
15453
# File 'lib/google/apis/compute_alpha/classes.rb', line 15451

def fixed
  @fixed
end

#percentFixnum

Specifies a percentage of instances between 0 to 100%, inclusive. For example, specify 80 for 80%. Corresponds to the JSON property percent

Returns:

  • (Fixnum)


15457
15458
15459
# File 'lib/google/apis/compute_alpha/classes.rb', line 15457

def percent
  @percent
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



15464
15465
15466
15467
15468
# File 'lib/google/apis/compute_alpha/classes.rb', line 15464

def update!(**args)
  @calculated = args[:calculated] if args.key?(:calculated)
  @fixed = args[:fixed] if args.key?(:fixed)
  @percent = args[:percent] if args.key?(:percent)
end