Class: Google::Apis::ComputeAlpha::FlexibleTimeRange

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Specifies a flexible time range with flexible start time and duration. It is possible to specify a contradictory time range that cannot be matched by any Interval. This causes a validation error.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FlexibleTimeRange

Returns a new instance of FlexibleTimeRange.



15524
15525
15526
# File 'lib/google/apis/compute_alpha/classes.rb', line 15524

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#end_time_not_earlier_thanString

Corresponds to the JSON property endTimeNotEarlierThan

Returns:

  • (String)


15497
15498
15499
# File 'lib/google/apis/compute_alpha/classes.rb', line 15497

def end_time_not_earlier_than
  @end_time_not_earlier_than
end

#end_time_not_later_thanString

Corresponds to the JSON property endTimeNotLaterThan

Returns:

  • (String)


15502
15503
15504
# File 'lib/google/apis/compute_alpha/classes.rb', line 15502

def end_time_not_later_than
  @end_time_not_later_than
end

#max_durationString

Corresponds to the JSON property maxDuration

Returns:

  • (String)


15507
15508
15509
# File 'lib/google/apis/compute_alpha/classes.rb', line 15507

def max_duration
  @max_duration
end

#min_durationString

Corresponds to the JSON property minDuration

Returns:

  • (String)


15512
15513
15514
# File 'lib/google/apis/compute_alpha/classes.rb', line 15512

def min_duration
  @min_duration
end

#start_time_not_earlier_thanString

Corresponds to the JSON property startTimeNotEarlierThan

Returns:

  • (String)


15517
15518
15519
# File 'lib/google/apis/compute_alpha/classes.rb', line 15517

def start_time_not_earlier_than
  @start_time_not_earlier_than
end

#start_time_not_later_thanString

Corresponds to the JSON property startTimeNotLaterThan

Returns:

  • (String)


15522
15523
15524
# File 'lib/google/apis/compute_alpha/classes.rb', line 15522

def start_time_not_later_than
  @start_time_not_later_than
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



15529
15530
15531
15532
15533
15534
15535
15536
# File 'lib/google/apis/compute_alpha/classes.rb', line 15529

def update!(**args)
  @end_time_not_earlier_than = args[:end_time_not_earlier_than] if args.key?(:end_time_not_earlier_than)
  @end_time_not_later_than = args[:end_time_not_later_than] if args.key?(:end_time_not_later_than)
  @max_duration = args[:max_duration] if args.key?(:max_duration)
  @min_duration = args[:min_duration] if args.key?(:min_duration)
  @start_time_not_earlier_than = args[:start_time_not_earlier_than] if args.key?(:start_time_not_earlier_than)
  @start_time_not_later_than = args[:start_time_not_later_than] if args.key?(:start_time_not_later_than)
end