Class: Google::Apis::ComputeAlpha::FlexibleTimeRange
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::FlexibleTimeRange
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Specifies a flexible time range with flexible start time and duration. It is possible to specify a contradictory time range that cannot be matched by any Interval. This causes a validation error.
Instance Attribute Summary collapse
-
#end_time_not_earlier_than ⇒ String
Corresponds to the JSON property
endTimeNotEarlierThan. -
#end_time_not_later_than ⇒ String
Corresponds to the JSON property
endTimeNotLaterThan. -
#max_duration ⇒ String
Corresponds to the JSON property
maxDuration. -
#min_duration ⇒ String
Corresponds to the JSON property
minDuration. -
#start_time_not_earlier_than ⇒ String
Corresponds to the JSON property
startTimeNotEarlierThan. -
#start_time_not_later_than ⇒ String
Corresponds to the JSON property
startTimeNotLaterThan.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FlexibleTimeRange
constructor
A new instance of FlexibleTimeRange.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FlexibleTimeRange
Returns a new instance of FlexibleTimeRange.
15530 15531 15532 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 15530 def initialize(**args) update!(**args) end |
Instance Attribute Details
#end_time_not_earlier_than ⇒ String
Corresponds to the JSON property endTimeNotEarlierThan
15503 15504 15505 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 15503 def end_time_not_earlier_than @end_time_not_earlier_than end |
#end_time_not_later_than ⇒ String
Corresponds to the JSON property endTimeNotLaterThan
15508 15509 15510 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 15508 def end_time_not_later_than @end_time_not_later_than end |
#max_duration ⇒ String
Corresponds to the JSON property maxDuration
15513 15514 15515 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 15513 def max_duration @max_duration end |
#min_duration ⇒ String
Corresponds to the JSON property minDuration
15518 15519 15520 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 15518 def min_duration @min_duration end |
#start_time_not_earlier_than ⇒ String
Corresponds to the JSON property startTimeNotEarlierThan
15523 15524 15525 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 15523 def start_time_not_earlier_than @start_time_not_earlier_than end |
#start_time_not_later_than ⇒ String
Corresponds to the JSON property startTimeNotLaterThan
15528 15529 15530 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 15528 def start_time_not_later_than @start_time_not_later_than end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
15535 15536 15537 15538 15539 15540 15541 15542 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 15535 def update!(**args) @end_time_not_earlier_than = args[:end_time_not_earlier_than] if args.key?(:end_time_not_earlier_than) @end_time_not_later_than = args[:end_time_not_later_than] if args.key?(:end_time_not_later_than) @max_duration = args[:max_duration] if args.key?(:max_duration) @min_duration = args[:min_duration] if args.key?(:min_duration) @start_time_not_earlier_than = args[:start_time_not_earlier_than] if args.key?(:start_time_not_earlier_than) @start_time_not_later_than = args[:start_time_not_later_than] if args.key?(:start_time_not_later_than) end |