Class: Google::Apis::ComputeAlpha::FlexibleTimeRange

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Specifies a flexible time range with flexible start time and duration. It is possible to specify a contradictory time range that cannot be matched by any Interval. This causes a validation error.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FlexibleTimeRange

Returns a new instance of FlexibleTimeRange.



15227
15228
15229
# File 'lib/google/apis/compute_alpha/classes.rb', line 15227

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#end_time_not_earlier_thanString

Corresponds to the JSON property endTimeNotEarlierThan

Returns:

  • (String)


15200
15201
15202
# File 'lib/google/apis/compute_alpha/classes.rb', line 15200

def end_time_not_earlier_than
  @end_time_not_earlier_than
end

#end_time_not_later_thanString

Corresponds to the JSON property endTimeNotLaterThan

Returns:

  • (String)


15205
15206
15207
# File 'lib/google/apis/compute_alpha/classes.rb', line 15205

def end_time_not_later_than
  @end_time_not_later_than
end

#max_durationString

Corresponds to the JSON property maxDuration

Returns:

  • (String)


15210
15211
15212
# File 'lib/google/apis/compute_alpha/classes.rb', line 15210

def max_duration
  @max_duration
end

#min_durationString

Corresponds to the JSON property minDuration

Returns:

  • (String)


15215
15216
15217
# File 'lib/google/apis/compute_alpha/classes.rb', line 15215

def min_duration
  @min_duration
end

#start_time_not_earlier_thanString

Corresponds to the JSON property startTimeNotEarlierThan

Returns:

  • (String)


15220
15221
15222
# File 'lib/google/apis/compute_alpha/classes.rb', line 15220

def start_time_not_earlier_than
  @start_time_not_earlier_than
end

#start_time_not_later_thanString

Corresponds to the JSON property startTimeNotLaterThan

Returns:

  • (String)


15225
15226
15227
# File 'lib/google/apis/compute_alpha/classes.rb', line 15225

def start_time_not_later_than
  @start_time_not_later_than
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



15232
15233
15234
15235
15236
15237
15238
15239
# File 'lib/google/apis/compute_alpha/classes.rb', line 15232

def update!(**args)
  @end_time_not_earlier_than = args[:end_time_not_earlier_than] if args.key?(:end_time_not_earlier_than)
  @end_time_not_later_than = args[:end_time_not_later_than] if args.key?(:end_time_not_later_than)
  @max_duration = args[:max_duration] if args.key?(:max_duration)
  @min_duration = args[:min_duration] if args.key?(:min_duration)
  @start_time_not_earlier_than = args[:start_time_not_earlier_than] if args.key?(:start_time_not_earlier_than)
  @start_time_not_later_than = args[:start_time_not_later_than] if args.key?(:start_time_not_later_than)
end