Class: Google::Apis::ComputeAlpha::FolderVmExtensionPolicyAggregatedListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FolderVmExtensionPolicyAggregatedListResponse

Returns a new instance of FolderVmExtensionPolicyAggregatedListResponse.



16246
16247
16248
# File 'lib/google/apis/compute_alpha/classes.rb', line 16246

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


16202
16203
16204
# File 'lib/google/apis/compute_alpha/classes.rb', line 16202

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


16207
16208
16209
# File 'lib/google/apis/compute_alpha/classes.rb', line 16207

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::VmExtensionPoliciesScopedList>

A list of VmExtensionPoliciesScopedList resources. Corresponds to the JSON property items



16212
16213
16214
# File 'lib/google/apis/compute_alpha/classes.rb', line 16212

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# FolderVmExtensionPolicyAggregatedList for lists of VmExtensionPolicies. Corresponds to the JSON property kind

Returns:

  • (String)


16219
16220
16221
# File 'lib/google/apis/compute_alpha/classes.rb', line 16219

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


16229
16230
16231
# File 'lib/google/apis/compute_alpha/classes.rb', line 16229

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


16234
16235
16236
# File 'lib/google/apis/compute_alpha/classes.rb', line 16234

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


16239
16240
16241
# File 'lib/google/apis/compute_alpha/classes.rb', line 16239

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::FolderVmExtensionPolicyAggregatedListResponse::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



16244
16245
16246
# File 'lib/google/apis/compute_alpha/classes.rb', line 16244

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



16251
16252
16253
16254
16255
16256
16257
16258
16259
16260
# File 'lib/google/apis/compute_alpha/classes.rb', line 16251

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end