Class: Google::Apis::ComputeAlpha::FolderVmExtensionPolicyAggregatedListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FolderVmExtensionPolicyAggregatedListResponse

Returns a new instance of FolderVmExtensionPolicyAggregatedListResponse.



15612
15613
15614
# File 'lib/google/apis/compute_alpha/classes.rb', line 15612

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


15568
15569
15570
# File 'lib/google/apis/compute_alpha/classes.rb', line 15568

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


15573
15574
15575
# File 'lib/google/apis/compute_alpha/classes.rb', line 15573

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::VmExtensionPoliciesScopedList>

A list of VmExtensionPoliciesScopedList resources. Corresponds to the JSON property items



15578
15579
15580
# File 'lib/google/apis/compute_alpha/classes.rb', line 15578

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# FolderVmExtensionPolicyAggregatedList for lists of VmExtensionPolicies. Corresponds to the JSON property kind

Returns:

  • (String)


15585
15586
15587
# File 'lib/google/apis/compute_alpha/classes.rb', line 15585

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


15595
15596
15597
# File 'lib/google/apis/compute_alpha/classes.rb', line 15595

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


15600
15601
15602
# File 'lib/google/apis/compute_alpha/classes.rb', line 15600

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


15605
15606
15607
# File 'lib/google/apis/compute_alpha/classes.rb', line 15605

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::FolderVmExtensionPolicyAggregatedListResponse::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



15610
15611
15612
# File 'lib/google/apis/compute_alpha/classes.rb', line 15610

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



15617
15618
15619
15620
15621
15622
15623
15624
15625
15626
# File 'lib/google/apis/compute_alpha/classes.rb', line 15617

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end