Class: Google::Apis::ComputeAlpha::ForwardingRuleAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ForwardingRuleAggregatedList

Returns a new instance of ForwardingRuleAggregatedList.



17096
17097
17098
# File 'lib/google/apis/compute_alpha/classes.rb', line 17096

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


17058
17059
17060
# File 'lib/google/apis/compute_alpha/classes.rb', line 17058

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::ForwardingRulesScopedList>

A list of ForwardingRulesScopedList resources. Corresponds to the JSON property items



17063
17064
17065
# File 'lib/google/apis/compute_alpha/classes.rb', line 17063

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# forwardingRuleAggregatedList for lists of forwarding rules. Corresponds to the JSON property kind

Returns:

  • (String)


17069
17070
17071
# File 'lib/google/apis/compute_alpha/classes.rb', line 17069

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


17079
17080
17081
# File 'lib/google/apis/compute_alpha/classes.rb', line 17079

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


17084
17085
17086
# File 'lib/google/apis/compute_alpha/classes.rb', line 17084

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


17089
17090
17091
# File 'lib/google/apis/compute_alpha/classes.rb', line 17089

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::ForwardingRuleAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



17094
17095
17096
# File 'lib/google/apis/compute_alpha/classes.rb', line 17094

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



17101
17102
17103
17104
17105
17106
17107
17108
17109
# File 'lib/google/apis/compute_alpha/classes.rb', line 17101

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end