Class: Google::Apis::ComputeAlpha::ForwardingRuleAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ForwardingRuleAggregatedList

Returns a new instance of ForwardingRuleAggregatedList.



16299
16300
16301
# File 'lib/google/apis/compute_alpha/classes.rb', line 16299

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


16261
16262
16263
# File 'lib/google/apis/compute_alpha/classes.rb', line 16261

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::ForwardingRulesScopedList>

A list of ForwardingRulesScopedList resources. Corresponds to the JSON property items



16266
16267
16268
# File 'lib/google/apis/compute_alpha/classes.rb', line 16266

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# forwardingRuleAggregatedList for lists of forwarding rules. Corresponds to the JSON property kind

Returns:

  • (String)


16272
16273
16274
# File 'lib/google/apis/compute_alpha/classes.rb', line 16272

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


16282
16283
16284
# File 'lib/google/apis/compute_alpha/classes.rb', line 16282

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


16287
16288
16289
# File 'lib/google/apis/compute_alpha/classes.rb', line 16287

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


16292
16293
16294
# File 'lib/google/apis/compute_alpha/classes.rb', line 16292

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::ForwardingRuleAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



16297
16298
16299
# File 'lib/google/apis/compute_alpha/classes.rb', line 16297

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



16304
16305
16306
16307
16308
16309
16310
16311
16312
# File 'lib/google/apis/compute_alpha/classes.rb', line 16304

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end