Class: Google::Apis::ComputeAlpha::ForwardingRuleAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::ForwardingRuleAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::ForwardingRulesScopedList>
A list of ForwardingRulesScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::ForwardingRuleAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ForwardingRuleAggregatedList
constructor
A new instance of ForwardingRuleAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ForwardingRuleAggregatedList
Returns a new instance of ForwardingRuleAggregatedList.
16122 16123 16124 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 16122 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
16084 16085 16086 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 16084 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::ForwardingRulesScopedList>
A list of ForwardingRulesScopedList resources.
Corresponds to the JSON property items
16089 16090 16091 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 16089 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
forwardingRuleAggregatedList for lists of forwarding rules.
Corresponds to the JSON property kind
16095 16096 16097 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 16095 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
16105 16106 16107 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 16105 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
16110 16111 16112 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 16110 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
16115 16116 16117 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 16115 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::ForwardingRuleAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
16120 16121 16122 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 16120 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
16127 16128 16129 16130 16131 16132 16133 16134 16135 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 16127 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |