Class: Google::Apis::ComputeAlpha::ForwardingRuleAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ForwardingRuleAggregatedList

Returns a new instance of ForwardingRuleAggregatedList.



16139
16140
16141
# File 'lib/google/apis/compute_alpha/classes.rb', line 16139

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


16101
16102
16103
# File 'lib/google/apis/compute_alpha/classes.rb', line 16101

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::ForwardingRulesScopedList>

A list of ForwardingRulesScopedList resources. Corresponds to the JSON property items



16106
16107
16108
# File 'lib/google/apis/compute_alpha/classes.rb', line 16106

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# forwardingRuleAggregatedList for lists of forwarding rules. Corresponds to the JSON property kind

Returns:

  • (String)


16112
16113
16114
# File 'lib/google/apis/compute_alpha/classes.rb', line 16112

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


16122
16123
16124
# File 'lib/google/apis/compute_alpha/classes.rb', line 16122

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


16127
16128
16129
# File 'lib/google/apis/compute_alpha/classes.rb', line 16127

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


16132
16133
16134
# File 'lib/google/apis/compute_alpha/classes.rb', line 16132

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::ForwardingRuleAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



16137
16138
16139
# File 'lib/google/apis/compute_alpha/classes.rb', line 16137

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



16144
16145
16146
16147
16148
16149
16150
16151
16152
# File 'lib/google/apis/compute_alpha/classes.rb', line 16144

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end