Class: Google::Apis::ComputeAlpha::ForwardingRuleAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ForwardingRuleAggregatedList

Returns a new instance of ForwardingRuleAggregatedList.



15842
15843
15844
# File 'lib/google/apis/compute_alpha/classes.rb', line 15842

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


15804
15805
15806
# File 'lib/google/apis/compute_alpha/classes.rb', line 15804

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::ForwardingRulesScopedList>

A list of ForwardingRulesScopedList resources. Corresponds to the JSON property items



15809
15810
15811
# File 'lib/google/apis/compute_alpha/classes.rb', line 15809

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# forwardingRuleAggregatedList for lists of forwarding rules. Corresponds to the JSON property kind

Returns:

  • (String)


15815
15816
15817
# File 'lib/google/apis/compute_alpha/classes.rb', line 15815

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


15825
15826
15827
# File 'lib/google/apis/compute_alpha/classes.rb', line 15825

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


15830
15831
15832
# File 'lib/google/apis/compute_alpha/classes.rb', line 15830

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


15835
15836
15837
# File 'lib/google/apis/compute_alpha/classes.rb', line 15835

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::ForwardingRuleAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



15840
15841
15842
# File 'lib/google/apis/compute_alpha/classes.rb', line 15840

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



15847
15848
15849
15850
15851
15852
15853
15854
15855
# File 'lib/google/apis/compute_alpha/classes.rb', line 15847

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end