Class: Google::Apis::ComputeAlpha::ForwardingRuleList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of ForwardingRule resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ForwardingRuleList

Returns a new instance of ForwardingRuleList.



17240
17241
17242
# File 'lib/google/apis/compute_alpha/classes.rb', line 17240

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


17208
17209
17210
# File 'lib/google/apis/compute_alpha/classes.rb', line 17208

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::ForwardingRule>

A list of ForwardingRule resources. Corresponds to the JSON property items



17213
17214
17215
# File 'lib/google/apis/compute_alpha/classes.rb', line 17213

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


17218
17219
17220
# File 'lib/google/apis/compute_alpha/classes.rb', line 17218

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


17228
17229
17230
# File 'lib/google/apis/compute_alpha/classes.rb', line 17228

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


17233
17234
17235
# File 'lib/google/apis/compute_alpha/classes.rb', line 17233

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::ForwardingRuleList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



17238
17239
17240
# File 'lib/google/apis/compute_alpha/classes.rb', line 17238

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



17245
17246
17247
17248
17249
17250
17251
17252
# File 'lib/google/apis/compute_alpha/classes.rb', line 17245

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end