Class: Google::Apis::ComputeAlpha::ForwardingRuleList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::ForwardingRuleList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Contains a list of ForwardingRule resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::ForwardingRule>
A list of ForwardingRule resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::ForwardingRuleList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ForwardingRuleList
constructor
A new instance of ForwardingRuleList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ForwardingRuleList
Returns a new instance of ForwardingRuleList.
17077 17078 17079 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 17077 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
17045 17046 17047 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 17045 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::ForwardingRule>
A list of ForwardingRule resources.
Corresponds to the JSON property items
17050 17051 17052 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 17050 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
17055 17056 17057 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 17055 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
17065 17066 17067 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 17065 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
17070 17071 17072 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 17070 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::ForwardingRuleList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
17075 17076 17077 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 17075 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
17082 17083 17084 17085 17086 17087 17088 17089 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 17082 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |