Class: Google::Apis::ComputeAlpha::ForwardingRuleList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of ForwardingRule resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ForwardingRuleList

Returns a new instance of ForwardingRuleList.



16266
16267
16268
# File 'lib/google/apis/compute_alpha/classes.rb', line 16266

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


16234
16235
16236
# File 'lib/google/apis/compute_alpha/classes.rb', line 16234

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::ForwardingRule>

A list of ForwardingRule resources. Corresponds to the JSON property items



16239
16240
16241
# File 'lib/google/apis/compute_alpha/classes.rb', line 16239

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


16244
16245
16246
# File 'lib/google/apis/compute_alpha/classes.rb', line 16244

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


16254
16255
16256
# File 'lib/google/apis/compute_alpha/classes.rb', line 16254

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


16259
16260
16261
# File 'lib/google/apis/compute_alpha/classes.rb', line 16259

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::ForwardingRuleList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



16264
16265
16266
# File 'lib/google/apis/compute_alpha/classes.rb', line 16264

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



16271
16272
16273
16274
16275
16276
16277
16278
# File 'lib/google/apis/compute_alpha/classes.rb', line 16271

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end