Class: Google::Apis::ComputeAlpha::ForwardingRuleList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of ForwardingRule resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ForwardingRuleList

Returns a new instance of ForwardingRuleList.



15986
15987
15988
# File 'lib/google/apis/compute_alpha/classes.rb', line 15986

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


15954
15955
15956
# File 'lib/google/apis/compute_alpha/classes.rb', line 15954

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::ForwardingRule>

A list of ForwardingRule resources. Corresponds to the JSON property items



15959
15960
15961
# File 'lib/google/apis/compute_alpha/classes.rb', line 15959

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


15964
15965
15966
# File 'lib/google/apis/compute_alpha/classes.rb', line 15964

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


15974
15975
15976
# File 'lib/google/apis/compute_alpha/classes.rb', line 15974

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


15979
15980
15981
# File 'lib/google/apis/compute_alpha/classes.rb', line 15979

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::ForwardingRuleList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



15984
15985
15986
# File 'lib/google/apis/compute_alpha/classes.rb', line 15984

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



15991
15992
15993
15994
15995
15996
15997
15998
# File 'lib/google/apis/compute_alpha/classes.rb', line 15991

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end