Class: Google::Apis::ComputeAlpha::ForwardingRuleServiceDirectoryRegistration

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Describes the auto-registration of the forwarding rule to Service Directory. The region and project of the Service Directory resource generated from this registration will be the same as this forwarding rule.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ForwardingRuleServiceDirectoryRegistration

Returns a new instance of ForwardingRuleServiceDirectoryRegistration.



16417
16418
16419
# File 'lib/google/apis/compute_alpha/classes.rb', line 16417

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#namespaceString

Service Directory namespace to register the forwarding rule under. Corresponds to the JSON property namespace

Returns:

  • (String)


16402
16403
16404
# File 'lib/google/apis/compute_alpha/classes.rb', line 16402

def namespace
  @namespace
end

#serviceString

Service Directory service to register the forwarding rule under. Corresponds to the JSON property service

Returns:

  • (String)


16407
16408
16409
# File 'lib/google/apis/compute_alpha/classes.rb', line 16407

def service
  @service
end

#service_directory_regionString

[Optional] Service Directory region to register this global forwarding rule under. Default to "us-central1". Only used for PSC for Google APIs. All PSC for Google APIs forwarding rules on the same network should use the same Service Directory region. Corresponds to the JSON property serviceDirectoryRegion

Returns:

  • (String)


16415
16416
16417
# File 'lib/google/apis/compute_alpha/classes.rb', line 16415

def service_directory_region
  @service_directory_region
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



16422
16423
16424
16425
16426
# File 'lib/google/apis/compute_alpha/classes.rb', line 16422

def update!(**args)
  @namespace = args[:namespace] if args.key?(:namespace)
  @service = args[:service] if args.key?(:service)
  @service_directory_region = args[:service_directory_region] if args.key?(:service_directory_region)
end