Class: Google::Apis::ComputeAlpha::FutureReservation
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::FutureReservation
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#advanced_deployment_control ⇒ Google::Apis::ComputeAlpha::ReservationAdvancedDeploymentControl
Advance control for cluster management, applicable only to DENSE deployment type reservations.
-
#aggregate_reservation ⇒ Google::Apis::ComputeAlpha::AllocationAggregateReservation
This reservation type is specified by total resource amounts (e.g. total count of CPUs) and can account for multiple instance SKUs.
-
#auto_created_reservations_delete_time ⇒ String
Future timestamp when the FR auto-created reservations will be deleted by Compute Engine.
-
#auto_created_reservations_duration ⇒ Google::Apis::ComputeAlpha::Duration
A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution.
-
#auto_delete_auto_created_reservations ⇒ Boolean
(also: #auto_delete_auto_created_reservations?)
Setting for enabling or disabling automatic deletion for auto-created reservation.
-
#colocation_resource ⇒ String
Full or partial URL of an existing future reservation to indicate intent for reserving capacity in the same cluster as the colocation resource.
-
#commitment_info ⇒ Google::Apis::ComputeAlpha::FutureReservationCommitmentInfo
If not present, then FR will not deliver a new commitment or update an existing commitment.
-
#confidential_compute_type ⇒ String
Corresponds to the JSON property
confidentialComputeType. -
#creation_timestamp ⇒ String
Output only.
-
#deployment_type ⇒ String
Type of the deployment requested as part of future reservation.
-
#description ⇒ String
An optional description of this resource.
-
#enable_emergent_maintenance ⇒ Boolean
(also: #enable_emergent_maintenance?)
Indicates if this group of VMs have emergent maintenance enabled.
-
#id ⇒ Fixnum
Output only.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
The name of the resource, provided by the client when initially creating the resource.
-
#name_prefix ⇒ String
Name prefix for the reservations to be created at the time of delivery.
-
#params ⇒ Google::Apis::ComputeAlpha::FutureReservationParams
Additional future reservation params.
-
#planning_status ⇒ String
Planning state before being submitted for evaluation Corresponds to the JSON property
planningStatus. -
#protection_tier ⇒ String
Protection tier for the workload.
-
#reservation_mode ⇒ String
The reservation mode which determines reservation-termination behavior and expected pricing.
-
#reservation_name ⇒ String
Name of reservations where the capacity is provisioned at the time of delivery of future reservations.
-
#resource_name ⇒ String
Name of the resource intended to be delivered.
-
#scheduling_type ⇒ String
Maintenance information for this reservation Corresponds to the JSON property
schedulingType. -
#self_link ⇒ String
Output only.
-
#self_link_with_id ⇒ String
Output only.
-
#share_settings ⇒ Google::Apis::ComputeAlpha::ShareSettings
The share setting for reservations and sole tenancy node groups.
-
#specific_reservation_required ⇒ Boolean
(also: #specific_reservation_required?)
Indicates whether the auto-created reservation can be consumed by VMs with affinity for "any" reservation.
-
#specific_sku_properties ⇒ Google::Apis::ComputeAlpha::FutureReservationSpecificSkuProperties
Future Reservation configuration to indicate instance properties and total count.
-
#status ⇒ Google::Apis::ComputeAlpha::FutureReservationStatus
[Output only] Represents status related to the future reservation.
-
#storage_pool_properties ⇒ Google::Apis::ComputeAlpha::FutureReservationStoragePoolProperties
Storage pool properties for the future reservation.
-
#time_window ⇒ Google::Apis::ComputeAlpha::FutureReservationTimeWindow
Time window for this Future Reservation.
-
#zone ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FutureReservation
constructor
A new instance of FutureReservation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FutureReservation
Returns a new instance of FutureReservation.
17691 17692 17693 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 17691 def initialize(**args) update!(**args) end |
Instance Attribute Details
#advanced_deployment_control ⇒ Google::Apis::ComputeAlpha::ReservationAdvancedDeploymentControl
Advance control for cluster management, applicable only to DENSE deployment
type reservations.
Corresponds to the JSON property advancedDeploymentControl
17485 17486 17487 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 17485 def advanced_deployment_control @advanced_deployment_control end |
#aggregate_reservation ⇒ Google::Apis::ComputeAlpha::AllocationAggregateReservation
This reservation type is specified by total resource amounts (e.g. total
count of CPUs) and can account for multiple instance SKUs. In other words,
one can create instances of varying shapes against this reservation.
Corresponds to the JSON property aggregateReservation
17492 17493 17494 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 17492 def aggregate_reservation @aggregate_reservation end |
#auto_created_reservations_delete_time ⇒ String
Future timestamp when the FR auto-created reservations will be deleted by
Compute Engine. Format of this field must be a valid
href="https://www.ietf.org/rfc/rfc3339.txt">RFC3339 value.
Corresponds to the JSON property autoCreatedReservationsDeleteTime
17499 17500 17501 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 17499 def auto_created_reservations_delete_time @auto_created_reservations_delete_time end |
#auto_created_reservations_duration ⇒ Google::Apis::ComputeAlpha::Duration
A Duration represents a fixed-length span of time represented
as a count of seconds and fractions of seconds at nanosecond
resolution. It is independent of any calendar and concepts like "day"
or "month". Range is approximately 10,000 years.
Corresponds to the JSON property autoCreatedReservationsDuration
17507 17508 17509 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 17507 def auto_created_reservations_duration @auto_created_reservations_duration end |
#auto_delete_auto_created_reservations ⇒ Boolean Also known as: auto_delete_auto_created_reservations?
Setting for enabling or disabling automatic deletion for auto-created
reservation. If set to true, auto-created reservations will be
deleted at Future Reservation's end time (default) or at user's defined
timestamp if any of the
[auto_created_reservations_delete_time, auto_created_reservations_duration]
values is specified.
For keeping auto-created reservation indefinitely, this value should be set
to false.
Corresponds to the JSON property autoDeleteAutoCreatedReservations
17519 17520 17521 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 17519 def auto_delete_auto_created_reservations @auto_delete_auto_created_reservations end |
#colocation_resource ⇒ String
Full or partial URL of an existing future reservation to indicate
intent for reserving capacity in the same cluster as the colocation
resource.
Corresponds to the JSON property colocationResource
17527 17528 17529 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 17527 def colocation_resource @colocation_resource end |
#commitment_info ⇒ Google::Apis::ComputeAlpha::FutureReservationCommitmentInfo
If not present, then FR will not deliver a new commitment or update an
existing commitment.
Corresponds to the JSON property commitmentInfo
17533 17534 17535 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 17533 def commitment_info @commitment_info end |
#confidential_compute_type ⇒ String
Corresponds to the JSON property confidentialComputeType
17538 17539 17540 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 17538 def confidential_compute_type @confidential_compute_type end |
#creation_timestamp ⇒ String
Output only. [Output Only] The creation timestamp for this future reservation
inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
17545 17546 17547 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 17545 def @creation_timestamp end |
#deployment_type ⇒ String
Type of the deployment requested as part of future reservation.
Corresponds to the JSON property deploymentType
17550 17551 17552 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 17550 def deployment_type @deployment_type end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the future reservation.
Corresponds to the JSON property description
17556 17557 17558 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 17556 def description @description end |
#enable_emergent_maintenance ⇒ Boolean Also known as: enable_emergent_maintenance?
Indicates if this group of VMs have emergent maintenance enabled.
Corresponds to the JSON property enableEmergentMaintenance
17561 17562 17563 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 17561 def enable_emergent_maintenance @enable_emergent_maintenance end |
#id ⇒ Fixnum
Output only. [Output Only] A unique identifier for this future reservation.
The server
defines this identifier.
Corresponds to the JSON property id
17569 17570 17571 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 17569 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#
futureReservation for future reservations.
Corresponds to the JSON property kind
17575 17576 17577 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 17575 def kind @kind end |
#name ⇒ String
The name of the resource, provided by the client when initially creating
the resource. The resource name must be 1-63 characters long, and comply
withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must be
a dash, lowercase letter, or digit, except the last character, which cannot
be a dash.
Corresponds to the JSON property name
17587 17588 17589 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 17587 def name @name end |
#name_prefix ⇒ String
Name prefix for the reservations to be created at the time of
delivery. The name prefix must comply with RFC1035.
Maximum allowed length for name prefix is 20. Automatically created
reservations name format will be -date-####.
Corresponds to the JSON property namePrefix
17595 17596 17597 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 17595 def name_prefix @name_prefix end |
#params ⇒ Google::Apis::ComputeAlpha::FutureReservationParams
Additional future reservation params.
Corresponds to the JSON property params
17600 17601 17602 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 17600 def params @params end |
#planning_status ⇒ String
Planning state before being submitted for evaluation
Corresponds to the JSON property planningStatus
17605 17606 17607 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 17605 def planning_status @planning_status end |
#protection_tier ⇒ String
Protection tier for the workload.
Corresponds to the JSON property protectionTier
17610 17611 17612 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 17610 def protection_tier @protection_tier end |
#reservation_mode ⇒ String
The reservation mode which determines reservation-termination behavior and
expected pricing.
Corresponds to the JSON property reservationMode
17616 17617 17618 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 17616 def reservation_mode @reservation_mode end |
#reservation_name ⇒ String
Name of reservations where the capacity is provisioned at the time of
delivery of future reservations. If the reservation with the given name
does not exist already, it is created automatically at the time of Approval
with INACTIVE state till specified start-time. Either provide the
reservation_name or a name_prefix.
Corresponds to the JSON property reservationName
17625 17626 17627 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 17625 def reservation_name @reservation_name end |
#resource_name ⇒ String
Name of the resource intended to be delivered. Name should conform to
RFC1035. This will be the name of storage pool or Exapool for persistent
disk FRs.
Corresponds to the JSON property resourceName
17632 17633 17634 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 17632 def resource_name @resource_name end |
#scheduling_type ⇒ String
Maintenance information for this reservation
Corresponds to the JSON property schedulingType
17637 17638 17639 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 17637 def scheduling_type @scheduling_type end |
#self_link ⇒ String
Output only. [Output Only] Server-defined fully-qualified URL for this
resource.
Corresponds to the JSON property selfLink
17643 17644 17645 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 17643 def self_link @self_link end |
#self_link_with_id ⇒ String
Output only. [Output Only] Server-defined URL for this resource with the
resource id.
Corresponds to the JSON property selfLinkWithId
17649 17650 17651 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 17649 def self_link_with_id @self_link_with_id end |
#share_settings ⇒ Google::Apis::ComputeAlpha::ShareSettings
The share setting for reservations and sole tenancy node groups.
Corresponds to the JSON property shareSettings
17654 17655 17656 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 17654 def share_settings @share_settings end |
#specific_reservation_required ⇒ Boolean Also known as: specific_reservation_required?
Indicates whether the auto-created reservation can be consumed by VMs with
affinity for "any" reservation. If the field is set, then only VMs that
target the reservation by name can consume from the delivered reservation.
Corresponds to the JSON property specificReservationRequired
17661 17662 17663 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 17661 def specific_reservation_required @specific_reservation_required end |
#specific_sku_properties ⇒ Google::Apis::ComputeAlpha::FutureReservationSpecificSkuProperties
Future Reservation configuration to indicate instance properties and
total count.
Corresponds to the JSON property specificSkuProperties
17668 17669 17670 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 17668 def specific_sku_properties @specific_sku_properties end |
#status ⇒ Google::Apis::ComputeAlpha::FutureReservationStatus
[Output only] Represents status related to the future reservation.
Corresponds to the JSON property status
17673 17674 17675 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 17673 def status @status end |
#storage_pool_properties ⇒ Google::Apis::ComputeAlpha::FutureReservationStoragePoolProperties
Storage pool properties for the future reservation.
Corresponds to the JSON property storagePoolProperties
17678 17679 17680 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 17678 def storage_pool_properties @storage_pool_properties end |
#time_window ⇒ Google::Apis::ComputeAlpha::FutureReservationTimeWindow
Time window for this Future Reservation.
Corresponds to the JSON property timeWindow
17683 17684 17685 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 17683 def time_window @time_window end |
#zone ⇒ String
Output only. [Output Only] URL of the Zone where this future reservation
resides.
Corresponds to the JSON property zone
17689 17690 17691 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 17689 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
17696 17697 17698 17699 17700 17701 17702 17703 17704 17705 17706 17707 17708 17709 17710 17711 17712 17713 17714 17715 17716 17717 17718 17719 17720 17721 17722 17723 17724 17725 17726 17727 17728 17729 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 17696 def update!(**args) @advanced_deployment_control = args[:advanced_deployment_control] if args.key?(:advanced_deployment_control) @aggregate_reservation = args[:aggregate_reservation] if args.key?(:aggregate_reservation) @auto_created_reservations_delete_time = args[:auto_created_reservations_delete_time] if args.key?(:auto_created_reservations_delete_time) @auto_created_reservations_duration = args[:auto_created_reservations_duration] if args.key?(:auto_created_reservations_duration) @auto_delete_auto_created_reservations = args[:auto_delete_auto_created_reservations] if args.key?(:auto_delete_auto_created_reservations) @colocation_resource = args[:colocation_resource] if args.key?(:colocation_resource) @commitment_info = args[:commitment_info] if args.key?(:commitment_info) @confidential_compute_type = args[:confidential_compute_type] if args.key?(:confidential_compute_type) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @deployment_type = args[:deployment_type] if args.key?(:deployment_type) @description = args[:description] if args.key?(:description) @enable_emergent_maintenance = args[:enable_emergent_maintenance] if args.key?(:enable_emergent_maintenance) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @name_prefix = args[:name_prefix] if args.key?(:name_prefix) @params = args[:params] if args.key?(:params) @planning_status = args[:planning_status] if args.key?(:planning_status) @protection_tier = args[:protection_tier] if args.key?(:protection_tier) @reservation_mode = args[:reservation_mode] if args.key?(:reservation_mode) @reservation_name = args[:reservation_name] if args.key?(:reservation_name) @resource_name = args[:resource_name] if args.key?(:resource_name) @scheduling_type = args[:scheduling_type] if args.key?(:scheduling_type) @self_link = args[:self_link] if args.key?(:self_link) @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id) @share_settings = args[:share_settings] if args.key?(:share_settings) @specific_reservation_required = args[:specific_reservation_required] if args.key?(:specific_reservation_required) @specific_sku_properties = args[:specific_sku_properties] if args.key?(:specific_sku_properties) @status = args[:status] if args.key?(:status) @storage_pool_properties = args[:storage_pool_properties] if args.key?(:storage_pool_properties) @time_window = args[:time_window] if args.key?(:time_window) @zone = args[:zone] if args.key?(:zone) end |