Class: Google::Apis::ComputeAlpha::FutureReservation

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FutureReservation

Returns a new instance of FutureReservation.



17528
17529
17530
# File 'lib/google/apis/compute_alpha/classes.rb', line 17528

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#advanced_deployment_controlGoogle::Apis::ComputeAlpha::ReservationAdvancedDeploymentControl

Advance control for cluster management, applicable only to DENSE deployment type reservations. Corresponds to the JSON property advancedDeploymentControl



17322
17323
17324
# File 'lib/google/apis/compute_alpha/classes.rb', line 17322

def advanced_deployment_control
  @advanced_deployment_control
end

#aggregate_reservationGoogle::Apis::ComputeAlpha::AllocationAggregateReservation

This reservation type is specified by total resource amounts (e.g. total count of CPUs) and can account for multiple instance SKUs. In other words, one can create instances of varying shapes against this reservation. Corresponds to the JSON property aggregateReservation



17329
17330
17331
# File 'lib/google/apis/compute_alpha/classes.rb', line 17329

def aggregate_reservation
  @aggregate_reservation
end

#auto_created_reservations_delete_timeString

Future timestamp when the FR auto-created reservations will be deleted by Compute Engine. Format of this field must be a valid href="https://www.ietf.org/rfc/rfc3339.txt">RFC3339 value. Corresponds to the JSON property autoCreatedReservationsDeleteTime

Returns:

  • (String)


17336
17337
17338
# File 'lib/google/apis/compute_alpha/classes.rb', line 17336

def auto_created_reservations_delete_time
  @auto_created_reservations_delete_time
end

#auto_created_reservations_durationGoogle::Apis::ComputeAlpha::Duration

A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution. It is independent of any calendar and concepts like "day" or "month". Range is approximately 10,000 years. Corresponds to the JSON property autoCreatedReservationsDuration



17344
17345
17346
# File 'lib/google/apis/compute_alpha/classes.rb', line 17344

def auto_created_reservations_duration
  @auto_created_reservations_duration
end

#auto_delete_auto_created_reservationsBoolean Also known as: auto_delete_auto_created_reservations?

Setting for enabling or disabling automatic deletion for auto-created reservation. If set to true, auto-created reservations will be deleted at Future Reservation's end time (default) or at user's defined timestamp if any of the [auto_created_reservations_delete_time, auto_created_reservations_duration] values is specified. For keeping auto-created reservation indefinitely, this value should be set to false. Corresponds to the JSON property autoDeleteAutoCreatedReservations

Returns:

  • (Boolean)


17356
17357
17358
# File 'lib/google/apis/compute_alpha/classes.rb', line 17356

def auto_delete_auto_created_reservations
  @auto_delete_auto_created_reservations
end

#colocation_resourceString

Full or partial URL of an existing future reservation to indicate intent for reserving capacity in the same cluster as the colocation resource. Corresponds to the JSON property colocationResource

Returns:

  • (String)


17364
17365
17366
# File 'lib/google/apis/compute_alpha/classes.rb', line 17364

def colocation_resource
  @colocation_resource
end

#commitment_infoGoogle::Apis::ComputeAlpha::FutureReservationCommitmentInfo

If not present, then FR will not deliver a new commitment or update an existing commitment. Corresponds to the JSON property commitmentInfo



17370
17371
17372
# File 'lib/google/apis/compute_alpha/classes.rb', line 17370

def commitment_info
  @commitment_info
end

#confidential_compute_typeString

Corresponds to the JSON property confidentialComputeType

Returns:

  • (String)


17375
17376
17377
# File 'lib/google/apis/compute_alpha/classes.rb', line 17375

def confidential_compute_type
  @confidential_compute_type
end

#creation_timestampString

Output only. [Output Only] The creation timestamp for this future reservation inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


17382
17383
17384
# File 'lib/google/apis/compute_alpha/classes.rb', line 17382

def creation_timestamp
  @creation_timestamp
end

#deployment_typeString

Type of the deployment requested as part of future reservation. Corresponds to the JSON property deploymentType

Returns:

  • (String)


17387
17388
17389
# File 'lib/google/apis/compute_alpha/classes.rb', line 17387

def deployment_type
  @deployment_type
end

#descriptionString

An optional description of this resource. Provide this property when you create the future reservation. Corresponds to the JSON property description

Returns:

  • (String)


17393
17394
17395
# File 'lib/google/apis/compute_alpha/classes.rb', line 17393

def description
  @description
end

#enable_emergent_maintenanceBoolean Also known as: enable_emergent_maintenance?

Indicates if this group of VMs have emergent maintenance enabled. Corresponds to the JSON property enableEmergentMaintenance

Returns:

  • (Boolean)


17398
17399
17400
# File 'lib/google/apis/compute_alpha/classes.rb', line 17398

def enable_emergent_maintenance
  @enable_emergent_maintenance
end

#idFixnum

Output only. [Output Only] A unique identifier for this future reservation. The server defines this identifier. Corresponds to the JSON property id

Returns:

  • (Fixnum)


17406
17407
17408
# File 'lib/google/apis/compute_alpha/classes.rb', line 17406

def id
  @id
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# futureReservation for future reservations. Corresponds to the JSON property kind

Returns:

  • (String)


17412
17413
17414
# File 'lib/google/apis/compute_alpha/classes.rb', line 17412

def kind
  @kind
end

#nameString

The name of the resource, provided by the client when initially creating the resource. The resource name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


17424
17425
17426
# File 'lib/google/apis/compute_alpha/classes.rb', line 17424

def name
  @name
end

#name_prefixString

Name prefix for the reservations to be created at the time of delivery. The name prefix must comply with RFC1035. Maximum allowed length for name prefix is 20. Automatically created reservations name format will be -date-####. Corresponds to the JSON property namePrefix

Returns:

  • (String)


17432
17433
17434
# File 'lib/google/apis/compute_alpha/classes.rb', line 17432

def name_prefix
  @name_prefix
end

#paramsGoogle::Apis::ComputeAlpha::FutureReservationParams

Additional future reservation params. Corresponds to the JSON property params



17437
17438
17439
# File 'lib/google/apis/compute_alpha/classes.rb', line 17437

def params
  @params
end

#planning_statusString

Planning state before being submitted for evaluation Corresponds to the JSON property planningStatus

Returns:

  • (String)


17442
17443
17444
# File 'lib/google/apis/compute_alpha/classes.rb', line 17442

def planning_status
  @planning_status
end

#protection_tierString

Protection tier for the workload. Corresponds to the JSON property protectionTier

Returns:

  • (String)


17447
17448
17449
# File 'lib/google/apis/compute_alpha/classes.rb', line 17447

def protection_tier
  @protection_tier
end

#reservation_modeString

The reservation mode which determines reservation-termination behavior and expected pricing. Corresponds to the JSON property reservationMode

Returns:

  • (String)


17453
17454
17455
# File 'lib/google/apis/compute_alpha/classes.rb', line 17453

def reservation_mode
  @reservation_mode
end

#reservation_nameString

Name of reservations where the capacity is provisioned at the time of delivery of future reservations. If the reservation with the given name does not exist already, it is created automatically at the time of Approval with INACTIVE state till specified start-time. Either provide the reservation_name or a name_prefix. Corresponds to the JSON property reservationName

Returns:

  • (String)


17462
17463
17464
# File 'lib/google/apis/compute_alpha/classes.rb', line 17462

def reservation_name
  @reservation_name
end

#resource_nameString

Name of the resource intended to be delivered. Name should conform to RFC1035. This will be the name of storage pool or Exapool for persistent disk FRs. Corresponds to the JSON property resourceName

Returns:

  • (String)


17469
17470
17471
# File 'lib/google/apis/compute_alpha/classes.rb', line 17469

def resource_name
  @resource_name
end

#scheduling_typeString

Maintenance information for this reservation Corresponds to the JSON property schedulingType

Returns:

  • (String)


17474
17475
17476
# File 'lib/google/apis/compute_alpha/classes.rb', line 17474

def scheduling_type
  @scheduling_type
end

Output only. [Output Only] Server-defined fully-qualified URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


17480
17481
17482
# File 'lib/google/apis/compute_alpha/classes.rb', line 17480

def self_link
  @self_link
end

Output only. [Output Only] Server-defined URL for this resource with the resource id. Corresponds to the JSON property selfLinkWithId

Returns:

  • (String)


17486
17487
17488
# File 'lib/google/apis/compute_alpha/classes.rb', line 17486

def self_link_with_id
  @self_link_with_id
end

#share_settingsGoogle::Apis::ComputeAlpha::ShareSettings

The share setting for reservations and sole tenancy node groups. Corresponds to the JSON property shareSettings



17491
17492
17493
# File 'lib/google/apis/compute_alpha/classes.rb', line 17491

def share_settings
  @share_settings
end

#specific_reservation_requiredBoolean Also known as: specific_reservation_required?

Indicates whether the auto-created reservation can be consumed by VMs with affinity for "any" reservation. If the field is set, then only VMs that target the reservation by name can consume from the delivered reservation. Corresponds to the JSON property specificReservationRequired

Returns:

  • (Boolean)


17498
17499
17500
# File 'lib/google/apis/compute_alpha/classes.rb', line 17498

def specific_reservation_required
  @specific_reservation_required
end

#specific_sku_propertiesGoogle::Apis::ComputeAlpha::FutureReservationSpecificSkuProperties

Future Reservation configuration to indicate instance properties and total count. Corresponds to the JSON property specificSkuProperties



17505
17506
17507
# File 'lib/google/apis/compute_alpha/classes.rb', line 17505

def specific_sku_properties
  @specific_sku_properties
end

#statusGoogle::Apis::ComputeAlpha::FutureReservationStatus

[Output only] Represents status related to the future reservation. Corresponds to the JSON property status



17510
17511
17512
# File 'lib/google/apis/compute_alpha/classes.rb', line 17510

def status
  @status
end

#storage_pool_propertiesGoogle::Apis::ComputeAlpha::FutureReservationStoragePoolProperties

Storage pool properties for the future reservation. Corresponds to the JSON property storagePoolProperties



17515
17516
17517
# File 'lib/google/apis/compute_alpha/classes.rb', line 17515

def storage_pool_properties
  @storage_pool_properties
end

#time_windowGoogle::Apis::ComputeAlpha::FutureReservationTimeWindow

Time window for this Future Reservation. Corresponds to the JSON property timeWindow



17520
17521
17522
# File 'lib/google/apis/compute_alpha/classes.rb', line 17520

def time_window
  @time_window
end

#zoneString

Output only. [Output Only] URL of the Zone where this future reservation resides. Corresponds to the JSON property zone

Returns:

  • (String)


17526
17527
17528
# File 'lib/google/apis/compute_alpha/classes.rb', line 17526

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



17533
17534
17535
17536
17537
17538
17539
17540
17541
17542
17543
17544
17545
17546
17547
17548
17549
17550
17551
17552
17553
17554
17555
17556
17557
17558
17559
17560
17561
17562
17563
17564
17565
17566
# File 'lib/google/apis/compute_alpha/classes.rb', line 17533

def update!(**args)
  @advanced_deployment_control = args[:advanced_deployment_control] if args.key?(:advanced_deployment_control)
  @aggregate_reservation = args[:aggregate_reservation] if args.key?(:aggregate_reservation)
  @auto_created_reservations_delete_time = args[:auto_created_reservations_delete_time] if args.key?(:auto_created_reservations_delete_time)
  @auto_created_reservations_duration = args[:auto_created_reservations_duration] if args.key?(:auto_created_reservations_duration)
  @auto_delete_auto_created_reservations = args[:auto_delete_auto_created_reservations] if args.key?(:auto_delete_auto_created_reservations)
  @colocation_resource = args[:colocation_resource] if args.key?(:colocation_resource)
  @commitment_info = args[:commitment_info] if args.key?(:commitment_info)
  @confidential_compute_type = args[:confidential_compute_type] if args.key?(:confidential_compute_type)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @deployment_type = args[:deployment_type] if args.key?(:deployment_type)
  @description = args[:description] if args.key?(:description)
  @enable_emergent_maintenance = args[:enable_emergent_maintenance] if args.key?(:enable_emergent_maintenance)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @name_prefix = args[:name_prefix] if args.key?(:name_prefix)
  @params = args[:params] if args.key?(:params)
  @planning_status = args[:planning_status] if args.key?(:planning_status)
  @protection_tier = args[:protection_tier] if args.key?(:protection_tier)
  @reservation_mode = args[:reservation_mode] if args.key?(:reservation_mode)
  @reservation_name = args[:reservation_name] if args.key?(:reservation_name)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @scheduling_type = args[:scheduling_type] if args.key?(:scheduling_type)
  @self_link = args[:self_link] if args.key?(:self_link)
  @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id)
  @share_settings = args[:share_settings] if args.key?(:share_settings)
  @specific_reservation_required = args[:specific_reservation_required] if args.key?(:specific_reservation_required)
  @specific_sku_properties = args[:specific_sku_properties] if args.key?(:specific_sku_properties)
  @status = args[:status] if args.key?(:status)
  @storage_pool_properties = args[:storage_pool_properties] if args.key?(:storage_pool_properties)
  @time_window = args[:time_window] if args.key?(:time_window)
  @zone = args[:zone] if args.key?(:zone)
end