Class: Google::Apis::ComputeAlpha::FutureReservation
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::FutureReservation
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#advanced_deployment_control ⇒ Google::Apis::ComputeAlpha::ReservationAdvancedDeploymentControl
Advance control for cluster management, applicable only to DENSE deployment type reservations.
-
#aggregate_reservation ⇒ Google::Apis::ComputeAlpha::AllocationAggregateReservation
This reservation type is specified by total resource amounts (e.g. total count of CPUs) and can account for multiple instance SKUs.
-
#auto_created_reservations_delete_time ⇒ String
Future timestamp when the FR auto-created reservations will be deleted by Compute Engine.
-
#auto_created_reservations_duration ⇒ Google::Apis::ComputeAlpha::Duration
A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution.
-
#auto_delete_auto_created_reservations ⇒ Boolean
(also: #auto_delete_auto_created_reservations?)
Setting for enabling or disabling automatic deletion for auto-created reservation.
-
#commitment_info ⇒ Google::Apis::ComputeAlpha::FutureReservationCommitmentInfo
If not present, then FR will not deliver a new commitment or update an existing commitment.
-
#confidential_compute_type ⇒ String
Corresponds to the JSON property
confidentialComputeType. -
#creation_timestamp ⇒ String
Output only.
-
#deployment_type ⇒ String
Type of the deployment requested as part of future reservation.
-
#description ⇒ String
An optional description of this resource.
-
#enable_emergent_maintenance ⇒ Boolean
(also: #enable_emergent_maintenance?)
Indicates if this group of VMs have emergent maintenance enabled.
-
#id ⇒ Fixnum
Output only.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
The name of the resource, provided by the client when initially creating the resource.
-
#name_prefix ⇒ String
Name prefix for the reservations to be created at the time of delivery.
-
#params ⇒ Google::Apis::ComputeAlpha::FutureReservationParams
Additional future reservation params.
-
#planning_status ⇒ String
Planning state before being submitted for evaluation Corresponds to the JSON property
planningStatus. -
#protection_tier ⇒ String
Protection tier for the workload.
-
#reservation_mode ⇒ String
The reservation mode which determines reservation-termination behavior and expected pricing.
-
#reservation_name ⇒ String
Name of reservations where the capacity is provisioned at the time of delivery of future reservations.
-
#scheduling_type ⇒ String
Maintenance information for this reservation Corresponds to the JSON property
schedulingType. -
#self_link ⇒ String
Output only.
-
#self_link_with_id ⇒ String
Output only.
-
#share_settings ⇒ Google::Apis::ComputeAlpha::ShareSettings
The share setting for reservations and sole tenancy node groups.
-
#specific_reservation_required ⇒ Boolean
(also: #specific_reservation_required?)
Indicates whether the auto-created reservation can be consumed by VMs with affinity for "any" reservation.
-
#specific_sku_properties ⇒ Google::Apis::ComputeAlpha::FutureReservationSpecificSkuProperties
Future Reservation configuration to indicate instance properties and total count.
-
#status ⇒ Google::Apis::ComputeAlpha::FutureReservationStatus
[Output only] Represents status related to the future reservation.
-
#time_window ⇒ Google::Apis::ComputeAlpha::FutureReservationTimeWindow
Time window for this Future Reservation.
-
#zone ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FutureReservation
constructor
A new instance of FutureReservation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FutureReservation
Returns a new instance of FutureReservation.
16875 16876 16877 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 16875 def initialize(**args) update!(**args) end |
Instance Attribute Details
#advanced_deployment_control ⇒ Google::Apis::ComputeAlpha::ReservationAdvancedDeploymentControl
Advance control for cluster management, applicable only to DENSE deployment
type reservations.
Corresponds to the JSON property advancedDeploymentControl
16688 16689 16690 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 16688 def advanced_deployment_control @advanced_deployment_control end |
#aggregate_reservation ⇒ Google::Apis::ComputeAlpha::AllocationAggregateReservation
This reservation type is specified by total resource amounts (e.g. total
count of CPUs) and can account for multiple instance SKUs. In other words,
one can create instances of varying shapes against this reservation.
Corresponds to the JSON property aggregateReservation
16695 16696 16697 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 16695 def aggregate_reservation @aggregate_reservation end |
#auto_created_reservations_delete_time ⇒ String
Future timestamp when the FR auto-created reservations will be deleted by
Compute Engine. Format of this field must be a valid
href="https://www.ietf.org/rfc/rfc3339.txt">RFC3339 value.
Corresponds to the JSON property autoCreatedReservationsDeleteTime
16702 16703 16704 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 16702 def auto_created_reservations_delete_time @auto_created_reservations_delete_time end |
#auto_created_reservations_duration ⇒ Google::Apis::ComputeAlpha::Duration
A Duration represents a fixed-length span of time represented
as a count of seconds and fractions of seconds at nanosecond
resolution. It is independent of any calendar and concepts like "day"
or "month". Range is approximately 10,000 years.
Corresponds to the JSON property autoCreatedReservationsDuration
16710 16711 16712 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 16710 def auto_created_reservations_duration @auto_created_reservations_duration end |
#auto_delete_auto_created_reservations ⇒ Boolean Also known as: auto_delete_auto_created_reservations?
Setting for enabling or disabling automatic deletion for auto-created
reservation. If set to true, auto-created reservations will be
deleted at Future Reservation's end time (default) or at user's defined
timestamp if any of the
[auto_created_reservations_delete_time, auto_created_reservations_duration]
values is specified.
For keeping auto-created reservation indefinitely, this value should be set
to false.
Corresponds to the JSON property autoDeleteAutoCreatedReservations
16722 16723 16724 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 16722 def auto_delete_auto_created_reservations @auto_delete_auto_created_reservations end |
#commitment_info ⇒ Google::Apis::ComputeAlpha::FutureReservationCommitmentInfo
If not present, then FR will not deliver a new commitment or update an
existing commitment.
Corresponds to the JSON property commitmentInfo
16729 16730 16731 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 16729 def commitment_info @commitment_info end |
#confidential_compute_type ⇒ String
Corresponds to the JSON property confidentialComputeType
16734 16735 16736 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 16734 def confidential_compute_type @confidential_compute_type end |
#creation_timestamp ⇒ String
Output only. [Output Only] The creation timestamp for this future reservation
inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
16741 16742 16743 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 16741 def @creation_timestamp end |
#deployment_type ⇒ String
Type of the deployment requested as part of future reservation.
Corresponds to the JSON property deploymentType
16746 16747 16748 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 16746 def deployment_type @deployment_type end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the future reservation.
Corresponds to the JSON property description
16752 16753 16754 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 16752 def description @description end |
#enable_emergent_maintenance ⇒ Boolean Also known as: enable_emergent_maintenance?
Indicates if this group of VMs have emergent maintenance enabled.
Corresponds to the JSON property enableEmergentMaintenance
16757 16758 16759 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 16757 def enable_emergent_maintenance @enable_emergent_maintenance end |
#id ⇒ Fixnum
Output only. [Output Only] A unique identifier for this future reservation.
The server
defines this identifier.
Corresponds to the JSON property id
16765 16766 16767 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 16765 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#
futureReservation for future reservations.
Corresponds to the JSON property kind
16771 16772 16773 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 16771 def kind @kind end |
#name ⇒ String
The name of the resource, provided by the client when initially creating
the resource. The resource name must be 1-63 characters long, and comply
withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must be
a dash, lowercase letter, or digit, except the last character, which cannot
be a dash.
Corresponds to the JSON property name
16783 16784 16785 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 16783 def name @name end |
#name_prefix ⇒ String
Name prefix for the reservations to be created at the time of
delivery. The name prefix must comply with RFC1035.
Maximum allowed length for name prefix is 20. Automatically created
reservations name format will be -date-####.
Corresponds to the JSON property namePrefix
16791 16792 16793 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 16791 def name_prefix @name_prefix end |
#params ⇒ Google::Apis::ComputeAlpha::FutureReservationParams
Additional future reservation params.
Corresponds to the JSON property params
16796 16797 16798 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 16796 def params @params end |
#planning_status ⇒ String
Planning state before being submitted for evaluation
Corresponds to the JSON property planningStatus
16801 16802 16803 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 16801 def planning_status @planning_status end |
#protection_tier ⇒ String
Protection tier for the workload.
Corresponds to the JSON property protectionTier
16806 16807 16808 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 16806 def protection_tier @protection_tier end |
#reservation_mode ⇒ String
The reservation mode which determines reservation-termination behavior and
expected pricing.
Corresponds to the JSON property reservationMode
16812 16813 16814 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 16812 def reservation_mode @reservation_mode end |
#reservation_name ⇒ String
Name of reservations where the capacity is provisioned at the time of
delivery of future reservations. If the reservation with the given name
does not exist already, it is created automatically at the time of Approval
with INACTIVE state till specified start-time. Either provide the
reservation_name or a name_prefix.
Corresponds to the JSON property reservationName
16821 16822 16823 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 16821 def reservation_name @reservation_name end |
#scheduling_type ⇒ String
Maintenance information for this reservation
Corresponds to the JSON property schedulingType
16826 16827 16828 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 16826 def scheduling_type @scheduling_type end |
#self_link ⇒ String
Output only. [Output Only] Server-defined fully-qualified URL for this
resource.
Corresponds to the JSON property selfLink
16832 16833 16834 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 16832 def self_link @self_link end |
#self_link_with_id ⇒ String
Output only. [Output Only] Server-defined URL for this resource with the
resource id.
Corresponds to the JSON property selfLinkWithId
16838 16839 16840 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 16838 def self_link_with_id @self_link_with_id end |
#share_settings ⇒ Google::Apis::ComputeAlpha::ShareSettings
The share setting for reservations and sole tenancy node groups.
Corresponds to the JSON property shareSettings
16843 16844 16845 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 16843 def share_settings @share_settings end |
#specific_reservation_required ⇒ Boolean Also known as: specific_reservation_required?
Indicates whether the auto-created reservation can be consumed by VMs with
affinity for "any" reservation. If the field is set, then only VMs that
target the reservation by name can consume from the delivered reservation.
Corresponds to the JSON property specificReservationRequired
16850 16851 16852 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 16850 def specific_reservation_required @specific_reservation_required end |
#specific_sku_properties ⇒ Google::Apis::ComputeAlpha::FutureReservationSpecificSkuProperties
Future Reservation configuration to indicate instance properties and
total count.
Corresponds to the JSON property specificSkuProperties
16857 16858 16859 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 16857 def specific_sku_properties @specific_sku_properties end |
#status ⇒ Google::Apis::ComputeAlpha::FutureReservationStatus
[Output only] Represents status related to the future reservation.
Corresponds to the JSON property status
16862 16863 16864 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 16862 def status @status end |
#time_window ⇒ Google::Apis::ComputeAlpha::FutureReservationTimeWindow
Time window for this Future Reservation.
Corresponds to the JSON property timeWindow
16867 16868 16869 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 16867 def time_window @time_window end |
#zone ⇒ String
Output only. [Output Only] URL of the Zone where this future reservation
resides.
Corresponds to the JSON property zone
16873 16874 16875 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 16873 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
16880 16881 16882 16883 16884 16885 16886 16887 16888 16889 16890 16891 16892 16893 16894 16895 16896 16897 16898 16899 16900 16901 16902 16903 16904 16905 16906 16907 16908 16909 16910 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 16880 def update!(**args) @advanced_deployment_control = args[:advanced_deployment_control] if args.key?(:advanced_deployment_control) @aggregate_reservation = args[:aggregate_reservation] if args.key?(:aggregate_reservation) @auto_created_reservations_delete_time = args[:auto_created_reservations_delete_time] if args.key?(:auto_created_reservations_delete_time) @auto_created_reservations_duration = args[:auto_created_reservations_duration] if args.key?(:auto_created_reservations_duration) @auto_delete_auto_created_reservations = args[:auto_delete_auto_created_reservations] if args.key?(:auto_delete_auto_created_reservations) @commitment_info = args[:commitment_info] if args.key?(:commitment_info) @confidential_compute_type = args[:confidential_compute_type] if args.key?(:confidential_compute_type) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @deployment_type = args[:deployment_type] if args.key?(:deployment_type) @description = args[:description] if args.key?(:description) @enable_emergent_maintenance = args[:enable_emergent_maintenance] if args.key?(:enable_emergent_maintenance) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @name_prefix = args[:name_prefix] if args.key?(:name_prefix) @params = args[:params] if args.key?(:params) @planning_status = args[:planning_status] if args.key?(:planning_status) @protection_tier = args[:protection_tier] if args.key?(:protection_tier) @reservation_mode = args[:reservation_mode] if args.key?(:reservation_mode) @reservation_name = args[:reservation_name] if args.key?(:reservation_name) @scheduling_type = args[:scheduling_type] if args.key?(:scheduling_type) @self_link = args[:self_link] if args.key?(:self_link) @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id) @share_settings = args[:share_settings] if args.key?(:share_settings) @specific_reservation_required = args[:specific_reservation_required] if args.key?(:specific_reservation_required) @specific_sku_properties = args[:specific_sku_properties] if args.key?(:specific_sku_properties) @status = args[:status] if args.key?(:status) @time_window = args[:time_window] if args.key?(:time_window) @zone = args[:zone] if args.key?(:zone) end |