Class: Google::Apis::ComputeAlpha::FutureReservation

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FutureReservation

Returns a new instance of FutureReservation.



16698
16699
16700
# File 'lib/google/apis/compute_alpha/classes.rb', line 16698

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#advanced_deployment_controlGoogle::Apis::ComputeAlpha::ReservationAdvancedDeploymentControl

Advance control for cluster management, applicable only to DENSE deployment type reservations. Corresponds to the JSON property advancedDeploymentControl



16511
16512
16513
# File 'lib/google/apis/compute_alpha/classes.rb', line 16511

def advanced_deployment_control
  @advanced_deployment_control
end

#aggregate_reservationGoogle::Apis::ComputeAlpha::AllocationAggregateReservation

This reservation type is specified by total resource amounts (e.g. total count of CPUs) and can account for multiple instance SKUs. In other words, one can create instances of varying shapes against this reservation. Corresponds to the JSON property aggregateReservation



16518
16519
16520
# File 'lib/google/apis/compute_alpha/classes.rb', line 16518

def aggregate_reservation
  @aggregate_reservation
end

#auto_created_reservations_delete_timeString

Future timestamp when the FR auto-created reservations will be deleted by Compute Engine. Format of this field must be a valid href="https://www.ietf.org/rfc/rfc3339.txt">RFC3339 value. Corresponds to the JSON property autoCreatedReservationsDeleteTime

Returns:

  • (String)


16525
16526
16527
# File 'lib/google/apis/compute_alpha/classes.rb', line 16525

def auto_created_reservations_delete_time
  @auto_created_reservations_delete_time
end

#auto_created_reservations_durationGoogle::Apis::ComputeAlpha::Duration

A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution. It is independent of any calendar and concepts like "day" or "month". Range is approximately 10,000 years. Corresponds to the JSON property autoCreatedReservationsDuration



16533
16534
16535
# File 'lib/google/apis/compute_alpha/classes.rb', line 16533

def auto_created_reservations_duration
  @auto_created_reservations_duration
end

#auto_delete_auto_created_reservationsBoolean Also known as: auto_delete_auto_created_reservations?

Setting for enabling or disabling automatic deletion for auto-created reservation. If set to true, auto-created reservations will be deleted at Future Reservation's end time (default) or at user's defined timestamp if any of the [auto_created_reservations_delete_time, auto_created_reservations_duration] values is specified. For keeping auto-created reservation indefinitely, this value should be set to false. Corresponds to the JSON property autoDeleteAutoCreatedReservations

Returns:

  • (Boolean)


16545
16546
16547
# File 'lib/google/apis/compute_alpha/classes.rb', line 16545

def auto_delete_auto_created_reservations
  @auto_delete_auto_created_reservations
end

#commitment_infoGoogle::Apis::ComputeAlpha::FutureReservationCommitmentInfo

If not present, then FR will not deliver a new commitment or update an existing commitment. Corresponds to the JSON property commitmentInfo



16552
16553
16554
# File 'lib/google/apis/compute_alpha/classes.rb', line 16552

def commitment_info
  @commitment_info
end

#confidential_compute_typeString

Corresponds to the JSON property confidentialComputeType

Returns:

  • (String)


16557
16558
16559
# File 'lib/google/apis/compute_alpha/classes.rb', line 16557

def confidential_compute_type
  @confidential_compute_type
end

#creation_timestampString

Output only. [Output Only] The creation timestamp for this future reservation inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


16564
16565
16566
# File 'lib/google/apis/compute_alpha/classes.rb', line 16564

def creation_timestamp
  @creation_timestamp
end

#deployment_typeString

Type of the deployment requested as part of future reservation. Corresponds to the JSON property deploymentType

Returns:

  • (String)


16569
16570
16571
# File 'lib/google/apis/compute_alpha/classes.rb', line 16569

def deployment_type
  @deployment_type
end

#descriptionString

An optional description of this resource. Provide this property when you create the future reservation. Corresponds to the JSON property description

Returns:

  • (String)


16575
16576
16577
# File 'lib/google/apis/compute_alpha/classes.rb', line 16575

def description
  @description
end

#enable_emergent_maintenanceBoolean Also known as: enable_emergent_maintenance?

Indicates if this group of VMs have emergent maintenance enabled. Corresponds to the JSON property enableEmergentMaintenance

Returns:

  • (Boolean)


16580
16581
16582
# File 'lib/google/apis/compute_alpha/classes.rb', line 16580

def enable_emergent_maintenance
  @enable_emergent_maintenance
end

#idFixnum

Output only. [Output Only] A unique identifier for this future reservation. The server defines this identifier. Corresponds to the JSON property id

Returns:

  • (Fixnum)


16588
16589
16590
# File 'lib/google/apis/compute_alpha/classes.rb', line 16588

def id
  @id
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# futureReservation for future reservations. Corresponds to the JSON property kind

Returns:

  • (String)


16594
16595
16596
# File 'lib/google/apis/compute_alpha/classes.rb', line 16594

def kind
  @kind
end

#nameString

The name of the resource, provided by the client when initially creating the resource. The resource name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


16606
16607
16608
# File 'lib/google/apis/compute_alpha/classes.rb', line 16606

def name
  @name
end

#name_prefixString

Name prefix for the reservations to be created at the time of delivery. The name prefix must comply with RFC1035. Maximum allowed length for name prefix is 20. Automatically created reservations name format will be -date-####. Corresponds to the JSON property namePrefix

Returns:

  • (String)


16614
16615
16616
# File 'lib/google/apis/compute_alpha/classes.rb', line 16614

def name_prefix
  @name_prefix
end

#paramsGoogle::Apis::ComputeAlpha::FutureReservationParams

Additional future reservation params. Corresponds to the JSON property params



16619
16620
16621
# File 'lib/google/apis/compute_alpha/classes.rb', line 16619

def params
  @params
end

#planning_statusString

Planning state before being submitted for evaluation Corresponds to the JSON property planningStatus

Returns:

  • (String)


16624
16625
16626
# File 'lib/google/apis/compute_alpha/classes.rb', line 16624

def planning_status
  @planning_status
end

#protection_tierString

Protection tier for the workload. Corresponds to the JSON property protectionTier

Returns:

  • (String)


16629
16630
16631
# File 'lib/google/apis/compute_alpha/classes.rb', line 16629

def protection_tier
  @protection_tier
end

#reservation_modeString

The reservation mode which determines reservation-termination behavior and expected pricing. Corresponds to the JSON property reservationMode

Returns:

  • (String)


16635
16636
16637
# File 'lib/google/apis/compute_alpha/classes.rb', line 16635

def reservation_mode
  @reservation_mode
end

#reservation_nameString

Name of reservations where the capacity is provisioned at the time of delivery of future reservations. If the reservation with the given name does not exist already, it is created automatically at the time of Approval with INACTIVE state till specified start-time. Either provide the reservation_name or a name_prefix. Corresponds to the JSON property reservationName

Returns:

  • (String)


16644
16645
16646
# File 'lib/google/apis/compute_alpha/classes.rb', line 16644

def reservation_name
  @reservation_name
end

#scheduling_typeString

Maintenance information for this reservation Corresponds to the JSON property schedulingType

Returns:

  • (String)


16649
16650
16651
# File 'lib/google/apis/compute_alpha/classes.rb', line 16649

def scheduling_type
  @scheduling_type
end

Output only. [Output Only] Server-defined fully-qualified URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


16655
16656
16657
# File 'lib/google/apis/compute_alpha/classes.rb', line 16655

def self_link
  @self_link
end

Output only. [Output Only] Server-defined URL for this resource with the resource id. Corresponds to the JSON property selfLinkWithId

Returns:

  • (String)


16661
16662
16663
# File 'lib/google/apis/compute_alpha/classes.rb', line 16661

def self_link_with_id
  @self_link_with_id
end

#share_settingsGoogle::Apis::ComputeAlpha::ShareSettings

The share setting for reservations and sole tenancy node groups. Corresponds to the JSON property shareSettings



16666
16667
16668
# File 'lib/google/apis/compute_alpha/classes.rb', line 16666

def share_settings
  @share_settings
end

#specific_reservation_requiredBoolean Also known as: specific_reservation_required?

Indicates whether the auto-created reservation can be consumed by VMs with affinity for "any" reservation. If the field is set, then only VMs that target the reservation by name can consume from the delivered reservation. Corresponds to the JSON property specificReservationRequired

Returns:

  • (Boolean)


16673
16674
16675
# File 'lib/google/apis/compute_alpha/classes.rb', line 16673

def specific_reservation_required
  @specific_reservation_required
end

#specific_sku_propertiesGoogle::Apis::ComputeAlpha::FutureReservationSpecificSkuProperties

Future Reservation configuration to indicate instance properties and total count. Corresponds to the JSON property specificSkuProperties



16680
16681
16682
# File 'lib/google/apis/compute_alpha/classes.rb', line 16680

def specific_sku_properties
  @specific_sku_properties
end

#statusGoogle::Apis::ComputeAlpha::FutureReservationStatus

[Output only] Represents status related to the future reservation. Corresponds to the JSON property status



16685
16686
16687
# File 'lib/google/apis/compute_alpha/classes.rb', line 16685

def status
  @status
end

#time_windowGoogle::Apis::ComputeAlpha::FutureReservationTimeWindow

Time window for this Future Reservation. Corresponds to the JSON property timeWindow



16690
16691
16692
# File 'lib/google/apis/compute_alpha/classes.rb', line 16690

def time_window
  @time_window
end

#zoneString

Output only. [Output Only] URL of the Zone where this future reservation resides. Corresponds to the JSON property zone

Returns:

  • (String)


16696
16697
16698
# File 'lib/google/apis/compute_alpha/classes.rb', line 16696

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



16703
16704
16705
16706
16707
16708
16709
16710
16711
16712
16713
16714
16715
16716
16717
16718
16719
16720
16721
16722
16723
16724
16725
16726
16727
16728
16729
16730
16731
16732
16733
# File 'lib/google/apis/compute_alpha/classes.rb', line 16703

def update!(**args)
  @advanced_deployment_control = args[:advanced_deployment_control] if args.key?(:advanced_deployment_control)
  @aggregate_reservation = args[:aggregate_reservation] if args.key?(:aggregate_reservation)
  @auto_created_reservations_delete_time = args[:auto_created_reservations_delete_time] if args.key?(:auto_created_reservations_delete_time)
  @auto_created_reservations_duration = args[:auto_created_reservations_duration] if args.key?(:auto_created_reservations_duration)
  @auto_delete_auto_created_reservations = args[:auto_delete_auto_created_reservations] if args.key?(:auto_delete_auto_created_reservations)
  @commitment_info = args[:commitment_info] if args.key?(:commitment_info)
  @confidential_compute_type = args[:confidential_compute_type] if args.key?(:confidential_compute_type)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @deployment_type = args[:deployment_type] if args.key?(:deployment_type)
  @description = args[:description] if args.key?(:description)
  @enable_emergent_maintenance = args[:enable_emergent_maintenance] if args.key?(:enable_emergent_maintenance)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @name_prefix = args[:name_prefix] if args.key?(:name_prefix)
  @params = args[:params] if args.key?(:params)
  @planning_status = args[:planning_status] if args.key?(:planning_status)
  @protection_tier = args[:protection_tier] if args.key?(:protection_tier)
  @reservation_mode = args[:reservation_mode] if args.key?(:reservation_mode)
  @reservation_name = args[:reservation_name] if args.key?(:reservation_name)
  @scheduling_type = args[:scheduling_type] if args.key?(:scheduling_type)
  @self_link = args[:self_link] if args.key?(:self_link)
  @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id)
  @share_settings = args[:share_settings] if args.key?(:share_settings)
  @specific_reservation_required = args[:specific_reservation_required] if args.key?(:specific_reservation_required)
  @specific_sku_properties = args[:specific_sku_properties] if args.key?(:specific_sku_properties)
  @status = args[:status] if args.key?(:status)
  @time_window = args[:time_window] if args.key?(:time_window)
  @zone = args[:zone] if args.key?(:zone)
end