Class: Google::Apis::ComputeAlpha::FutureReservationCommitmentInfo

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FutureReservationCommitmentInfo

Returns a new instance of FutureReservationCommitmentInfo.



16759
16760
16761
# File 'lib/google/apis/compute_alpha/classes.rb', line 16759

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#commitment_nameString

name of the commitment where capacity is being delivered to. Corresponds to the JSON property commitmentName

Returns:

  • (String)


16743
16744
16745
# File 'lib/google/apis/compute_alpha/classes.rb', line 16743

def commitment_name
  @commitment_name
end

#commitment_planString

Indicates if a Commitment needs to be created as part of FR delivery. If this field is not present, then no commitment needs to be created. Corresponds to the JSON property commitmentPlan

Returns:

  • (String)


16750
16751
16752
# File 'lib/google/apis/compute_alpha/classes.rb', line 16750

def commitment_plan
  @commitment_plan
end

#previous_commitment_termsString

Only applicable if FR is delivering to the same reservation. If set, all parent commitments will be extended to match the end date of the plan for this commitment. Corresponds to the JSON property previousCommitmentTerms

Returns:

  • (String)


16757
16758
16759
# File 'lib/google/apis/compute_alpha/classes.rb', line 16757

def previous_commitment_terms
  @previous_commitment_terms
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



16764
16765
16766
16767
16768
# File 'lib/google/apis/compute_alpha/classes.rb', line 16764

def update!(**args)
  @commitment_name = args[:commitment_name] if args.key?(:commitment_name)
  @commitment_plan = args[:commitment_plan] if args.key?(:commitment_plan)
  @previous_commitment_terms = args[:previous_commitment_terms] if args.key?(:previous_commitment_terms)
end