Class: Google::Apis::ComputeAlpha::FutureReservationCommitmentInfo
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::FutureReservationCommitmentInfo
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#commitment_name ⇒ String
name of the commitment where capacity is being delivered to.
-
#commitment_plan ⇒ String
Indicates if a Commitment needs to be created as part of FR delivery.
-
#previous_commitment_terms ⇒ String
Only applicable if FR is delivering to the same reservation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FutureReservationCommitmentInfo
constructor
A new instance of FutureReservationCommitmentInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FutureReservationCommitmentInfo
Returns a new instance of FutureReservationCommitmentInfo.
16782 16783 16784 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 16782 def initialize(**args) update!(**args) end |
Instance Attribute Details
#commitment_name ⇒ String
name of the commitment where capacity is being delivered to.
Corresponds to the JSON property commitmentName
16766 16767 16768 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 16766 def commitment_name @commitment_name end |
#commitment_plan ⇒ String
Indicates if a Commitment needs to be created as part of FR delivery. If
this field is not present, then no
commitment needs to be created.
Corresponds to the JSON property commitmentPlan
16773 16774 16775 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 16773 def commitment_plan @commitment_plan end |
#previous_commitment_terms ⇒ String
Only applicable if FR is delivering to the same reservation. If set, all
parent commitments will be extended to match the end date of the plan for
this commitment.
Corresponds to the JSON property previousCommitmentTerms
16780 16781 16782 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 16780 def previous_commitment_terms @previous_commitment_terms end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
16787 16788 16789 16790 16791 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 16787 def update!(**args) @commitment_name = args[:commitment_name] if args.key?(:commitment_name) @commitment_plan = args[:commitment_plan] if args.key?(:commitment_plan) @previous_commitment_terms = args[:previous_commitment_terms] if args.key?(:previous_commitment_terms) end |