Class: Google::Apis::ComputeAlpha::FutureReservationParams
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::FutureReservationParams
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Additional future reservation params.
Instance Attribute Summary collapse
-
#resource_manager_tags ⇒ Hash<String,String>
Input only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FutureReservationParams
constructor
A new instance of FutureReservationParams.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FutureReservationParams
Returns a new instance of FutureReservationParams.
16810 16811 16812 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 16810 def initialize(**args) update!(**args) end |
Instance Attribute Details
#resource_manager_tags ⇒ Hash<String,String>
Input only. Resource manager tags to be bound to the future reservation. Tag
keys and
values have the same definition as resource
manager tags. Keys and values can be either in numeric format,
such as tagKeys/tag_key_idand `tagValues/`tag_value_id or in
namespaced format such as org_id|project_id`/`tag_key_short_name and
tag_value_short_name. The field is ignored (both PUT &
PATCH) when empty.
Corresponds to the JSON property resourceManagerTags
16808 16809 16810 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 16808 def @resource_manager_tags end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
16815 16816 16817 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 16815 def update!(**args) @resource_manager_tags = args[:resource_manager_tags] if args.key?(:resource_manager_tags) end |