Class: Google::Apis::ComputeAlpha::FutureReservationStatus
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::FutureReservationStatus
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
[Output only] Represents status related to the future reservation.
Instance Attribute Summary collapse
-
#amendment_status ⇒ String
Output only.
-
#auto_created_reservations ⇒ Array<String>
Output only.
-
#exapool_provisioned_capacity_gb ⇒ Google::Apis::ComputeAlpha::StoragePoolExapoolProvisionedCapacityGb
Exapool provisioned capacities for each SKU type Corresponds to the JSON property
exapoolProvisionedCapacityGb. -
#existing_matching_usage_info ⇒ Google::Apis::ComputeAlpha::FutureReservationStatusExistingMatchingUsageInfo
[Output Only] Represents the existing matching usage for the future reservation.
-
#fulfilled_count ⇒ Fixnum
Output only.
-
#last_known_good_state ⇒ Google::Apis::ComputeAlpha::FutureReservationStatusLastKnownGoodState
The state that the future reservation will be reverted to should the amendment be declined.
-
#lock_time ⇒ String
Output only.
-
#procurement_status ⇒ String
Output only.
-
#specific_sku_properties ⇒ Google::Apis::ComputeAlpha::FutureReservationStatusSpecificSkuProperties
Properties to be set for the Future Reservation.
-
#storage_pool_provisioned_capacity ⇒ Google::Apis::ComputeAlpha::FutureReservationStoragePoolProvisionedCapacity
Storage pool provisioned capacities for each SKU type.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FutureReservationStatus
constructor
A new instance of FutureReservationStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FutureReservationStatus
Returns a new instance of FutureReservationStatus.
18022 18023 18024 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 18022 def initialize(**args) update!(**args) end |
Instance Attribute Details
#amendment_status ⇒ String
Output only. [Output Only] The current status of the requested amendment.
Corresponds to the JSON property amendmentStatus
17965 17966 17967 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 17965 def amendment_status @amendment_status end |
#auto_created_reservations ⇒ Array<String>
Output only. Fully qualified urls of the automatically created reservations at
start_time.
Corresponds to the JSON property autoCreatedReservations
17971 17972 17973 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 17971 def auto_created_reservations @auto_created_reservations end |
#exapool_provisioned_capacity_gb ⇒ Google::Apis::ComputeAlpha::StoragePoolExapoolProvisionedCapacityGb
Exapool provisioned capacities for each SKU type
Corresponds to the JSON property exapoolProvisionedCapacityGb
17976 17977 17978 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 17976 def exapool_provisioned_capacity_gb @exapool_provisioned_capacity_gb end |
#existing_matching_usage_info ⇒ Google::Apis::ComputeAlpha::FutureReservationStatusExistingMatchingUsageInfo
[Output Only] Represents the existing matching usage for the future
reservation.
Corresponds to the JSON property existingMatchingUsageInfo
17982 17983 17984 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 17982 def existing_matching_usage_info @existing_matching_usage_info end |
#fulfilled_count ⇒ Fixnum
Output only. This count indicates the fulfilled capacity so far. This is set
during
"PROVISIONING" state. This count also includes capacity delivered as part
of existing matching reservations.
Corresponds to the JSON property fulfilledCount
17990 17991 17992 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 17990 def fulfilled_count @fulfilled_count end |
#last_known_good_state ⇒ Google::Apis::ComputeAlpha::FutureReservationStatusLastKnownGoodState
The state that the future reservation will be reverted to should the
amendment be declined.
Corresponds to the JSON property lastKnownGoodState
17996 17997 17998 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 17996 def last_known_good_state @last_known_good_state end |
#lock_time ⇒ String
Output only. Time when Future Reservation would become LOCKED, after which no
modifications to Future Reservation will be allowed. Applicable only
after the Future Reservation is in the APPROVED state. The lock_time is
an RFC3339 string. The procurement_status will transition to PROCURING
state at this time.
Corresponds to the JSON property lockTime
18005 18006 18007 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 18005 def lock_time @lock_time end |
#procurement_status ⇒ String
Output only. Current state of this Future Reservation
Corresponds to the JSON property procurementStatus
18010 18011 18012 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 18010 def procurement_status @procurement_status end |
#specific_sku_properties ⇒ Google::Apis::ComputeAlpha::FutureReservationStatusSpecificSkuProperties
Properties to be set for the Future Reservation.
Corresponds to the JSON property specificSkuProperties
18015 18016 18017 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 18015 def specific_sku_properties @specific_sku_properties end |
#storage_pool_provisioned_capacity ⇒ Google::Apis::ComputeAlpha::FutureReservationStoragePoolProvisionedCapacity
Storage pool provisioned capacities for each SKU type.
Corresponds to the JSON property storagePoolProvisionedCapacity
18020 18021 18022 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 18020 def storage_pool_provisioned_capacity @storage_pool_provisioned_capacity end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
18027 18028 18029 18030 18031 18032 18033 18034 18035 18036 18037 18038 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 18027 def update!(**args) @amendment_status = args[:amendment_status] if args.key?(:amendment_status) @auto_created_reservations = args[:auto_created_reservations] if args.key?(:auto_created_reservations) @exapool_provisioned_capacity_gb = args[:exapool_provisioned_capacity_gb] if args.key?(:exapool_provisioned_capacity_gb) @existing_matching_usage_info = args[:existing_matching_usage_info] if args.key?(:existing_matching_usage_info) @fulfilled_count = args[:fulfilled_count] if args.key?(:fulfilled_count) @last_known_good_state = args[:last_known_good_state] if args.key?(:last_known_good_state) @lock_time = args[:lock_time] if args.key?(:lock_time) @procurement_status = args[:procurement_status] if args.key?(:procurement_status) @specific_sku_properties = args[:specific_sku_properties] if args.key?(:specific_sku_properties) @storage_pool_provisioned_capacity = args[:storage_pool_provisioned_capacity] if args.key?(:storage_pool_provisioned_capacity) end |