Class: Google::Apis::ComputeAlpha::FutureReservationStatus

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

[Output only] Represents status related to the future reservation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FutureReservationStatus

Returns a new instance of FutureReservationStatus.



17891
17892
17893
# File 'lib/google/apis/compute_alpha/classes.rb', line 17891

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#amendment_statusString

Output only. [Output Only] The current status of the requested amendment. Corresponds to the JSON property amendmentStatus

Returns:

  • (String)


17834
17835
17836
# File 'lib/google/apis/compute_alpha/classes.rb', line 17834

def amendment_status
  @amendment_status
end

#auto_created_reservationsArray<String>

Output only. Fully qualified urls of the automatically created reservations at start_time. Corresponds to the JSON property autoCreatedReservations

Returns:

  • (Array<String>)


17840
17841
17842
# File 'lib/google/apis/compute_alpha/classes.rb', line 17840

def auto_created_reservations
  @auto_created_reservations
end

#exapool_provisioned_capacity_gbGoogle::Apis::ComputeAlpha::StoragePoolExapoolProvisionedCapacityGb

Exapool provisioned capacities for each SKU type Corresponds to the JSON property exapoolProvisionedCapacityGb



17845
17846
17847
# File 'lib/google/apis/compute_alpha/classes.rb', line 17845

def exapool_provisioned_capacity_gb
  @exapool_provisioned_capacity_gb
end

#existing_matching_usage_infoGoogle::Apis::ComputeAlpha::FutureReservationStatusExistingMatchingUsageInfo

[Output Only] Represents the existing matching usage for the future reservation. Corresponds to the JSON property existingMatchingUsageInfo



17851
17852
17853
# File 'lib/google/apis/compute_alpha/classes.rb', line 17851

def existing_matching_usage_info
  @existing_matching_usage_info
end

#fulfilled_countFixnum

Output only. This count indicates the fulfilled capacity so far. This is set during "PROVISIONING" state. This count also includes capacity delivered as part of existing matching reservations. Corresponds to the JSON property fulfilledCount

Returns:

  • (Fixnum)


17859
17860
17861
# File 'lib/google/apis/compute_alpha/classes.rb', line 17859

def fulfilled_count
  @fulfilled_count
end

#last_known_good_stateGoogle::Apis::ComputeAlpha::FutureReservationStatusLastKnownGoodState

The state that the future reservation will be reverted to should the amendment be declined. Corresponds to the JSON property lastKnownGoodState



17865
17866
17867
# File 'lib/google/apis/compute_alpha/classes.rb', line 17865

def last_known_good_state
  @last_known_good_state
end

#lock_timeString

Output only. Time when Future Reservation would become LOCKED, after which no modifications to Future Reservation will be allowed. Applicable only after the Future Reservation is in the APPROVED state. The lock_time is an RFC3339 string. The procurement_status will transition to PROCURING state at this time. Corresponds to the JSON property lockTime

Returns:

  • (String)


17874
17875
17876
# File 'lib/google/apis/compute_alpha/classes.rb', line 17874

def lock_time
  @lock_time
end

#procurement_statusString

Output only. Current state of this Future Reservation Corresponds to the JSON property procurementStatus

Returns:

  • (String)


17879
17880
17881
# File 'lib/google/apis/compute_alpha/classes.rb', line 17879

def procurement_status
  @procurement_status
end

#specific_sku_propertiesGoogle::Apis::ComputeAlpha::FutureReservationStatusSpecificSkuProperties

Properties to be set for the Future Reservation. Corresponds to the JSON property specificSkuProperties



17884
17885
17886
# File 'lib/google/apis/compute_alpha/classes.rb', line 17884

def specific_sku_properties
  @specific_sku_properties
end

#storage_pool_provisioned_capacityGoogle::Apis::ComputeAlpha::FutureReservationStoragePoolProvisionedCapacity

Storage pool provisioned capacities for each SKU type. Corresponds to the JSON property storagePoolProvisionedCapacity



17889
17890
17891
# File 'lib/google/apis/compute_alpha/classes.rb', line 17889

def storage_pool_provisioned_capacity
  @storage_pool_provisioned_capacity
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



17896
17897
17898
17899
17900
17901
17902
17903
17904
17905
17906
17907
# File 'lib/google/apis/compute_alpha/classes.rb', line 17896

def update!(**args)
  @amendment_status = args[:amendment_status] if args.key?(:amendment_status)
  @auto_created_reservations = args[:auto_created_reservations] if args.key?(:auto_created_reservations)
  @exapool_provisioned_capacity_gb = args[:exapool_provisioned_capacity_gb] if args.key?(:exapool_provisioned_capacity_gb)
  @existing_matching_usage_info = args[:existing_matching_usage_info] if args.key?(:existing_matching_usage_info)
  @fulfilled_count = args[:fulfilled_count] if args.key?(:fulfilled_count)
  @last_known_good_state = args[:last_known_good_state] if args.key?(:last_known_good_state)
  @lock_time = args[:lock_time] if args.key?(:lock_time)
  @procurement_status = args[:procurement_status] if args.key?(:procurement_status)
  @specific_sku_properties = args[:specific_sku_properties] if args.key?(:specific_sku_properties)
  @storage_pool_provisioned_capacity = args[:storage_pool_provisioned_capacity] if args.key?(:storage_pool_provisioned_capacity)
end