Class: Google::Apis::ComputeAlpha::FutureReservationStatus
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::FutureReservationStatus
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
[Output only] Represents status related to the future reservation.
Instance Attribute Summary collapse
-
#amendment_status ⇒ String
Output only.
-
#auto_created_reservations ⇒ Array<String>
Output only.
-
#existing_matching_usage_info ⇒ Google::Apis::ComputeAlpha::FutureReservationStatusExistingMatchingUsageInfo
[Output Only] Represents the existing matching usage for the future reservation.
-
#fulfilled_count ⇒ Fixnum
Output only.
-
#last_known_good_state ⇒ Google::Apis::ComputeAlpha::FutureReservationStatusLastKnownGoodState
The state that the future reservation will be reverted to should the amendment be declined.
-
#lock_time ⇒ String
Output only.
-
#procurement_status ⇒ String
Output only.
-
#specific_sku_properties ⇒ Google::Apis::ComputeAlpha::FutureReservationStatusSpecificSkuProperties
Properties to be set for the Future Reservation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FutureReservationStatus
constructor
A new instance of FutureReservationStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FutureReservationStatus
Returns a new instance of FutureReservationStatus.
16885 16886 16887 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 16885 def initialize(**args) update!(**args) end |
Instance Attribute Details
#amendment_status ⇒ String
Output only. [Output Only] The current status of the requested amendment.
Corresponds to the JSON property amendmentStatus
16838 16839 16840 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 16838 def amendment_status @amendment_status end |
#auto_created_reservations ⇒ Array<String>
Output only. Fully qualified urls of the automatically created reservations at
start_time.
Corresponds to the JSON property autoCreatedReservations
16844 16845 16846 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 16844 def auto_created_reservations @auto_created_reservations end |
#existing_matching_usage_info ⇒ Google::Apis::ComputeAlpha::FutureReservationStatusExistingMatchingUsageInfo
[Output Only] Represents the existing matching usage for the future
reservation.
Corresponds to the JSON property existingMatchingUsageInfo
16850 16851 16852 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 16850 def existing_matching_usage_info @existing_matching_usage_info end |
#fulfilled_count ⇒ Fixnum
Output only. This count indicates the fulfilled capacity so far. This is set
during
"PROVISIONING" state. This count also includes capacity delivered as part
of existing matching reservations.
Corresponds to the JSON property fulfilledCount
16858 16859 16860 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 16858 def fulfilled_count @fulfilled_count end |
#last_known_good_state ⇒ Google::Apis::ComputeAlpha::FutureReservationStatusLastKnownGoodState
The state that the future reservation will be reverted to should the
amendment be declined.
Corresponds to the JSON property lastKnownGoodState
16864 16865 16866 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 16864 def last_known_good_state @last_known_good_state end |
#lock_time ⇒ String
Output only. Time when Future Reservation would become LOCKED, after which no
modifications to Future Reservation will be allowed. Applicable only
after the Future Reservation is in the APPROVED state. The lock_time is
an RFC3339 string. The procurement_status will transition to PROCURING
state at this time.
Corresponds to the JSON property lockTime
16873 16874 16875 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 16873 def lock_time @lock_time end |
#procurement_status ⇒ String
Output only. Current state of this Future Reservation
Corresponds to the JSON property procurementStatus
16878 16879 16880 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 16878 def procurement_status @procurement_status end |
#specific_sku_properties ⇒ Google::Apis::ComputeAlpha::FutureReservationStatusSpecificSkuProperties
Properties to be set for the Future Reservation.
Corresponds to the JSON property specificSkuProperties
16883 16884 16885 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 16883 def specific_sku_properties @specific_sku_properties end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
16890 16891 16892 16893 16894 16895 16896 16897 16898 16899 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 16890 def update!(**args) @amendment_status = args[:amendment_status] if args.key?(:amendment_status) @auto_created_reservations = args[:auto_created_reservations] if args.key?(:auto_created_reservations) @existing_matching_usage_info = args[:existing_matching_usage_info] if args.key?(:existing_matching_usage_info) @fulfilled_count = args[:fulfilled_count] if args.key?(:fulfilled_count) @last_known_good_state = args[:last_known_good_state] if args.key?(:last_known_good_state) @lock_time = args[:lock_time] if args.key?(:lock_time) @procurement_status = args[:procurement_status] if args.key?(:procurement_status) @specific_sku_properties = args[:specific_sku_properties] if args.key?(:specific_sku_properties) end |