Class: Google::Apis::ComputeAlpha::FutureReservationStatusLastKnownGoodState
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::FutureReservationStatusLastKnownGoodState
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
The state that the future reservation will be reverted to should the amendment be declined.
Instance Attribute Summary collapse
-
#description ⇒ String
Output only.
-
#existing_matching_usage_info ⇒ Google::Apis::ComputeAlpha::FutureReservationStatusExistingMatchingUsageInfo
[Output Only] Represents the existing matching usage for the future reservation.
-
#future_reservation_specs ⇒ Google::Apis::ComputeAlpha::FutureReservationStatusLastKnownGoodStateFutureReservationSpecs
The properties of the last known good state for the Future Reservation.
-
#lock_time ⇒ String
Output only.
-
#name_prefix ⇒ String
Output only.
-
#procurement_status ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FutureReservationStatusLastKnownGoodState
constructor
A new instance of FutureReservationStatusLastKnownGoodState.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FutureReservationStatusLastKnownGoodState
Returns a new instance of FutureReservationStatusLastKnownGoodState.
16993 16994 16995 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 16993 def initialize(**args) update!(**args) end |
Instance Attribute Details
#description ⇒ String
Output only. [Output Only] The description of the FutureReservation before an
amendment was requested.
Corresponds to the JSON property description
16961 16962 16963 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 16961 def description @description end |
#existing_matching_usage_info ⇒ Google::Apis::ComputeAlpha::FutureReservationStatusExistingMatchingUsageInfo
[Output Only] Represents the existing matching usage for the future
reservation.
Corresponds to the JSON property existingMatchingUsageInfo
16967 16968 16969 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 16967 def existing_matching_usage_info @existing_matching_usage_info end |
#future_reservation_specs ⇒ Google::Apis::ComputeAlpha::FutureReservationStatusLastKnownGoodStateFutureReservationSpecs
The properties of the last known good state for the Future Reservation.
Corresponds to the JSON property futureReservationSpecs
16972 16973 16974 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 16972 def future_reservation_specs @future_reservation_specs end |
#lock_time ⇒ String
Output only. [Output Only] The lock time of the FutureReservation before an
amendment was requested.
Corresponds to the JSON property lockTime
16978 16979 16980 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 16978 def lock_time @lock_time end |
#name_prefix ⇒ String
Output only. [Output Only] The name prefix of the Future Reservation before an
amendment was requested.
Corresponds to the JSON property namePrefix
16984 16985 16986 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 16984 def name_prefix @name_prefix end |
#procurement_status ⇒ String
Output only. [Output Only] The status of the last known good state for the
Future
Reservation.
Corresponds to the JSON property procurementStatus
16991 16992 16993 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 16991 def procurement_status @procurement_status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
16998 16999 17000 17001 17002 17003 17004 17005 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 16998 def update!(**args) @description = args[:description] if args.key?(:description) @existing_matching_usage_info = args[:existing_matching_usage_info] if args.key?(:existing_matching_usage_info) @future_reservation_specs = args[:future_reservation_specs] if args.key?(:future_reservation_specs) @lock_time = args[:lock_time] if args.key?(:lock_time) @name_prefix = args[:name_prefix] if args.key?(:name_prefix) @procurement_status = args[:procurement_status] if args.key?(:procurement_status) end |