Class: Google::Apis::ComputeAlpha::FutureReservationStatusLastKnownGoodState
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::FutureReservationStatusLastKnownGoodState
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
The state that the future reservation will be reverted to should the amendment be declined.
Instance Attribute Summary collapse
-
#description ⇒ String
Output only.
-
#existing_matching_usage_info ⇒ Google::Apis::ComputeAlpha::FutureReservationStatusExistingMatchingUsageInfo
[Output Only] Represents the existing matching usage for the future reservation.
-
#future_reservation_specs ⇒ Google::Apis::ComputeAlpha::FutureReservationStatusLastKnownGoodStateFutureReservationSpecs
The properties of the last known good state for the Future Reservation.
-
#lock_time ⇒ String
Output only.
-
#name_prefix ⇒ String
Output only.
-
#procurement_status ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FutureReservationStatusLastKnownGoodState
constructor
A new instance of FutureReservationStatusLastKnownGoodState.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FutureReservationStatusLastKnownGoodState
Returns a new instance of FutureReservationStatusLastKnownGoodState.
16658 16659 16660 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 16658 def initialize(**args) update!(**args) end |
Instance Attribute Details
#description ⇒ String
Output only. [Output Only] The description of the FutureReservation before an
amendment was requested.
Corresponds to the JSON property description
16626 16627 16628 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 16626 def description @description end |
#existing_matching_usage_info ⇒ Google::Apis::ComputeAlpha::FutureReservationStatusExistingMatchingUsageInfo
[Output Only] Represents the existing matching usage for the future
reservation.
Corresponds to the JSON property existingMatchingUsageInfo
16632 16633 16634 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 16632 def existing_matching_usage_info @existing_matching_usage_info end |
#future_reservation_specs ⇒ Google::Apis::ComputeAlpha::FutureReservationStatusLastKnownGoodStateFutureReservationSpecs
The properties of the last known good state for the Future Reservation.
Corresponds to the JSON property futureReservationSpecs
16637 16638 16639 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 16637 def future_reservation_specs @future_reservation_specs end |
#lock_time ⇒ String
Output only. [Output Only] The lock time of the FutureReservation before an
amendment was requested.
Corresponds to the JSON property lockTime
16643 16644 16645 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 16643 def lock_time @lock_time end |
#name_prefix ⇒ String
Output only. [Output Only] The name prefix of the Future Reservation before an
amendment was requested.
Corresponds to the JSON property namePrefix
16649 16650 16651 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 16649 def name_prefix @name_prefix end |
#procurement_status ⇒ String
Output only. [Output Only] The status of the last known good state for the
Future
Reservation.
Corresponds to the JSON property procurementStatus
16656 16657 16658 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 16656 def procurement_status @procurement_status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
16663 16664 16665 16666 16667 16668 16669 16670 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 16663 def update!(**args) @description = args[:description] if args.key?(:description) @existing_matching_usage_info = args[:existing_matching_usage_info] if args.key?(:existing_matching_usage_info) @future_reservation_specs = args[:future_reservation_specs] if args.key?(:future_reservation_specs) @lock_time = args[:lock_time] if args.key?(:lock_time) @name_prefix = args[:name_prefix] if args.key?(:name_prefix) @procurement_status = args[:procurement_status] if args.key?(:procurement_status) end |