Class: Google::Apis::ComputeAlpha::FutureReservationStatusLastKnownGoodStateFutureReservationSpecs

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

The properties of the last known good state for the Future Reservation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FutureReservationStatusLastKnownGoodStateFutureReservationSpecs

Returns a new instance of FutureReservationStatusLastKnownGoodStateFutureReservationSpecs.



17190
17191
17192
# File 'lib/google/apis/compute_alpha/classes.rb', line 17190

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#share_settingsGoogle::Apis::ComputeAlpha::ShareSettings

The share setting for reservations and sole tenancy node groups. Corresponds to the JSON property shareSettings



17177
17178
17179
# File 'lib/google/apis/compute_alpha/classes.rb', line 17177

def share_settings
  @share_settings
end

#specific_sku_propertiesGoogle::Apis::ComputeAlpha::FutureReservationSpecificSkuProperties

Output only. [Output Only] The previous instance related properties of the Future Reservation. Corresponds to the JSON property specificSkuProperties



17183
17184
17185
# File 'lib/google/apis/compute_alpha/classes.rb', line 17183

def specific_sku_properties
  @specific_sku_properties
end

#time_windowGoogle::Apis::ComputeAlpha::FutureReservationTimeWindow

Output only. [Output Only] The previous time window of the Future Reservation. Corresponds to the JSON property timeWindow



17188
17189
17190
# File 'lib/google/apis/compute_alpha/classes.rb', line 17188

def time_window
  @time_window
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



17195
17196
17197
17198
17199
# File 'lib/google/apis/compute_alpha/classes.rb', line 17195

def update!(**args)
  @share_settings = args[:share_settings] if args.key?(:share_settings)
  @specific_sku_properties = args[:specific_sku_properties] if args.key?(:specific_sku_properties)
  @time_window = args[:time_window] if args.key?(:time_window)
end