Class: Google::Apis::ComputeAlpha::FutureReservationStoragePoolProvisionedCapacity

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Storage pool provisioned capacities for each SKU type.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FutureReservationStoragePoolProvisionedCapacity

Returns a new instance of FutureReservationStoragePoolProvisionedCapacity.



18097
18098
18099
# File 'lib/google/apis/compute_alpha/classes.rb', line 18097

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#pool_provisioned_capacity_gbFixnum

Size of the storage pool in GiB. Corresponds to the JSON property poolProvisionedCapacityGb

Returns:

  • (Fixnum)


18083
18084
18085
# File 'lib/google/apis/compute_alpha/classes.rb', line 18083

def pool_provisioned_capacity_gb
  @pool_provisioned_capacity_gb
end

#pool_provisioned_iopsFixnum

Provisioned IOPS of the storage pool. Only relevant if the storage pool type is hyperdisk-balanced. Corresponds to the JSON property poolProvisionedIops

Returns:

  • (Fixnum)


18089
18090
18091
# File 'lib/google/apis/compute_alpha/classes.rb', line 18089

def pool_provisioned_iops
  @pool_provisioned_iops
end

#pool_provisioned_throughputFixnum

Provisioned throughput of the storage pool in MiB/s. Only relevant if the storage pool type is hyperdisk-balanced or hyperdisk-throughput. Corresponds to the JSON property poolProvisionedThroughput

Returns:

  • (Fixnum)


18095
18096
18097
# File 'lib/google/apis/compute_alpha/classes.rb', line 18095

def pool_provisioned_throughput
  @pool_provisioned_throughput
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



18102
18103
18104
18105
18106
# File 'lib/google/apis/compute_alpha/classes.rb', line 18102

def update!(**args)
  @pool_provisioned_capacity_gb = args[:pool_provisioned_capacity_gb] if args.key?(:pool_provisioned_capacity_gb)
  @pool_provisioned_iops = args[:pool_provisioned_iops] if args.key?(:pool_provisioned_iops)
  @pool_provisioned_throughput = args[:pool_provisioned_throughput] if args.key?(:pool_provisioned_throughput)
end