Class: Google::Apis::ComputeAlpha::FutureReservationStoragePoolProvisionedCapacity

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Storage pool provisioned capacities for each SKU type.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FutureReservationStoragePoolProvisionedCapacity

Returns a new instance of FutureReservationStoragePoolProvisionedCapacity.



17934
17935
17936
# File 'lib/google/apis/compute_alpha/classes.rb', line 17934

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#pool_provisioned_capacity_gbFixnum

Size of the storage pool in GiB. Corresponds to the JSON property poolProvisionedCapacityGb

Returns:

  • (Fixnum)


17920
17921
17922
# File 'lib/google/apis/compute_alpha/classes.rb', line 17920

def pool_provisioned_capacity_gb
  @pool_provisioned_capacity_gb
end

#pool_provisioned_iopsFixnum

Provisioned IOPS of the storage pool. Only relevant if the storage pool type is hyperdisk-balanced. Corresponds to the JSON property poolProvisionedIops

Returns:

  • (Fixnum)


17926
17927
17928
# File 'lib/google/apis/compute_alpha/classes.rb', line 17926

def pool_provisioned_iops
  @pool_provisioned_iops
end

#pool_provisioned_throughputFixnum

Provisioned throughput of the storage pool in MiB/s. Only relevant if the storage pool type is hyperdisk-balanced or hyperdisk-throughput. Corresponds to the JSON property poolProvisionedThroughput

Returns:

  • (Fixnum)


17932
17933
17934
# File 'lib/google/apis/compute_alpha/classes.rb', line 17932

def pool_provisioned_throughput
  @pool_provisioned_throughput
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



17939
17940
17941
17942
17943
# File 'lib/google/apis/compute_alpha/classes.rb', line 17939

def update!(**args)
  @pool_provisioned_capacity_gb = args[:pool_provisioned_capacity_gb] if args.key?(:pool_provisioned_capacity_gb)
  @pool_provisioned_iops = args[:pool_provisioned_iops] if args.key?(:pool_provisioned_iops)
  @pool_provisioned_throughput = args[:pool_provisioned_throughput] if args.key?(:pool_provisioned_throughput)
end