Class: Google::Apis::ComputeAlpha::FutureReservationTimeWindow
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::FutureReservationTimeWindow
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#duration ⇒ Google::Apis::ComputeAlpha::Duration
A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution.
-
#end_time ⇒ String
Corresponds to the JSON property
endTime. -
#start_time ⇒ String
Start time of the Future Reservation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FutureReservationTimeWindow
constructor
A new instance of FutureReservationTimeWindow.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FutureReservationTimeWindow
Returns a new instance of FutureReservationTimeWindow.
18132 18133 18134 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 18132 def initialize(**args) update!(**args) end |
Instance Attribute Details
#duration ⇒ Google::Apis::ComputeAlpha::Duration
A Duration represents a fixed-length span of time represented
as a count of seconds and fractions of seconds at nanosecond
resolution. It is independent of any calendar and concepts like "day"
or "month". Range is approximately 10,000 years.
Corresponds to the JSON property duration
18119 18120 18121 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 18119 def duration @duration end |
#end_time ⇒ String
Corresponds to the JSON property endTime
18124 18125 18126 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 18124 def end_time @end_time end |
#start_time ⇒ String
Start time of the Future Reservation. The start_time is an RFC3339
string.
Corresponds to the JSON property startTime
18130 18131 18132 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 18130 def start_time @start_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
18137 18138 18139 18140 18141 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 18137 def update!(**args) @duration = args[:duration] if args.key?(:duration) @end_time = args[:end_time] if args.key?(:end_time) @start_time = args[:start_time] if args.key?(:start_time) end |