Class: Google::Apis::ComputeAlpha::FutureReservationTimeWindow
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::FutureReservationTimeWindow
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#duration ⇒ Google::Apis::ComputeAlpha::Duration
A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution.
-
#end_time ⇒ String
Corresponds to the JSON property
endTime. -
#start_time ⇒ String
Start time of the Future Reservation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FutureReservationTimeWindow
constructor
A new instance of FutureReservationTimeWindow.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FutureReservationTimeWindow
Returns a new instance of FutureReservationTimeWindow.
17083 17084 17085 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 17083 def initialize(**args) update!(**args) end |
Instance Attribute Details
#duration ⇒ Google::Apis::ComputeAlpha::Duration
A Duration represents a fixed-length span of time represented
as a count of seconds and fractions of seconds at nanosecond
resolution. It is independent of any calendar and concepts like "day"
or "month". Range is approximately 10,000 years.
Corresponds to the JSON property duration
17070 17071 17072 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 17070 def duration @duration end |
#end_time ⇒ String
Corresponds to the JSON property endTime
17075 17076 17077 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 17075 def end_time @end_time end |
#start_time ⇒ String
Start time of the Future Reservation. The start_time is an RFC3339
string.
Corresponds to the JSON property startTime
17081 17082 17083 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 17081 def start_time @start_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
17088 17089 17090 17091 17092 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 17088 def update!(**args) @duration = args[:duration] if args.key?(:duration) @end_time = args[:end_time] if args.key?(:end_time) @start_time = args[:start_time] if args.key?(:start_time) end |