Class: Google::Apis::ComputeAlpha::FutureReservationTimeWindow
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::FutureReservationTimeWindow
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#duration ⇒ Google::Apis::ComputeAlpha::Duration
A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution.
-
#end_time ⇒ String
Corresponds to the JSON property
endTime. -
#start_time ⇒ String
Start time of the Future Reservation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FutureReservationTimeWindow
constructor
A new instance of FutureReservationTimeWindow.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FutureReservationTimeWindow
Returns a new instance of FutureReservationTimeWindow.
16748 16749 16750 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 16748 def initialize(**args) update!(**args) end |
Instance Attribute Details
#duration ⇒ Google::Apis::ComputeAlpha::Duration
A Duration represents a fixed-length span of time represented
as a count of seconds and fractions of seconds at nanosecond
resolution. It is independent of any calendar and concepts like "day"
or "month". Range is approximately 10,000 years.
Corresponds to the JSON property duration
16735 16736 16737 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 16735 def duration @duration end |
#end_time ⇒ String
Corresponds to the JSON property endTime
16740 16741 16742 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 16740 def end_time @end_time end |
#start_time ⇒ String
Start time of the Future Reservation. The start_time is an RFC3339
string.
Corresponds to the JSON property startTime
16746 16747 16748 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 16746 def start_time @start_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
16753 16754 16755 16756 16757 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 16753 def update!(**args) @duration = args[:duration] if args.key?(:duration) @end_time = args[:end_time] if args.key?(:end_time) @start_time = args[:start_time] if args.key?(:start_time) end |