Class: Google::Apis::ComputeAlpha::FutureReservationsAggregatedListResponse
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::FutureReservationsAggregatedListResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Contains a list of future reservations.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::FutureReservationsScopedList>
A list of Future reservation resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::FutureReservationsAggregatedListResponse::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FutureReservationsAggregatedListResponse
constructor
A new instance of FutureReservationsAggregatedListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FutureReservationsAggregatedListResponse
Returns a new instance of FutureReservationsAggregatedListResponse.
18195 18196 18197 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 18195 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
18151 18152 18153 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 18151 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
18156 18157 18158 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 18156 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::FutureReservationsScopedList>
A list of Future reservation resources.
Corresponds to the JSON property items
18161 18162 18163 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 18161 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
futureReservationsAggregatedListResponse for future
resevation aggregated list response.
Corresponds to the JSON property kind
18168 18169 18170 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 18168 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
18178 18179 18180 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 18178 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
18183 18184 18185 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 18183 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
18188 18189 18190 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 18188 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::FutureReservationsAggregatedListResponse::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
18193 18194 18195 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 18193 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
18200 18201 18202 18203 18204 18205 18206 18207 18208 18209 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 18200 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |