Class: Google::Apis::ComputeAlpha::FutureReservationsAggregatedListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of future reservations.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FutureReservationsAggregatedListResponse

Returns a new instance of FutureReservationsAggregatedListResponse.



18032
18033
18034
# File 'lib/google/apis/compute_alpha/classes.rb', line 18032

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


17988
17989
17990
# File 'lib/google/apis/compute_alpha/classes.rb', line 17988

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


17993
17994
17995
# File 'lib/google/apis/compute_alpha/classes.rb', line 17993

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::FutureReservationsScopedList>

A list of Future reservation resources. Corresponds to the JSON property items



17998
17999
18000
# File 'lib/google/apis/compute_alpha/classes.rb', line 17998

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# futureReservationsAggregatedListResponse for future resevation aggregated list response. Corresponds to the JSON property kind

Returns:

  • (String)


18005
18006
18007
# File 'lib/google/apis/compute_alpha/classes.rb', line 18005

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


18015
18016
18017
# File 'lib/google/apis/compute_alpha/classes.rb', line 18015

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


18020
18021
18022
# File 'lib/google/apis/compute_alpha/classes.rb', line 18020

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


18025
18026
18027
# File 'lib/google/apis/compute_alpha/classes.rb', line 18025

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::FutureReservationsAggregatedListResponse::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



18030
18031
18032
# File 'lib/google/apis/compute_alpha/classes.rb', line 18030

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



18037
18038
18039
18040
18041
18042
18043
18044
18045
18046
# File 'lib/google/apis/compute_alpha/classes.rb', line 18037

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end