Class: Google::Apis::ComputeAlpha::FutureReservationsAggregatedListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of future reservations.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FutureReservationsAggregatedListResponse

Returns a new instance of FutureReservationsAggregatedListResponse.



17308
17309
17310
# File 'lib/google/apis/compute_alpha/classes.rb', line 17308

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


17264
17265
17266
# File 'lib/google/apis/compute_alpha/classes.rb', line 17264

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


17269
17270
17271
# File 'lib/google/apis/compute_alpha/classes.rb', line 17269

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::FutureReservationsScopedList>

A list of Future reservation resources. Corresponds to the JSON property items



17274
17275
17276
# File 'lib/google/apis/compute_alpha/classes.rb', line 17274

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# futureReservationsAggregatedListResponse for future resevation aggregated list response. Corresponds to the JSON property kind

Returns:

  • (String)


17281
17282
17283
# File 'lib/google/apis/compute_alpha/classes.rb', line 17281

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


17291
17292
17293
# File 'lib/google/apis/compute_alpha/classes.rb', line 17291

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


17296
17297
17298
# File 'lib/google/apis/compute_alpha/classes.rb', line 17296

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


17301
17302
17303
# File 'lib/google/apis/compute_alpha/classes.rb', line 17301

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::FutureReservationsAggregatedListResponse::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



17306
17307
17308
# File 'lib/google/apis/compute_alpha/classes.rb', line 17306

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



17313
17314
17315
17316
17317
17318
17319
17320
17321
17322
# File 'lib/google/apis/compute_alpha/classes.rb', line 17313

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end