Class: Google::Apis::ComputeAlpha::FutureReservationsAggregatedListResponse
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::FutureReservationsAggregatedListResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Contains a list of future reservations.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::FutureReservationsScopedList>
A list of Future reservation resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::FutureReservationsAggregatedListResponse::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FutureReservationsAggregatedListResponse
constructor
A new instance of FutureReservationsAggregatedListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FutureReservationsAggregatedListResponse
Returns a new instance of FutureReservationsAggregatedListResponse.
17123 17124 17125 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 17123 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
17079 17080 17081 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 17079 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
17084 17085 17086 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 17084 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::FutureReservationsScopedList>
A list of Future reservation resources.
Corresponds to the JSON property items
17089 17090 17091 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 17089 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
futureReservationsAggregatedListResponse for future
resevation aggregated list response.
Corresponds to the JSON property kind
17096 17097 17098 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 17096 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
17106 17107 17108 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 17106 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
17111 17112 17113 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 17111 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
17116 17117 17118 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 17116 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::FutureReservationsAggregatedListResponse::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
17121 17122 17123 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 17121 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
17128 17129 17130 17131 17132 17133 17134 17135 17136 17137 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 17128 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |