Class: Google::Apis::ComputeAlpha::FutureReservationsAggregatedListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of future reservations.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FutureReservationsAggregatedListResponse

Returns a new instance of FutureReservationsAggregatedListResponse.



17140
17141
17142
# File 'lib/google/apis/compute_alpha/classes.rb', line 17140

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


17096
17097
17098
# File 'lib/google/apis/compute_alpha/classes.rb', line 17096

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


17101
17102
17103
# File 'lib/google/apis/compute_alpha/classes.rb', line 17101

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::FutureReservationsScopedList>

A list of Future reservation resources. Corresponds to the JSON property items



17106
17107
17108
# File 'lib/google/apis/compute_alpha/classes.rb', line 17106

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# futureReservationsAggregatedListResponse for future resevation aggregated list response. Corresponds to the JSON property kind

Returns:

  • (String)


17113
17114
17115
# File 'lib/google/apis/compute_alpha/classes.rb', line 17113

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


17123
17124
17125
# File 'lib/google/apis/compute_alpha/classes.rb', line 17123

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


17128
17129
17130
# File 'lib/google/apis/compute_alpha/classes.rb', line 17128

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


17133
17134
17135
# File 'lib/google/apis/compute_alpha/classes.rb', line 17133

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::FutureReservationsAggregatedListResponse::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



17138
17139
17140
# File 'lib/google/apis/compute_alpha/classes.rb', line 17138

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



17145
17146
17147
17148
17149
17150
17151
17152
17153
17154
# File 'lib/google/apis/compute_alpha/classes.rb', line 17145

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end