Class: Google::Apis::ComputeAlpha::FutureReservationsListResponse
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::FutureReservationsListResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] The unique identifier for the resource.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::FutureReservation>
[Output Only] A list of future reservation resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::FutureReservationsListResponse::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FutureReservationsListResponse
constructor
A new instance of FutureReservationsListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FutureReservationsListResponse
Returns a new instance of FutureReservationsListResponse.
17439 17440 17441 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 17439 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
17394 17395 17396 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 17394 def etag @etag end |
#id ⇒ String
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
17400 17401 17402 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 17400 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::FutureReservation>
[Output Only] A list of future reservation resources.
Corresponds to the JSON property items
17405 17406 17407 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 17405 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource.Alwayscompute#
FutureReservationsListResponse for lists of
reservations
Corresponds to the JSON property kind
17412 17413 17414 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 17412 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
17422 17423 17424 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 17422 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
17427 17428 17429 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 17427 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
17432 17433 17434 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 17432 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::FutureReservationsListResponse::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
17437 17438 17439 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 17437 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
17444 17445 17446 17447 17448 17449 17450 17451 17452 17453 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 17444 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |