Class: Google::Apis::ComputeAlpha::FutureReservationsListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FutureReservationsListResponse

Returns a new instance of FutureReservationsListResponse.



17285
17286
17287
# File 'lib/google/apis/compute_alpha/classes.rb', line 17285

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


17240
17241
17242
# File 'lib/google/apis/compute_alpha/classes.rb', line 17240

def etag
  @etag
end

#idString

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


17246
17247
17248
# File 'lib/google/apis/compute_alpha/classes.rb', line 17246

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::FutureReservation>

[Output Only] A list of future reservation resources. Corresponds to the JSON property items



17251
17252
17253
# File 'lib/google/apis/compute_alpha/classes.rb', line 17251

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource.Alwayscompute# FutureReservationsListResponse for lists of reservations Corresponds to the JSON property kind

Returns:

  • (String)


17258
17259
17260
# File 'lib/google/apis/compute_alpha/classes.rb', line 17258

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


17268
17269
17270
# File 'lib/google/apis/compute_alpha/classes.rb', line 17268

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


17273
17274
17275
# File 'lib/google/apis/compute_alpha/classes.rb', line 17273

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


17278
17279
17280
# File 'lib/google/apis/compute_alpha/classes.rb', line 17278

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::FutureReservationsListResponse::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



17283
17284
17285
# File 'lib/google/apis/compute_alpha/classes.rb', line 17283

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



17290
17291
17292
17293
17294
17295
17296
17297
17298
17299
# File 'lib/google/apis/compute_alpha/classes.rb', line 17290

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end