Class: Google::Apis::ComputeAlpha::FutureReservationsListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FutureReservationsListResponse

Returns a new instance of FutureReservationsListResponse.



16950
16951
16952
# File 'lib/google/apis/compute_alpha/classes.rb', line 16950

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


16905
16906
16907
# File 'lib/google/apis/compute_alpha/classes.rb', line 16905

def etag
  @etag
end

#idString

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


16911
16912
16913
# File 'lib/google/apis/compute_alpha/classes.rb', line 16911

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::FutureReservation>

[Output Only] A list of future reservation resources. Corresponds to the JSON property items



16916
16917
16918
# File 'lib/google/apis/compute_alpha/classes.rb', line 16916

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource.Alwayscompute# FutureReservationsListResponse for lists of reservations Corresponds to the JSON property kind

Returns:

  • (String)


16923
16924
16925
# File 'lib/google/apis/compute_alpha/classes.rb', line 16923

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


16933
16934
16935
# File 'lib/google/apis/compute_alpha/classes.rb', line 16933

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


16938
16939
16940
# File 'lib/google/apis/compute_alpha/classes.rb', line 16938

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


16943
16944
16945
# File 'lib/google/apis/compute_alpha/classes.rb', line 16943

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::FutureReservationsListResponse::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



16948
16949
16950
# File 'lib/google/apis/compute_alpha/classes.rb', line 16948

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



16955
16956
16957
16958
16959
16960
16961
16962
16963
16964
# File 'lib/google/apis/compute_alpha/classes.rb', line 16955

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end