Class: Google::Apis::ComputeAlpha::FutureResourcesRecommendation
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::FutureResourcesRecommendation
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Recommendation for single resources specification, to be created in the future.
Instance Attribute Summary collapse
-
#end_time ⇒ String
Corresponds to the JSON property
endTime. -
#location ⇒ String
The advised location for resource usage.
-
#other_locations ⇒ Hash<String,Google::Apis::ComputeAlpha::FutureResourcesRecommendationOtherLocation>
List of locations in the request scope that were not recommended.
-
#recommendation_id ⇒ String
Unique id of the recommendation, a UUID string generated by the API.
-
#recommendation_type ⇒ String
Type of recommendation.
-
#start_time ⇒ String
Corresponds to the JSON property
startTime.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FutureResourcesRecommendation
constructor
A new instance of FutureResourcesRecommendation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FutureResourcesRecommendation
Returns a new instance of FutureResourcesRecommendation.
18558 18559 18560 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 18558 def initialize(**args) update!(**args) end |
Instance Attribute Details
#end_time ⇒ String
Corresponds to the JSON property endTime
18526 18527 18528 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 18526 def end_time @end_time end |
#location ⇒ String
The advised location for resource usage. When a zone, in format
'zones/'.
If not set, it means that no location is recommended - see
other_locations for details.
Corresponds to the JSON property location
18534 18535 18536 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 18534 def location @location end |
#other_locations ⇒ Hash<String,Google::Apis::ComputeAlpha::FutureResourcesRecommendationOtherLocation>
List of locations in the request scope that were not
recommended. Keys of the map are zones, in format 'zones/'.
The values are status information indicating the recommendation status.
Corresponds to the JSON property otherLocations
18541 18542 18543 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 18541 def other_locations @other_locations end |
#recommendation_id ⇒ String
Unique id of the recommendation, a UUID string generated by the API.
Corresponds to the JSON property recommendationId
18546 18547 18548 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 18546 def recommendation_id @recommendation_id end |
#recommendation_type ⇒ String
Type of recommendation. Currently only FUTURE_RESERVATION is supported.
Corresponds to the JSON property recommendationType
18551 18552 18553 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 18551 def recommendation_type @recommendation_type end |
#start_time ⇒ String
Corresponds to the JSON property startTime
18556 18557 18558 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 18556 def start_time @start_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
18563 18564 18565 18566 18567 18568 18569 18570 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 18563 def update!(**args) @end_time = args[:end_time] if args.key?(:end_time) @location = args[:location] if args.key?(:location) @other_locations = args[:other_locations] if args.key?(:other_locations) @recommendation_id = args[:recommendation_id] if args.key?(:recommendation_id) @recommendation_type = args[:recommendation_type] if args.key?(:recommendation_type) @start_time = args[:start_time] if args.key?(:start_time) end |