Class: Google::Apis::ComputeAlpha::FutureResourcesRecommendation

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Recommendation for single resources specification, to be created in the future.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FutureResourcesRecommendation

Returns a new instance of FutureResourcesRecommendation.



17503
17504
17505
# File 'lib/google/apis/compute_alpha/classes.rb', line 17503

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#end_timeString

Corresponds to the JSON property endTime

Returns:

  • (String)


17471
17472
17473
# File 'lib/google/apis/compute_alpha/classes.rb', line 17471

def end_time
  @end_time
end

#locationString

The advised location for resource usage. When a zone, in format 'zones/'. If not set, it means that no location is recommended - see other_locations for details. Corresponds to the JSON property location

Returns:

  • (String)


17479
17480
17481
# File 'lib/google/apis/compute_alpha/classes.rb', line 17479

def location
  @location
end

#other_locationsHash<String,Google::Apis::ComputeAlpha::FutureResourcesRecommendationOtherLocation>

List of locations in the request scope that were not recommended. Keys of the map are zones, in format 'zones/'. The values are status information indicating the recommendation status. Corresponds to the JSON property otherLocations



17486
17487
17488
# File 'lib/google/apis/compute_alpha/classes.rb', line 17486

def other_locations
  @other_locations
end

#recommendation_idString

Unique id of the recommendation, a UUID string generated by the API. Corresponds to the JSON property recommendationId

Returns:

  • (String)


17491
17492
17493
# File 'lib/google/apis/compute_alpha/classes.rb', line 17491

def recommendation_id
  @recommendation_id
end

#recommendation_typeString

Type of recommendation. Currently only FUTURE_RESERVATION is supported. Corresponds to the JSON property recommendationType

Returns:

  • (String)


17496
17497
17498
# File 'lib/google/apis/compute_alpha/classes.rb', line 17496

def recommendation_type
  @recommendation_type
end

#start_timeString

Corresponds to the JSON property startTime

Returns:

  • (String)


17501
17502
17503
# File 'lib/google/apis/compute_alpha/classes.rb', line 17501

def start_time
  @start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



17508
17509
17510
17511
17512
17513
17514
17515
# File 'lib/google/apis/compute_alpha/classes.rb', line 17508

def update!(**args)
  @end_time = args[:end_time] if args.key?(:end_time)
  @location = args[:location] if args.key?(:location)
  @other_locations = args[:other_locations] if args.key?(:other_locations)
  @recommendation_id = args[:recommendation_id] if args.key?(:recommendation_id)
  @recommendation_type = args[:recommendation_type] if args.key?(:recommendation_type)
  @start_time = args[:start_time] if args.key?(:start_time)
end