Class: Google::Apis::ComputeAlpha::FutureResourcesRecommendation
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::FutureResourcesRecommendation
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Recommendation for single resources specification, to be created in the future.
Instance Attribute Summary collapse
-
#end_time ⇒ String
Corresponds to the JSON property
endTime. -
#location ⇒ String
The advised location for resource usage.
-
#other_locations ⇒ Hash<String,Google::Apis::ComputeAlpha::FutureResourcesRecommendationOtherLocation>
List of locations in the request scope that were not recommended.
-
#recommendation_id ⇒ String
Unique id of the recommendation, a UUID string generated by the API.
-
#recommendation_type ⇒ String
Type of recommendation.
-
#start_time ⇒ String
Corresponds to the JSON property
startTime.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FutureResourcesRecommendation
constructor
A new instance of FutureResourcesRecommendation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FutureResourcesRecommendation
Returns a new instance of FutureResourcesRecommendation.
17509 17510 17511 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 17509 def initialize(**args) update!(**args) end |
Instance Attribute Details
#end_time ⇒ String
Corresponds to the JSON property endTime
17477 17478 17479 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 17477 def end_time @end_time end |
#location ⇒ String
The advised location for resource usage. When a zone, in format
'zones/'.
If not set, it means that no location is recommended - see
other_locations for details.
Corresponds to the JSON property location
17485 17486 17487 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 17485 def location @location end |
#other_locations ⇒ Hash<String,Google::Apis::ComputeAlpha::FutureResourcesRecommendationOtherLocation>
List of locations in the request scope that were not
recommended. Keys of the map are zones, in format 'zones/'.
The values are status information indicating the recommendation status.
Corresponds to the JSON property otherLocations
17492 17493 17494 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 17492 def other_locations @other_locations end |
#recommendation_id ⇒ String
Unique id of the recommendation, a UUID string generated by the API.
Corresponds to the JSON property recommendationId
17497 17498 17499 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 17497 def recommendation_id @recommendation_id end |
#recommendation_type ⇒ String
Type of recommendation. Currently only FUTURE_RESERVATION is supported.
Corresponds to the JSON property recommendationType
17502 17503 17504 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 17502 def recommendation_type @recommendation_type end |
#start_time ⇒ String
Corresponds to the JSON property startTime
17507 17508 17509 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 17507 def start_time @start_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
17514 17515 17516 17517 17518 17519 17520 17521 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 17514 def update!(**args) @end_time = args[:end_time] if args.key?(:end_time) @location = args[:location] if args.key?(:location) @other_locations = args[:other_locations] if args.key?(:other_locations) @recommendation_id = args[:recommendation_id] if args.key?(:recommendation_id) @recommendation_type = args[:recommendation_type] if args.key?(:recommendation_type) @start_time = args[:start_time] if args.key?(:start_time) end |