Class: Google::Apis::ComputeAlpha::FutureResourcesRecommendation
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::FutureResourcesRecommendation
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Recommendation for single resources specification, to be created in the future.
Instance Attribute Summary collapse
-
#end_time ⇒ String
Corresponds to the JSON property
endTime. -
#location ⇒ String
The advised location for resource usage.
-
#other_locations ⇒ Hash<String,Google::Apis::ComputeAlpha::FutureResourcesRecommendationOtherLocation>
List of locations in the request scope that were not recommended.
-
#recommendation_id ⇒ String
Unique id of the recommendation, a UUID string generated by the API.
-
#recommendation_type ⇒ String
Type of recommendation.
-
#start_time ⇒ String
Corresponds to the JSON property
startTime.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FutureResourcesRecommendation
constructor
A new instance of FutureResourcesRecommendation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FutureResourcesRecommendation
Returns a new instance of FutureResourcesRecommendation.
17174 17175 17176 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 17174 def initialize(**args) update!(**args) end |
Instance Attribute Details
#end_time ⇒ String
Corresponds to the JSON property endTime
17142 17143 17144 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 17142 def end_time @end_time end |
#location ⇒ String
The advised location for resource usage. When a zone, in format
'zones/'.
If not set, it means that no location is recommended - see
other_locations for details.
Corresponds to the JSON property location
17150 17151 17152 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 17150 def location @location end |
#other_locations ⇒ Hash<String,Google::Apis::ComputeAlpha::FutureResourcesRecommendationOtherLocation>
List of locations in the request scope that were not
recommended. Keys of the map are zones, in format 'zones/'.
The values are status information indicating the recommendation status.
Corresponds to the JSON property otherLocations
17157 17158 17159 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 17157 def other_locations @other_locations end |
#recommendation_id ⇒ String
Unique id of the recommendation, a UUID string generated by the API.
Corresponds to the JSON property recommendationId
17162 17163 17164 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 17162 def recommendation_id @recommendation_id end |
#recommendation_type ⇒ String
Type of recommendation. Currently only FUTURE_RESERVATION is supported.
Corresponds to the JSON property recommendationType
17167 17168 17169 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 17167 def recommendation_type @recommendation_type end |
#start_time ⇒ String
Corresponds to the JSON property startTime
17172 17173 17174 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 17172 def start_time @start_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
17179 17180 17181 17182 17183 17184 17185 17186 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 17179 def update!(**args) @end_time = args[:end_time] if args.key?(:end_time) @location = args[:location] if args.key?(:location) @other_locations = args[:other_locations] if args.key?(:other_locations) @recommendation_id = args[:recommendation_id] if args.key?(:recommendation_id) @recommendation_type = args[:recommendation_type] if args.key?(:recommendation_type) @start_time = args[:start_time] if args.key?(:start_time) end |