Class: Google::Apis::ComputeAlpha::FutureResourcesRecommendationOtherLocation

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Information about recommendation status for locations that were allowed but not used by the response.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FutureResourcesRecommendationOtherLocation

Returns a new instance of FutureResourcesRecommendationOtherLocation.



17542
17543
17544
# File 'lib/google/apis/compute_alpha/classes.rb', line 17542

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#detailsString

Details (human readable) describing the situation. For example, if status is CONDITION_NOT_MET, then details contain information about the parameters of the time window that did not meet the required conditions. Corresponds to the JSON property details

Returns:

  • (String)


17535
17536
17537
# File 'lib/google/apis/compute_alpha/classes.rb', line 17535

def details
  @details
end

#statusString

Status of recommendation in this location. Corresponds to the JSON property status

Returns:

  • (String)


17540
17541
17542
# File 'lib/google/apis/compute_alpha/classes.rb', line 17540

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



17547
17548
17549
17550
# File 'lib/google/apis/compute_alpha/classes.rb', line 17547

def update!(**args)
  @details = args[:details] if args.key?(:details)
  @status = args[:status] if args.key?(:status)
end