Class: Google::Apis::ComputeAlpha::FutureResourcesRecommendationOtherLocation

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Information about recommendation status for locations that were allowed but not used by the response.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FutureResourcesRecommendationOtherLocation

Returns a new instance of FutureResourcesRecommendationOtherLocation.



17207
17208
17209
# File 'lib/google/apis/compute_alpha/classes.rb', line 17207

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#detailsString

Details (human readable) describing the situation. For example, if status is CONDITION_NOT_MET, then details contain information about the parameters of the time window that did not meet the required conditions. Corresponds to the JSON property details

Returns:

  • (String)


17200
17201
17202
# File 'lib/google/apis/compute_alpha/classes.rb', line 17200

def details
  @details
end

#statusString

Status of recommendation in this location. Corresponds to the JSON property status

Returns:

  • (String)


17205
17206
17207
# File 'lib/google/apis/compute_alpha/classes.rb', line 17205

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



17212
17213
17214
17215
# File 'lib/google/apis/compute_alpha/classes.rb', line 17212

def update!(**args)
  @details = args[:details] if args.key?(:details)
  @status = args[:status] if args.key?(:status)
end