Class: Google::Apis::ComputeAlpha::FutureResourcesSpecSpecificSkuResources
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::FutureResourcesSpecSpecificSkuResources
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#instance_count ⇒ Fixnum
Size of the request, in instance count.
-
#local_ssd_partitions ⇒ Array<Google::Apis::ComputeAlpha::FutureResourcesSpecLocalSsdPartition>
Local SSD partitions.
-
#machine_type ⇒ String
The machine type to use for instances that will use the reservation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FutureResourcesSpecSpecificSkuResources
constructor
A new instance of FutureResourcesSpecSpecificSkuResources.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FutureResourcesSpecSpecificSkuResources
Returns a new instance of FutureResourcesSpecSpecificSkuResources.
17716 17717 17718 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 17716 def initialize(**args) update!(**args) end |
Instance Attribute Details
#instance_count ⇒ Fixnum
Size of the request, in instance count.
Corresponds to the JSON property instanceCount
17699 17700 17701 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 17699 def instance_count @instance_count end |
#local_ssd_partitions ⇒ Array<Google::Apis::ComputeAlpha::FutureResourcesSpecLocalSsdPartition>
Local SSD partitions. You do not have to include SSD partitions that
are built in the machine type.
Corresponds to the JSON property localSsdPartitions
17705 17706 17707 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 17705 def local_ssd_partitions @local_ssd_partitions end |
#machine_type ⇒ String
The machine type to use for instances that will use the reservation.
This field only accepts machine type names. e.g. n2-standard-4
and does not accept machine type full or partial url. e.g.
projects/my-l7ilb-project/zones/us-central1-a/machineTypes/n2-standard-4.
Use for GPU reservations.
Corresponds to the JSON property machineType
17714 17715 17716 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 17714 def machine_type @machine_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
17721 17722 17723 17724 17725 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 17721 def update!(**args) @instance_count = args[:instance_count] if args.key?(:instance_count) @local_ssd_partitions = args[:local_ssd_partitions] if args.key?(:local_ssd_partitions) @machine_type = args[:machine_type] if args.key?(:machine_type) end |