Class: Google::Apis::ComputeAlpha::FutureResourcesSpecSpecificSkuResources

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FutureResourcesSpecSpecificSkuResources

Returns a new instance of FutureResourcesSpecSpecificSkuResources.



17381
17382
17383
# File 'lib/google/apis/compute_alpha/classes.rb', line 17381

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#instance_countFixnum

Size of the request, in instance count. Corresponds to the JSON property instanceCount

Returns:

  • (Fixnum)


17364
17365
17366
# File 'lib/google/apis/compute_alpha/classes.rb', line 17364

def instance_count
  @instance_count
end

#local_ssd_partitionsArray<Google::Apis::ComputeAlpha::FutureResourcesSpecLocalSsdPartition>

Local SSD partitions. You do not have to include SSD partitions that are built in the machine type. Corresponds to the JSON property localSsdPartitions



17370
17371
17372
# File 'lib/google/apis/compute_alpha/classes.rb', line 17370

def local_ssd_partitions
  @local_ssd_partitions
end

#machine_typeString

The machine type to use for instances that will use the reservation. This field only accepts machine type names. e.g. n2-standard-4 and does not accept machine type full or partial url. e.g. projects/my-l7ilb-project/zones/us-central1-a/machineTypes/n2-standard-4. Use for GPU reservations. Corresponds to the JSON property machineType

Returns:

  • (String)


17379
17380
17381
# File 'lib/google/apis/compute_alpha/classes.rb', line 17379

def machine_type
  @machine_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



17386
17387
17388
17389
17390
# File 'lib/google/apis/compute_alpha/classes.rb', line 17386

def update!(**args)
  @instance_count = args[:instance_count] if args.key?(:instance_count)
  @local_ssd_partitions = args[:local_ssd_partitions] if args.key?(:local_ssd_partitions)
  @machine_type = args[:machine_type] if args.key?(:machine_type)
end