Class: Google::Apis::ComputeAlpha::GetVersionOperationMetadataSbomInfo
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::GetVersionOperationMetadataSbomInfo
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#current_component_versions ⇒ Hash<String,String>
A mapping of components to their currently-applied versions or other appropriate identifiers.
-
#target_component_versions ⇒ Hash<String,String>
A mapping of components to their target versions or other appropriate identifiers.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GetVersionOperationMetadataSbomInfo
constructor
A new instance of GetVersionOperationMetadataSbomInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GetVersionOperationMetadataSbomInfo
Returns a new instance of GetVersionOperationMetadataSbomInfo.
17935 17936 17937 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 17935 def initialize(**args) update!(**args) end |
Instance Attribute Details
#current_component_versions ⇒ Hash<String,String>
A mapping of components to their currently-applied versions or other
appropriate identifiers.
Corresponds to the JSON property currentComponentVersions
17927 17928 17929 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 17927 def current_component_versions @current_component_versions end |
#target_component_versions ⇒ Hash<String,String>
A mapping of components to their target versions or other appropriate
identifiers.
Corresponds to the JSON property targetComponentVersions
17933 17934 17935 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 17933 def target_component_versions @target_component_versions end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
17940 17941 17942 17943 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 17940 def update!(**args) @current_component_versions = args[:current_component_versions] if args.key?(:current_component_versions) @target_component_versions = args[:target_component_versions] if args.key?(:target_component_versions) end |