Class: Google::Apis::ComputeAlpha::GetVersionOperationMetadataSbomInfo

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GetVersionOperationMetadataSbomInfo

Returns a new instance of GetVersionOperationMetadataSbomInfo.



17958
17959
17960
# File 'lib/google/apis/compute_alpha/classes.rb', line 17958

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#current_component_versionsHash<String,String>

SBOM versions currently applied to the resource. The key is the component name and the value is the version. Corresponds to the JSON property currentComponentVersions

Returns:

  • (Hash<String,String>)


17950
17951
17952
# File 'lib/google/apis/compute_alpha/classes.rb', line 17950

def current_component_versions
  @current_component_versions
end

#target_component_versionsHash<String,String>

SBOM versions scheduled for the next maintenance. The key is the component name and the value is the version. Corresponds to the JSON property targetComponentVersions

Returns:

  • (Hash<String,String>)


17956
17957
17958
# File 'lib/google/apis/compute_alpha/classes.rb', line 17956

def target_component_versions
  @target_component_versions
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



17963
17964
17965
17966
# File 'lib/google/apis/compute_alpha/classes.rb', line 17963

def update!(**args)
  @current_component_versions = args[:current_component_versions] if args.key?(:current_component_versions)
  @target_component_versions = args[:target_component_versions] if args.key?(:target_component_versions)
end