Class: Google::Apis::ComputeAlpha::GetVersionOperationMetadataSbomInfo

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GetVersionOperationMetadataSbomInfo

Returns a new instance of GetVersionOperationMetadataSbomInfo.



17623
17624
17625
# File 'lib/google/apis/compute_alpha/classes.rb', line 17623

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#current_component_versionsHash<String,String>

SBOM versions currently applied to the resource. The key is the component name and the value is the version. Corresponds to the JSON property currentComponentVersions

Returns:

  • (Hash<String,String>)


17615
17616
17617
# File 'lib/google/apis/compute_alpha/classes.rb', line 17615

def current_component_versions
  @current_component_versions
end

#target_component_versionsHash<String,String>

SBOM versions scheduled for the next maintenance. The key is the component name and the value is the version. Corresponds to the JSON property targetComponentVersions

Returns:

  • (Hash<String,String>)


17621
17622
17623
# File 'lib/google/apis/compute_alpha/classes.rb', line 17621

def target_component_versions
  @target_component_versions
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



17628
17629
17630
17631
# File 'lib/google/apis/compute_alpha/classes.rb', line 17628

def update!(**args)
  @current_component_versions = args[:current_component_versions] if args.key?(:current_component_versions)
  @target_component_versions = args[:target_component_versions] if args.key?(:target_component_versions)
end