Class: Google::Apis::ComputeAlpha::GlobalListVmExtensionsResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GlobalListVmExtensionsResponse

Returns a new instance of GlobalListVmExtensionsResponse.



19167
19168
19169
# File 'lib/google/apis/compute_alpha/classes.rb', line 19167

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Output only. Fingerprint of this resource. A hash of the contents stored in this object. This field is used in optimistic locking. This field will be ignored when inserting a VmExtensionPolicy. An up-to-date fingerprint must be provided in order to update the VmExtensionPolicy. To see the latest value of the fingerprint, make a get() request to retrieve a VmExtensionPolicy. Corresponds to the JSON property etag

Returns:

  • (String)


19125
19126
19127
# File 'lib/google/apis/compute_alpha/classes.rb', line 19125

def etag
  @etag
end

#idString

Output only. Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


19130
19131
19132
# File 'lib/google/apis/compute_alpha/classes.rb', line 19130

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::GlobalVmExtension>

Output only. A list of VM extensions. Corresponds to the JSON property items



19135
19136
19137
# File 'lib/google/apis/compute_alpha/classes.rb', line 19135

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


19140
19141
19142
# File 'lib/google/apis/compute_alpha/classes.rb', line 19140

def kind
  @kind
end

#next_page_tokenString

Output only. This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


19150
19151
19152
# File 'lib/google/apis/compute_alpha/classes.rb', line 19150

def next_page_token
  @next_page_token
end

Output only. Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


19155
19156
19157
# File 'lib/google/apis/compute_alpha/classes.rb', line 19155

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


19160
19161
19162
# File 'lib/google/apis/compute_alpha/classes.rb', line 19160

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::GlobalListVmExtensionsResponse::Warning

Output only. Informational warning message. Corresponds to the JSON property warning



19165
19166
19167
# File 'lib/google/apis/compute_alpha/classes.rb', line 19165

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



19172
19173
19174
19175
19176
19177
19178
19179
19180
19181
# File 'lib/google/apis/compute_alpha/classes.rb', line 19172

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end