Class: Google::Apis::ComputeAlpha::GlobalListVmExtensionsResponse
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::GlobalListVmExtensionsResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Output only.
-
#id ⇒ String
Output only.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::GlobalVmExtension>
Output only.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
Output only.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::GlobalListVmExtensionsResponse::Warning
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GlobalListVmExtensionsResponse
constructor
A new instance of GlobalListVmExtensionsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GlobalListVmExtensionsResponse
Returns a new instance of GlobalListVmExtensionsResponse.
18218 18219 18220 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 18218 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Output only. Fingerprint of this resource. A hash of the contents stored
in this object. This field is used in optimistic locking. This field will
be ignored when inserting a VmExtensionPolicy. An up-to-date
fingerprint must be provided in order to update the VmExtensionPolicy.
To see the latest value of the fingerprint, make a get() request to
retrieve a VmExtensionPolicy.
Corresponds to the JSON property etag
18176 18177 18178 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 18176 def etag @etag end |
#id ⇒ String
Output only. Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
18181 18182 18183 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 18181 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::GlobalVmExtension>
Output only. A list of VM extensions.
Corresponds to the JSON property items
18186 18187 18188 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 18186 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
18191 18192 18193 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 18191 def kind @kind end |
#next_page_token ⇒ String
Output only. This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
18201 18202 18203 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 18201 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. Server-defined URL for this resource.
Corresponds to the JSON property selfLink
18206 18207 18208 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 18206 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. Unreachable resources.
Corresponds to the JSON property unreachables
18211 18212 18213 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 18211 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::GlobalListVmExtensionsResponse::Warning
Output only. Informational warning message.
Corresponds to the JSON property warning
18216 18217 18218 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 18216 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
18223 18224 18225 18226 18227 18228 18229 18230 18231 18232 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 18223 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |