Class: Google::Apis::ComputeAlpha::GlobalListVmExtensionsResponse
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::GlobalListVmExtensionsResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Output only.
-
#id ⇒ String
Output only.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::GlobalVmExtension>
Output only.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
Output only.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::GlobalListVmExtensionsResponse::Warning
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GlobalListVmExtensionsResponse
constructor
A new instance of GlobalListVmExtensionsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GlobalListVmExtensionsResponse
Returns a new instance of GlobalListVmExtensionsResponse.
17721 17722 17723 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 17721 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Output only. Fingerprint of this resource. A hash of the contents stored
in this object. This field is used in optimistic locking. This field will
be ignored when inserting a VmExtensionPolicy. An up-to-date
fingerprint must be provided in order to update the VmExtensionPolicy.
To see the latest value of the fingerprint, make a get() request to
retrieve a VmExtensionPolicy.
Corresponds to the JSON property etag
17679 17680 17681 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 17679 def etag @etag end |
#id ⇒ String
Output only. Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
17684 17685 17686 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 17684 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::GlobalVmExtension>
Output only. A list of VM extensions.
Corresponds to the JSON property items
17689 17690 17691 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 17689 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
17694 17695 17696 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 17694 def kind @kind end |
#next_page_token ⇒ String
Output only. This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
17704 17705 17706 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 17704 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. Server-defined URL for this resource.
Corresponds to the JSON property selfLink
17709 17710 17711 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 17709 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. Unreachable resources.
Corresponds to the JSON property unreachables
17714 17715 17716 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 17714 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::GlobalListVmExtensionsResponse::Warning
Output only. Informational warning message.
Corresponds to the JSON property warning
17719 17720 17721 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 17719 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
17726 17727 17728 17729 17730 17731 17732 17733 17734 17735 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 17726 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |