Class: Google::Apis::ComputeAlpha::GlobalVmExtensionPolicy

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Message describing GlobalVmExtensionPolicy object.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GlobalVmExtensionPolicy

Returns a new instance of GlobalVmExtensionPolicy.



18528
18529
18530
# File 'lib/google/apis/compute_alpha/classes.rb', line 18528

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


18446
18447
18448
# File 'lib/google/apis/compute_alpha/classes.rb', line 18446

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


18452
18453
18454
# File 'lib/google/apis/compute_alpha/classes.rb', line 18452

def description
  @description
end

#extension_policiesHash<String,Google::Apis::ComputeAlpha::GlobalVmExtensionPolicyExtensionPolicy>

Required. Map from extension (eg: "cloudops") to its policy configuration. The key is the name of the extension. Corresponds to the JSON property extensionPolicies



18458
18459
18460
# File 'lib/google/apis/compute_alpha/classes.rb', line 18458

def extension_policies
  @extension_policies
end

#idFixnum

Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


18465
18466
18467
# File 'lib/google/apis/compute_alpha/classes.rb', line 18465

def id
  @id
end

#instance_selectorsArray<Google::Apis::ComputeAlpha::GlobalVmExtensionPolicyInstanceSelector>

Optional. Selector to target VMs for a policy. There is a logical "AND" between instance_selectors. Corresponds to the JSON property instanceSelectors



18471
18472
18473
# File 'lib/google/apis/compute_alpha/classes.rb', line 18471

def instance_selectors
  @instance_selectors
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# globalVmExtensionPolicy for globalVmExtensionPolicies. Corresponds to the JSON property kind

Returns:

  • (String)


18477
18478
18479
# File 'lib/google/apis/compute_alpha/classes.rb', line 18477

def kind
  @kind
end

#nameString

Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


18488
18489
18490
# File 'lib/google/apis/compute_alpha/classes.rb', line 18488

def name
  @name
end

#priorityFixnum

Optional. Used to resolve conflicts when multiple policies are active for the same extension. Defaults to 0. Larger the number, higher the priority. When the priority is the same, the policy with the newer create time has higher priority. Corresponds to the JSON property priority

Returns:

  • (Fixnum)


18497
18498
18499
# File 'lib/google/apis/compute_alpha/classes.rb', line 18497

def priority
  @priority
end

#rollout_operationGoogle::Apis::ComputeAlpha::GlobalVmExtensionPolicyRolloutOperation

Represents the rollout operation Corresponds to the JSON property rolloutOperation



18502
18503
18504
# File 'lib/google/apis/compute_alpha/classes.rb', line 18502

def rollout_operation
  @rollout_operation
end

#scoped_resource_statusString

Output only. [Output Only] The scoped resource status. It's only for tracking the purging status of the policy. Corresponds to the JSON property scopedResourceStatus

Returns:

  • (String)


18509
18510
18511
# File 'lib/google/apis/compute_alpha/classes.rb', line 18509

def scoped_resource_status
  @scoped_resource_status
end

Output only. [Output Only] Server-defined fully-qualified URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


18515
18516
18517
# File 'lib/google/apis/compute_alpha/classes.rb', line 18515

def self_link
  @self_link
end

Output only. [Output Only] Server-defined URL for this resource's resource id. Corresponds to the JSON property selfLinkWithId

Returns:

  • (String)


18520
18521
18522
# File 'lib/google/apis/compute_alpha/classes.rb', line 18520

def self_link_with_id
  @self_link_with_id
end

#update_timestampString

Output only. [Output Only] Update timestamp inRFC3339 text format. Corresponds to the JSON property updateTimestamp

Returns:

  • (String)


18526
18527
18528
# File 'lib/google/apis/compute_alpha/classes.rb', line 18526

def update_timestamp
  @update_timestamp
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



18533
18534
18535
18536
18537
18538
18539
18540
18541
18542
18543
18544
18545
18546
18547
# File 'lib/google/apis/compute_alpha/classes.rb', line 18533

def update!(**args)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @extension_policies = args[:extension_policies] if args.key?(:extension_policies)
  @id = args[:id] if args.key?(:id)
  @instance_selectors = args[:instance_selectors] if args.key?(:instance_selectors)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @priority = args[:priority] if args.key?(:priority)
  @rollout_operation = args[:rollout_operation] if args.key?(:rollout_operation)
  @scoped_resource_status = args[:scoped_resource_status] if args.key?(:scoped_resource_status)
  @self_link = args[:self_link] if args.key?(:self_link)
  @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id)
  @update_timestamp = args[:update_timestamp] if args.key?(:update_timestamp)
end