Class: Google::Apis::ComputeAlpha::GlobalVmExtensionPolicyList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::GlobalVmExtensionPolicyList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Response to list global VM extension policy resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::GlobalVmExtensionPolicy>
A list of GlobalVmExtensionPolicy resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::GlobalVmExtensionPolicyList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GlobalVmExtensionPolicyList
constructor
A new instance of GlobalVmExtensionPolicyList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GlobalVmExtensionPolicyList
Returns a new instance of GlobalVmExtensionPolicyList.
19861 19862 19863 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 19861 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
19819 19820 19821 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 19819 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
19824 19825 19826 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 19824 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::GlobalVmExtensionPolicy>
A list of GlobalVmExtensionPolicy resources.
Corresponds to the JSON property items
19829 19830 19831 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 19829 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
19834 19835 19836 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 19834 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
19844 19845 19846 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 19844 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
19849 19850 19851 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 19849 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
19854 19855 19856 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 19854 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::GlobalVmExtensionPolicyList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
19859 19860 19861 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 19859 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
19866 19867 19868 19869 19870 19871 19872 19873 19874 19875 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 19866 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |