Class: Google::Apis::ComputeAlpha::GlobalVmExtensionPolicyList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Response to list global VM extension policy resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GlobalVmExtensionPolicyList

Returns a new instance of GlobalVmExtensionPolicyList.



18865
18866
18867
# File 'lib/google/apis/compute_alpha/classes.rb', line 18865

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


18823
18824
18825
# File 'lib/google/apis/compute_alpha/classes.rb', line 18823

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


18828
18829
18830
# File 'lib/google/apis/compute_alpha/classes.rb', line 18828

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::GlobalVmExtensionPolicy>

A list of GlobalVmExtensionPolicy resources. Corresponds to the JSON property items



18833
18834
18835
# File 'lib/google/apis/compute_alpha/classes.rb', line 18833

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


18838
18839
18840
# File 'lib/google/apis/compute_alpha/classes.rb', line 18838

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


18848
18849
18850
# File 'lib/google/apis/compute_alpha/classes.rb', line 18848

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


18853
18854
18855
# File 'lib/google/apis/compute_alpha/classes.rb', line 18853

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


18858
18859
18860
# File 'lib/google/apis/compute_alpha/classes.rb', line 18858

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::GlobalVmExtensionPolicyList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



18863
18864
18865
# File 'lib/google/apis/compute_alpha/classes.rb', line 18863

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



18870
18871
18872
18873
18874
18875
18876
18877
18878
18879
# File 'lib/google/apis/compute_alpha/classes.rb', line 18870

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end