Class: Google::Apis::ComputeAlpha::GlobalVmExtensionPolicyList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Response to list global VM extension policy resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GlobalVmExtensionPolicyList

Returns a new instance of GlobalVmExtensionPolicyList.



18857
18858
18859
# File 'lib/google/apis/compute_alpha/classes.rb', line 18857

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


18815
18816
18817
# File 'lib/google/apis/compute_alpha/classes.rb', line 18815

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


18820
18821
18822
# File 'lib/google/apis/compute_alpha/classes.rb', line 18820

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::GlobalVmExtensionPolicy>

A list of GlobalVmExtensionPolicy resources. Corresponds to the JSON property items



18825
18826
18827
# File 'lib/google/apis/compute_alpha/classes.rb', line 18825

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


18830
18831
18832
# File 'lib/google/apis/compute_alpha/classes.rb', line 18830

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


18840
18841
18842
# File 'lib/google/apis/compute_alpha/classes.rb', line 18840

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


18845
18846
18847
# File 'lib/google/apis/compute_alpha/classes.rb', line 18845

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


18850
18851
18852
# File 'lib/google/apis/compute_alpha/classes.rb', line 18850

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::GlobalVmExtensionPolicyList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



18855
18856
18857
# File 'lib/google/apis/compute_alpha/classes.rb', line 18855

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



18862
18863
18864
18865
18866
18867
18868
18869
18870
18871
# File 'lib/google/apis/compute_alpha/classes.rb', line 18862

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end