Class: Google::Apis::ComputeAlpha::GlobalVmExtensionPolicyList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::GlobalVmExtensionPolicyList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Response to list global VM extension policy resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::GlobalVmExtensionPolicy>
A list of GlobalVmExtensionPolicy resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::GlobalVmExtensionPolicyList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GlobalVmExtensionPolicyList
constructor
A new instance of GlobalVmExtensionPolicyList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GlobalVmExtensionPolicyList
Returns a new instance of GlobalVmExtensionPolicyList.
18646 18647 18648 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 18646 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
18604 18605 18606 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 18604 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
18609 18610 18611 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 18609 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::GlobalVmExtensionPolicy>
A list of GlobalVmExtensionPolicy resources.
Corresponds to the JSON property items
18614 18615 18616 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 18614 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
18619 18620 18621 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 18619 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
18629 18630 18631 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 18629 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
18634 18635 18636 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 18634 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
18639 18640 18641 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 18639 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::GlobalVmExtensionPolicyList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
18644 18645 18646 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 18644 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
18651 18652 18653 18654 18655 18656 18657 18658 18659 18660 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 18651 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |