Class: Google::Apis::ComputeAlpha::GlobalVmExtensionPolicyList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Response to list global VM extension policy resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GlobalVmExtensionPolicyList

Returns a new instance of GlobalVmExtensionPolicyList.



18663
18664
18665
# File 'lib/google/apis/compute_alpha/classes.rb', line 18663

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


18621
18622
18623
# File 'lib/google/apis/compute_alpha/classes.rb', line 18621

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


18626
18627
18628
# File 'lib/google/apis/compute_alpha/classes.rb', line 18626

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::GlobalVmExtensionPolicy>

A list of GlobalVmExtensionPolicy resources. Corresponds to the JSON property items



18631
18632
18633
# File 'lib/google/apis/compute_alpha/classes.rb', line 18631

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


18636
18637
18638
# File 'lib/google/apis/compute_alpha/classes.rb', line 18636

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


18646
18647
18648
# File 'lib/google/apis/compute_alpha/classes.rb', line 18646

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


18651
18652
18653
# File 'lib/google/apis/compute_alpha/classes.rb', line 18651

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


18656
18657
18658
# File 'lib/google/apis/compute_alpha/classes.rb', line 18656

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::GlobalVmExtensionPolicyList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



18661
18662
18663
# File 'lib/google/apis/compute_alpha/classes.rb', line 18661

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



18668
18669
18670
18671
18672
18673
18674
18675
18676
18677
# File 'lib/google/apis/compute_alpha/classes.rb', line 18668

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end