Class: Google::Apis::ComputeAlpha::GlobalVmExtensionPolicyList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::GlobalVmExtensionPolicyList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Response to list global VM extension policy resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::GlobalVmExtensionPolicy>
A list of GlobalVmExtensionPolicy resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::GlobalVmExtensionPolicyList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GlobalVmExtensionPolicyList
constructor
A new instance of GlobalVmExtensionPolicyList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GlobalVmExtensionPolicyList
Returns a new instance of GlobalVmExtensionPolicyList.
18334 18335 18336 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 18334 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
18292 18293 18294 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 18292 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
18297 18298 18299 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 18297 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::GlobalVmExtensionPolicy>
A list of GlobalVmExtensionPolicy resources.
Corresponds to the JSON property items
18302 18303 18304 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 18302 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
18307 18308 18309 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 18307 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
18317 18318 18319 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 18317 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
18322 18323 18324 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 18322 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
18327 18328 18329 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 18327 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::GlobalVmExtensionPolicyList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
18332 18333 18334 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 18332 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
18339 18340 18341 18342 18343 18344 18345 18346 18347 18348 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 18339 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |