Class: Google::Apis::ComputeAlpha::GlobalVmExtensionPolicyRolloutOperationRolloutStatus
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::GlobalVmExtensionPolicyRolloutOperationRolloutStatus
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#current_rollouts ⇒ Array<Google::Apis::ComputeAlpha::GlobalVmExtensionPolicyRolloutOperationRolloutStatusRolloutMetadata>
Output only.
-
#previous_rollout ⇒ Google::Apis::ComputeAlpha::GlobalVmExtensionPolicyRolloutOperationRolloutStatusRolloutMetadata
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GlobalVmExtensionPolicyRolloutOperationRolloutStatus
constructor
A new instance of GlobalVmExtensionPolicyRolloutOperationRolloutStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GlobalVmExtensionPolicyRolloutOperationRolloutStatus
Returns a new instance of GlobalVmExtensionPolicyRolloutOperationRolloutStatus.
20054 20055 20056 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 20054 def initialize(**args) update!(**args) end |
Instance Attribute Details
#current_rollouts ⇒ Array<Google::Apis::ComputeAlpha::GlobalVmExtensionPolicyRolloutOperationRolloutStatusRolloutMetadata>
Output only. [Output Only] The current rollouts for the latest version of the
resource. There should be only one current rollout, but for
scalability, we make it repeated.
Corresponds to the JSON property currentRollouts
20045 20046 20047 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 20045 def current_rollouts @current_rollouts end |
#previous_rollout ⇒ Google::Apis::ComputeAlpha::GlobalVmExtensionPolicyRolloutOperationRolloutStatusRolloutMetadata
Output only. [Output Only] The last completed rollout resource. This field
will not
be populated until the first rollout is completed.
Corresponds to the JSON property previousRollout
20052 20053 20054 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 20052 def previous_rollout @previous_rollout end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
20059 20060 20061 20062 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 20059 def update!(**args) @current_rollouts = args[:current_rollouts] if args.key?(:current_rollouts) @previous_rollout = args[:previous_rollout] if args.key?(:previous_rollout) end |