Class: Google::Apis::ComputeAlpha::GlobalVmExtensionPolicyRolloutOperationRolloutStatus
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::GlobalVmExtensionPolicyRolloutOperationRolloutStatus
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#current_rollouts ⇒ Array<Google::Apis::ComputeAlpha::GlobalVmExtensionPolicyRolloutOperationRolloutStatusRolloutMetadata>
Output only.
-
#previous_rollout ⇒ Google::Apis::ComputeAlpha::GlobalVmExtensionPolicyRolloutOperationRolloutStatusRolloutMetadata
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GlobalVmExtensionPolicyRolloutOperationRolloutStatus
constructor
A new instance of GlobalVmExtensionPolicyRolloutOperationRolloutStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GlobalVmExtensionPolicyRolloutOperationRolloutStatus
Returns a new instance of GlobalVmExtensionPolicyRolloutOperationRolloutStatus.
18856 18857 18858 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 18856 def initialize(**args) update!(**args) end |
Instance Attribute Details
#current_rollouts ⇒ Array<Google::Apis::ComputeAlpha::GlobalVmExtensionPolicyRolloutOperationRolloutStatusRolloutMetadata>
Output only. [Output Only] The current rollouts for the latest version of the
resource. There should be only one current rollout, but for
scalability, we make it repeated.
Corresponds to the JSON property currentRollouts
18847 18848 18849 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 18847 def current_rollouts @current_rollouts end |
#previous_rollout ⇒ Google::Apis::ComputeAlpha::GlobalVmExtensionPolicyRolloutOperationRolloutStatusRolloutMetadata
Output only. [Output Only] The last completed rollout resource. This field
will not
be populated until the first rollout is completed.
Corresponds to the JSON property previousRollout
18854 18855 18856 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 18854 def previous_rollout @previous_rollout end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
18861 18862 18863 18864 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 18861 def update!(**args) @current_rollouts = args[:current_rollouts] if args.key?(:current_rollouts) @previous_rollout = args[:previous_rollout] if args.key?(:previous_rollout) end |