Class: Google::Apis::ComputeAlpha::GlobalVmExtensionPolicyRolloutOperationRolloutStatus
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::GlobalVmExtensionPolicyRolloutOperationRolloutStatus
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#current_rollouts ⇒ Array<Google::Apis::ComputeAlpha::GlobalVmExtensionPolicyRolloutOperationRolloutStatusRolloutMetadata>
Output only.
-
#previous_rollout ⇒ Google::Apis::ComputeAlpha::GlobalVmExtensionPolicyRolloutOperationRolloutStatusRolloutMetadata
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GlobalVmExtensionPolicyRolloutOperationRolloutStatus
constructor
A new instance of GlobalVmExtensionPolicyRolloutOperationRolloutStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GlobalVmExtensionPolicyRolloutOperationRolloutStatus
Returns a new instance of GlobalVmExtensionPolicyRolloutOperationRolloutStatus.
18524 18525 18526 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 18524 def initialize(**args) update!(**args) end |
Instance Attribute Details
#current_rollouts ⇒ Array<Google::Apis::ComputeAlpha::GlobalVmExtensionPolicyRolloutOperationRolloutStatusRolloutMetadata>
Output only. [Output Only] The current rollouts for the latest version of the
resource. There should be only one current rollout, but for
scalability, we make it repeated.
Corresponds to the JSON property currentRollouts
18515 18516 18517 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 18515 def current_rollouts @current_rollouts end |
#previous_rollout ⇒ Google::Apis::ComputeAlpha::GlobalVmExtensionPolicyRolloutOperationRolloutStatusRolloutMetadata
Output only. [Output Only] The last completed rollout resource. This field
will not
be populated until the first rollout is completed.
Corresponds to the JSON property previousRollout
18522 18523 18524 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 18522 def previous_rollout @previous_rollout end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
18529 18530 18531 18532 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 18529 def update!(**args) @current_rollouts = args[:current_rollouts] if args.key?(:current_rollouts) @previous_rollout = args[:previous_rollout] if args.key?(:previous_rollout) end |