Class: Google::Apis::ComputeAlpha::GlobalVmExtensionPolicyRolloutOperationRolloutStatusRolloutMetadata

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GlobalVmExtensionPolicyRolloutOperationRolloutStatusRolloutMetadata

Returns a new instance of GlobalVmExtensionPolicyRolloutOperationRolloutStatusRolloutMetadata.



19822
19823
19824
# File 'lib/google/apis/compute_alpha/classes.rb', line 19822

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#location_rollout_statusHash<String,Google::Apis::ComputeAlpha::GlobalVmExtensionPolicyRolloutOperationRolloutStatusRolloutMetadataLocationRolloutStatus>

Output only. [Output Only] The rollout status for each location. The list of the locations is the same as the list of locations in the rollout plan. Corresponds to the JSON property locationRolloutStatus



19802
19803
19804
# File 'lib/google/apis/compute_alpha/classes.rb', line 19802

def location_rollout_status
  @location_rollout_status
end

#rolloutString

Output only. [Output Only] The name of the rollout. Ex. projects//locations/global/rollouts/. Corresponds to the JSON property rollout

Returns:

  • (String)


19808
19809
19810
# File 'lib/google/apis/compute_alpha/classes.rb', line 19808

def rollout
  @rollout
end

#rollout_planString

Output only. [Output Only] The name of the rollout plan. Ex. projects//locations/global/rolloutPlans/. Corresponds to the JSON property rolloutPlan

Returns:

  • (String)


19815
19816
19817
# File 'lib/google/apis/compute_alpha/classes.rb', line 19815

def rollout_plan
  @rollout_plan
end

#stateString

Output only. [Output Only] The overall state of the rollout. Corresponds to the JSON property state

Returns:

  • (String)


19820
19821
19822
# File 'lib/google/apis/compute_alpha/classes.rb', line 19820

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



19827
19828
19829
19830
19831
19832
# File 'lib/google/apis/compute_alpha/classes.rb', line 19827

def update!(**args)
  @location_rollout_status = args[:location_rollout_status] if args.key?(:location_rollout_status)
  @rollout = args[:rollout] if args.key?(:rollout)
  @rollout_plan = args[:rollout_plan] if args.key?(:rollout_plan)
  @state = args[:state] if args.key?(:state)
end