Class: Google::Apis::ComputeAlpha::GlobalVmExtensionPolicyRolloutOperationRolloutStatusRolloutMetadata

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GlobalVmExtensionPolicyRolloutOperationRolloutStatusRolloutMetadata

Returns a new instance of GlobalVmExtensionPolicyRolloutOperationRolloutStatusRolloutMetadata.



18902
18903
18904
# File 'lib/google/apis/compute_alpha/classes.rb', line 18902

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#location_rollout_statusHash<String,Google::Apis::ComputeAlpha::GlobalVmExtensionPolicyRolloutOperationRolloutStatusRolloutMetadataLocationRolloutStatus>

Output only. [Output Only] The rollout status for each location. The list of the locations is the same as the list of locations in the rollout plan. Corresponds to the JSON property locationRolloutStatus



18882
18883
18884
# File 'lib/google/apis/compute_alpha/classes.rb', line 18882

def location_rollout_status
  @location_rollout_status
end

#rolloutString

Output only. [Output Only] The name of the rollout. Ex. projects//locations/global/rollouts/. Corresponds to the JSON property rollout

Returns:

  • (String)


18888
18889
18890
# File 'lib/google/apis/compute_alpha/classes.rb', line 18888

def rollout
  @rollout
end

#rollout_planString

Output only. [Output Only] The name of the rollout plan. Ex. projects//locations/global/rolloutPlans/. Corresponds to the JSON property rolloutPlan

Returns:

  • (String)


18895
18896
18897
# File 'lib/google/apis/compute_alpha/classes.rb', line 18895

def rollout_plan
  @rollout_plan
end

#stateString

Output only. [Output Only] The overall state of the rollout. Corresponds to the JSON property state

Returns:

  • (String)


18900
18901
18902
# File 'lib/google/apis/compute_alpha/classes.rb', line 18900

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



18907
18908
18909
18910
18911
18912
# File 'lib/google/apis/compute_alpha/classes.rb', line 18907

def update!(**args)
  @location_rollout_status = args[:location_rollout_status] if args.key?(:location_rollout_status)
  @rollout = args[:rollout] if args.key?(:rollout)
  @rollout_plan = args[:rollout_plan] if args.key?(:rollout_plan)
  @state = args[:state] if args.key?(:state)
end