Class: Google::Apis::ComputeAlpha::GroupMaintenanceInfo
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::GroupMaintenanceInfo
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Maintenance Info for ReservationBlocks.
Instance Attribute Summary collapse
-
#instance_maintenance_ongoing_count ⇒ Fixnum
Describes number of instances that have ongoing maintenance.
-
#instance_maintenance_pending_count ⇒ Fixnum
Describes number of instances that have pending maintenance.
-
#maintenance_ongoing_count ⇒ Fixnum
Progress for ongoing maintenance for this group of VMs/hosts.
-
#maintenance_pending_count ⇒ Fixnum
Progress for ongoing maintenance for this group of VMs/hosts.
-
#scheduling_type ⇒ String
The type of maintenance for the reservation.
-
#subblock_infra_maintenance_ongoing_count ⇒ Fixnum
Describes number of subblock Infrastructure that has ongoing maintenance.
-
#subblock_infra_maintenance_pending_count ⇒ Fixnum
Describes number of subblock Infrastructure that has pending maintenance.
-
#upcoming_group_maintenance ⇒ Google::Apis::ComputeAlpha::UpcomingMaintenance
Upcoming Maintenance notification information.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GroupMaintenanceInfo
constructor
A new instance of GroupMaintenanceInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GroupMaintenanceInfo
Returns a new instance of GroupMaintenanceInfo.
18986 18987 18988 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 18986 def initialize(**args) update!(**args) end |
Instance Attribute Details
#instance_maintenance_ongoing_count ⇒ Fixnum
Describes number of instances that have ongoing maintenance.
Corresponds to the JSON property instanceMaintenanceOngoingCount
18941 18942 18943 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 18941 def instance_maintenance_ongoing_count @instance_maintenance_ongoing_count end |
#instance_maintenance_pending_count ⇒ Fixnum
Describes number of instances that have pending maintenance.
Corresponds to the JSON property instanceMaintenancePendingCount
18946 18947 18948 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 18946 def instance_maintenance_pending_count @instance_maintenance_pending_count end |
#maintenance_ongoing_count ⇒ Fixnum
Progress for ongoing maintenance for this group of VMs/hosts.
Describes number of hosts in the block that have ongoing maintenance.
Corresponds to the JSON property maintenanceOngoingCount
18952 18953 18954 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 18952 def maintenance_ongoing_count @maintenance_ongoing_count end |
#maintenance_pending_count ⇒ Fixnum
Progress for ongoing maintenance for this group of VMs/hosts.
Describes number of hosts in the block that have pending maintenance.
Corresponds to the JSON property maintenancePendingCount
18958 18959 18960 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 18958 def maintenance_pending_count @maintenance_pending_count end |
#scheduling_type ⇒ String
The type of maintenance for the reservation.
Corresponds to the JSON property schedulingType
18963 18964 18965 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 18963 def scheduling_type @scheduling_type end |
#subblock_infra_maintenance_ongoing_count ⇒ Fixnum
Describes number of subblock Infrastructure that has ongoing maintenance.
Here, Subblock Infrastructure Maintenance pertains to upstream hardware
contained in the Subblock that is necessary for a VM Family(e.g. NVLink
Domains). Not all VM Families will support this field.
Corresponds to the JSON property subblockInfraMaintenanceOngoingCount
18971 18972 18973 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 18971 def subblock_infra_maintenance_ongoing_count @subblock_infra_maintenance_ongoing_count end |
#subblock_infra_maintenance_pending_count ⇒ Fixnum
Describes number of subblock Infrastructure that has pending maintenance.
Here, Subblock Infrastructure Maintenance pertains to upstream hardware
contained in the Subblock that is necessary for a VM Family (e.g. NVLink
Domains). Not all VM Families will support this field.
Corresponds to the JSON property subblockInfraMaintenancePendingCount
18979 18980 18981 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 18979 def subblock_infra_maintenance_pending_count @subblock_infra_maintenance_pending_count end |
#upcoming_group_maintenance ⇒ Google::Apis::ComputeAlpha::UpcomingMaintenance
Upcoming Maintenance notification information.
Corresponds to the JSON property upcomingGroupMaintenance
18984 18985 18986 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 18984 def upcoming_group_maintenance @upcoming_group_maintenance end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
18991 18992 18993 18994 18995 18996 18997 18998 18999 19000 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 18991 def update!(**args) @instance_maintenance_ongoing_count = args[:instance_maintenance_ongoing_count] if args.key?(:instance_maintenance_ongoing_count) @instance_maintenance_pending_count = args[:instance_maintenance_pending_count] if args.key?(:instance_maintenance_pending_count) @maintenance_ongoing_count = args[:maintenance_ongoing_count] if args.key?(:maintenance_ongoing_count) @maintenance_pending_count = args[:maintenance_pending_count] if args.key?(:maintenance_pending_count) @scheduling_type = args[:scheduling_type] if args.key?(:scheduling_type) @subblock_infra_maintenance_ongoing_count = args[:subblock_infra_maintenance_ongoing_count] if args.key?(:subblock_infra_maintenance_ongoing_count) @subblock_infra_maintenance_pending_count = args[:subblock_infra_maintenance_pending_count] if args.key?(:subblock_infra_maintenance_pending_count) @upcoming_group_maintenance = args[:upcoming_group_maintenance] if args.key?(:upcoming_group_maintenance) end |