Class: Google::Apis::ComputeAlpha::GroupMaintenanceInfo
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::GroupMaintenanceInfo
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Maintenance Info for ReservationBlocks.
Instance Attribute Summary collapse
-
#instance_maintenance_ongoing_count ⇒ Fixnum
Describes number of instances that have ongoing maintenance.
-
#instance_maintenance_pending_count ⇒ Fixnum
Describes number of instances that have pending maintenance.
-
#maintenance_ongoing_count ⇒ Fixnum
Progress for ongoing maintenance for this group of VMs/hosts.
-
#maintenance_pending_count ⇒ Fixnum
Progress for ongoing maintenance for this group of VMs/hosts.
-
#scheduling_type ⇒ String
The type of maintenance for the reservation.
-
#subblock_infra_maintenance_ongoing_count ⇒ Fixnum
Describes number of subblock Infrastructure that has ongoing maintenance.
-
#subblock_infra_maintenance_pending_count ⇒ Fixnum
Describes number of subblock Infrastructure that has pending maintenance.
-
#upcoming_group_maintenance ⇒ Google::Apis::ComputeAlpha::UpcomingMaintenance
Upcoming Maintenance notification information.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GroupMaintenanceInfo
constructor
A new instance of GroupMaintenanceInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GroupMaintenanceInfo
Returns a new instance of GroupMaintenanceInfo.
18621 18622 18623 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 18621 def initialize(**args) update!(**args) end |
Instance Attribute Details
#instance_maintenance_ongoing_count ⇒ Fixnum
Describes number of instances that have ongoing maintenance.
Corresponds to the JSON property instanceMaintenanceOngoingCount
18576 18577 18578 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 18576 def instance_maintenance_ongoing_count @instance_maintenance_ongoing_count end |
#instance_maintenance_pending_count ⇒ Fixnum
Describes number of instances that have pending maintenance.
Corresponds to the JSON property instanceMaintenancePendingCount
18581 18582 18583 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 18581 def instance_maintenance_pending_count @instance_maintenance_pending_count end |
#maintenance_ongoing_count ⇒ Fixnum
Progress for ongoing maintenance for this group of VMs/hosts.
Describes number of hosts in the block that have ongoing maintenance.
Corresponds to the JSON property maintenanceOngoingCount
18587 18588 18589 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 18587 def maintenance_ongoing_count @maintenance_ongoing_count end |
#maintenance_pending_count ⇒ Fixnum
Progress for ongoing maintenance for this group of VMs/hosts.
Describes number of hosts in the block that have pending maintenance.
Corresponds to the JSON property maintenancePendingCount
18593 18594 18595 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 18593 def maintenance_pending_count @maintenance_pending_count end |
#scheduling_type ⇒ String
The type of maintenance for the reservation.
Corresponds to the JSON property schedulingType
18598 18599 18600 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 18598 def scheduling_type @scheduling_type end |
#subblock_infra_maintenance_ongoing_count ⇒ Fixnum
Describes number of subblock Infrastructure that has ongoing maintenance.
Here, Subblock Infrastructure Maintenance pertains to upstream hardware
contained in the Subblock that is necessary for a VM Family(e.g. NVLink
Domains). Not all VM Families will support this field.
Corresponds to the JSON property subblockInfraMaintenanceOngoingCount
18606 18607 18608 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 18606 def subblock_infra_maintenance_ongoing_count @subblock_infra_maintenance_ongoing_count end |
#subblock_infra_maintenance_pending_count ⇒ Fixnum
Describes number of subblock Infrastructure that has pending maintenance.
Here, Subblock Infrastructure Maintenance pertains to upstream hardware
contained in the Subblock that is necessary for a VM Family (e.g. NVLink
Domains). Not all VM Families will support this field.
Corresponds to the JSON property subblockInfraMaintenancePendingCount
18614 18615 18616 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 18614 def subblock_infra_maintenance_pending_count @subblock_infra_maintenance_pending_count end |
#upcoming_group_maintenance ⇒ Google::Apis::ComputeAlpha::UpcomingMaintenance
Upcoming Maintenance notification information.
Corresponds to the JSON property upcomingGroupMaintenance
18619 18620 18621 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 18619 def upcoming_group_maintenance @upcoming_group_maintenance end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
18626 18627 18628 18629 18630 18631 18632 18633 18634 18635 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 18626 def update!(**args) @instance_maintenance_ongoing_count = args[:instance_maintenance_ongoing_count] if args.key?(:instance_maintenance_ongoing_count) @instance_maintenance_pending_count = args[:instance_maintenance_pending_count] if args.key?(:instance_maintenance_pending_count) @maintenance_ongoing_count = args[:maintenance_ongoing_count] if args.key?(:maintenance_ongoing_count) @maintenance_pending_count = args[:maintenance_pending_count] if args.key?(:maintenance_pending_count) @scheduling_type = args[:scheduling_type] if args.key?(:scheduling_type) @subblock_infra_maintenance_ongoing_count = args[:subblock_infra_maintenance_ongoing_count] if args.key?(:subblock_infra_maintenance_ongoing_count) @subblock_infra_maintenance_pending_count = args[:subblock_infra_maintenance_pending_count] if args.key?(:subblock_infra_maintenance_pending_count) @upcoming_group_maintenance = args[:upcoming_group_maintenance] if args.key?(:upcoming_group_maintenance) end |