Class: Google::Apis::ComputeAlpha::HaController

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

HaController handles failover for a VM Instance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HaController

Returns a new instance of HaController.



20773
20774
20775
# File 'lib/google/apis/compute_alpha/classes.rb', line 20773

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backend_servicesArray<String>

Advanced configuration option. If specified, these Backend Services need to be pre-created. Currently, only one backend service can be specified, and it must be L4 Internal Load Balancer (ILB). Corresponds to the JSON property backendServices

Returns:

  • (Array<String>)


20668
20669
20670
# File 'lib/google/apis/compute_alpha/classes.rb', line 20668

def backend_services
  @backend_services
end

#creation_timestampString

Output only. [Output Only] Creation timestamp in RFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


20674
20675
20676
# File 'lib/google/apis/compute_alpha/classes.rb', line 20674

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


20680
20681
20682
# File 'lib/google/apis/compute_alpha/classes.rb', line 20680

def description
  @description
end

#failover_capacityString

Capacity guarantee settings for the event of a failover. This determines whether capacity is guaranteed to be available in the zones used by the HaController. Deprecated: This field is deprecated and has no effect. Corresponds to the JSON property failoverCapacity

Returns:

  • (String)


20688
20689
20690
# File 'lib/google/apis/compute_alpha/classes.rb', line 20688

def failover_capacity
  @failover_capacity
end

#failover_initiationString

Indicates how failover should be initiated. Corresponds to the JSON property failoverInitiation

Returns:

  • (String)


20693
20694
20695
# File 'lib/google/apis/compute_alpha/classes.rb', line 20693

def failover_initiation
  @failover_initiation
end

#idFixnum

Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


20700
20701
20702
# File 'lib/google/apis/compute_alpha/classes.rb', line 20700

def id
  @id
end

#instance_nameString

Name of the instance that HaController is in charge of. If not specified the HaController's resource name will be used instead. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property instanceName

Returns:

  • (String)


20712
20713
20714
# File 'lib/google/apis/compute_alpha/classes.rb', line 20712

def instance_name
  @instance_name
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute#haController for HaControllers. Corresponds to the JSON property kind

Returns:

  • (String)


20718
20719
20720
# File 'lib/google/apis/compute_alpha/classes.rb', line 20718

def kind
  @kind
end

#nameString

Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


20730
20731
20732
# File 'lib/google/apis/compute_alpha/classes.rb', line 20730

def name
  @name
end

#networking_auto_configurationGoogle::Apis::ComputeAlpha::HaControllerNetworkingAutoConfiguration

Basic networking configuration. Required backend services and forwarding rules will be automatically created with default parameters. Corresponds to the JSON property networkingAutoConfiguration



20736
20737
20738
# File 'lib/google/apis/compute_alpha/classes.rb', line 20736

def networking_auto_configuration
  @networking_auto_configuration
end

#regionString

Output only. [Output Only] URL of the region where the resource resides. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body. Corresponds to the JSON property region

Returns:

  • (String)


20743
20744
20745
# File 'lib/google/apis/compute_alpha/classes.rb', line 20743

def region
  @region
end

#secondary_zone_capacityString

Indicates the capacity guarantees in the secondary zone. Corresponds to the JSON property secondaryZoneCapacity

Returns:

  • (String)


20748
20749
20750
# File 'lib/google/apis/compute_alpha/classes.rb', line 20748

def secondary_zone_capacity
  @secondary_zone_capacity
end

Output only. [Output only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


20753
20754
20755
# File 'lib/google/apis/compute_alpha/classes.rb', line 20753

def self_link
  @self_link
end

Output only. [Output Only] Server-defined URL for this resource with the resource id. Corresponds to the JSON property selfLinkWithId

Returns:

  • (String)


20759
20760
20761
# File 'lib/google/apis/compute_alpha/classes.rb', line 20759

def self_link_with_id
  @self_link_with_id
end

#statusGoogle::Apis::ComputeAlpha::HaControllerStatus

Contains information about current status of the HaController. Corresponds to the JSON property status



20764
20765
20766
# File 'lib/google/apis/compute_alpha/classes.rb', line 20764

def status
  @status
end

#zone_configurationsHash<String,Google::Apis::ComputeAlpha::HaControllerZoneConfiguration>

Map of zone configurations Key: name of the zone Value: ZoneConfiguration Corresponds to the JSON property zoneConfigurations



20771
20772
20773
# File 'lib/google/apis/compute_alpha/classes.rb', line 20771

def zone_configurations
  @zone_configurations
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20778
20779
20780
20781
20782
20783
20784
20785
20786
20787
20788
20789
20790
20791
20792
20793
20794
20795
# File 'lib/google/apis/compute_alpha/classes.rb', line 20778

def update!(**args)
  @backend_services = args[:backend_services] if args.key?(:backend_services)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @failover_capacity = args[:failover_capacity] if args.key?(:failover_capacity)
  @failover_initiation = args[:failover_initiation] if args.key?(:failover_initiation)
  @id = args[:id] if args.key?(:id)
  @instance_name = args[:instance_name] if args.key?(:instance_name)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @networking_auto_configuration = args[:networking_auto_configuration] if args.key?(:networking_auto_configuration)
  @region = args[:region] if args.key?(:region)
  @secondary_zone_capacity = args[:secondary_zone_capacity] if args.key?(:secondary_zone_capacity)
  @self_link = args[:self_link] if args.key?(:self_link)
  @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id)
  @status = args[:status] if args.key?(:status)
  @zone_configurations = args[:zone_configurations] if args.key?(:zone_configurations)
end