Class: Google::Apis::ComputeAlpha::HaController
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::HaController
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
HaController handles failover for a VM Instance.
Instance Attribute Summary collapse
-
#backend_services ⇒ Array<String>
Advanced configuration option.
-
#creation_timestamp ⇒ String
Output only.
-
#description ⇒ String
An optional description of this resource.
-
#failover_capacity ⇒ String
Capacity guarantee settings for the event of a failover.
-
#failover_initiation ⇒ String
Indicates how failover should be initiated.
-
#id ⇒ Fixnum
Output only.
-
#instance_name ⇒ String
Name of the instance that HaController is in charge of.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
Name of the resource.
-
#networking_auto_configuration ⇒ Google::Apis::ComputeAlpha::HaControllerNetworkingAutoConfiguration
Basic networking configuration.
-
#region ⇒ String
Output only.
-
#secondary_zone_capacity ⇒ String
Indicates the capacity guarantees in the secondary zone.
-
#self_link ⇒ String
Output only.
-
#self_link_with_id ⇒ String
Output only.
-
#status ⇒ Google::Apis::ComputeAlpha::HaControllerStatus
Contains information about current status of the HaController.
-
#zone_configurations ⇒ Hash<String,Google::Apis::ComputeAlpha::HaControllerZoneConfiguration>
Map of zone configurations Key: name of the zone Value: ZoneConfiguration Corresponds to the JSON property
zoneConfigurations.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HaController
constructor
A new instance of HaController.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HaController
Returns a new instance of HaController.
20501 20502 20503 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 20501 def initialize(**args) update!(**args) end |
Instance Attribute Details
#backend_services ⇒ Array<String>
Advanced configuration option. If specified, these Backend Services need to
be pre-created.
Currently, only one backend service can be specified, and it must be L4
Internal Load Balancer (ILB).
Corresponds to the JSON property backendServices
20396 20397 20398 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 20396 def backend_services @backend_services end |
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp in RFC3339
text format.
Corresponds to the JSON property creationTimestamp
20402 20403 20404 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 20402 def @creation_timestamp end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
20408 20409 20410 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 20408 def description @description end |
#failover_capacity ⇒ String
Capacity guarantee settings for the event of a failover.
This determines whether capacity is guaranteed to be available
in the zones used by the HaController.
Deprecated: This field is deprecated and has no effect.
Corresponds to the JSON property failoverCapacity
20416 20417 20418 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 20416 def failover_capacity @failover_capacity end |
#failover_initiation ⇒ String
Indicates how failover should be initiated.
Corresponds to the JSON property failoverInitiation
20421 20422 20423 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 20421 def failover_initiation @failover_initiation end |
#id ⇒ Fixnum
Output only. [Output Only] The unique identifier for the resource. This
identifier is
defined by the server.
Corresponds to the JSON property id
20428 20429 20430 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 20428 def id @id end |
#instance_name ⇒ String
Name of the instance that HaController is in charge of.
If not specified the HaController's resource name will be used instead.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character
must be a lowercase letter, and all following characters must be a dash,
lowercase letter, or digit, except the last character, which cannot be a
dash.
Corresponds to the JSON property instanceName
20440 20441 20442 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 20440 def instance_name @instance_name end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#haController
for HaControllers.
Corresponds to the JSON property kind
20446 20447 20448 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 20446 def kind @kind end |
#name ⇒ String
Name of the resource.
Provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character
must be a lowercase letter, and all following characters must be a dash,
lowercase letter, or digit, except the last character, which cannot be a
dash.
Corresponds to the JSON property name
20458 20459 20460 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 20458 def name @name end |
#networking_auto_configuration ⇒ Google::Apis::ComputeAlpha::HaControllerNetworkingAutoConfiguration
Basic networking configuration. Required backend services and forwarding
rules will be automatically created with default parameters.
Corresponds to the JSON property networkingAutoConfiguration
20464 20465 20466 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 20464 def networking_auto_configuration @networking_auto_configuration end |
#region ⇒ String
Output only. [Output Only] URL of the region where the resource resides.
You must specify this field as part of the HTTP request URL.
It is not settable as a field in the request body.
Corresponds to the JSON property region
20471 20472 20473 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 20471 def region @region end |
#secondary_zone_capacity ⇒ String
Indicates the capacity guarantees in the secondary zone.
Corresponds to the JSON property secondaryZoneCapacity
20476 20477 20478 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 20476 def secondary_zone_capacity @secondary_zone_capacity end |
#self_link ⇒ String
Output only. [Output only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
20481 20482 20483 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 20481 def self_link @self_link end |
#self_link_with_id ⇒ String
Output only. [Output Only] Server-defined URL for this resource with the
resource id.
Corresponds to the JSON property selfLinkWithId
20487 20488 20489 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 20487 def self_link_with_id @self_link_with_id end |
#status ⇒ Google::Apis::ComputeAlpha::HaControllerStatus
Contains information about current status of the HaController.
Corresponds to the JSON property status
20492 20493 20494 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 20492 def status @status end |
#zone_configurations ⇒ Hash<String,Google::Apis::ComputeAlpha::HaControllerZoneConfiguration>
Map of zone configurations
Key: name of the zone
Value: ZoneConfiguration
Corresponds to the JSON property zoneConfigurations
20499 20500 20501 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 20499 def zone_configurations @zone_configurations end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
20506 20507 20508 20509 20510 20511 20512 20513 20514 20515 20516 20517 20518 20519 20520 20521 20522 20523 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 20506 def update!(**args) @backend_services = args[:backend_services] if args.key?(:backend_services) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @failover_capacity = args[:failover_capacity] if args.key?(:failover_capacity) @failover_initiation = args[:failover_initiation] if args.key?(:failover_initiation) @id = args[:id] if args.key?(:id) @instance_name = args[:instance_name] if args.key?(:instance_name) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @networking_auto_configuration = args[:networking_auto_configuration] if args.key?(:networking_auto_configuration) @region = args[:region] if args.key?(:region) @secondary_zone_capacity = args[:secondary_zone_capacity] if args.key?(:secondary_zone_capacity) @self_link = args[:self_link] if args.key?(:self_link) @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id) @status = args[:status] if args.key?(:status) @zone_configurations = args[:zone_configurations] if args.key?(:zone_configurations) end |