Class: Google::Apis::ComputeAlpha::HaController
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::HaController
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
HaController handles failover for a VM Instance.
Instance Attribute Summary collapse
-
#backend_services ⇒ Array<String>
Advanced configuration option.
-
#creation_timestamp ⇒ String
Output only.
-
#description ⇒ String
An optional description of this resource.
-
#failover_capacity ⇒ String
Capacity guarantee settings for the event of a failover.
-
#failover_initiation ⇒ String
Indicates how failover should be initiated.
-
#id ⇒ Fixnum
Output only.
-
#instance_name ⇒ String
Name of the instance that HaController is in charge of.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
Name of the resource.
-
#networking_auto_configuration ⇒ Google::Apis::ComputeAlpha::HaControllerNetworkingAutoConfiguration
Basic networking configuration.
-
#region ⇒ String
Output only.
-
#secondary_zone_capacity ⇒ String
Indicates the capacity guarantees in the secondary zone.
-
#self_link ⇒ String
Output only.
-
#self_link_with_id ⇒ String
Output only.
-
#status ⇒ Google::Apis::ComputeAlpha::HaControllerStatus
Contains information about current status of the HaController.
-
#zone_configurations ⇒ Hash<String,Google::Apis::ComputeAlpha::HaControllerZoneConfiguration>
Map of zone configurations Key: name of the zone Value: ZoneConfiguration Corresponds to the JSON property
zoneConfigurations.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HaController
constructor
A new instance of HaController.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HaController
Returns a new instance of HaController.
19769 19770 19771 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 19769 def initialize(**args) update!(**args) end |
Instance Attribute Details
#backend_services ⇒ Array<String>
Advanced configuration option. If specified, these Backend Services need to
be pre-created.
Currently, only one backend service can be specified, and it must be L4
Internal Load Balancer (ILB).
Corresponds to the JSON property backendServices
19664 19665 19666 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 19664 def backend_services @backend_services end |
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp in RFC3339
text format.
Corresponds to the JSON property creationTimestamp
19670 19671 19672 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 19670 def @creation_timestamp end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
19676 19677 19678 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 19676 def description @description end |
#failover_capacity ⇒ String
Capacity guarantee settings for the event of a failover.
This determines whether capacity is guaranteed to be available
in the zones used by the HaController.
Deprecated: This field is deprecated and has no effect.
Corresponds to the JSON property failoverCapacity
19684 19685 19686 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 19684 def failover_capacity @failover_capacity end |
#failover_initiation ⇒ String
Indicates how failover should be initiated.
Corresponds to the JSON property failoverInitiation
19689 19690 19691 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 19689 def failover_initiation @failover_initiation end |
#id ⇒ Fixnum
Output only. [Output Only] The unique identifier for the resource. This
identifier is
defined by the server.
Corresponds to the JSON property id
19696 19697 19698 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 19696 def id @id end |
#instance_name ⇒ String
Name of the instance that HaController is in charge of.
If not specified the HaController's resource name will be used instead.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character
must be a lowercase letter, and all following characters must be a dash,
lowercase letter, or digit, except the last character, which cannot be a
dash.
Corresponds to the JSON property instanceName
19708 19709 19710 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 19708 def instance_name @instance_name end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#haController
for HaControllers.
Corresponds to the JSON property kind
19714 19715 19716 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 19714 def kind @kind end |
#name ⇒ String
Name of the resource.
Provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character
must be a lowercase letter, and all following characters must be a dash,
lowercase letter, or digit, except the last character, which cannot be a
dash.
Corresponds to the JSON property name
19726 19727 19728 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 19726 def name @name end |
#networking_auto_configuration ⇒ Google::Apis::ComputeAlpha::HaControllerNetworkingAutoConfiguration
Basic networking configuration. Required backend services and forwarding
rules will be automatically created with default parameters.
Corresponds to the JSON property networkingAutoConfiguration
19732 19733 19734 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 19732 def networking_auto_configuration @networking_auto_configuration end |
#region ⇒ String
Output only. [Output Only] URL of the region where the resource resides.
You must specify this field as part of the HTTP request URL.
It is not settable as a field in the request body.
Corresponds to the JSON property region
19739 19740 19741 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 19739 def region @region end |
#secondary_zone_capacity ⇒ String
Indicates the capacity guarantees in the secondary zone.
Corresponds to the JSON property secondaryZoneCapacity
19744 19745 19746 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 19744 def secondary_zone_capacity @secondary_zone_capacity end |
#self_link ⇒ String
Output only. [Output only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
19749 19750 19751 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 19749 def self_link @self_link end |
#self_link_with_id ⇒ String
Output only. [Output Only] Server-defined URL for this resource with the
resource id.
Corresponds to the JSON property selfLinkWithId
19755 19756 19757 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 19755 def self_link_with_id @self_link_with_id end |
#status ⇒ Google::Apis::ComputeAlpha::HaControllerStatus
Contains information about current status of the HaController.
Corresponds to the JSON property status
19760 19761 19762 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 19760 def status @status end |
#zone_configurations ⇒ Hash<String,Google::Apis::ComputeAlpha::HaControllerZoneConfiguration>
Map of zone configurations
Key: name of the zone
Value: ZoneConfiguration
Corresponds to the JSON property zoneConfigurations
19767 19768 19769 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 19767 def zone_configurations @zone_configurations end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
19774 19775 19776 19777 19778 19779 19780 19781 19782 19783 19784 19785 19786 19787 19788 19789 19790 19791 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 19774 def update!(**args) @backend_services = args[:backend_services] if args.key?(:backend_services) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @failover_capacity = args[:failover_capacity] if args.key?(:failover_capacity) @failover_initiation = args[:failover_initiation] if args.key?(:failover_initiation) @id = args[:id] if args.key?(:id) @instance_name = args[:instance_name] if args.key?(:instance_name) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @networking_auto_configuration = args[:networking_auto_configuration] if args.key?(:networking_auto_configuration) @region = args[:region] if args.key?(:region) @secondary_zone_capacity = args[:secondary_zone_capacity] if args.key?(:secondary_zone_capacity) @self_link = args[:self_link] if args.key?(:self_link) @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id) @status = args[:status] if args.key?(:status) @zone_configurations = args[:zone_configurations] if args.key?(:zone_configurations) end |