Class: Google::Apis::ComputeAlpha::HaController

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

HaController handles failover for a VM Instance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HaController

Returns a new instance of HaController.



19214
19215
19216
# File 'lib/google/apis/compute_alpha/classes.rb', line 19214

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backend_servicesArray<String>

Advanced configuration option. If specified, these Backend Services need to be pre-created. Currently, only one backend service can be specified, and it must be L4 Internal Load Balancer (ILB). Corresponds to the JSON property backendServices

Returns:

  • (Array<String>)


19110
19111
19112
# File 'lib/google/apis/compute_alpha/classes.rb', line 19110

def backend_services
  @backend_services
end

#creation_timestampString

Output only. [Output Only] Creation timestamp in RFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


19116
19117
19118
# File 'lib/google/apis/compute_alpha/classes.rb', line 19116

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


19122
19123
19124
# File 'lib/google/apis/compute_alpha/classes.rb', line 19122

def description
  @description
end

#failover_capacityString

Capacity guarantee settings for the event of a failover. This determines whether capacity is guaranteed to be available in the zones used by the HaController. Corresponds to the JSON property failoverCapacity

Returns:

  • (String)


19129
19130
19131
# File 'lib/google/apis/compute_alpha/classes.rb', line 19129

def failover_capacity
  @failover_capacity
end

#failover_initiationString

Indicates how failover should be initiated. Corresponds to the JSON property failoverInitiation

Returns:

  • (String)


19134
19135
19136
# File 'lib/google/apis/compute_alpha/classes.rb', line 19134

def failover_initiation
  @failover_initiation
end

#idFixnum

Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


19141
19142
19143
# File 'lib/google/apis/compute_alpha/classes.rb', line 19141

def id
  @id
end

#instance_nameString

Name of the instance that HaController is in charge of. If not specified the HaController's resource name will be used instead. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property instanceName

Returns:

  • (String)


19153
19154
19155
# File 'lib/google/apis/compute_alpha/classes.rb', line 19153

def instance_name
  @instance_name
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute#haController for HaControllers. Corresponds to the JSON property kind

Returns:

  • (String)


19159
19160
19161
# File 'lib/google/apis/compute_alpha/classes.rb', line 19159

def kind
  @kind
end

#nameString

Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


19171
19172
19173
# File 'lib/google/apis/compute_alpha/classes.rb', line 19171

def name
  @name
end

#networking_auto_configurationGoogle::Apis::ComputeAlpha::HaControllerNetworkingAutoConfiguration

Basic networking configuration. Required backend services and forwarding rules will be automatically created with default parameters. Corresponds to the JSON property networkingAutoConfiguration



19177
19178
19179
# File 'lib/google/apis/compute_alpha/classes.rb', line 19177

def networking_auto_configuration
  @networking_auto_configuration
end

#regionString

Output only. [Output Only] URL of the region where the resource resides. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body. Corresponds to the JSON property region

Returns:

  • (String)


19184
19185
19186
# File 'lib/google/apis/compute_alpha/classes.rb', line 19184

def region
  @region
end

#secondary_zone_capacityString

Indicates the capacity guarantees in the secondary zone. Corresponds to the JSON property secondaryZoneCapacity

Returns:

  • (String)


19189
19190
19191
# File 'lib/google/apis/compute_alpha/classes.rb', line 19189

def secondary_zone_capacity
  @secondary_zone_capacity
end

Output only. [Output only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


19194
19195
19196
# File 'lib/google/apis/compute_alpha/classes.rb', line 19194

def self_link
  @self_link
end

Output only. [Output Only] Server-defined URL for this resource with the resource id. Corresponds to the JSON property selfLinkWithId

Returns:

  • (String)


19200
19201
19202
# File 'lib/google/apis/compute_alpha/classes.rb', line 19200

def self_link_with_id
  @self_link_with_id
end

#statusGoogle::Apis::ComputeAlpha::HaControllerStatus

Contains information about current status of the HaController. Corresponds to the JSON property status



19205
19206
19207
# File 'lib/google/apis/compute_alpha/classes.rb', line 19205

def status
  @status
end

#zone_configurationsHash<String,Google::Apis::ComputeAlpha::HaControllerZoneConfiguration>

Map of zone configurations Key: name of the zone Value: ZoneConfiguration Corresponds to the JSON property zoneConfigurations



19212
19213
19214
# File 'lib/google/apis/compute_alpha/classes.rb', line 19212

def zone_configurations
  @zone_configurations
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



19219
19220
19221
19222
19223
19224
19225
19226
19227
19228
19229
19230
19231
19232
19233
19234
19235
19236
# File 'lib/google/apis/compute_alpha/classes.rb', line 19219

def update!(**args)
  @backend_services = args[:backend_services] if args.key?(:backend_services)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @failover_capacity = args[:failover_capacity] if args.key?(:failover_capacity)
  @failover_initiation = args[:failover_initiation] if args.key?(:failover_initiation)
  @id = args[:id] if args.key?(:id)
  @instance_name = args[:instance_name] if args.key?(:instance_name)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @networking_auto_configuration = args[:networking_auto_configuration] if args.key?(:networking_auto_configuration)
  @region = args[:region] if args.key?(:region)
  @secondary_zone_capacity = args[:secondary_zone_capacity] if args.key?(:secondary_zone_capacity)
  @self_link = args[:self_link] if args.key?(:self_link)
  @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id)
  @status = args[:status] if args.key?(:status)
  @zone_configurations = args[:zone_configurations] if args.key?(:zone_configurations)
end