Class: Google::Apis::ComputeAlpha::HaControllerStatus
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::HaControllerStatus
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Contains information about current status of the HaController.
Instance Attribute Summary collapse
-
#failover_progress ⇒ Google::Apis::ComputeAlpha::HaControllerStatusFailoverProgress
Contains information about the current failover operation.
-
#last_failover_info ⇒ Google::Apis::ComputeAlpha::HaControllerStatusFailoverProgress
Contains information about the current failover operation.
-
#ongoing_failover ⇒ Boolean
(also: #ongoing_failover?)
Output only.
-
#primary_instance ⇒ String
Output only.
-
#primary_zone ⇒ String
Output only.
-
#ready_for_failover ⇒ Boolean
(also: #ready_for_failover?)
Output only.
-
#zone_status ⇒ Hash<String,Google::Apis::ComputeAlpha::HaControllerStatusZoneStatus>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HaControllerStatus
constructor
A new instance of HaControllerStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HaControllerStatus
Returns a new instance of HaControllerStatus.
20902 20903 20904 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 20902 def initialize(**args) update!(**args) end |
Instance Attribute Details
#failover_progress ⇒ Google::Apis::ComputeAlpha::HaControllerStatusFailoverProgress
Contains information about the current failover operation.
Corresponds to the JSON property failoverProgress
20858 20859 20860 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 20858 def failover_progress @failover_progress end |
#last_failover_info ⇒ Google::Apis::ComputeAlpha::HaControllerStatusFailoverProgress
Contains information about the current failover operation.
Corresponds to the JSON property lastFailoverInfo
20863 20864 20865 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 20863 def last_failover_info @last_failover_info end |
#ongoing_failover ⇒ Boolean Also known as: ongoing_failover?
Output only. [Output Only] Indicates if the failover is currently in-progress.
Corresponds to the JSON property ongoingFailover
20868 20869 20870 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 20868 def ongoing_failover @ongoing_failover end |
#primary_instance ⇒ String
Output only. [Output Only] The URL to the instance that is intended to be
primary at
this moment. Primary instance will be changed at the very beginning of a
failover operation.
Corresponds to the JSON property primaryInstance
20877 20878 20879 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 20877 def primary_instance @primary_instance end |
#primary_zone ⇒ String
Output only. [Output Only] The name of the zone that is intended to be primary
at this
moment. Primary zone will be changed at the very beginning of a failover
operation. The zone may not be operational in the middle of a failover
operation.
Corresponds to the JSON property primaryZone
20886 20887 20888 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 20886 def primary_zone @primary_zone end |
#ready_for_failover ⇒ Boolean Also known as: ready_for_failover?
Output only. [Output Only] Indicates if the resource is ready for initiating a
failover to the secondary zone.
Corresponds to the JSON property readyForFailover
20892 20893 20894 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 20892 def ready_for_failover @ready_for_failover end |
#zone_status ⇒ Hash<String,Google::Apis::ComputeAlpha::HaControllerStatusZoneStatus>
Output only. [Output Only] Map of zone statuses.
Key: name of the zone
Value: ZoneStatus
Corresponds to the JSON property zoneStatus
20900 20901 20902 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 20900 def zone_status @zone_status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
20907 20908 20909 20910 20911 20912 20913 20914 20915 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 20907 def update!(**args) @failover_progress = args[:failover_progress] if args.key?(:failover_progress) @last_failover_info = args[:last_failover_info] if args.key?(:last_failover_info) @ongoing_failover = args[:ongoing_failover] if args.key?(:ongoing_failover) @primary_instance = args[:primary_instance] if args.key?(:primary_instance) @primary_zone = args[:primary_zone] if args.key?(:primary_zone) @ready_for_failover = args[:ready_for_failover] if args.key?(:ready_for_failover) @zone_status = args[:zone_status] if args.key?(:zone_status) end |