Class: Google::Apis::ComputeAlpha::HaControllerStatus

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains information about current status of the HaController.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HaControllerStatus

Returns a new instance of HaControllerStatus.



19343
19344
19345
# File 'lib/google/apis/compute_alpha/classes.rb', line 19343

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#failover_progressGoogle::Apis::ComputeAlpha::HaControllerStatusFailoverProgress

Contains information about the current failover operation. Corresponds to the JSON property failoverProgress



19299
19300
19301
# File 'lib/google/apis/compute_alpha/classes.rb', line 19299

def failover_progress
  @failover_progress
end

#last_failover_infoGoogle::Apis::ComputeAlpha::HaControllerStatusFailoverProgress

Contains information about the current failover operation. Corresponds to the JSON property lastFailoverInfo



19304
19305
19306
# File 'lib/google/apis/compute_alpha/classes.rb', line 19304

def last_failover_info
  @last_failover_info
end

#ongoing_failoverBoolean Also known as: ongoing_failover?

Output only. [Output Only] Indicates if the failover is currently in-progress. Corresponds to the JSON property ongoingFailover

Returns:

  • (Boolean)


19309
19310
19311
# File 'lib/google/apis/compute_alpha/classes.rb', line 19309

def ongoing_failover
  @ongoing_failover
end

#primary_instanceString

Output only. [Output Only] The URL to the instance that is intended to be primary at this moment. Primary instance will be changed at the very beginning of a failover operation. Corresponds to the JSON property primaryInstance

Returns:

  • (String)


19318
19319
19320
# File 'lib/google/apis/compute_alpha/classes.rb', line 19318

def primary_instance
  @primary_instance
end

#primary_zoneString

Output only. [Output Only] The name of the zone that is intended to be primary at this moment. Primary zone will be changed at the very beginning of a failover operation. The zone may not be operational in the middle of a failover operation. Corresponds to the JSON property primaryZone

Returns:

  • (String)


19327
19328
19329
# File 'lib/google/apis/compute_alpha/classes.rb', line 19327

def primary_zone
  @primary_zone
end

#ready_for_failoverBoolean Also known as: ready_for_failover?

Output only. [Output Only] Indicates if the resource is ready for initiating a failover to the secondary zone. Corresponds to the JSON property readyForFailover

Returns:

  • (Boolean)


19333
19334
19335
# File 'lib/google/apis/compute_alpha/classes.rb', line 19333

def ready_for_failover
  @ready_for_failover
end

#zone_statusHash<String,Google::Apis::ComputeAlpha::HaControllerStatusZoneStatus>

Output only. [Output Only] Map of zone statuses. Key: name of the zone Value: ZoneStatus Corresponds to the JSON property zoneStatus



19341
19342
19343
# File 'lib/google/apis/compute_alpha/classes.rb', line 19341

def zone_status
  @zone_status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



19348
19349
19350
19351
19352
19353
19354
19355
19356
# File 'lib/google/apis/compute_alpha/classes.rb', line 19348

def update!(**args)
  @failover_progress = args[:failover_progress] if args.key?(:failover_progress)
  @last_failover_info = args[:last_failover_info] if args.key?(:last_failover_info)
  @ongoing_failover = args[:ongoing_failover] if args.key?(:ongoing_failover)
  @primary_instance = args[:primary_instance] if args.key?(:primary_instance)
  @primary_zone = args[:primary_zone] if args.key?(:primary_zone)
  @ready_for_failover = args[:ready_for_failover] if args.key?(:ready_for_failover)
  @zone_status = args[:zone_status] if args.key?(:zone_status)
end