Class: Google::Apis::ComputeAlpha::HaControllerStatusFailoverProgress
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::HaControllerStatusFailoverProgress
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Contains information about the current failover operation.
Instance Attribute Summary collapse
-
#failover_complete_timestamp ⇒ String
Output only.
-
#failover_trigger ⇒ String
Output only.
-
#failover_trigger_timestamp ⇒ String
Output only.
-
#last_failover_attempt ⇒ Google::Apis::ComputeAlpha::HaControllerStatusFailoverProgressLastFailoverAttempt
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HaControllerStatusFailoverProgress
constructor
A new instance of HaControllerStatusFailoverProgress.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HaControllerStatusFailoverProgress
Returns a new instance of HaControllerStatusFailoverProgress.
20947 20948 20949 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 20947 def initialize(**args) update!(**args) end |
Instance Attribute Details
#failover_complete_timestamp ⇒ String
Output only. [Output Only] Timestamp of the failover completion.
Filled only if the failover is completed, in lastFailoverInfo.
Corresponds to the JSON property failoverCompleteTimestamp
20926 20927 20928 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 20926 def @failover_complete_timestamp end |
#failover_trigger ⇒ String
Output only. [Output Only] Indicates if failover has been triggered
automatically or
manually.
Corresponds to the JSON property failoverTrigger
20933 20934 20935 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 20933 def failover_trigger @failover_trigger end |
#failover_trigger_timestamp ⇒ String
Output only. [Output Only] Timestamp of the last failover trigger.
Corresponds to the JSON property failoverTriggerTimestamp
20938 20939 20940 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 20938 def @failover_trigger_timestamp end |
#last_failover_attempt ⇒ Google::Apis::ComputeAlpha::HaControllerStatusFailoverProgressLastFailoverAttempt
Output only. [Output Only] Contains details of the last failed failover. This
field
is filled only if the current failover is failing
Corresponds to the JSON property lastFailoverAttempt
20945 20946 20947 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 20945 def last_failover_attempt @last_failover_attempt end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
20952 20953 20954 20955 20956 20957 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 20952 def update!(**args) @failover_complete_timestamp = args[:failover_complete_timestamp] if args.key?(:failover_complete_timestamp) @failover_trigger = args[:failover_trigger] if args.key?(:failover_trigger) @failover_trigger_timestamp = args[:failover_trigger_timestamp] if args.key?(:failover_trigger_timestamp) @last_failover_attempt = args[:last_failover_attempt] if args.key?(:last_failover_attempt) end |