Class: Google::Apis::ComputeAlpha::HaControllerStatusFailoverProgress

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains information about the current failover operation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HaControllerStatusFailoverProgress

Returns a new instance of HaControllerStatusFailoverProgress.



20675
20676
20677
# File 'lib/google/apis/compute_alpha/classes.rb', line 20675

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#failover_complete_timestampString

Output only. [Output Only] Timestamp of the failover completion. Filled only if the failover is completed, in lastFailoverInfo. Corresponds to the JSON property failoverCompleteTimestamp

Returns:

  • (String)


20654
20655
20656
# File 'lib/google/apis/compute_alpha/classes.rb', line 20654

def failover_complete_timestamp
  @failover_complete_timestamp
end

#failover_triggerString

Output only. [Output Only] Indicates if failover has been triggered automatically or manually. Corresponds to the JSON property failoverTrigger

Returns:

  • (String)


20661
20662
20663
# File 'lib/google/apis/compute_alpha/classes.rb', line 20661

def failover_trigger
  @failover_trigger
end

#failover_trigger_timestampString

Output only. [Output Only] Timestamp of the last failover trigger. Corresponds to the JSON property failoverTriggerTimestamp

Returns:

  • (String)


20666
20667
20668
# File 'lib/google/apis/compute_alpha/classes.rb', line 20666

def failover_trigger_timestamp
  @failover_trigger_timestamp
end

#last_failover_attemptGoogle::Apis::ComputeAlpha::HaControllerStatusFailoverProgressLastFailoverAttempt

Output only. [Output Only] Contains details of the last failed failover. This field is filled only if the current failover is failing Corresponds to the JSON property lastFailoverAttempt



20673
20674
20675
# File 'lib/google/apis/compute_alpha/classes.rb', line 20673

def last_failover_attempt
  @last_failover_attempt
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20680
20681
20682
20683
20684
20685
# File 'lib/google/apis/compute_alpha/classes.rb', line 20680

def update!(**args)
  @failover_complete_timestamp = args[:failover_complete_timestamp] if args.key?(:failover_complete_timestamp)
  @failover_trigger = args[:failover_trigger] if args.key?(:failover_trigger)
  @failover_trigger_timestamp = args[:failover_trigger_timestamp] if args.key?(:failover_trigger_timestamp)
  @last_failover_attempt = args[:last_failover_attempt] if args.key?(:last_failover_attempt)
end