Class: Google::Apis::ComputeAlpha::HaControllerStatusFailoverProgress

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains information about the current failover operation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HaControllerStatusFailoverProgress

Returns a new instance of HaControllerStatusFailoverProgress.



19943
19944
19945
# File 'lib/google/apis/compute_alpha/classes.rb', line 19943

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#failover_complete_timestampString

Output only. [Output Only] Timestamp of the failover completion. Filled only if the failover is completed, in lastFailoverInfo. Corresponds to the JSON property failoverCompleteTimestamp

Returns:

  • (String)


19922
19923
19924
# File 'lib/google/apis/compute_alpha/classes.rb', line 19922

def failover_complete_timestamp
  @failover_complete_timestamp
end

#failover_triggerString

Output only. [Output Only] Indicates if failover has been triggered automatically or manually. Corresponds to the JSON property failoverTrigger

Returns:

  • (String)


19929
19930
19931
# File 'lib/google/apis/compute_alpha/classes.rb', line 19929

def failover_trigger
  @failover_trigger
end

#failover_trigger_timestampString

Output only. [Output Only] Timestamp of the last failover trigger. Corresponds to the JSON property failoverTriggerTimestamp

Returns:

  • (String)


19934
19935
19936
# File 'lib/google/apis/compute_alpha/classes.rb', line 19934

def failover_trigger_timestamp
  @failover_trigger_timestamp
end

#last_failover_attemptGoogle::Apis::ComputeAlpha::HaControllerStatusFailoverProgressLastFailoverAttempt

Output only. [Output Only] Contains details of the last failed failover. This field is filled only if the current failover is failing Corresponds to the JSON property lastFailoverAttempt



19941
19942
19943
# File 'lib/google/apis/compute_alpha/classes.rb', line 19941

def last_failover_attempt
  @last_failover_attempt
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



19948
19949
19950
19951
19952
19953
# File 'lib/google/apis/compute_alpha/classes.rb', line 19948

def update!(**args)
  @failover_complete_timestamp = args[:failover_complete_timestamp] if args.key?(:failover_complete_timestamp)
  @failover_trigger = args[:failover_trigger] if args.key?(:failover_trigger)
  @failover_trigger_timestamp = args[:failover_trigger_timestamp] if args.key?(:failover_trigger_timestamp)
  @last_failover_attempt = args[:last_failover_attempt] if args.key?(:last_failover_attempt)
end