Class: Google::Apis::ComputeAlpha::HaControllerStatusFailoverProgress
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::HaControllerStatusFailoverProgress
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Contains information about the current failover operation.
Instance Attribute Summary collapse
-
#failover_complete_timestamp ⇒ String
Output only.
-
#failover_trigger ⇒ String
Output only.
-
#failover_trigger_timestamp ⇒ String
Output only.
-
#last_failover_attempt ⇒ Google::Apis::ComputeAlpha::HaControllerStatusFailoverProgressLastFailoverAttempt
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HaControllerStatusFailoverProgress
constructor
A new instance of HaControllerStatusFailoverProgress.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HaControllerStatusFailoverProgress
Returns a new instance of HaControllerStatusFailoverProgress.
19754 19755 19756 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 19754 def initialize(**args) update!(**args) end |
Instance Attribute Details
#failover_complete_timestamp ⇒ String
Output only. [Output Only] Timestamp of the failover completion.
Filled only if the failover is completed, in lastFailoverInfo.
Corresponds to the JSON property failoverCompleteTimestamp
19733 19734 19735 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 19733 def @failover_complete_timestamp end |
#failover_trigger ⇒ String
Output only. [Output Only] Indicates if failover has been triggered
automatically or
manually.
Corresponds to the JSON property failoverTrigger
19740 19741 19742 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 19740 def failover_trigger @failover_trigger end |
#failover_trigger_timestamp ⇒ String
Output only. [Output Only] Timestamp of the last failover trigger.
Corresponds to the JSON property failoverTriggerTimestamp
19745 19746 19747 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 19745 def @failover_trigger_timestamp end |
#last_failover_attempt ⇒ Google::Apis::ComputeAlpha::HaControllerStatusFailoverProgressLastFailoverAttempt
Output only. [Output Only] Contains details of the last failed failover. This
field
is filled only if the current failover is failing
Corresponds to the JSON property lastFailoverAttempt
19752 19753 19754 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 19752 def last_failover_attempt @last_failover_attempt end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
19759 19760 19761 19762 19763 19764 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 19759 def update!(**args) @failover_complete_timestamp = args[:failover_complete_timestamp] if args.key?(:failover_complete_timestamp) @failover_trigger = args[:failover_trigger] if args.key?(:failover_trigger) @failover_trigger_timestamp = args[:failover_trigger_timestamp] if args.key?(:failover_trigger_timestamp) @last_failover_attempt = args[:last_failover_attempt] if args.key?(:last_failover_attempt) end |