Class: Google::Apis::ComputeAlpha::HaControllerStatusFailoverProgress
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::HaControllerStatusFailoverProgress
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Contains information about the current failover operation.
Instance Attribute Summary collapse
-
#failover_complete_timestamp ⇒ String
Output only.
-
#failover_trigger ⇒ String
Output only.
-
#failover_trigger_timestamp ⇒ String
Output only.
-
#last_failover_attempt ⇒ Google::Apis::ComputeAlpha::HaControllerStatusFailoverProgressLastFailoverAttempt
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HaControllerStatusFailoverProgress
constructor
A new instance of HaControllerStatusFailoverProgress.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HaControllerStatusFailoverProgress
Returns a new instance of HaControllerStatusFailoverProgress.
19388 19389 19390 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 19388 def initialize(**args) update!(**args) end |
Instance Attribute Details
#failover_complete_timestamp ⇒ String
Output only. [Output Only] Timestamp of the failover completion.
Filled only if the failover is completed, in lastFailoverInfo.
Corresponds to the JSON property failoverCompleteTimestamp
19367 19368 19369 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 19367 def @failover_complete_timestamp end |
#failover_trigger ⇒ String
Output only. [Output Only] Indicates if failover has been triggered
automatically or
manually.
Corresponds to the JSON property failoverTrigger
19374 19375 19376 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 19374 def failover_trigger @failover_trigger end |
#failover_trigger_timestamp ⇒ String
Output only. [Output Only] Timestamp of the last failover trigger.
Corresponds to the JSON property failoverTriggerTimestamp
19379 19380 19381 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 19379 def @failover_trigger_timestamp end |
#last_failover_attempt ⇒ Google::Apis::ComputeAlpha::HaControllerStatusFailoverProgressLastFailoverAttempt
Output only. [Output Only] Contains details of the last failed failover. This
field
is filled only if the current failover is failing
Corresponds to the JSON property lastFailoverAttempt
19386 19387 19388 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 19386 def last_failover_attempt @last_failover_attempt end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
19393 19394 19395 19396 19397 19398 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 19393 def update!(**args) @failover_complete_timestamp = args[:failover_complete_timestamp] if args.key?(:failover_complete_timestamp) @failover_trigger = args[:failover_trigger] if args.key?(:failover_trigger) @failover_trigger_timestamp = args[:failover_trigger_timestamp] if args.key?(:failover_trigger_timestamp) @last_failover_attempt = args[:last_failover_attempt] if args.key?(:last_failover_attempt) end |