Class: Google::Apis::ComputeAlpha::HaControllerStatusZoneStatus
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::HaControllerStatusZoneStatus
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Contains the status of a specific zone.
Instance Attribute Summary collapse
-
#is_primary ⇒ Boolean
(also: #is_primary?)
Output only.
-
#is_zone_ready ⇒ Boolean
(also: #is_zone_ready?)
Output only.
-
#last_error ⇒ Google::Apis::ComputeAlpha::HaControllerStatusZoneStatusLastError
Contains details of the last failed operation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HaControllerStatusZoneStatus
constructor
A new instance of HaControllerStatusZoneStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HaControllerStatusZoneStatus
Returns a new instance of HaControllerStatusZoneStatus.
19574 19575 19576 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 19574 def initialize(**args) update!(**args) end |
Instance Attribute Details
#is_primary ⇒ Boolean Also known as: is_primary?
Output only. [Output Only] Indicates if the zone is primary at this moment.
Corresponds to the JSON property isPrimary
19559 19560 19561 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 19559 def is_primary @is_primary end |
#is_zone_ready ⇒ Boolean Also known as: is_zone_ready?
Output only. [Output Only] Indicates if the zone is ready for initiating a
failover.
Corresponds to the JSON property isZoneReady
19566 19567 19568 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 19566 def is_zone_ready @is_zone_ready end |
#last_error ⇒ Google::Apis::ComputeAlpha::HaControllerStatusZoneStatusLastError
Contains details of the last failed operation.
Corresponds to the JSON property lastError
19572 19573 19574 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 19572 def last_error @last_error end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
19579 19580 19581 19582 19583 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 19579 def update!(**args) @is_primary = args[:is_primary] if args.key?(:is_primary) @is_zone_ready = args[:is_zone_ready] if args.key?(:is_zone_ready) @last_error = args[:last_error] if args.key?(:last_error) end |