Class: Google::Apis::ComputeAlpha::HaControllerZoneConfiguration
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::HaControllerZoneConfiguration
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Config for a zone that the HaController may use for running the VM instance.
Instance Attribute Summary collapse
-
#node_affinities ⇒ Array<Google::Apis::ComputeAlpha::HaControllerZoneConfigurationNodeAffinity>
A set of node affinity configurations.
-
#reservation_affinity ⇒ Google::Apis::ComputeAlpha::HaControllerZoneConfigurationReservationAffinity
Specifies the reservations that this instance can consume from.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HaControllerZoneConfiguration
constructor
A new instance of HaControllerZoneConfiguration.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HaControllerZoneConfiguration
Returns a new instance of HaControllerZoneConfiguration.
19753 19754 19755 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 19753 def initialize(**args) update!(**args) end |
Instance Attribute Details
#node_affinities ⇒ Array<Google::Apis::ComputeAlpha::HaControllerZoneConfigurationNodeAffinity>
A set of node affinity configurations. Refer toConfiguring node
affinity for more information.
Overrides reservationAffinity.
Corresponds to the JSON property nodeAffinities
19743 19744 19745 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 19743 def node_affinities @node_affinities end |
#reservation_affinity ⇒ Google::Apis::ComputeAlpha::HaControllerZoneConfigurationReservationAffinity
Specifies the reservations that this instance can consume from.
This message should be an exact copy of the Instances representation
of AllocationAffinity.
LINT.IfChange(HaControllerAllocationAffinityMixer)
Corresponds to the JSON property reservationAffinity
19751 19752 19753 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 19751 def reservation_affinity @reservation_affinity end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
19758 19759 19760 19761 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 19758 def update!(**args) @node_affinities = args[:node_affinities] if args.key?(:node_affinities) @reservation_affinity = args[:reservation_affinity] if args.key?(:reservation_affinity) end |