Class: Google::Apis::ComputeAlpha::HaControllerZoneConfigurationNodeAffinity

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Node Affinity: the configuration of desired nodes onto which the Instance could be scheduled. This message should be an exact copy of the Instances representation of NodeAffinity.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HaControllerZoneConfigurationNodeAffinity

Returns a new instance of HaControllerZoneConfigurationNodeAffinity.



21077
21078
21079
# File 'lib/google/apis/compute_alpha/classes.rb', line 21077

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#keyString

Corresponds to the label key of Node resource. Corresponds to the JSON property key

Returns:

  • (String)


21064
21065
21066
# File 'lib/google/apis/compute_alpha/classes.rb', line 21064

def key
  @key
end

#operatorString

Defines the operation of node selection. Valid operators areIN for affinity and NOT_IN for anti-affinity. Corresponds to the JSON property operator

Returns:

  • (String)


21070
21071
21072
# File 'lib/google/apis/compute_alpha/classes.rb', line 21070

def operator
  @operator
end

#valuesArray<String>

Corresponds to the label values of Node resource. Corresponds to the JSON property values

Returns:

  • (Array<String>)


21075
21076
21077
# File 'lib/google/apis/compute_alpha/classes.rb', line 21075

def values
  @values
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



21082
21083
21084
21085
21086
# File 'lib/google/apis/compute_alpha/classes.rb', line 21082

def update!(**args)
  @key = args[:key] if args.key?(:key)
  @operator = args[:operator] if args.key?(:operator)
  @values = args[:values] if args.key?(:values)
end