Class: Google::Apis::ComputeAlpha::HaControllerZoneConfigurationNodeAffinity

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Node Affinity: the configuration of desired nodes onto which the Instance could be scheduled. This message should be an exact copy of the Instances representation of NodeAffinity.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HaControllerZoneConfigurationNodeAffinity

Returns a new instance of HaControllerZoneConfigurationNodeAffinity.



20341
20342
20343
# File 'lib/google/apis/compute_alpha/classes.rb', line 20341

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#keyString

Corresponds to the label key of Node resource. Corresponds to the JSON property key

Returns:

  • (String)


20328
20329
20330
# File 'lib/google/apis/compute_alpha/classes.rb', line 20328

def key
  @key
end

#operatorString

Defines the operation of node selection. Valid operators areIN for affinity and NOT_IN for anti-affinity. Corresponds to the JSON property operator

Returns:

  • (String)


20334
20335
20336
# File 'lib/google/apis/compute_alpha/classes.rb', line 20334

def operator
  @operator
end

#valuesArray<String>

Corresponds to the label values of Node resource. Corresponds to the JSON property values

Returns:

  • (Array<String>)


20339
20340
20341
# File 'lib/google/apis/compute_alpha/classes.rb', line 20339

def values
  @values
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20346
20347
20348
20349
20350
# File 'lib/google/apis/compute_alpha/classes.rb', line 20346

def update!(**args)
  @key = args[:key] if args.key?(:key)
  @operator = args[:operator] if args.key?(:operator)
  @values = args[:values] if args.key?(:values)
end