Class: Google::Apis::ComputeAlpha::HaControllerZoneConfigurationNodeAffinity

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Node Affinity: the configuration of desired nodes onto which the Instance could be scheduled. This message should be an exact copy of the Instances representation of NodeAffinity.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HaControllerZoneConfigurationNodeAffinity

Returns a new instance of HaControllerZoneConfigurationNodeAffinity.



20146
20147
20148
# File 'lib/google/apis/compute_alpha/classes.rb', line 20146

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#keyString

Corresponds to the label key of Node resource. Corresponds to the JSON property key

Returns:

  • (String)


20133
20134
20135
# File 'lib/google/apis/compute_alpha/classes.rb', line 20133

def key
  @key
end

#operatorString

Defines the operation of node selection. Valid operators areIN for affinity and NOT_IN for anti-affinity. Corresponds to the JSON property operator

Returns:

  • (String)


20139
20140
20141
# File 'lib/google/apis/compute_alpha/classes.rb', line 20139

def operator
  @operator
end

#valuesArray<String>

Corresponds to the label values of Node resource. Corresponds to the JSON property values

Returns:

  • (Array<String>)


20144
20145
20146
# File 'lib/google/apis/compute_alpha/classes.rb', line 20144

def values
  @values
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20151
20152
20153
20154
20155
# File 'lib/google/apis/compute_alpha/classes.rb', line 20151

def update!(**args)
  @key = args[:key] if args.key?(:key)
  @operator = args[:operator] if args.key?(:operator)
  @values = args[:values] if args.key?(:values)
end