Class: Google::Apis::ComputeAlpha::HaControllerZoneConfigurationNodeAffinity
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::HaControllerZoneConfigurationNodeAffinity
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Node Affinity: the configuration of desired nodes onto which the Instance could be scheduled. This message should be an exact copy of the Instances representation of NodeAffinity. LINT.IfChange(HaControllerNodeAffinityMixer)
Instance Attribute Summary collapse
-
#key ⇒ String
Corresponds to the label key of Node resource.
-
#operator ⇒ String
Defines the operation of node selection.
-
#values ⇒ Array<String>
Corresponds to the label values of Node resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HaControllerZoneConfigurationNodeAffinity
constructor
A new instance of HaControllerZoneConfigurationNodeAffinity.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HaControllerZoneConfigurationNodeAffinity
Returns a new instance of HaControllerZoneConfigurationNodeAffinity.
19788 19789 19790 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 19788 def initialize(**args) update!(**args) end |
Instance Attribute Details
#key ⇒ String
Corresponds to the label key of Node resource.
Corresponds to the JSON property key
19775 19776 19777 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 19775 def key @key end |
#operator ⇒ String
Defines the operation of node selection. Valid operators areIN for affinity
and NOT_IN for anti-affinity.
Corresponds to the JSON property operator
19781 19782 19783 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 19781 def operator @operator end |
#values ⇒ Array<String>
Corresponds to the label values of Node resource.
Corresponds to the JSON property values
19786 19787 19788 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 19786 def values @values end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
19793 19794 19795 19796 19797 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 19793 def update!(**args) @key = args[:key] if args.key?(:key) @operator = args[:operator] if args.key?(:operator) @values = args[:values] if args.key?(:values) end |