Class: Google::Apis::ComputeAlpha::HaControllersAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HaControllersAggregatedList

Returns a new instance of HaControllersAggregatedList.



21455
21456
21457
# File 'lib/google/apis/compute_alpha/classes.rb', line 21455

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


21411
21412
21413
# File 'lib/google/apis/compute_alpha/classes.rb', line 21411

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


21416
21417
21418
# File 'lib/google/apis/compute_alpha/classes.rb', line 21416

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::HaControllersScopedList>

A list of HaControllersScopedList resources. Corresponds to the JSON property items



21421
21422
21423
# File 'lib/google/apis/compute_alpha/classes.rb', line 21421

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# haControllersAggregatedList for lists of HaControllers. Corresponds to the JSON property kind

Returns:

  • (String)


21428
21429
21430
# File 'lib/google/apis/compute_alpha/classes.rb', line 21428

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


21438
21439
21440
# File 'lib/google/apis/compute_alpha/classes.rb', line 21438

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


21443
21444
21445
# File 'lib/google/apis/compute_alpha/classes.rb', line 21443

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


21448
21449
21450
# File 'lib/google/apis/compute_alpha/classes.rb', line 21448

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::HaControllersAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



21453
21454
21455
# File 'lib/google/apis/compute_alpha/classes.rb', line 21453

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



21460
21461
21462
21463
21464
21465
21466
21467
21468
21469
# File 'lib/google/apis/compute_alpha/classes.rb', line 21460

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end