Class: Google::Apis::ComputeAlpha::HaControllersAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HaControllersAggregatedList

Returns a new instance of HaControllersAggregatedList.



21183
21184
21185
# File 'lib/google/apis/compute_alpha/classes.rb', line 21183

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


21139
21140
21141
# File 'lib/google/apis/compute_alpha/classes.rb', line 21139

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


21144
21145
21146
# File 'lib/google/apis/compute_alpha/classes.rb', line 21144

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::HaControllersScopedList>

A list of HaControllersScopedList resources. Corresponds to the JSON property items



21149
21150
21151
# File 'lib/google/apis/compute_alpha/classes.rb', line 21149

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# haControllersAggregatedList for lists of HaControllers. Corresponds to the JSON property kind

Returns:

  • (String)


21156
21157
21158
# File 'lib/google/apis/compute_alpha/classes.rb', line 21156

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


21166
21167
21168
# File 'lib/google/apis/compute_alpha/classes.rb', line 21166

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


21171
21172
21173
# File 'lib/google/apis/compute_alpha/classes.rb', line 21171

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


21176
21177
21178
# File 'lib/google/apis/compute_alpha/classes.rb', line 21176

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::HaControllersAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



21181
21182
21183
# File 'lib/google/apis/compute_alpha/classes.rb', line 21181

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



21188
21189
21190
21191
21192
21193
21194
21195
21196
21197
# File 'lib/google/apis/compute_alpha/classes.rb', line 21188

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end