Class: Google::Apis::ComputeAlpha::HaControllersAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::HaControllersAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::HaControllersScopedList>
A list of HaControllersScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::HaControllersAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HaControllersAggregatedList
constructor
A new instance of HaControllersAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HaControllersAggregatedList
Returns a new instance of HaControllersAggregatedList.
20455 20456 20457 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 20455 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
20411 20412 20413 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 20411 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
20416 20417 20418 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 20416 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::HaControllersScopedList>
A list of HaControllersScopedList resources.
Corresponds to the JSON property items
20421 20422 20423 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 20421 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
haControllersAggregatedList for lists of
HaControllers.
Corresponds to the JSON property kind
20428 20429 20430 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 20428 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
20438 20439 20440 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 20438 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
20443 20444 20445 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 20443 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
20448 20449 20450 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 20448 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::HaControllersAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
20453 20454 20455 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 20453 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
20460 20461 20462 20463 20464 20465 20466 20467 20468 20469 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 20460 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |