Class: Google::Apis::ComputeAlpha::HaControllersAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HaControllersAggregatedList

Returns a new instance of HaControllersAggregatedList.



20235
20236
20237
# File 'lib/google/apis/compute_alpha/classes.rb', line 20235

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


20191
20192
20193
# File 'lib/google/apis/compute_alpha/classes.rb', line 20191

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


20196
20197
20198
# File 'lib/google/apis/compute_alpha/classes.rb', line 20196

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::HaControllersScopedList>

A list of HaControllersScopedList resources. Corresponds to the JSON property items



20201
20202
20203
# File 'lib/google/apis/compute_alpha/classes.rb', line 20201

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# haControllersAggregatedList for lists of HaControllers. Corresponds to the JSON property kind

Returns:

  • (String)


20208
20209
20210
# File 'lib/google/apis/compute_alpha/classes.rb', line 20208

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


20218
20219
20220
# File 'lib/google/apis/compute_alpha/classes.rb', line 20218

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


20223
20224
20225
# File 'lib/google/apis/compute_alpha/classes.rb', line 20223

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


20228
20229
20230
# File 'lib/google/apis/compute_alpha/classes.rb', line 20228

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::HaControllersAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



20233
20234
20235
# File 'lib/google/apis/compute_alpha/classes.rb', line 20233

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20240
20241
20242
20243
20244
20245
20246
20247
20248
20249
# File 'lib/google/apis/compute_alpha/classes.rb', line 20240

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end