Class: Google::Apis::ComputeAlpha::HaControllersAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HaControllersAggregatedList

Returns a new instance of HaControllersAggregatedList.



20261
20262
20263
# File 'lib/google/apis/compute_alpha/classes.rb', line 20261

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


20217
20218
20219
# File 'lib/google/apis/compute_alpha/classes.rb', line 20217

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


20222
20223
20224
# File 'lib/google/apis/compute_alpha/classes.rb', line 20222

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::HaControllersScopedList>

A list of HaControllersScopedList resources. Corresponds to the JSON property items



20227
20228
20229
# File 'lib/google/apis/compute_alpha/classes.rb', line 20227

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# haControllersAggregatedList for lists of HaControllers. Corresponds to the JSON property kind

Returns:

  • (String)


20234
20235
20236
# File 'lib/google/apis/compute_alpha/classes.rb', line 20234

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


20244
20245
20246
# File 'lib/google/apis/compute_alpha/classes.rb', line 20244

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


20249
20250
20251
# File 'lib/google/apis/compute_alpha/classes.rb', line 20249

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


20254
20255
20256
# File 'lib/google/apis/compute_alpha/classes.rb', line 20254

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::HaControllersAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



20259
20260
20261
# File 'lib/google/apis/compute_alpha/classes.rb', line 20259

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20266
20267
20268
20269
20270
20271
20272
20273
20274
20275
# File 'lib/google/apis/compute_alpha/classes.rb', line 20266

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end