Class: Google::Apis::ComputeAlpha::HaControllersAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::HaControllersAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::HaControllersScopedList>
A list of HaControllersScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::HaControllersAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HaControllersAggregatedList
constructor
A new instance of HaControllersAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HaControllersAggregatedList
Returns a new instance of HaControllersAggregatedList.
19895 19896 19897 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 19895 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
19851 19852 19853 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 19851 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
19856 19857 19858 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 19856 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::HaControllersScopedList>
A list of HaControllersScopedList resources.
Corresponds to the JSON property items
19861 19862 19863 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 19861 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
haControllersAggregatedList for lists of
HaControllers.
Corresponds to the JSON property kind
19868 19869 19870 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 19868 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
19878 19879 19880 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 19878 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
19883 19884 19885 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 19883 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
19888 19889 19890 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 19888 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::HaControllersAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
19893 19894 19895 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 19893 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
19900 19901 19902 19903 19904 19905 19906 19907 19908 19909 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 19900 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |