Class: Google::Apis::ComputeAlpha::HaControllersList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HaControllersList

Returns a new instance of HaControllersList.



21604
21605
21606
# File 'lib/google/apis/compute_alpha/classes.rb', line 21604

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


21568
21569
21570
# File 'lib/google/apis/compute_alpha/classes.rb', line 21568

def etag
  @etag
end

#idString

Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


21573
21574
21575
# File 'lib/google/apis/compute_alpha/classes.rb', line 21573

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::HaController>

A list of HaControllers in the specified project and region. Corresponds to the JSON property items



21578
21579
21580
# File 'lib/google/apis/compute_alpha/classes.rb', line 21578

def items
  @items
end

#next_page_tokenString

This token allows you to get the next page of results formaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


21587
21588
21589
# File 'lib/google/apis/compute_alpha/classes.rb', line 21587

def next_page_token
  @next_page_token
end

Output only. [Output only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


21592
21593
21594
# File 'lib/google/apis/compute_alpha/classes.rb', line 21592

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


21597
21598
21599
# File 'lib/google/apis/compute_alpha/classes.rb', line 21597

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::HaControllersList::Warning

Informational warning message. Corresponds to the JSON property warning



21602
21603
21604
# File 'lib/google/apis/compute_alpha/classes.rb', line 21602

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



21609
21610
21611
21612
21613
21614
21615
21616
21617
# File 'lib/google/apis/compute_alpha/classes.rb', line 21609

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end