Class: Google::Apis::ComputeAlpha::HaControllersList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::HaControllersList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::HaController>
A list of HaControllers in the specified project and region.
-
#next_page_token ⇒ String
This token allows you to get the next page of results formaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::HaControllersList::Warning
Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HaControllersList
constructor
A new instance of HaControllersList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HaControllersList
Returns a new instance of HaControllersList.
21332 21333 21334 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 21332 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
21296 21297 21298 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 21296 def etag @etag end |
#id ⇒ String
Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
21301 21302 21303 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 21301 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::HaController>
A list of HaControllers in the specified project and region.
Corresponds to the JSON property items
21306 21307 21308 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 21306 def items @items end |
#next_page_token ⇒ String
This token allows you to get the next page of results formaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
21315 21316 21317 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 21315 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
21320 21321 21322 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 21320 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output only] Unreachable resources.
Corresponds to the JSON property unreachables
21325 21326 21327 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 21325 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::HaControllersList::Warning
Informational warning message.
Corresponds to the JSON property warning
21330 21331 21332 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 21330 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
21337 21338 21339 21340 21341 21342 21343 21344 21345 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 21337 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |