Class: Google::Apis::ComputeAlpha::HaControllersList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HaControllersList

Returns a new instance of HaControllersList.



20604
20605
20606
# File 'lib/google/apis/compute_alpha/classes.rb', line 20604

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


20568
20569
20570
# File 'lib/google/apis/compute_alpha/classes.rb', line 20568

def etag
  @etag
end

#idString

Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


20573
20574
20575
# File 'lib/google/apis/compute_alpha/classes.rb', line 20573

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::HaController>

A list of HaControllers in the specified project and region. Corresponds to the JSON property items



20578
20579
20580
# File 'lib/google/apis/compute_alpha/classes.rb', line 20578

def items
  @items
end

#next_page_tokenString

This token allows you to get the next page of results formaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


20587
20588
20589
# File 'lib/google/apis/compute_alpha/classes.rb', line 20587

def next_page_token
  @next_page_token
end

Output only. [Output only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


20592
20593
20594
# File 'lib/google/apis/compute_alpha/classes.rb', line 20592

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


20597
20598
20599
# File 'lib/google/apis/compute_alpha/classes.rb', line 20597

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::HaControllersList::Warning

Informational warning message. Corresponds to the JSON property warning



20602
20603
20604
# File 'lib/google/apis/compute_alpha/classes.rb', line 20602

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20609
20610
20611
20612
20613
20614
20615
20616
20617
# File 'lib/google/apis/compute_alpha/classes.rb', line 20609

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end