Class: Google::Apis::ComputeAlpha::HaControllersList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::HaControllersList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::HaController>
A list of HaControllers in the specified project and region.
-
#next_page_token ⇒ String
This token allows you to get the next page of results formaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::HaControllersList::Warning
Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HaControllersList
constructor
A new instance of HaControllersList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HaControllersList
Returns a new instance of HaControllersList.
20604 20605 20606 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 20604 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
20568 20569 20570 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 20568 def etag @etag end |
#id ⇒ String
Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
20573 20574 20575 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 20573 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::HaController>
A list of HaControllers in the specified project and region.
Corresponds to the JSON property items
20578 20579 20580 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 20578 def items @items end |
#next_page_token ⇒ String
This token allows you to get the next page of results formaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
20587 20588 20589 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 20587 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
20592 20593 20594 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 20592 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output only] Unreachable resources.
Corresponds to the JSON property unreachables
20597 20598 20599 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 20597 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::HaControllersList::Warning
Informational warning message.
Corresponds to the JSON property warning
20602 20603 20604 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 20602 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
20609 20610 20611 20612 20613 20614 20615 20616 20617 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 20609 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |