Class: Google::Apis::ComputeAlpha::HaControllersList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HaControllersList

Returns a new instance of HaControllersList.



20408
20409
20410
# File 'lib/google/apis/compute_alpha/classes.rb', line 20408

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


20372
20373
20374
# File 'lib/google/apis/compute_alpha/classes.rb', line 20372

def etag
  @etag
end

#idString

Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


20377
20378
20379
# File 'lib/google/apis/compute_alpha/classes.rb', line 20377

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::HaController>

A list of HaControllers in the specified project and region. Corresponds to the JSON property items



20382
20383
20384
# File 'lib/google/apis/compute_alpha/classes.rb', line 20382

def items
  @items
end

#next_page_tokenString

This token allows you to get the next page of results formaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


20391
20392
20393
# File 'lib/google/apis/compute_alpha/classes.rb', line 20391

def next_page_token
  @next_page_token
end

Output only. [Output only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


20396
20397
20398
# File 'lib/google/apis/compute_alpha/classes.rb', line 20396

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


20401
20402
20403
# File 'lib/google/apis/compute_alpha/classes.rb', line 20401

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::HaControllersList::Warning

Informational warning message. Corresponds to the JSON property warning



20406
20407
20408
# File 'lib/google/apis/compute_alpha/classes.rb', line 20406

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20413
20414
20415
20416
20417
20418
20419
20420
20421
# File 'lib/google/apis/compute_alpha/classes.rb', line 20413

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end