Class: Google::Apis::ComputeAlpha::HaControllersList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HaControllersList

Returns a new instance of HaControllersList.



20417
20418
20419
# File 'lib/google/apis/compute_alpha/classes.rb', line 20417

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


20381
20382
20383
# File 'lib/google/apis/compute_alpha/classes.rb', line 20381

def etag
  @etag
end

#idString

Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


20386
20387
20388
# File 'lib/google/apis/compute_alpha/classes.rb', line 20386

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::HaController>

A list of HaControllers in the specified project and region. Corresponds to the JSON property items



20391
20392
20393
# File 'lib/google/apis/compute_alpha/classes.rb', line 20391

def items
  @items
end

#next_page_tokenString

This token allows you to get the next page of results formaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


20400
20401
20402
# File 'lib/google/apis/compute_alpha/classes.rb', line 20400

def next_page_token
  @next_page_token
end

Output only. [Output only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


20405
20406
20407
# File 'lib/google/apis/compute_alpha/classes.rb', line 20405

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


20410
20411
20412
# File 'lib/google/apis/compute_alpha/classes.rb', line 20410

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::HaControllersList::Warning

Informational warning message. Corresponds to the JSON property warning



20415
20416
20417
# File 'lib/google/apis/compute_alpha/classes.rb', line 20415

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20422
20423
20424
20425
20426
20427
20428
20429
20430
# File 'lib/google/apis/compute_alpha/classes.rb', line 20422

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end