Class: Google::Apis::ComputeAlpha::HaControllersList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HaControllersList

Returns a new instance of HaControllersList.



20051
20052
20053
# File 'lib/google/apis/compute_alpha/classes.rb', line 20051

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


20015
20016
20017
# File 'lib/google/apis/compute_alpha/classes.rb', line 20015

def etag
  @etag
end

#idString

Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


20020
20021
20022
# File 'lib/google/apis/compute_alpha/classes.rb', line 20020

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::HaController>

A list of HaControllers in the specified project and region. Corresponds to the JSON property items



20025
20026
20027
# File 'lib/google/apis/compute_alpha/classes.rb', line 20025

def items
  @items
end

#next_page_tokenString

This token allows you to get the next page of results formaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


20034
20035
20036
# File 'lib/google/apis/compute_alpha/classes.rb', line 20034

def next_page_token
  @next_page_token
end

Output only. [Output only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


20039
20040
20041
# File 'lib/google/apis/compute_alpha/classes.rb', line 20039

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


20044
20045
20046
# File 'lib/google/apis/compute_alpha/classes.rb', line 20044

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::HaControllersList::Warning

Informational warning message. Corresponds to the JSON property warning



20049
20050
20051
# File 'lib/google/apis/compute_alpha/classes.rb', line 20049

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20056
20057
20058
20059
20060
20061
20062
20063
20064
# File 'lib/google/apis/compute_alpha/classes.rb', line 20056

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end