Class: Google::Apis::ComputeAlpha::HealthAggregationPolicy

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Represents a health aggregation policy. A health aggregation policy resource defines a policy to aggregate health. For more information, see Health checks overview.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HealthAggregationPolicy

Returns a new instance of HealthAggregationPolicy.



20998
20999
21000
# File 'lib/google/apis/compute_alpha/classes.rb', line 20998

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


20895
20896
20897
# File 'lib/google/apis/compute_alpha/classes.rb', line 20895

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


20901
20902
20903
# File 'lib/google/apis/compute_alpha/classes.rb', line 20901

def description
  @description
end

#fingerprintString

Fingerprint of this resource. A hash of the contents stored in this object. This field is used in optimistic locking. This field will be ignored when inserting a HealthAggregationPolicy. An up-to-date fingerprint must be provided in order to patch the HealthAggregationPolicy; Otherwise, the request will fail with error 412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve the HealthAggregationPolicy. Corresponds to the JSON property fingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


20913
20914
20915
# File 'lib/google/apis/compute_alpha/classes.rb', line 20913

def fingerprint
  @fingerprint
end

#healthy_percent_thresholdFixnum

Can only be set if the policyType field isBACKEND_SERVICE_POLICY. Specifies the threshold (as a percentage) of healthy endpoints required in order to consider the aggregated health result HEALTHY. Defaults to 60. Must be in range [0, 100]. Not applicable if the policyType field isDNB_PUBLIC_IP_POLICY. Can be mutated. This field is optional, and will be set to the default if unspecified. Note that both this threshold and minHealthyThreshold must be satisfied in order for HEALTHY to be the aggregated result. "Endpoints" refers to network endpoints within a Network Endpoint Group or instances within an Instance Group. Corresponds to the JSON property healthyPercentThreshold

Returns:

  • (Fixnum)


20928
20929
20930
# File 'lib/google/apis/compute_alpha/classes.rb', line 20928

def healthy_percent_threshold
  @healthy_percent_threshold
end

#idFixnum

Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


20935
20936
20937
# File 'lib/google/apis/compute_alpha/classes.rb', line 20935

def id
  @id
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# healthAggregationPolicy for health aggregation policies. Corresponds to the JSON property kind

Returns:

  • (String)


20942
20943
20944
# File 'lib/google/apis/compute_alpha/classes.rb', line 20942

def kind
  @kind
end

#min_healthy_thresholdFixnum

Can only be set if the policyType field isBACKEND_SERVICE_POLICY. Specifies the minimum number of healthy endpoints required in order to consider the aggregated health result HEALTHY. Defaults to 1. Must be positive. Not applicable if the policyType field isDNB_PUBLIC_IP_POLICY. Can be mutated. This field is optional, and will be set to the default if unspecified. Note that both this threshold and healthyPercentThreshold must be satisfied in order for HEALTHY to be the aggregated result. "Endpoints" refers to network endpoints within a Network Endpoint Group or instances within an Instance Group. Corresponds to the JSON property minHealthyThreshold

Returns:

  • (Fixnum)


20957
20958
20959
# File 'lib/google/apis/compute_alpha/classes.rb', line 20957

def min_healthy_threshold
  @min_healthy_threshold
end

#nameString

Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


20968
20969
20970
# File 'lib/google/apis/compute_alpha/classes.rb', line 20968

def name
  @name
end

#policy_typeString

Specifies the type of the healthAggregationPolicy. The only allowed value for global resources is DNS_PUBLIC_IP_POLICY. The only allowed value for regional resources is BACKEND_SERVICE_POLICY. Must be specified when the healthAggregationPolicy is created, and cannot be mutated. Corresponds to the JSON property policyType

Returns:

  • (String)


20977
20978
20979
# File 'lib/google/apis/compute_alpha/classes.rb', line 20977

def policy_type
  @policy_type
end

#regionString

Output only. [Output Only] URL of the region where the health aggregation policy resides. This field applies only to the regional resource. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body. Corresponds to the JSON property region

Returns:

  • (String)


20986
20987
20988
# File 'lib/google/apis/compute_alpha/classes.rb', line 20986

def region
  @region
end

Output only. [Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


20991
20992
20993
# File 'lib/google/apis/compute_alpha/classes.rb', line 20991

def self_link
  @self_link
end

Output only. [Output Only] Server-defined URL with id for the resource. Corresponds to the JSON property selfLinkWithId

Returns:

  • (String)


20996
20997
20998
# File 'lib/google/apis/compute_alpha/classes.rb', line 20996

def self_link_with_id
  @self_link_with_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



21003
21004
21005
21006
21007
21008
21009
21010
21011
21012
21013
21014
21015
21016
# File 'lib/google/apis/compute_alpha/classes.rb', line 21003

def update!(**args)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @fingerprint = args[:fingerprint] if args.key?(:fingerprint)
  @healthy_percent_threshold = args[:healthy_percent_threshold] if args.key?(:healthy_percent_threshold)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @min_healthy_threshold = args[:min_healthy_threshold] if args.key?(:min_healthy_threshold)
  @name = args[:name] if args.key?(:name)
  @policy_type = args[:policy_type] if args.key?(:policy_type)
  @region = args[:region] if args.key?(:region)
  @self_link = args[:self_link] if args.key?(:self_link)
  @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id)
end