Class: Google::Apis::ComputeAlpha::HealthAggregationPolicyAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::HealthAggregationPolicyAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Contains a list of HealthAggregationPoliciesScopedList.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::HealthAggregationPoliciesScopedList>
A list of HealthAggregationPoliciesScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::HealthAggregationPolicyAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HealthAggregationPolicyAggregatedList
constructor
A new instance of HealthAggregationPolicyAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HealthAggregationPolicyAggregatedList
Returns a new instance of HealthAggregationPolicyAggregatedList.
22191 22192 22193 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 22191 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
22154 22155 22156 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 22154 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::HealthAggregationPoliciesScopedList>
A list of HealthAggregationPoliciesScopedList resources.
Corresponds to the JSON property items
22159 22160 22161 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 22159 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
22164 22165 22166 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 22164 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
22174 22175 22176 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 22174 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
22179 22180 22181 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 22179 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
22184 22185 22186 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 22184 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::HealthAggregationPolicyAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
22189 22190 22191 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 22189 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
22196 22197 22198 22199 22200 22201 22202 22203 22204 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 22196 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |