Class: Google::Apis::ComputeAlpha::HealthAggregationPolicyAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of HealthAggregationPoliciesScopedList.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HealthAggregationPolicyAggregatedList

Returns a new instance of HealthAggregationPolicyAggregatedList.



21791
21792
21793
# File 'lib/google/apis/compute_alpha/classes.rb', line 21791

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


21754
21755
21756
# File 'lib/google/apis/compute_alpha/classes.rb', line 21754

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::HealthAggregationPoliciesScopedList>

A list of HealthAggregationPoliciesScopedList resources. Corresponds to the JSON property items



21759
21760
21761
# File 'lib/google/apis/compute_alpha/classes.rb', line 21759

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


21764
21765
21766
# File 'lib/google/apis/compute_alpha/classes.rb', line 21764

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


21774
21775
21776
# File 'lib/google/apis/compute_alpha/classes.rb', line 21774

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


21779
21780
21781
# File 'lib/google/apis/compute_alpha/classes.rb', line 21779

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


21784
21785
21786
# File 'lib/google/apis/compute_alpha/classes.rb', line 21784

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::HealthAggregationPolicyAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



21789
21790
21791
# File 'lib/google/apis/compute_alpha/classes.rb', line 21789

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



21796
21797
21798
21799
21800
21801
21802
21803
21804
# File 'lib/google/apis/compute_alpha/classes.rb', line 21796

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end