Class: Google::Apis::ComputeAlpha::HealthAggregationPolicyAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of HealthAggregationPoliciesScopedList.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HealthAggregationPolicyAggregatedList

Returns a new instance of HealthAggregationPolicyAggregatedList.



21055
21056
21057
# File 'lib/google/apis/compute_alpha/classes.rb', line 21055

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


21018
21019
21020
# File 'lib/google/apis/compute_alpha/classes.rb', line 21018

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::HealthAggregationPoliciesScopedList>

A list of HealthAggregationPoliciesScopedList resources. Corresponds to the JSON property items



21023
21024
21025
# File 'lib/google/apis/compute_alpha/classes.rb', line 21023

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


21028
21029
21030
# File 'lib/google/apis/compute_alpha/classes.rb', line 21028

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


21038
21039
21040
# File 'lib/google/apis/compute_alpha/classes.rb', line 21038

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


21043
21044
21045
# File 'lib/google/apis/compute_alpha/classes.rb', line 21043

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


21048
21049
21050
# File 'lib/google/apis/compute_alpha/classes.rb', line 21048

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::HealthAggregationPolicyAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



21053
21054
21055
# File 'lib/google/apis/compute_alpha/classes.rb', line 21053

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



21060
21061
21062
21063
21064
21065
21066
21067
21068
# File 'lib/google/apis/compute_alpha/classes.rb', line 21060

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end