Class: Google::Apis::ComputeAlpha::HealthAggregationPolicyAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::HealthAggregationPolicyAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Contains a list of HealthAggregationPoliciesScopedList.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::HealthAggregationPoliciesScopedList>
A list of HealthAggregationPoliciesScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::HealthAggregationPolicyAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HealthAggregationPolicyAggregatedList
constructor
A new instance of HealthAggregationPolicyAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HealthAggregationPolicyAggregatedList
Returns a new instance of HealthAggregationPolicyAggregatedList.
20867 20868 20869 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 20867 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
20830 20831 20832 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 20830 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::HealthAggregationPoliciesScopedList>
A list of HealthAggregationPoliciesScopedList resources.
Corresponds to the JSON property items
20835 20836 20837 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 20835 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
20840 20841 20842 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 20840 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
20850 20851 20852 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 20850 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
20855 20856 20857 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 20855 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
20860 20861 20862 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 20860 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::HealthAggregationPolicyAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
20865 20866 20867 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 20865 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
20872 20873 20874 20875 20876 20877 20878 20879 20880 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 20872 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |