Class: Google::Apis::ComputeAlpha::HealthAggregationPolicyAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of HealthAggregationPoliciesScopedList.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HealthAggregationPolicyAggregatedList

Returns a new instance of HealthAggregationPolicyAggregatedList.



20510
20511
20512
# File 'lib/google/apis/compute_alpha/classes.rb', line 20510

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


20473
20474
20475
# File 'lib/google/apis/compute_alpha/classes.rb', line 20473

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::HealthAggregationPoliciesScopedList>

A list of HealthAggregationPoliciesScopedList resources. Corresponds to the JSON property items



20478
20479
20480
# File 'lib/google/apis/compute_alpha/classes.rb', line 20478

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


20483
20484
20485
# File 'lib/google/apis/compute_alpha/classes.rb', line 20483

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


20493
20494
20495
# File 'lib/google/apis/compute_alpha/classes.rb', line 20493

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


20498
20499
20500
# File 'lib/google/apis/compute_alpha/classes.rb', line 20498

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


20503
20504
20505
# File 'lib/google/apis/compute_alpha/classes.rb', line 20503

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::HealthAggregationPolicyAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



20508
20509
20510
# File 'lib/google/apis/compute_alpha/classes.rb', line 20508

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20515
20516
20517
20518
20519
20520
20521
20522
20523
# File 'lib/google/apis/compute_alpha/classes.rb', line 20515

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end