Class: Google::Apis::ComputeAlpha::HealthAggregationPolicyList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::HealthAggregationPolicyList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::HealthAggregationPolicy>
A list of HealthAggregationPolicy resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
-
#warning ⇒ Google::Apis::ComputeAlpha::HealthAggregationPolicyList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HealthAggregationPolicyList
constructor
A new instance of HealthAggregationPolicyList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HealthAggregationPolicyList
Returns a new instance of HealthAggregationPolicyList.
22190 22191 22192 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 22190 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
22156 22157 22158 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 22156 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::HealthAggregationPolicy>
A list of HealthAggregationPolicy resources.
Corresponds to the JSON property items
22161 22162 22163 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 22161 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#
healthAggregationPolicy for health aggregation
policies.
Corresponds to the JSON property kind
22168 22169 22170 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 22168 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
22178 22179 22180 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 22178 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
22183 22184 22185 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 22183 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::HealthAggregationPolicyList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
22188 22189 22190 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 22188 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
22195 22196 22197 22198 22199 22200 22201 22202 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 22195 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |