Class: Google::Apis::ComputeAlpha::HealthAggregationPolicyList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::HealthAggregationPolicyList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::HealthAggregationPolicy>
A list of HealthAggregationPolicy resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
-
#warning ⇒ Google::Apis::ComputeAlpha::HealthAggregationPolicyList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HealthAggregationPolicyList
constructor
A new instance of HealthAggregationPolicyList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HealthAggregationPolicyList
Returns a new instance of HealthAggregationPolicyList.
20977 20978 20979 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 20977 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
20943 20944 20945 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 20943 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::HealthAggregationPolicy>
A list of HealthAggregationPolicy resources.
Corresponds to the JSON property items
20948 20949 20950 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 20948 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#
healthAggregationPolicy for health aggregation
policies.
Corresponds to the JSON property kind
20955 20956 20957 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 20955 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
20965 20966 20967 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 20965 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
20970 20971 20972 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 20970 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::HealthAggregationPolicyList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
20975 20976 20977 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 20975 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
20982 20983 20984 20985 20986 20987 20988 20989 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 20982 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |