Class: Google::Apis::ComputeAlpha::HealthAggregationPolicyList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HealthAggregationPolicyList

Returns a new instance of HealthAggregationPolicyList.



21003
21004
21005
# File 'lib/google/apis/compute_alpha/classes.rb', line 21003

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


20969
20970
20971
# File 'lib/google/apis/compute_alpha/classes.rb', line 20969

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::HealthAggregationPolicy>

A list of HealthAggregationPolicy resources. Corresponds to the JSON property items



20974
20975
20976
# File 'lib/google/apis/compute_alpha/classes.rb', line 20974

def items
  @items
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# healthAggregationPolicy for health aggregation policies. Corresponds to the JSON property kind

Returns:

  • (String)


20981
20982
20983
# File 'lib/google/apis/compute_alpha/classes.rb', line 20981

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


20991
20992
20993
# File 'lib/google/apis/compute_alpha/classes.rb', line 20991

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


20996
20997
20998
# File 'lib/google/apis/compute_alpha/classes.rb', line 20996

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::HealthAggregationPolicyList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



21001
21002
21003
# File 'lib/google/apis/compute_alpha/classes.rb', line 21001

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



21008
21009
21010
21011
21012
21013
21014
21015
# File 'lib/google/apis/compute_alpha/classes.rb', line 21008

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end