Class: Google::Apis::ComputeAlpha::HealthAggregationPolicyList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HealthAggregationPolicyList

Returns a new instance of HealthAggregationPolicyList.



20637
20638
20639
# File 'lib/google/apis/compute_alpha/classes.rb', line 20637

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


20603
20604
20605
# File 'lib/google/apis/compute_alpha/classes.rb', line 20603

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::HealthAggregationPolicy>

A list of HealthAggregationPolicy resources. Corresponds to the JSON property items



20608
20609
20610
# File 'lib/google/apis/compute_alpha/classes.rb', line 20608

def items
  @items
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# healthAggregationPolicy for health aggregation policies. Corresponds to the JSON property kind

Returns:

  • (String)


20615
20616
20617
# File 'lib/google/apis/compute_alpha/classes.rb', line 20615

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


20625
20626
20627
# File 'lib/google/apis/compute_alpha/classes.rb', line 20625

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


20630
20631
20632
# File 'lib/google/apis/compute_alpha/classes.rb', line 20630

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::HealthAggregationPolicyList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



20635
20636
20637
# File 'lib/google/apis/compute_alpha/classes.rb', line 20635

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20642
20643
20644
20645
20646
20647
20648
20649
# File 'lib/google/apis/compute_alpha/classes.rb', line 20642

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end