Class: Google::Apis::ComputeAlpha::HealthCheck
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::HealthCheck
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Represents a health check resource. Google Compute Engine has two health check resources:
- Regional
- Global These health check resources can be used for load balancing and for autohealing VMs in a managed instance group (MIG). Load balancing Health check requirements vary depending on the type of load balancer. For details about the type of health check supported for each load balancer and corresponding backend type, see Health checks overview: Load balancer guide. Autohealing in MIGs The health checks that you use for autohealing VMs in a MIG can be either regional or global. For more information, see Set up an application health check and autohealing. For more information, seeHealth checks overview.
Instance Attribute Summary collapse
-
#check_interval_sec ⇒ Fixnum
How often (in seconds) to send a health check.
-
#creation_timestamp ⇒ String
Output only.
-
#description ⇒ String
An optional description of this resource.
-
#grpc_health_check ⇒ Google::Apis::ComputeAlpha::GrpcHealthCheck
Corresponds to the JSON property
grpcHealthCheck. -
#grpc_tls_health_check ⇒ Google::Apis::ComputeAlpha::GrpctlsHealthCheck
Corresponds to the JSON property
grpcTlsHealthCheck. -
#healthy_threshold ⇒ Fixnum
A so-far unhealthy instance will be marked healthy after this many consecutive successes.
-
#http2_health_check ⇒ Google::Apis::ComputeAlpha::Http2HealthCheck
Corresponds to the JSON property
http2HealthCheck. -
#http_health_check ⇒ Google::Apis::ComputeAlpha::HttpHealthCheck
Corresponds to the JSON property
httpHealthCheck. -
#https_health_check ⇒ Google::Apis::ComputeAlpha::HttpsHealthCheck
Corresponds to the JSON property
httpsHealthCheck. -
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource.
-
#kind ⇒ String
Output only.
-
#log_config ⇒ Google::Apis::ComputeAlpha::HealthCheckLogConfig
Configuration of logging on a health check.
-
#name ⇒ String
Name of the resource.
-
#region ⇒ String
Output only.
-
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
-
#self_link_with_id ⇒ String
Output only.
-
#source_regions ⇒ Array<String>
The list of cloud regions from which health checks are performed.
-
#ssl_health_check ⇒ Google::Apis::ComputeAlpha::SslHealthCheck
Corresponds to the JSON property
sslHealthCheck. -
#tcp_health_check ⇒ Google::Apis::ComputeAlpha::TcpHealthCheck
Corresponds to the JSON property
tcpHealthCheck. -
#timeout_sec ⇒ Fixnum
How long (in seconds) to wait before claiming failure.
-
#type ⇒ String
Specifies the type of the healthCheck, either TCP,SSL, HTTP, HTTPS,HTTP2 or GRPC.
-
#udp_health_check ⇒ Google::Apis::ComputeAlpha::UdpHealthCheck
Corresponds to the JSON property
udpHealthCheck. -
#unhealthy_threshold ⇒ Fixnum
A so-far healthy instance will be marked unhealthy after this many consecutive failures.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HealthCheck
constructor
A new instance of HealthCheck.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HealthCheck
Returns a new instance of HealthCheck.
21233 21234 21235 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 21233 def initialize(**args) update!(**args) end |
Instance Attribute Details
#check_interval_sec ⇒ Fixnum
How often (in seconds) to send a health check. The default value is 5
seconds.
Corresponds to the JSON property checkIntervalSec
21087 21088 21089 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 21087 def check_interval_sec @check_interval_sec end |
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp in3339
text format.
Corresponds to the JSON property creationTimestamp
21093 21094 21095 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 21093 def @creation_timestamp end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
21099 21100 21101 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 21099 def description @description end |
#grpc_health_check ⇒ Google::Apis::ComputeAlpha::GrpcHealthCheck
Corresponds to the JSON property grpcHealthCheck
21104 21105 21106 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 21104 def grpc_health_check @grpc_health_check end |
#grpc_tls_health_check ⇒ Google::Apis::ComputeAlpha::GrpctlsHealthCheck
Corresponds to the JSON property grpcTlsHealthCheck
21109 21110 21111 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 21109 def grpc_tls_health_check @grpc_tls_health_check end |
#healthy_threshold ⇒ Fixnum
A so-far unhealthy instance will be marked healthy after this
many consecutive successes. The default value is 2.
Corresponds to the JSON property healthyThreshold
21115 21116 21117 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 21115 def healthy_threshold @healthy_threshold end |
#http2_health_check ⇒ Google::Apis::ComputeAlpha::Http2HealthCheck
Corresponds to the JSON property http2HealthCheck
21120 21121 21122 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 21120 def http2_health_check @http2_health_check end |
#http_health_check ⇒ Google::Apis::ComputeAlpha::HttpHealthCheck
Corresponds to the JSON property httpHealthCheck
21125 21126 21127 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 21125 def http_health_check @http_health_check end |
#https_health_check ⇒ Google::Apis::ComputeAlpha::HttpsHealthCheck
Corresponds to the JSON property httpsHealthCheck
21130 21131 21132 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 21130 def https_health_check @https_health_check end |
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
21136 21137 21138 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 21136 def id @id end |
#kind ⇒ String
Output only. Type of the resource.
Corresponds to the JSON property kind
21141 21142 21143 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 21141 def kind @kind end |
#log_config ⇒ Google::Apis::ComputeAlpha::HealthCheckLogConfig
Configuration of logging on a health check. If logging is enabled, logs
will be exported to Stackdriver.
Corresponds to the JSON property logConfig
21147 21148 21149 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 21147 def log_config @log_config end |
#name ⇒ String
Name of the resource. Provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
For example, a name that is 1-63 characters long, matches the regular
expression [a-z]([-a-z0-9]*[a-z0-9])?, and otherwise complies with
RFC1035. This regular expression describes a name where the first
character is a lowercase letter, and all following characters are a dash,
lowercase letter, or digit, except the last character, which isn't a dash.
Corresponds to the JSON property name
21158 21159 21160 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 21158 def name @name end |
#region ⇒ String
Output only. [Output Only] Region where the health check resides. Not
applicable to
global health checks.
Corresponds to the JSON property region
21165 21166 21167 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 21165 def region @region end |
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
21170 21171 21172 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 21170 def self_link @self_link end |
#self_link_with_id ⇒ String
Output only. [Output Only] Server-defined URL for this resource with the
resource id.
Corresponds to the JSON property selfLinkWithId
21176 21177 21178 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 21176 def self_link_with_id @self_link_with_id end |
#source_regions ⇒ Array<String>
The list of cloud regions from which health checks are performed. If any regions are specified, then exactly 3 regions should be specified. The region names must be valid names of Google Cloud regions. This can only be set for global health check. If this list is non-empty, then there are restrictions on what other health check fields are supported and what other resources can use this health check:
- SSL, HTTP2, and GRPC protocols are not supported.
- The TCP request field is not supported.
- The proxyHeader field for HTTP, HTTPS, and TCP is not supported.
- The checkIntervalSec field must be at least 30.
- The health check cannot be used with BackendService nor with managed
instance group auto-healing.
Corresponds to the JSON property
sourceRegions
21195 21196 21197 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 21195 def source_regions @source_regions end |
#ssl_health_check ⇒ Google::Apis::ComputeAlpha::SslHealthCheck
Corresponds to the JSON property sslHealthCheck
21200 21201 21202 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 21200 def ssl_health_check @ssl_health_check end |
#tcp_health_check ⇒ Google::Apis::ComputeAlpha::TcpHealthCheck
Corresponds to the JSON property tcpHealthCheck
21205 21206 21207 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 21205 def tcp_health_check @tcp_health_check end |
#timeout_sec ⇒ Fixnum
How long (in seconds) to wait before claiming failure. The default value is
5 seconds. It is invalid for timeoutSec to have greater
value than checkIntervalSec.
Corresponds to the JSON property timeoutSec
21212 21213 21214 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 21212 def timeout_sec @timeout_sec end |
#type ⇒ String
Specifies the type of the healthCheck, either TCP,SSL, HTTP, HTTPS,HTTP2 or
GRPC. Exactly one of the
protocol-specific health check fields must be specified, which must matchtype
field.
Corresponds to the JSON property type
21220 21221 21222 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 21220 def type @type end |
#udp_health_check ⇒ Google::Apis::ComputeAlpha::UdpHealthCheck
Corresponds to the JSON property udpHealthCheck
21225 21226 21227 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 21225 def udp_health_check @udp_health_check end |
#unhealthy_threshold ⇒ Fixnum
A so-far healthy instance will be marked unhealthy after this many
consecutive failures. The default value is 2.
Corresponds to the JSON property unhealthyThreshold
21231 21232 21233 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 21231 def unhealthy_threshold @unhealthy_threshold end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
21238 21239 21240 21241 21242 21243 21244 21245 21246 21247 21248 21249 21250 21251 21252 21253 21254 21255 21256 21257 21258 21259 21260 21261 21262 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 21238 def update!(**args) @check_interval_sec = args[:check_interval_sec] if args.key?(:check_interval_sec) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @grpc_health_check = args[:grpc_health_check] if args.key?(:grpc_health_check) @grpc_tls_health_check = args[:grpc_tls_health_check] if args.key?(:grpc_tls_health_check) @healthy_threshold = args[:healthy_threshold] if args.key?(:healthy_threshold) @http2_health_check = args[:http2_health_check] if args.key?(:http2_health_check) @http_health_check = args[:http_health_check] if args.key?(:http_health_check) @https_health_check = args[:https_health_check] if args.key?(:https_health_check) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @log_config = args[:log_config] if args.key?(:log_config) @name = args[:name] if args.key?(:name) @region = args[:region] if args.key?(:region) @self_link = args[:self_link] if args.key?(:self_link) @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id) @source_regions = args[:source_regions] if args.key?(:source_regions) @ssl_health_check = args[:ssl_health_check] if args.key?(:ssl_health_check) @tcp_health_check = args[:tcp_health_check] if args.key?(:tcp_health_check) @timeout_sec = args[:timeout_sec] if args.key?(:timeout_sec) @type = args[:type] if args.key?(:type) @udp_health_check = args[:udp_health_check] if args.key?(:udp_health_check) @unhealthy_threshold = args[:unhealthy_threshold] if args.key?(:unhealthy_threshold) end |