Class: Google::Apis::ComputeAlpha::HealthCheckList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::HealthCheckList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Contains a list of HealthCheck resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::HealthCheck>
A list of HealthCheck resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::HealthCheckList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HealthCheckList
constructor
A new instance of HealthCheckList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HealthCheckList
Returns a new instance of HealthCheckList.
22517 22518 22519 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 22517 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
22485 22486 22487 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 22485 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::HealthCheck>
A list of HealthCheck resources.
Corresponds to the JSON property items
22490 22491 22492 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 22490 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
22495 22496 22497 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 22495 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
22505 22506 22507 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 22505 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
22510 22511 22512 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 22510 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::HealthCheckList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
22515 22516 22517 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 22515 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
22522 22523 22524 22525 22526 22527 22528 22529 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 22522 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |