Class: Google::Apis::ComputeAlpha::HealthCheckList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of HealthCheck resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HealthCheckList

Returns a new instance of HealthCheckList.



22245
22246
22247
# File 'lib/google/apis/compute_alpha/classes.rb', line 22245

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


22213
22214
22215
# File 'lib/google/apis/compute_alpha/classes.rb', line 22213

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::HealthCheck>

A list of HealthCheck resources. Corresponds to the JSON property items



22218
22219
22220
# File 'lib/google/apis/compute_alpha/classes.rb', line 22218

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


22223
22224
22225
# File 'lib/google/apis/compute_alpha/classes.rb', line 22223

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


22233
22234
22235
# File 'lib/google/apis/compute_alpha/classes.rb', line 22233

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


22238
22239
22240
# File 'lib/google/apis/compute_alpha/classes.rb', line 22238

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::HealthCheckList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



22243
22244
22245
# File 'lib/google/apis/compute_alpha/classes.rb', line 22243

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



22250
22251
22252
22253
22254
22255
22256
22257
# File 'lib/google/apis/compute_alpha/classes.rb', line 22250

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end