Class: Google::Apis::ComputeAlpha::HealthCheckList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of HealthCheck resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HealthCheckList

Returns a new instance of HealthCheckList.



21517
21518
21519
# File 'lib/google/apis/compute_alpha/classes.rb', line 21517

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


21485
21486
21487
# File 'lib/google/apis/compute_alpha/classes.rb', line 21485

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::HealthCheck>

A list of HealthCheck resources. Corresponds to the JSON property items



21490
21491
21492
# File 'lib/google/apis/compute_alpha/classes.rb', line 21490

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


21495
21496
21497
# File 'lib/google/apis/compute_alpha/classes.rb', line 21495

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


21505
21506
21507
# File 'lib/google/apis/compute_alpha/classes.rb', line 21505

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


21510
21511
21512
# File 'lib/google/apis/compute_alpha/classes.rb', line 21510

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::HealthCheckList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



21515
21516
21517
# File 'lib/google/apis/compute_alpha/classes.rb', line 21515

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



21522
21523
21524
21525
21526
21527
21528
21529
# File 'lib/google/apis/compute_alpha/classes.rb', line 21522

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end