Class: Google::Apis::ComputeAlpha::HealthCheckList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of HealthCheck resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HealthCheckList

Returns a new instance of HealthCheckList.



21509
21510
21511
# File 'lib/google/apis/compute_alpha/classes.rb', line 21509

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


21477
21478
21479
# File 'lib/google/apis/compute_alpha/classes.rb', line 21477

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::HealthCheck>

A list of HealthCheck resources. Corresponds to the JSON property items



21482
21483
21484
# File 'lib/google/apis/compute_alpha/classes.rb', line 21482

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


21487
21488
21489
# File 'lib/google/apis/compute_alpha/classes.rb', line 21487

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


21497
21498
21499
# File 'lib/google/apis/compute_alpha/classes.rb', line 21497

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


21502
21503
21504
# File 'lib/google/apis/compute_alpha/classes.rb', line 21502

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::HealthCheckList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



21507
21508
21509
# File 'lib/google/apis/compute_alpha/classes.rb', line 21507

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



21514
21515
21516
21517
21518
21519
21520
21521
# File 'lib/google/apis/compute_alpha/classes.rb', line 21514

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end