Class: Google::Apis::ComputeAlpha::HealthCheckList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::HealthCheckList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Contains a list of HealthCheck resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::HealthCheck>
A list of HealthCheck resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::HealthCheckList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HealthCheckList
constructor
A new instance of HealthCheckList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HealthCheckList
Returns a new instance of HealthCheckList.
21330 21331 21332 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 21330 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
21298 21299 21300 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 21298 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::HealthCheck>
A list of HealthCheck resources.
Corresponds to the JSON property items
21303 21304 21305 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 21303 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
21308 21309 21310 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 21308 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
21318 21319 21320 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 21318 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
21323 21324 21325 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 21323 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::HealthCheckList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
21328 21329 21330 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 21328 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
21335 21336 21337 21338 21339 21340 21341 21342 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 21335 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |