Class: Google::Apis::ComputeAlpha::HealthCheckList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of HealthCheck resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HealthCheckList

Returns a new instance of HealthCheckList.



20964
20965
20966
# File 'lib/google/apis/compute_alpha/classes.rb', line 20964

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


20932
20933
20934
# File 'lib/google/apis/compute_alpha/classes.rb', line 20932

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::HealthCheck>

A list of HealthCheck resources. Corresponds to the JSON property items



20937
20938
20939
# File 'lib/google/apis/compute_alpha/classes.rb', line 20937

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


20942
20943
20944
# File 'lib/google/apis/compute_alpha/classes.rb', line 20942

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


20952
20953
20954
# File 'lib/google/apis/compute_alpha/classes.rb', line 20952

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


20957
20958
20959
# File 'lib/google/apis/compute_alpha/classes.rb', line 20957

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::HealthCheckList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



20962
20963
20964
# File 'lib/google/apis/compute_alpha/classes.rb', line 20962

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20969
20970
20971
20972
20973
20974
20975
20976
# File 'lib/google/apis/compute_alpha/classes.rb', line 20969

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end