Class: Google::Apis::ComputeAlpha::HealthCheckServiceAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::HealthCheckServiceAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Contains a list of HealthCheckServicesScopedList.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::HealthCheckServicesScopedList>
A list of HealthCheckServicesScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::HealthCheckServiceAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HealthCheckServiceAggregatedList
constructor
A new instance of HealthCheckServiceAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HealthCheckServiceAggregatedList
Returns a new instance of HealthCheckServiceAggregatedList.
21856 21857 21858 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 21856 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
21819 21820 21821 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 21819 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::HealthCheckServicesScopedList>
A list of HealthCheckServicesScopedList resources.
Corresponds to the JSON property items
21824 21825 21826 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 21824 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
21829 21830 21831 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 21829 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
21839 21840 21841 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 21839 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
21844 21845 21846 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 21844 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
21849 21850 21851 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 21849 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::HealthCheckServiceAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
21854 21855 21856 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 21854 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
21861 21862 21863 21864 21865 21866 21867 21868 21869 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 21861 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |