Class: Google::Apis::ComputeAlpha::HealthCheckServiceAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::HealthCheckServiceAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Contains a list of HealthCheckServicesScopedList.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::HealthCheckServicesScopedList>
A list of HealthCheckServicesScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::HealthCheckServiceAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HealthCheckServiceAggregatedList
constructor
A new instance of HealthCheckServiceAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HealthCheckServiceAggregatedList
Returns a new instance of HealthCheckServiceAggregatedList.
21848 21849 21850 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 21848 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
21811 21812 21813 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 21811 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::HealthCheckServicesScopedList>
A list of HealthCheckServicesScopedList resources.
Corresponds to the JSON property items
21816 21817 21818 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 21816 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
21821 21822 21823 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 21821 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
21831 21832 21833 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 21831 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
21836 21837 21838 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 21836 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
21841 21842 21843 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 21841 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::HealthCheckServiceAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
21846 21847 21848 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 21846 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
21853 21854 21855 21856 21857 21858 21859 21860 21861 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 21853 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |