Class: Google::Apis::ComputeAlpha::HealthCheckServiceAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of HealthCheckServicesScopedList.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HealthCheckServiceAggregatedList

Returns a new instance of HealthCheckServiceAggregatedList.



21643
21644
21645
# File 'lib/google/apis/compute_alpha/classes.rb', line 21643

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


21606
21607
21608
# File 'lib/google/apis/compute_alpha/classes.rb', line 21606

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::HealthCheckServicesScopedList>

A list of HealthCheckServicesScopedList resources. Corresponds to the JSON property items



21611
21612
21613
# File 'lib/google/apis/compute_alpha/classes.rb', line 21611

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


21616
21617
21618
# File 'lib/google/apis/compute_alpha/classes.rb', line 21616

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


21626
21627
21628
# File 'lib/google/apis/compute_alpha/classes.rb', line 21626

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


21631
21632
21633
# File 'lib/google/apis/compute_alpha/classes.rb', line 21631

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


21636
21637
21638
# File 'lib/google/apis/compute_alpha/classes.rb', line 21636

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::HealthCheckServiceAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



21641
21642
21643
# File 'lib/google/apis/compute_alpha/classes.rb', line 21641

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



21648
21649
21650
21651
21652
21653
21654
21655
21656
# File 'lib/google/apis/compute_alpha/classes.rb', line 21648

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end