Class: Google::Apis::ComputeAlpha::HealthCheckServiceAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of HealthCheckServicesScopedList.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HealthCheckServiceAggregatedList

Returns a new instance of HealthCheckServiceAggregatedList.



21669
21670
21671
# File 'lib/google/apis/compute_alpha/classes.rb', line 21669

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


21632
21633
21634
# File 'lib/google/apis/compute_alpha/classes.rb', line 21632

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::HealthCheckServicesScopedList>

A list of HealthCheckServicesScopedList resources. Corresponds to the JSON property items



21637
21638
21639
# File 'lib/google/apis/compute_alpha/classes.rb', line 21637

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


21642
21643
21644
# File 'lib/google/apis/compute_alpha/classes.rb', line 21642

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


21652
21653
21654
# File 'lib/google/apis/compute_alpha/classes.rb', line 21652

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


21657
21658
21659
# File 'lib/google/apis/compute_alpha/classes.rb', line 21657

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


21662
21663
21664
# File 'lib/google/apis/compute_alpha/classes.rb', line 21662

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::HealthCheckServiceAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



21667
21668
21669
# File 'lib/google/apis/compute_alpha/classes.rb', line 21667

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



21674
21675
21676
21677
21678
21679
21680
21681
21682
# File 'lib/google/apis/compute_alpha/classes.rb', line 21674

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end