Class: Google::Apis::ComputeAlpha::HealthCheckServiceAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of HealthCheckServicesScopedList.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HealthCheckServiceAggregatedList

Returns a new instance of HealthCheckServiceAggregatedList.



21303
21304
21305
# File 'lib/google/apis/compute_alpha/classes.rb', line 21303

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


21266
21267
21268
# File 'lib/google/apis/compute_alpha/classes.rb', line 21266

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::HealthCheckServicesScopedList>

A list of HealthCheckServicesScopedList resources. Corresponds to the JSON property items



21271
21272
21273
# File 'lib/google/apis/compute_alpha/classes.rb', line 21271

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


21276
21277
21278
# File 'lib/google/apis/compute_alpha/classes.rb', line 21276

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


21286
21287
21288
# File 'lib/google/apis/compute_alpha/classes.rb', line 21286

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


21291
21292
21293
# File 'lib/google/apis/compute_alpha/classes.rb', line 21291

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


21296
21297
21298
# File 'lib/google/apis/compute_alpha/classes.rb', line 21296

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::HealthCheckServiceAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



21301
21302
21303
# File 'lib/google/apis/compute_alpha/classes.rb', line 21301

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



21308
21309
21310
21311
21312
21313
21314
21315
21316
# File 'lib/google/apis/compute_alpha/classes.rb', line 21308

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end