Class: Google::Apis::ComputeAlpha::HealthCheckServicesList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HealthCheckServicesList

Returns a new instance of HealthCheckServicesList.



21815
21816
21817
# File 'lib/google/apis/compute_alpha/classes.rb', line 21815

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Output only. [Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


21780
21781
21782
# File 'lib/google/apis/compute_alpha/classes.rb', line 21780

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::HealthCheckService>

Output only. A list of HealthCheckService resources. Corresponds to the JSON property items



21785
21786
21787
# File 'lib/google/apis/compute_alpha/classes.rb', line 21785

def items
  @items
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# healthCheckServicesList for lists of HealthCheckServices. Corresponds to the JSON property kind

Returns:

  • (String)


21792
21793
21794
# File 'lib/google/apis/compute_alpha/classes.rb', line 21792

def kind
  @kind
end

#next_page_tokenString

Output only. [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


21803
21804
21805
# File 'lib/google/apis/compute_alpha/classes.rb', line 21803

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


21808
21809
21810
# File 'lib/google/apis/compute_alpha/classes.rb', line 21808

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::HealthCheckServicesList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



21813
21814
21815
# File 'lib/google/apis/compute_alpha/classes.rb', line 21813

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



21820
21821
21822
21823
21824
21825
21826
21827
# File 'lib/google/apis/compute_alpha/classes.rb', line 21820

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end