Class: Google::Apis::ComputeAlpha::HealthChecksAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HealthChecksAggregatedList

Returns a new instance of HealthChecksAggregatedList.



22965
22966
22967
# File 'lib/google/apis/compute_alpha/classes.rb', line 22965

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


22928
22929
22930
# File 'lib/google/apis/compute_alpha/classes.rb', line 22928

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::HealthChecksScopedList>

A list of HealthChecksScopedList resources. Corresponds to the JSON property items



22933
22934
22935
# File 'lib/google/apis/compute_alpha/classes.rb', line 22933

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


22938
22939
22940
# File 'lib/google/apis/compute_alpha/classes.rb', line 22938

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


22948
22949
22950
# File 'lib/google/apis/compute_alpha/classes.rb', line 22948

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


22953
22954
22955
# File 'lib/google/apis/compute_alpha/classes.rb', line 22953

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


22958
22959
22960
# File 'lib/google/apis/compute_alpha/classes.rb', line 22958

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::HealthChecksAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



22963
22964
22965
# File 'lib/google/apis/compute_alpha/classes.rb', line 22963

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



22970
22971
22972
22973
22974
22975
22976
22977
22978
# File 'lib/google/apis/compute_alpha/classes.rb', line 22970

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end