Class: Google::Apis::ComputeAlpha::HealthChecksAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HealthChecksAggregatedList

Returns a new instance of HealthChecksAggregatedList.



22237
22238
22239
# File 'lib/google/apis/compute_alpha/classes.rb', line 22237

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


22200
22201
22202
# File 'lib/google/apis/compute_alpha/classes.rb', line 22200

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::HealthChecksScopedList>

A list of HealthChecksScopedList resources. Corresponds to the JSON property items



22205
22206
22207
# File 'lib/google/apis/compute_alpha/classes.rb', line 22205

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


22210
22211
22212
# File 'lib/google/apis/compute_alpha/classes.rb', line 22210

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


22220
22221
22222
# File 'lib/google/apis/compute_alpha/classes.rb', line 22220

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


22225
22226
22227
# File 'lib/google/apis/compute_alpha/classes.rb', line 22225

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


22230
22231
22232
# File 'lib/google/apis/compute_alpha/classes.rb', line 22230

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::HealthChecksAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



22235
22236
22237
# File 'lib/google/apis/compute_alpha/classes.rb', line 22235

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



22242
22243
22244
22245
22246
22247
22248
22249
22250
# File 'lib/google/apis/compute_alpha/classes.rb', line 22242

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end