Class: Google::Apis::ComputeAlpha::HealthChecksAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HealthChecksAggregatedList

Returns a new instance of HealthChecksAggregatedList.



22024
22025
22026
# File 'lib/google/apis/compute_alpha/classes.rb', line 22024

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


21987
21988
21989
# File 'lib/google/apis/compute_alpha/classes.rb', line 21987

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::HealthChecksScopedList>

A list of HealthChecksScopedList resources. Corresponds to the JSON property items



21992
21993
21994
# File 'lib/google/apis/compute_alpha/classes.rb', line 21992

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


21997
21998
21999
# File 'lib/google/apis/compute_alpha/classes.rb', line 21997

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


22007
22008
22009
# File 'lib/google/apis/compute_alpha/classes.rb', line 22007

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


22012
22013
22014
# File 'lib/google/apis/compute_alpha/classes.rb', line 22012

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


22017
22018
22019
# File 'lib/google/apis/compute_alpha/classes.rb', line 22017

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::HealthChecksAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



22022
22023
22024
# File 'lib/google/apis/compute_alpha/classes.rb', line 22022

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



22029
22030
22031
22032
22033
22034
22035
22036
22037
# File 'lib/google/apis/compute_alpha/classes.rb', line 22029

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end