Class: Google::Apis::ComputeAlpha::HealthChecksAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::HealthChecksAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::HealthChecksScopedList>
A list of HealthChecksScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::HealthChecksAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HealthChecksAggregatedList
constructor
A new instance of HealthChecksAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HealthChecksAggregatedList
Returns a new instance of HealthChecksAggregatedList.
22041 22042 22043 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 22041 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
22004 22005 22006 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 22004 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::HealthChecksScopedList>
A list of HealthChecksScopedList resources.
Corresponds to the JSON property items
22009 22010 22011 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 22009 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
22014 22015 22016 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 22014 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
22024 22025 22026 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 22024 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
22029 22030 22031 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 22029 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
22034 22035 22036 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 22034 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::HealthChecksAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
22039 22040 22041 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 22039 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
22046 22047 22048 22049 22050 22051 22052 22053 22054 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 22046 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |