Class: Google::Apis::ComputeAlpha::HealthChecksAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::HealthChecksAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::HealthChecksScopedList>
A list of HealthChecksScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::HealthChecksAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HealthChecksAggregatedList
constructor
A new instance of HealthChecksAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HealthChecksAggregatedList
Returns a new instance of HealthChecksAggregatedList.
22050 22051 22052 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 22050 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
22013 22014 22015 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 22013 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::HealthChecksScopedList>
A list of HealthChecksScopedList resources.
Corresponds to the JSON property items
22018 22019 22020 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 22018 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
22023 22024 22025 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 22023 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
22033 22034 22035 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 22033 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
22038 22039 22040 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 22038 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
22043 22044 22045 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 22043 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::HealthChecksAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
22048 22049 22050 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 22048 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
22055 22056 22057 22058 22059 22060 22061 22062 22063 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 22055 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |