Class: Google::Apis::ComputeAlpha::HealthChecksAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HealthChecksAggregatedList

Returns a new instance of HealthChecksAggregatedList.



21684
21685
21686
# File 'lib/google/apis/compute_alpha/classes.rb', line 21684

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


21647
21648
21649
# File 'lib/google/apis/compute_alpha/classes.rb', line 21647

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::HealthChecksScopedList>

A list of HealthChecksScopedList resources. Corresponds to the JSON property items



21652
21653
21654
# File 'lib/google/apis/compute_alpha/classes.rb', line 21652

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


21657
21658
21659
# File 'lib/google/apis/compute_alpha/classes.rb', line 21657

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


21667
21668
21669
# File 'lib/google/apis/compute_alpha/classes.rb', line 21667

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


21672
21673
21674
# File 'lib/google/apis/compute_alpha/classes.rb', line 21672

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


21677
21678
21679
# File 'lib/google/apis/compute_alpha/classes.rb', line 21677

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::HealthChecksAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



21682
21683
21684
# File 'lib/google/apis/compute_alpha/classes.rb', line 21682

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



21689
21690
21691
21692
21693
21694
21695
21696
21697
# File 'lib/google/apis/compute_alpha/classes.rb', line 21689

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end