Class: Google::Apis::ComputeAlpha::HealthSource

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Represents a health source. A health source resource specifies the source resources and the health aggregation policy applied to the source resources to determine the aggregated health status.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HealthSource

Returns a new instance of HealthSource.



22332
22333
22334
# File 'lib/google/apis/compute_alpha/classes.rb', line 22332

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


22244
22245
22246
# File 'lib/google/apis/compute_alpha/classes.rb', line 22244

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


22250
22251
22252
# File 'lib/google/apis/compute_alpha/classes.rb', line 22250

def description
  @description
end

#fingerprintString

Fingerprint of this resource. A hash of the contents stored in this object. This field is used in optimistic locking. This field will be ignored when inserting a HealthSource. An up-to-date fingerprint must be provided in order to patch the HealthSource; Otherwise, the request will fail with error 412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve the HealthSource. Corresponds to the JSON property fingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


22262
22263
22264
# File 'lib/google/apis/compute_alpha/classes.rb', line 22262

def fingerprint
  @fingerprint
end

#health_aggregation_policyString

URL to the HealthAggregationPolicy resource. Must be set. Must be regional and in the same region as the HealthSource. Can be mutated. Corresponds to the JSON property healthAggregationPolicy

Returns:

  • (String)


22269
22270
22271
# File 'lib/google/apis/compute_alpha/classes.rb', line 22269

def health_aggregation_policy
  @health_aggregation_policy
end

#idFixnum

Output only. [Output Only] A unique identifier for this resource type. The server generates this identifier. Corresponds to the JSON property id

Returns:

  • (Fixnum)


22276
22277
22278
# File 'lib/google/apis/compute_alpha/classes.rb', line 22276

def id
  @id
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute#healthSource for health sources. Corresponds to the JSON property kind

Returns:

  • (String)


22282
22283
22284
# File 'lib/google/apis/compute_alpha/classes.rb', line 22282

def kind
  @kind
end

#nameString

Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


22293
22294
22295
# File 'lib/google/apis/compute_alpha/classes.rb', line 22293

def name
  @name
end

#regionString

Output only. [Output Only] URL of the region where the health source resides. This field applies only to the regional resource. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body. Corresponds to the JSON property region

Returns:

  • (String)


22301
22302
22303
# File 'lib/google/apis/compute_alpha/classes.rb', line 22301

def region
  @region
end

Output only. [Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


22306
22307
22308
# File 'lib/google/apis/compute_alpha/classes.rb', line 22306

def self_link
  @self_link
end

Output only. [Output Only] Server-defined URL with id for the resource. Corresponds to the JSON property selfLinkWithId

Returns:

  • (String)


22311
22312
22313
# File 'lib/google/apis/compute_alpha/classes.rb', line 22311

def self_link_with_id
  @self_link_with_id
end

#source_typeString

Specifies the type of the HealthSource. The only allowed value is BACKEND_SERVICE. Must be specified when theHealthSource is created, and cannot be mutated. Corresponds to the JSON property sourceType

Returns:

  • (String)


22318
22319
22320
# File 'lib/google/apis/compute_alpha/classes.rb', line 22318

def source_type
  @source_type
end

#sourcesArray<String>

URLs to the source resources. Must be size 1. Must be aBackendService if the sourceType is BACKEND_SERVICE. TheBackendService must have load balancing schemeINTERNAL or INTERNAL_MANAGED and must be regional and in the same region as the HealthSource (cross-region deployment for INTERNAL_MANAGED is not supported). TheBackendService may use only IGs, MIGs, or NEGs of typeGCE_VM_IP or GCE_VM_IP_PORT. TheBackendService may not use haPolicy. Can be mutated. Corresponds to the JSON property sources

Returns:

  • (Array<String>)


22330
22331
22332
# File 'lib/google/apis/compute_alpha/classes.rb', line 22330

def sources
  @sources
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



22337
22338
22339
22340
22341
22342
22343
22344
22345
22346
22347
22348
22349
22350
# File 'lib/google/apis/compute_alpha/classes.rb', line 22337

def update!(**args)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @fingerprint = args[:fingerprint] if args.key?(:fingerprint)
  @health_aggregation_policy = args[:health_aggregation_policy] if args.key?(:health_aggregation_policy)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @region = args[:region] if args.key?(:region)
  @self_link = args[:self_link] if args.key?(:self_link)
  @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id)
  @source_type = args[:source_type] if args.key?(:source_type)
  @sources = args[:sources] if args.key?(:sources)
end