Class: Google::Apis::ComputeAlpha::HealthSourceAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::HealthSourceAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Contains a list of HealthSourcesScopedList.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::HealthSourcesScopedList>
A list of HealthSourcesScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::HealthSourceAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HealthSourceAggregatedList
constructor
A new instance of HealthSourceAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HealthSourceAggregatedList
Returns a new instance of HealthSourceAggregatedList.
23584 23585 23586 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 23584 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
23547 23548 23549 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 23547 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::HealthSourcesScopedList>
A list of HealthSourcesScopedList resources.
Corresponds to the JSON property items
23552 23553 23554 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 23552 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
23557 23558 23559 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 23557 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
23567 23568 23569 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 23567 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
23572 23573 23574 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 23572 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
23577 23578 23579 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 23577 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::HealthSourceAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
23582 23583 23584 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 23582 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
23589 23590 23591 23592 23593 23594 23595 23596 23597 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 23589 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |