Class: Google::Apis::ComputeAlpha::HealthSourceAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of HealthSourcesScopedList.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HealthSourceAggregatedList

Returns a new instance of HealthSourceAggregatedList.



23312
23313
23314
# File 'lib/google/apis/compute_alpha/classes.rb', line 23312

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


23275
23276
23277
# File 'lib/google/apis/compute_alpha/classes.rb', line 23275

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::HealthSourcesScopedList>

A list of HealthSourcesScopedList resources. Corresponds to the JSON property items



23280
23281
23282
# File 'lib/google/apis/compute_alpha/classes.rb', line 23280

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


23285
23286
23287
# File 'lib/google/apis/compute_alpha/classes.rb', line 23285

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


23295
23296
23297
# File 'lib/google/apis/compute_alpha/classes.rb', line 23295

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


23300
23301
23302
# File 'lib/google/apis/compute_alpha/classes.rb', line 23300

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


23305
23306
23307
# File 'lib/google/apis/compute_alpha/classes.rb', line 23305

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::HealthSourceAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



23310
23311
23312
# File 'lib/google/apis/compute_alpha/classes.rb', line 23310

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



23317
23318
23319
23320
23321
23322
23323
23324
23325
# File 'lib/google/apis/compute_alpha/classes.rb', line 23317

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end