Class: Google::Apis::ComputeAlpha::HealthSourceAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of HealthSourcesScopedList.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HealthSourceAggregatedList

Returns a new instance of HealthSourceAggregatedList.



22584
22585
22586
# File 'lib/google/apis/compute_alpha/classes.rb', line 22584

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


22547
22548
22549
# File 'lib/google/apis/compute_alpha/classes.rb', line 22547

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::HealthSourcesScopedList>

A list of HealthSourcesScopedList resources. Corresponds to the JSON property items



22552
22553
22554
# File 'lib/google/apis/compute_alpha/classes.rb', line 22552

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


22557
22558
22559
# File 'lib/google/apis/compute_alpha/classes.rb', line 22557

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


22567
22568
22569
# File 'lib/google/apis/compute_alpha/classes.rb', line 22567

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


22572
22573
22574
# File 'lib/google/apis/compute_alpha/classes.rb', line 22572

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


22577
22578
22579
# File 'lib/google/apis/compute_alpha/classes.rb', line 22577

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::HealthSourceAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



22582
22583
22584
# File 'lib/google/apis/compute_alpha/classes.rb', line 22582

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



22589
22590
22591
22592
22593
22594
22595
22596
22597
# File 'lib/google/apis/compute_alpha/classes.rb', line 22589

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end