Class: Google::Apis::ComputeAlpha::HealthSourceAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of HealthSourcesScopedList.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HealthSourceAggregatedList

Returns a new instance of HealthSourceAggregatedList.



22371
22372
22373
# File 'lib/google/apis/compute_alpha/classes.rb', line 22371

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


22334
22335
22336
# File 'lib/google/apis/compute_alpha/classes.rb', line 22334

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::HealthSourcesScopedList>

A list of HealthSourcesScopedList resources. Corresponds to the JSON property items



22339
22340
22341
# File 'lib/google/apis/compute_alpha/classes.rb', line 22339

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


22344
22345
22346
# File 'lib/google/apis/compute_alpha/classes.rb', line 22344

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


22354
22355
22356
# File 'lib/google/apis/compute_alpha/classes.rb', line 22354

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


22359
22360
22361
# File 'lib/google/apis/compute_alpha/classes.rb', line 22359

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


22364
22365
22366
# File 'lib/google/apis/compute_alpha/classes.rb', line 22364

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::HealthSourceAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



22369
22370
22371
# File 'lib/google/apis/compute_alpha/classes.rb', line 22369

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



22376
22377
22378
22379
22380
22381
22382
22383
22384
# File 'lib/google/apis/compute_alpha/classes.rb', line 22376

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end