Class: Google::Apis::ComputeAlpha::HealthSourceAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::HealthSourceAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Contains a list of HealthSourcesScopedList.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::HealthSourcesScopedList>
A list of HealthSourcesScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::HealthSourceAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HealthSourceAggregatedList
constructor
A new instance of HealthSourceAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HealthSourceAggregatedList
Returns a new instance of HealthSourceAggregatedList.
22388 22389 22390 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 22388 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
22351 22352 22353 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 22351 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::HealthSourcesScopedList>
A list of HealthSourcesScopedList resources.
Corresponds to the JSON property items
22356 22357 22358 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 22356 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
22361 22362 22363 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 22361 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
22371 22372 22373 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 22371 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
22376 22377 22378 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 22376 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
22381 22382 22383 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 22381 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::HealthSourceAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
22386 22387 22388 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 22386 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
22393 22394 22395 22396 22397 22398 22399 22400 22401 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 22393 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |