Class: Google::Apis::ComputeAlpha::HealthSourceList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::HealthSourceList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::HealthSource>
A list of HealthSource resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
-
#warning ⇒ Google::Apis::ComputeAlpha::HealthSourceList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HealthSourceList
constructor
A new instance of HealthSourceList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HealthSourceList
Returns a new instance of HealthSourceList.
23742 23743 23744 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 23742 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
23709 23710 23711 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 23709 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::HealthSource>
A list of HealthSource resources.
Corresponds to the JSON property items
23714 23715 23716 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 23714 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#healthSource
for health sources.
Corresponds to the JSON property kind
23720 23721 23722 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 23720 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
23730 23731 23732 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 23730 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
23735 23736 23737 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 23735 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::HealthSourceList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
23740 23741 23742 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 23740 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
23747 23748 23749 23750 23751 23752 23753 23754 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 23747 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |