Class: Google::Apis::ComputeAlpha::HealthSourceList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HealthSourceList

Returns a new instance of HealthSourceList.



22734
22735
22736
# File 'lib/google/apis/compute_alpha/classes.rb', line 22734

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


22701
22702
22703
# File 'lib/google/apis/compute_alpha/classes.rb', line 22701

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::HealthSource>

A list of HealthSource resources. Corresponds to the JSON property items



22706
22707
22708
# File 'lib/google/apis/compute_alpha/classes.rb', line 22706

def items
  @items
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute#healthSource for health sources. Corresponds to the JSON property kind

Returns:

  • (String)


22712
22713
22714
# File 'lib/google/apis/compute_alpha/classes.rb', line 22712

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


22722
22723
22724
# File 'lib/google/apis/compute_alpha/classes.rb', line 22722

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


22727
22728
22729
# File 'lib/google/apis/compute_alpha/classes.rb', line 22727

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::HealthSourceList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



22732
22733
22734
# File 'lib/google/apis/compute_alpha/classes.rb', line 22732

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



22739
22740
22741
22742
22743
22744
22745
22746
# File 'lib/google/apis/compute_alpha/classes.rb', line 22739

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end