Class: Google::Apis::ComputeAlpha::HealthSourceList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::HealthSourceList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::HealthSource>
A list of HealthSource resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
-
#warning ⇒ Google::Apis::ComputeAlpha::HealthSourceList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HealthSourceList
constructor
A new instance of HealthSourceList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HealthSourceList
Returns a new instance of HealthSourceList.
22529 22530 22531 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 22529 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
22496 22497 22498 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 22496 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::HealthSource>
A list of HealthSource resources.
Corresponds to the JSON property items
22501 22502 22503 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 22501 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#healthSource
for health sources.
Corresponds to the JSON property kind
22507 22508 22509 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 22507 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
22517 22518 22519 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 22517 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
22522 22523 22524 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 22522 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::HealthSourceList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
22527 22528 22529 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 22527 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
22534 22535 22536 22537 22538 22539 22540 22541 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 22534 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |