Class: Google::Apis::ComputeAlpha::HealthSourceList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::HealthSourceList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::HealthSource>
A list of HealthSource resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
-
#warning ⇒ Google::Apis::ComputeAlpha::HealthSourceList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HealthSourceList
constructor
A new instance of HealthSourceList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HealthSourceList
Returns a new instance of HealthSourceList.
22555 22556 22557 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 22555 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
22522 22523 22524 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 22522 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::HealthSource>
A list of HealthSource resources.
Corresponds to the JSON property items
22527 22528 22529 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 22527 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#healthSource
for health sources.
Corresponds to the JSON property kind
22533 22534 22535 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 22533 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
22543 22544 22545 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 22543 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
22548 22549 22550 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 22548 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::HealthSourceList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
22553 22554 22555 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 22553 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
22560 22561 22562 22563 22564 22565 22566 22567 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 22560 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |