Class: Google::Apis::ComputeAlpha::HealthSourcesGetHealthResponseSourceInfo

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HealthSourcesGetHealthResponseSourceInfo

Returns a new instance of HealthSourcesGetHealthResponseSourceInfo.



22637
22638
22639
# File 'lib/google/apis/compute_alpha/classes.rb', line 22637

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backendsArray<Google::Apis::ComputeAlpha::HealthSourcesGetHealthResponseSourceInfoBackendInfo>

Represents an instance group or network endpoint group behind the source backend service. Only used if the sourceType of the regionHealthSource is BACKEND_SERVICE. Corresponds to the JSON property backends



22623
22624
22625
# File 'lib/google/apis/compute_alpha/classes.rb', line 22623

def backends
  @backends
end

#forwarding_ruleString

Fully qualified URL of the forwarding rule associated with the source resource if it is a L4ILB backend service. Corresponds to the JSON property forwardingRule

Returns:

  • (String)


22629
22630
22631
# File 'lib/google/apis/compute_alpha/classes.rb', line 22629

def forwarding_rule
  @forwarding_rule
end

#sourceString

Fully qualified URL of the associated source resource. This is always a backend service URL. Corresponds to the JSON property source

Returns:

  • (String)


22635
22636
22637
# File 'lib/google/apis/compute_alpha/classes.rb', line 22635

def source
  @source
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



22642
22643
22644
22645
22646
# File 'lib/google/apis/compute_alpha/classes.rb', line 22642

def update!(**args)
  @backends = args[:backends] if args.key?(:backends)
  @forwarding_rule = args[:forwarding_rule] if args.key?(:forwarding_rule)
  @source = args[:source] if args.key?(:source)
end