Class: Google::Apis::ComputeAlpha::HealthSourcesGetHealthResponseSourceInfo

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HealthSourcesGetHealthResponseSourceInfo

Returns a new instance of HealthSourcesGetHealthResponseSourceInfo.



22654
22655
22656
# File 'lib/google/apis/compute_alpha/classes.rb', line 22654

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backendsArray<Google::Apis::ComputeAlpha::HealthSourcesGetHealthResponseSourceInfoBackendInfo>

Represents an instance group or network endpoint group behind the source backend service. Only used if the sourceType of the regionHealthSource is BACKEND_SERVICE. Corresponds to the JSON property backends



22640
22641
22642
# File 'lib/google/apis/compute_alpha/classes.rb', line 22640

def backends
  @backends
end

#forwarding_ruleString

Fully qualified URL of the forwarding rule associated with the source resource if it is a L4ILB backend service. Corresponds to the JSON property forwardingRule

Returns:

  • (String)


22646
22647
22648
# File 'lib/google/apis/compute_alpha/classes.rb', line 22646

def forwarding_rule
  @forwarding_rule
end

#sourceString

Fully qualified URL of the associated source resource. This is always a backend service URL. Corresponds to the JSON property source

Returns:

  • (String)


22652
22653
22654
# File 'lib/google/apis/compute_alpha/classes.rb', line 22652

def source
  @source
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



22659
22660
22661
22662
22663
# File 'lib/google/apis/compute_alpha/classes.rb', line 22659

def update!(**args)
  @backends = args[:backends] if args.key?(:backends)
  @forwarding_rule = args[:forwarding_rule] if args.key?(:forwarding_rule)
  @source = args[:source] if args.key?(:source)
end