Class: Google::Apis::ComputeAlpha::HealthSourcesGetHealthResponseSourceInfo
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::HealthSourcesGetHealthResponseSourceInfo
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#backends ⇒ Array<Google::Apis::ComputeAlpha::HealthSourcesGetHealthResponseSourceInfoBackendInfo>
Represents an instance group or network endpoint group behind the source backend service.
-
#forwarding_rule ⇒ String
Fully qualified URL of the forwarding rule associated with the source resource if it is a L4ILB backend service.
-
#source ⇒ String
Fully qualified URL of the associated source resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HealthSourcesGetHealthResponseSourceInfo
constructor
A new instance of HealthSourcesGetHealthResponseSourceInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HealthSourcesGetHealthResponseSourceInfo
Returns a new instance of HealthSourcesGetHealthResponseSourceInfo.
22297 22298 22299 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 22297 def initialize(**args) update!(**args) end |
Instance Attribute Details
#backends ⇒ Array<Google::Apis::ComputeAlpha::HealthSourcesGetHealthResponseSourceInfoBackendInfo>
Represents an instance group or network endpoint group behind the source
backend service. Only used if the sourceType of the regionHealthSource
is BACKEND_SERVICE.
Corresponds to the JSON property backends
22283 22284 22285 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 22283 def backends @backends end |
#forwarding_rule ⇒ String
Fully qualified URL of the forwarding rule associated with the source
resource if it is a L4ILB backend service.
Corresponds to the JSON property forwardingRule
22289 22290 22291 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 22289 def forwarding_rule @forwarding_rule end |
#source ⇒ String
Fully qualified URL of the associated source resource. This is always a
backend service URL.
Corresponds to the JSON property source
22295 22296 22297 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 22295 def source @source end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
22302 22303 22304 22305 22306 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 22302 def update!(**args) @backends = args[:backends] if args.key?(:backends) @forwarding_rule = args[:forwarding_rule] if args.key?(:forwarding_rule) @source = args[:source] if args.key?(:source) end |