Class: Google::Apis::ComputeAlpha::HealthSourcesGetHealthResponseSourceInfoBackendInfo
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::HealthSourcesGetHealthResponseSourceInfoBackendInfo
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#endpoint_count ⇒ Fixnum
Total number of endpoints when determining the health of the regionHealthSource.
-
#group ⇒ String
Fully qualified URL of an instance group or network endpoint group behind the source backend service.
-
#healthy_endpoint_count ⇒ Fixnum
Number of endpoints considered healthy when determining health of the regionHealthSource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HealthSourcesGetHealthResponseSourceInfoBackendInfo
constructor
A new instance of HealthSourcesGetHealthResponseSourceInfoBackendInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HealthSourcesGetHealthResponseSourceInfoBackendInfo
Returns a new instance of HealthSourcesGetHealthResponseSourceInfoBackendInfo.
23612 23613 23614 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 23612 def initialize(**args) update!(**args) end |
Instance Attribute Details
#endpoint_count ⇒ Fixnum
Total number of endpoints when determining the health of the
regionHealthSource.
Corresponds to the JSON property endpointCount
23598 23599 23600 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 23598 def endpoint_count @endpoint_count end |
#group ⇒ String
Fully qualified URL of an instance group or network endpoint group
behind the source backend service.
Corresponds to the JSON property group
23604 23605 23606 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 23604 def group @group end |
#healthy_endpoint_count ⇒ Fixnum
Number of endpoints considered healthy when determining health of the
regionHealthSource.
Corresponds to the JSON property healthyEndpointCount
23610 23611 23612 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 23610 def healthy_endpoint_count @healthy_endpoint_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
23617 23618 23619 23620 23621 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 23617 def update!(**args) @endpoint_count = args[:endpoint_count] if args.key?(:endpoint_count) @group = args[:group] if args.key?(:group) @healthy_endpoint_count = args[:healthy_endpoint_count] if args.key?(:healthy_endpoint_count) end |