Class: Google::Apis::ComputeAlpha::HealthSourcesGetHealthResponseSourceInfoBackendInfo

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HealthSourcesGetHealthResponseSourceInfoBackendInfo

Returns a new instance of HealthSourcesGetHealthResponseSourceInfoBackendInfo.



22331
22332
22333
# File 'lib/google/apis/compute_alpha/classes.rb', line 22331

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#endpoint_countFixnum

Total number of endpoints when determining the health of the regionHealthSource. Corresponds to the JSON property endpointCount

Returns:

  • (Fixnum)


22317
22318
22319
# File 'lib/google/apis/compute_alpha/classes.rb', line 22317

def endpoint_count
  @endpoint_count
end

#groupString

Fully qualified URL of an instance group or network endpoint group behind the source backend service. Corresponds to the JSON property group

Returns:

  • (String)


22323
22324
22325
# File 'lib/google/apis/compute_alpha/classes.rb', line 22323

def group
  @group
end

#healthy_endpoint_countFixnum

Number of endpoints considered healthy when determining health of the regionHealthSource. Corresponds to the JSON property healthyEndpointCount

Returns:

  • (Fixnum)


22329
22330
22331
# File 'lib/google/apis/compute_alpha/classes.rb', line 22329

def healthy_endpoint_count
  @healthy_endpoint_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



22336
22337
22338
22339
22340
# File 'lib/google/apis/compute_alpha/classes.rb', line 22336

def update!(**args)
  @endpoint_count = args[:endpoint_count] if args.key?(:endpoint_count)
  @group = args[:group] if args.key?(:group)
  @healthy_endpoint_count = args[:healthy_endpoint_count] if args.key?(:healthy_endpoint_count)
end