Class: Google::Apis::ComputeAlpha::HealthStatus

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HealthStatus

Returns a new instance of HealthStatus.



24056
24057
24058
# File 'lib/google/apis/compute_alpha/classes.rb', line 24056

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#annotationsHash<String,String>

Metadata defined as annotations for network endpoint. Corresponds to the JSON property annotations

Returns:

  • (Hash<String,String>)


24000
24001
24002
# File 'lib/google/apis/compute_alpha/classes.rb', line 24000

def annotations
  @annotations
end

#forwarding_ruleString

URL of the forwarding rule associated with the health status of the instance. Corresponds to the JSON property forwardingRule

Returns:

  • (String)


24006
24007
24008
# File 'lib/google/apis/compute_alpha/classes.rb', line 24006

def forwarding_rule
  @forwarding_rule
end

#forwarding_rule_ipString

A forwarding rule IP address assigned to this instance. Corresponds to the JSON property forwardingRuleIp

Returns:

  • (String)


24011
24012
24013
# File 'lib/google/apis/compute_alpha/classes.rb', line 24011

def forwarding_rule_ip
  @forwarding_rule_ip
end

#health_stateString

Health state of the IPv4 address of the instance. Corresponds to the JSON property healthState

Returns:

  • (String)


24016
24017
24018
# File 'lib/google/apis/compute_alpha/classes.rb', line 24016

def health_state
  @health_state
end

#instanceString

URL of the instance resource. Corresponds to the JSON property instance

Returns:

  • (String)


24021
24022
24023
# File 'lib/google/apis/compute_alpha/classes.rb', line 24021

def instance
  @instance
end

#ip_addressString

For target pool based Network Load Balancing, it indicates the forwarding rule's IP address assigned to this instance. For other types of load balancing, the field indicates VM internal ip. Corresponds to the JSON property ipAddress

Returns:

  • (String)


24028
24029
24030
# File 'lib/google/apis/compute_alpha/classes.rb', line 24028

def ip_address
  @ip_address
end

#ipv6_addressString

Corresponds to the JSON property ipv6Address

Returns:

  • (String)


24033
24034
24035
# File 'lib/google/apis/compute_alpha/classes.rb', line 24033

def ipv6_address
  @ipv6_address
end

#ipv6_health_stateString

Health state of the IPv6 address of the instance. Corresponds to the JSON property ipv6HealthState

Returns:

  • (String)


24038
24039
24040
# File 'lib/google/apis/compute_alpha/classes.rb', line 24038

def ipv6_health_state
  @ipv6_health_state
end

#portFixnum

The named port of the instance group, not necessarily the port that is health-checked. Corresponds to the JSON property port

Returns:

  • (Fixnum)


24044
24045
24046
# File 'lib/google/apis/compute_alpha/classes.rb', line 24044

def port
  @port
end

#weightString

Corresponds to the JSON property weight

Returns:

  • (String)


24049
24050
24051
# File 'lib/google/apis/compute_alpha/classes.rb', line 24049

def weight
  @weight
end

#weight_errorString

Corresponds to the JSON property weightError

Returns:

  • (String)


24054
24055
24056
# File 'lib/google/apis/compute_alpha/classes.rb', line 24054

def weight_error
  @weight_error
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



24061
24062
24063
24064
24065
24066
24067
24068
24069
24070
24071
24072
24073
# File 'lib/google/apis/compute_alpha/classes.rb', line 24061

def update!(**args)
  @annotations = args[:annotations] if args.key?(:annotations)
  @forwarding_rule = args[:forwarding_rule] if args.key?(:forwarding_rule)
  @forwarding_rule_ip = args[:forwarding_rule_ip] if args.key?(:forwarding_rule_ip)
  @health_state = args[:health_state] if args.key?(:health_state)
  @instance = args[:instance] if args.key?(:instance)
  @ip_address = args[:ip_address] if args.key?(:ip_address)
  @ipv6_address = args[:ipv6_address] if args.key?(:ipv6_address)
  @ipv6_health_state = args[:ipv6_health_state] if args.key?(:ipv6_health_state)
  @port = args[:port] if args.key?(:port)
  @weight = args[:weight] if args.key?(:weight)
  @weight_error = args[:weight_error] if args.key?(:weight_error)
end