Class: Google::Apis::ComputeAlpha::HealthStatus
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::HealthStatus
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#annotations ⇒ Hash<String,String>
Metadata defined as annotations for network endpoint.
-
#forwarding_rule ⇒ String
URL of the forwarding rule associated with the health status of the instance.
-
#forwarding_rule_ip ⇒ String
A forwarding rule IP address assigned to this instance.
-
#health_state ⇒ String
Health state of the IPv4 address of the instance.
-
#instance ⇒ String
URL of the instance resource.
-
#ip_address ⇒ String
For target pool based Network Load Balancing, it indicates the forwarding rule's IP address assigned to this instance.
-
#ipv6_address ⇒ String
Corresponds to the JSON property
ipv6Address. -
#ipv6_health_state ⇒ String
Health state of the IPv6 address of the instance.
-
#port ⇒ Fixnum
The named port of the instance group, not necessarily the port that is health-checked.
-
#weight ⇒ String
Corresponds to the JSON property
weight. -
#weight_error ⇒ String
Corresponds to the JSON property
weightError.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HealthStatus
constructor
A new instance of HealthStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HealthStatus
Returns a new instance of HealthStatus.
24056 24057 24058 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24056 def initialize(**args) update!(**args) end |
Instance Attribute Details
#annotations ⇒ Hash<String,String>
Metadata defined as annotations for network endpoint.
Corresponds to the JSON property annotations
24000 24001 24002 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24000 def annotations @annotations end |
#forwarding_rule ⇒ String
URL of the forwarding rule associated with the health status of the
instance.
Corresponds to the JSON property forwardingRule
24006 24007 24008 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24006 def forwarding_rule @forwarding_rule end |
#forwarding_rule_ip ⇒ String
A forwarding rule IP address assigned to this instance.
Corresponds to the JSON property forwardingRuleIp
24011 24012 24013 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24011 def forwarding_rule_ip @forwarding_rule_ip end |
#health_state ⇒ String
Health state of the IPv4 address of the instance.
Corresponds to the JSON property healthState
24016 24017 24018 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24016 def health_state @health_state end |
#instance ⇒ String
URL of the instance resource.
Corresponds to the JSON property instance
24021 24022 24023 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24021 def instance @instance end |
#ip_address ⇒ String
For target pool based Network Load Balancing, it indicates the forwarding
rule's IP address assigned to this instance. For other types of load
balancing, the field indicates VM internal ip.
Corresponds to the JSON property ipAddress
24028 24029 24030 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24028 def ip_address @ip_address end |
#ipv6_address ⇒ String
Corresponds to the JSON property ipv6Address
24033 24034 24035 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24033 def ipv6_address @ipv6_address end |
#ipv6_health_state ⇒ String
Health state of the IPv6 address of the instance.
Corresponds to the JSON property ipv6HealthState
24038 24039 24040 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24038 def ipv6_health_state @ipv6_health_state end |
#port ⇒ Fixnum
The named port of the instance group, not necessarily the port that is
health-checked.
Corresponds to the JSON property port
24044 24045 24046 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24044 def port @port end |
#weight ⇒ String
Corresponds to the JSON property weight
24049 24050 24051 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24049 def weight @weight end |
#weight_error ⇒ String
Corresponds to the JSON property weightError
24054 24055 24056 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24054 def weight_error @weight_error end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
24061 24062 24063 24064 24065 24066 24067 24068 24069 24070 24071 24072 24073 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24061 def update!(**args) @annotations = args[:annotations] if args.key?(:annotations) @forwarding_rule = args[:forwarding_rule] if args.key?(:forwarding_rule) @forwarding_rule_ip = args[:forwarding_rule_ip] if args.key?(:forwarding_rule_ip) @health_state = args[:health_state] if args.key?(:health_state) @instance = args[:instance] if args.key?(:instance) @ip_address = args[:ip_address] if args.key?(:ip_address) @ipv6_address = args[:ipv6_address] if args.key?(:ipv6_address) @ipv6_health_state = args[:ipv6_health_state] if args.key?(:ipv6_health_state) @port = args[:port] if args.key?(:port) @weight = args[:weight] if args.key?(:weight) @weight_error = args[:weight_error] if args.key?(:weight_error) end |