Class: Google::Apis::ComputeAlpha::HealthStatus
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::HealthStatus
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#annotations ⇒ Hash<String,String>
Metadata defined as annotations for network endpoint.
-
#forwarding_rule ⇒ String
URL of the forwarding rule associated with the health status of the instance.
-
#forwarding_rule_ip ⇒ String
A forwarding rule IP address assigned to this instance.
-
#health_state ⇒ String
Health state of the IPv4 address of the instance.
-
#instance ⇒ String
URL of the instance resource.
-
#ip_address ⇒ String
For target pool based Network Load Balancing, it indicates the forwarding rule's IP address assigned to this instance.
-
#ipv6_address ⇒ String
Corresponds to the JSON property
ipv6Address. -
#ipv6_health_state ⇒ String
Health state of the IPv6 address of the instance.
-
#port ⇒ Fixnum
The named port of the instance group, not necessarily the port that is health-checked.
-
#weight ⇒ String
Corresponds to the JSON property
weight. -
#weight_error ⇒ String
Corresponds to the JSON property
weightError.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HealthStatus
constructor
A new instance of HealthStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HealthStatus
Returns a new instance of HealthStatus.
23056 23057 23058 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 23056 def initialize(**args) update!(**args) end |
Instance Attribute Details
#annotations ⇒ Hash<String,String>
Metadata defined as annotations for network endpoint.
Corresponds to the JSON property annotations
23000 23001 23002 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 23000 def annotations @annotations end |
#forwarding_rule ⇒ String
URL of the forwarding rule associated with the health status of the
instance.
Corresponds to the JSON property forwardingRule
23006 23007 23008 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 23006 def forwarding_rule @forwarding_rule end |
#forwarding_rule_ip ⇒ String
A forwarding rule IP address assigned to this instance.
Corresponds to the JSON property forwardingRuleIp
23011 23012 23013 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 23011 def forwarding_rule_ip @forwarding_rule_ip end |
#health_state ⇒ String
Health state of the IPv4 address of the instance.
Corresponds to the JSON property healthState
23016 23017 23018 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 23016 def health_state @health_state end |
#instance ⇒ String
URL of the instance resource.
Corresponds to the JSON property instance
23021 23022 23023 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 23021 def instance @instance end |
#ip_address ⇒ String
For target pool based Network Load Balancing, it indicates the forwarding
rule's IP address assigned to this instance. For other types of load
balancing, the field indicates VM internal ip.
Corresponds to the JSON property ipAddress
23028 23029 23030 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 23028 def ip_address @ip_address end |
#ipv6_address ⇒ String
Corresponds to the JSON property ipv6Address
23033 23034 23035 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 23033 def ipv6_address @ipv6_address end |
#ipv6_health_state ⇒ String
Health state of the IPv6 address of the instance.
Corresponds to the JSON property ipv6HealthState
23038 23039 23040 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 23038 def ipv6_health_state @ipv6_health_state end |
#port ⇒ Fixnum
The named port of the instance group, not necessarily the port that is
health-checked.
Corresponds to the JSON property port
23044 23045 23046 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 23044 def port @port end |
#weight ⇒ String
Corresponds to the JSON property weight
23049 23050 23051 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 23049 def weight @weight end |
#weight_error ⇒ String
Corresponds to the JSON property weightError
23054 23055 23056 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 23054 def weight_error @weight_error end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
23061 23062 23063 23064 23065 23066 23067 23068 23069 23070 23071 23072 23073 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 23061 def update!(**args) @annotations = args[:annotations] if args.key?(:annotations) @forwarding_rule = args[:forwarding_rule] if args.key?(:forwarding_rule) @forwarding_rule_ip = args[:forwarding_rule_ip] if args.key?(:forwarding_rule_ip) @health_state = args[:health_state] if args.key?(:health_state) @instance = args[:instance] if args.key?(:instance) @ip_address = args[:ip_address] if args.key?(:ip_address) @ipv6_address = args[:ipv6_address] if args.key?(:ipv6_address) @ipv6_health_state = args[:ipv6_health_state] if args.key?(:ipv6_health_state) @port = args[:port] if args.key?(:port) @weight = args[:weight] if args.key?(:weight) @weight_error = args[:weight_error] if args.key?(:weight_error) end |