Class: Google::Apis::ComputeAlpha::HealthStatus

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HealthStatus

Returns a new instance of HealthStatus.



22869
22870
22871
# File 'lib/google/apis/compute_alpha/classes.rb', line 22869

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#annotationsHash<String,String>

Metadata defined as annotations for network endpoint. Corresponds to the JSON property annotations

Returns:

  • (Hash<String,String>)


22813
22814
22815
# File 'lib/google/apis/compute_alpha/classes.rb', line 22813

def annotations
  @annotations
end

#forwarding_ruleString

URL of the forwarding rule associated with the health status of the instance. Corresponds to the JSON property forwardingRule

Returns:

  • (String)


22819
22820
22821
# File 'lib/google/apis/compute_alpha/classes.rb', line 22819

def forwarding_rule
  @forwarding_rule
end

#forwarding_rule_ipString

A forwarding rule IP address assigned to this instance. Corresponds to the JSON property forwardingRuleIp

Returns:

  • (String)


22824
22825
22826
# File 'lib/google/apis/compute_alpha/classes.rb', line 22824

def forwarding_rule_ip
  @forwarding_rule_ip
end

#health_stateString

Health state of the IPv4 address of the instance. Corresponds to the JSON property healthState

Returns:

  • (String)


22829
22830
22831
# File 'lib/google/apis/compute_alpha/classes.rb', line 22829

def health_state
  @health_state
end

#instanceString

URL of the instance resource. Corresponds to the JSON property instance

Returns:

  • (String)


22834
22835
22836
# File 'lib/google/apis/compute_alpha/classes.rb', line 22834

def instance
  @instance
end

#ip_addressString

For target pool based Network Load Balancing, it indicates the forwarding rule's IP address assigned to this instance. For other types of load balancing, the field indicates VM internal ip. Corresponds to the JSON property ipAddress

Returns:

  • (String)


22841
22842
22843
# File 'lib/google/apis/compute_alpha/classes.rb', line 22841

def ip_address
  @ip_address
end

#ipv6_addressString

Corresponds to the JSON property ipv6Address

Returns:

  • (String)


22846
22847
22848
# File 'lib/google/apis/compute_alpha/classes.rb', line 22846

def ipv6_address
  @ipv6_address
end

#ipv6_health_stateString

Health state of the IPv6 address of the instance. Corresponds to the JSON property ipv6HealthState

Returns:

  • (String)


22851
22852
22853
# File 'lib/google/apis/compute_alpha/classes.rb', line 22851

def ipv6_health_state
  @ipv6_health_state
end

#portFixnum

The named port of the instance group, not necessarily the port that is health-checked. Corresponds to the JSON property port

Returns:

  • (Fixnum)


22857
22858
22859
# File 'lib/google/apis/compute_alpha/classes.rb', line 22857

def port
  @port
end

#weightString

Corresponds to the JSON property weight

Returns:

  • (String)


22862
22863
22864
# File 'lib/google/apis/compute_alpha/classes.rb', line 22862

def weight
  @weight
end

#weight_errorString

Corresponds to the JSON property weightError

Returns:

  • (String)


22867
22868
22869
# File 'lib/google/apis/compute_alpha/classes.rb', line 22867

def weight_error
  @weight_error
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



22874
22875
22876
22877
22878
22879
22880
22881
22882
22883
22884
22885
22886
# File 'lib/google/apis/compute_alpha/classes.rb', line 22874

def update!(**args)
  @annotations = args[:annotations] if args.key?(:annotations)
  @forwarding_rule = args[:forwarding_rule] if args.key?(:forwarding_rule)
  @forwarding_rule_ip = args[:forwarding_rule_ip] if args.key?(:forwarding_rule_ip)
  @health_state = args[:health_state] if args.key?(:health_state)
  @instance = args[:instance] if args.key?(:instance)
  @ip_address = args[:ip_address] if args.key?(:ip_address)
  @ipv6_address = args[:ipv6_address] if args.key?(:ipv6_address)
  @ipv6_health_state = args[:ipv6_health_state] if args.key?(:ipv6_health_state)
  @port = args[:port] if args.key?(:port)
  @weight = args[:weight] if args.key?(:weight)
  @weight_error = args[:weight_error] if args.key?(:weight_error)
end