Class: Google::Apis::ComputeAlpha::HealthStatus
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::HealthStatus
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#annotations ⇒ Hash<String,String>
Metadata defined as annotations for network endpoint.
-
#forwarding_rule ⇒ String
URL of the forwarding rule associated with the health status of the instance.
-
#forwarding_rule_ip ⇒ String
A forwarding rule IP address assigned to this instance.
-
#health_state ⇒ String
Health state of the IPv4 address of the instance.
-
#instance ⇒ String
URL of the instance resource.
-
#ip_address ⇒ String
For target pool based Network Load Balancing, it indicates the forwarding rule's IP address assigned to this instance.
-
#ipv6_address ⇒ String
Corresponds to the JSON property
ipv6Address. -
#ipv6_health_state ⇒ String
Health state of the IPv6 address of the instance.
-
#port ⇒ Fixnum
The named port of the instance group, not necessarily the port that is health-checked.
-
#weight ⇒ String
Corresponds to the JSON property
weight. -
#weight_error ⇒ String
Corresponds to the JSON property
weightError.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HealthStatus
constructor
A new instance of HealthStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HealthStatus
Returns a new instance of HealthStatus.
22503 22504 22505 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 22503 def initialize(**args) update!(**args) end |
Instance Attribute Details
#annotations ⇒ Hash<String,String>
Metadata defined as annotations for network endpoint.
Corresponds to the JSON property annotations
22447 22448 22449 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 22447 def annotations @annotations end |
#forwarding_rule ⇒ String
URL of the forwarding rule associated with the health status of the
instance.
Corresponds to the JSON property forwardingRule
22453 22454 22455 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 22453 def forwarding_rule @forwarding_rule end |
#forwarding_rule_ip ⇒ String
A forwarding rule IP address assigned to this instance.
Corresponds to the JSON property forwardingRuleIp
22458 22459 22460 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 22458 def forwarding_rule_ip @forwarding_rule_ip end |
#health_state ⇒ String
Health state of the IPv4 address of the instance.
Corresponds to the JSON property healthState
22463 22464 22465 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 22463 def health_state @health_state end |
#instance ⇒ String
URL of the instance resource.
Corresponds to the JSON property instance
22468 22469 22470 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 22468 def instance @instance end |
#ip_address ⇒ String
For target pool based Network Load Balancing, it indicates the forwarding
rule's IP address assigned to this instance. For other types of load
balancing, the field indicates VM internal ip.
Corresponds to the JSON property ipAddress
22475 22476 22477 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 22475 def ip_address @ip_address end |
#ipv6_address ⇒ String
Corresponds to the JSON property ipv6Address
22480 22481 22482 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 22480 def ipv6_address @ipv6_address end |
#ipv6_health_state ⇒ String
Health state of the IPv6 address of the instance.
Corresponds to the JSON property ipv6HealthState
22485 22486 22487 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 22485 def ipv6_health_state @ipv6_health_state end |
#port ⇒ Fixnum
The named port of the instance group, not necessarily the port that is
health-checked.
Corresponds to the JSON property port
22491 22492 22493 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 22491 def port @port end |
#weight ⇒ String
Corresponds to the JSON property weight
22496 22497 22498 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 22496 def weight @weight end |
#weight_error ⇒ String
Corresponds to the JSON property weightError
22501 22502 22503 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 22501 def weight_error @weight_error end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
22508 22509 22510 22511 22512 22513 22514 22515 22516 22517 22518 22519 22520 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 22508 def update!(**args) @annotations = args[:annotations] if args.key?(:annotations) @forwarding_rule = args[:forwarding_rule] if args.key?(:forwarding_rule) @forwarding_rule_ip = args[:forwarding_rule_ip] if args.key?(:forwarding_rule_ip) @health_state = args[:health_state] if args.key?(:health_state) @instance = args[:instance] if args.key?(:instance) @ip_address = args[:ip_address] if args.key?(:ip_address) @ipv6_address = args[:ipv6_address] if args.key?(:ipv6_address) @ipv6_health_state = args[:ipv6_health_state] if args.key?(:ipv6_health_state) @port = args[:port] if args.key?(:port) @weight = args[:weight] if args.key?(:weight) @weight_error = args[:weight_error] if args.key?(:weight_error) end |