Class: Google::Apis::ComputeAlpha::HealthStatusForNetworkEndpoint
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::HealthStatusForNetworkEndpoint
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#backend_service ⇒ Google::Apis::ComputeAlpha::BackendServiceReference
URL of the backend service associated with the health state of the network endpoint.
-
#forwarding_rule ⇒ Google::Apis::ComputeAlpha::ForwardingRuleReference
URL of the forwarding rule associated with the health state of the network endpoint.
-
#health_check ⇒ Google::Apis::ComputeAlpha::HealthCheckReference
A full or valid partial URL to a health check.
-
#health_check_service ⇒ Google::Apis::ComputeAlpha::HealthCheckServiceReference
A full or valid partial URL to a health check service.
-
#health_state ⇒ String
Health state of the network endpoint determined based on the health checks configured.
-
#ipv6_health_state ⇒ String
Health state of the ipv6 network endpoint determined based on the health checks configured.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HealthStatusForNetworkEndpoint
constructor
A new instance of HealthStatusForNetworkEndpoint.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HealthStatusForNetworkEndpoint
Returns a new instance of HealthStatusForNetworkEndpoint.
23119 23120 23121 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 23119 def initialize(**args) update!(**args) end |
Instance Attribute Details
#backend_service ⇒ Google::Apis::ComputeAlpha::BackendServiceReference
URL of the backend service associated with the health state of the network
endpoint.
Corresponds to the JSON property backendService
23076 23077 23078 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 23076 def backend_service @backend_service end |
#forwarding_rule ⇒ Google::Apis::ComputeAlpha::ForwardingRuleReference
URL of the forwarding rule associated with the health state of the network
endpoint.
Corresponds to the JSON property forwardingRule
23082 23083 23084 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 23082 def forwarding_rule @forwarding_rule end |
#health_check ⇒ Google::Apis::ComputeAlpha::HealthCheckReference
A full or valid partial URL to a health check. For example, the following are valid URLs:
- https://www.googleapis.com/compute/beta/projects/project-id/global/ httpHealthChecks/health-check
- projects/project-id/global/httpHealthChecks/health-check
- global/httpHealthChecks/health-check
Corresponds to the JSON property
healthCheck
23093 23094 23095 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 23093 def health_check @health_check end |
#health_check_service ⇒ Google::Apis::ComputeAlpha::HealthCheckServiceReference
A full or valid partial URL to a health check service. For example, the following are valid URLs:
- https://www.googleapis.com/compute/beta/projects/project-id/regions/us- west1/healthCheckServices/health-check-service
- projects/project-id/regions/us-west1/healthCheckServices/health-check- service
- regions/us-west1/healthCheckServices/health-check-service
Corresponds to the JSON property
healthCheckService
23105 23106 23107 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 23105 def health_check_service @health_check_service end |
#health_state ⇒ String
Health state of the network endpoint determined based on the health checks
configured.
Corresponds to the JSON property healthState
23111 23112 23113 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 23111 def health_state @health_state end |
#ipv6_health_state ⇒ String
Health state of the ipv6 network endpoint determined based on the health
checks configured.
Corresponds to the JSON property ipv6HealthState
23117 23118 23119 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 23117 def ipv6_health_state @ipv6_health_state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
23124 23125 23126 23127 23128 23129 23130 23131 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 23124 def update!(**args) @backend_service = args[:backend_service] if args.key?(:backend_service) @forwarding_rule = args[:forwarding_rule] if args.key?(:forwarding_rule) @health_check = args[:health_check] if args.key?(:health_check) @health_check_service = args[:health_check_service] if args.key?(:health_check_service) @health_state = args[:health_state] if args.key?(:health_state) @ipv6_health_state = args[:ipv6_health_state] if args.key?(:ipv6_health_state) end |