Class: Google::Apis::ComputeAlpha::HealthStatusForNetworkEndpoint

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HealthStatusForNetworkEndpoint

Returns a new instance of HealthStatusForNetworkEndpoint.



22914
22915
22916
# File 'lib/google/apis/compute_alpha/classes.rb', line 22914

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backend_serviceGoogle::Apis::ComputeAlpha::BackendServiceReference

URL of the backend service associated with the health state of the network endpoint. Corresponds to the JSON property backendService



22871
22872
22873
# File 'lib/google/apis/compute_alpha/classes.rb', line 22871

def backend_service
  @backend_service
end

#forwarding_ruleGoogle::Apis::ComputeAlpha::ForwardingRuleReference

URL of the forwarding rule associated with the health state of the network endpoint. Corresponds to the JSON property forwardingRule



22877
22878
22879
# File 'lib/google/apis/compute_alpha/classes.rb', line 22877

def forwarding_rule
  @forwarding_rule
end

#health_checkGoogle::Apis::ComputeAlpha::HealthCheckReference

A full or valid partial URL to a health check. For example, the following are valid URLs:



22888
22889
22890
# File 'lib/google/apis/compute_alpha/classes.rb', line 22888

def health_check
  @health_check
end

#health_check_serviceGoogle::Apis::ComputeAlpha::HealthCheckServiceReference

A full or valid partial URL to a health check service. For example, the following are valid URLs:



22900
22901
22902
# File 'lib/google/apis/compute_alpha/classes.rb', line 22900

def health_check_service
  @health_check_service
end

#health_stateString

Health state of the network endpoint determined based on the health checks configured. Corresponds to the JSON property healthState

Returns:

  • (String)


22906
22907
22908
# File 'lib/google/apis/compute_alpha/classes.rb', line 22906

def health_state
  @health_state
end

#ipv6_health_stateString

Health state of the ipv6 network endpoint determined based on the health checks configured. Corresponds to the JSON property ipv6HealthState

Returns:

  • (String)


22912
22913
22914
# File 'lib/google/apis/compute_alpha/classes.rb', line 22912

def ipv6_health_state
  @ipv6_health_state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



22919
22920
22921
22922
22923
22924
22925
22926
# File 'lib/google/apis/compute_alpha/classes.rb', line 22919

def update!(**args)
  @backend_service = args[:backend_service] if args.key?(:backend_service)
  @forwarding_rule = args[:forwarding_rule] if args.key?(:forwarding_rule)
  @health_check = args[:health_check] if args.key?(:health_check)
  @health_check_service = args[:health_check_service] if args.key?(:health_check_service)
  @health_state = args[:health_state] if args.key?(:health_state)
  @ipv6_health_state = args[:ipv6_health_state] if args.key?(:ipv6_health_state)
end