Class: Google::Apis::ComputeAlpha::HealthStatusForNetworkEndpoint

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HealthStatusForNetworkEndpoint

Returns a new instance of HealthStatusForNetworkEndpoint.



22574
22575
22576
# File 'lib/google/apis/compute_alpha/classes.rb', line 22574

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backend_serviceGoogle::Apis::ComputeAlpha::BackendServiceReference

URL of the backend service associated with the health state of the network endpoint. Corresponds to the JSON property backendService



22531
22532
22533
# File 'lib/google/apis/compute_alpha/classes.rb', line 22531

def backend_service
  @backend_service
end

#forwarding_ruleGoogle::Apis::ComputeAlpha::ForwardingRuleReference

URL of the forwarding rule associated with the health state of the network endpoint. Corresponds to the JSON property forwardingRule



22537
22538
22539
# File 'lib/google/apis/compute_alpha/classes.rb', line 22537

def forwarding_rule
  @forwarding_rule
end

#health_checkGoogle::Apis::ComputeAlpha::HealthCheckReference

A full or valid partial URL to a health check. For example, the following are valid URLs:



22548
22549
22550
# File 'lib/google/apis/compute_alpha/classes.rb', line 22548

def health_check
  @health_check
end

#health_check_serviceGoogle::Apis::ComputeAlpha::HealthCheckServiceReference

A full or valid partial URL to a health check service. For example, the following are valid URLs:



22560
22561
22562
# File 'lib/google/apis/compute_alpha/classes.rb', line 22560

def health_check_service
  @health_check_service
end

#health_stateString

Health state of the network endpoint determined based on the health checks configured. Corresponds to the JSON property healthState

Returns:

  • (String)


22566
22567
22568
# File 'lib/google/apis/compute_alpha/classes.rb', line 22566

def health_state
  @health_state
end

#ipv6_health_stateString

Health state of the ipv6 network endpoint determined based on the health checks configured. Corresponds to the JSON property ipv6HealthState

Returns:

  • (String)


22572
22573
22574
# File 'lib/google/apis/compute_alpha/classes.rb', line 22572

def ipv6_health_state
  @ipv6_health_state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



22579
22580
22581
22582
22583
22584
22585
22586
# File 'lib/google/apis/compute_alpha/classes.rb', line 22579

def update!(**args)
  @backend_service = args[:backend_service] if args.key?(:backend_service)
  @forwarding_rule = args[:forwarding_rule] if args.key?(:forwarding_rule)
  @health_check = args[:health_check] if args.key?(:health_check)
  @health_check_service = args[:health_check_service] if args.key?(:health_check_service)
  @health_state = args[:health_state] if args.key?(:health_state)
  @ipv6_health_state = args[:ipv6_health_state] if args.key?(:ipv6_health_state)
end