Class: Google::Apis::ComputeAlpha::HostPhysicalTopology

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HostPhysicalTopology

Returns a new instance of HostPhysicalTopology.



24024
24025
24026
# File 'lib/google/apis/compute_alpha/classes.rb', line 24024

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#blockString

The unique identifier of the capacity block within the cluster. Corresponds to the JSON property block

Returns:

  • (String)


24006
24007
24008
# File 'lib/google/apis/compute_alpha/classes.rb', line 24006

def block
  @block
end

#clusterString

The cluster name of the reservation sub-block. Corresponds to the JSON property cluster

Returns:

  • (String)


24011
24012
24013
# File 'lib/google/apis/compute_alpha/classes.rb', line 24011

def cluster
  @cluster
end

#hostString

The unique identifier of the capacity host within the capacity sub-block. Corresponds to the JSON property host

Returns:

  • (String)


24016
24017
24018
# File 'lib/google/apis/compute_alpha/classes.rb', line 24016

def host
  @host
end

#sub_blockString

The unique identifier of the capacity sub-block within the capacity block. Corresponds to the JSON property subBlock

Returns:

  • (String)


24022
24023
24024
# File 'lib/google/apis/compute_alpha/classes.rb', line 24022

def sub_block
  @sub_block
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



24029
24030
24031
24032
24033
24034
# File 'lib/google/apis/compute_alpha/classes.rb', line 24029

def update!(**args)
  @block = args[:block] if args.key?(:block)
  @cluster = args[:cluster] if args.key?(:cluster)
  @host = args[:host] if args.key?(:host)
  @sub_block = args[:sub_block] if args.key?(:sub_block)
end