Class: Google::Apis::ComputeAlpha::HostPhysicalTopology
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::HostPhysicalTopology
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#block ⇒ String
The unique identifier of the capacity block within the cluster.
-
#cluster ⇒ String
The cluster name of the reservation sub-block.
-
#host ⇒ String
The unique identifier of the capacity host within the capacity sub-block.
-
#sub_block ⇒ String
The unique identifier of the capacity sub-block within the capacity block.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HostPhysicalTopology
constructor
A new instance of HostPhysicalTopology.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HostPhysicalTopology
Returns a new instance of HostPhysicalTopology.
23109 23110 23111 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 23109 def initialize(**args) update!(**args) end |
Instance Attribute Details
#block ⇒ String
The unique identifier of the capacity block within the cluster.
Corresponds to the JSON property block
23091 23092 23093 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 23091 def block @block end |
#cluster ⇒ String
The cluster name of the reservation sub-block.
Corresponds to the JSON property cluster
23096 23097 23098 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 23096 def cluster @cluster end |
#host ⇒ String
The unique identifier of the capacity host within the capacity sub-block.
Corresponds to the JSON property host
23101 23102 23103 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 23101 def host @host end |
#sub_block ⇒ String
The unique identifier of the capacity sub-block within the capacity
block.
Corresponds to the JSON property subBlock
23107 23108 23109 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 23107 def sub_block @sub_block end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
23114 23115 23116 23117 23118 23119 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 23114 def update!(**args) @block = args[:block] if args.key?(:block) @cluster = args[:cluster] if args.key?(:cluster) @host = args[:host] if args.key?(:host) @sub_block = args[:sub_block] if args.key?(:sub_block) end |