Class: Google::Apis::ComputeAlpha::HostRule
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::HostRule
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
UrlMaps A host-matching rule for a URL. If matched, will use the namedPathMatcher to select the BackendService.
Instance Attribute Summary collapse
-
#description ⇒ String
An optional description of this resource.
-
#hosts ⇒ Array<String>
The list of host patterns to match.
-
#path_matcher ⇒ String
The name of the PathMatcher to use to match the path portion of the URL if the hostRule matches the URL's host portion.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HostRule
constructor
A new instance of HostRule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HostRule
Returns a new instance of HostRule.
22667 22668 22669 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 22667 def initialize(**args) update!(**args) end |
Instance Attribute Details
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
22646 22647 22648 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 22646 def description @description end |
#hosts ⇒ Array<String>
The list of host patterns to match. They must be valid hostnames with optional port numbers in the format host:port.* matches any string of ([a-z0-9- .]*). In that case, * must be the first character, and if followed by anything, the immediate following character must be either - or ..
- based matching is not supported when the URL map is bound
to a target gRPC proxy that has the validateForProxyless field
set to true.
Corresponds to the JSON property
hosts
22659 22660 22661 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 22659 def hosts @hosts end |
#path_matcher ⇒ String
The name of the PathMatcher to use to match the path portion
of the URL if the hostRule matches the URL's host portion.
Corresponds to the JSON property pathMatcher
22665 22666 22667 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 22665 def path_matcher @path_matcher end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
22672 22673 22674 22675 22676 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 22672 def update!(**args) @description = args[:description] if args.key?(:description) @hosts = args[:hosts] if args.key?(:hosts) @path_matcher = args[:path_matcher] if args.key?(:path_matcher) end |