Class: Google::Apis::ComputeAlpha::HostsListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HostsListResponse

Returns a new instance of HostsListResponse.



24447
24448
24449
# File 'lib/google/apis/compute_alpha/classes.rb', line 24447

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


24404
24405
24406
# File 'lib/google/apis/compute_alpha/classes.rb', line 24404

def etag
  @etag
end

#idString

The unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


24409
24410
24411
# File 'lib/google/apis/compute_alpha/classes.rb', line 24409

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::Host>

A list of host resources. Corresponds to the JSON property items



24414
24415
24416
# File 'lib/google/apis/compute_alpha/classes.rb', line 24414

def items
  @items
end

#kindString

The type of resource. Always compute#host for a list of hosts. Corresponds to the JSON property kind

Returns:

  • (String)


24419
24420
24421
# File 'lib/google/apis/compute_alpha/classes.rb', line 24419

def kind
  @kind
end

#next_page_tokenString

This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


24429
24430
24431
# File 'lib/google/apis/compute_alpha/classes.rb', line 24429

def next_page_token
  @next_page_token
end

The server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


24434
24435
24436
# File 'lib/google/apis/compute_alpha/classes.rb', line 24434

def self_link
  @self_link
end

#unreachablesArray<String>

Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


24440
24441
24442
# File 'lib/google/apis/compute_alpha/classes.rb', line 24440

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::HostsListResponse::Warning

An informational warning message. Corresponds to the JSON property warning



24445
24446
24447
# File 'lib/google/apis/compute_alpha/classes.rb', line 24445

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



24452
24453
24454
24455
24456
24457
24458
24459
24460
24461
# File 'lib/google/apis/compute_alpha/classes.rb', line 24452

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end