Class: Google::Apis::ComputeAlpha::HostsListResponse
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::HostsListResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
The unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::Host>
A list of host resources.
-
#kind ⇒ String
The type of resource.
-
#next_page_token ⇒ String
This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
The server-defined URL for this resource.
-
#unreachables ⇒ Array<String>
Unreachable resources.
-
#warning ⇒ Google::Apis::ComputeAlpha::HostsListResponse::Warning
An informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HostsListResponse
constructor
A new instance of HostsListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HostsListResponse
Returns a new instance of HostsListResponse.
24175 24176 24177 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24175 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
24132 24133 24134 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24132 def etag @etag end |
#id ⇒ String
The unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
24137 24138 24139 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24137 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::Host>
A list of host resources.
Corresponds to the JSON property items
24142 24143 24144 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24142 def items @items end |
#kind ⇒ String
The type of resource. Always compute#host for a list of hosts.
Corresponds to the JSON property kind
24147 24148 24149 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24147 def kind @kind end |
#next_page_token ⇒ String
This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
24157 24158 24159 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24157 def next_page_token @next_page_token end |
#self_link ⇒ String
The server-defined URL for this resource.
Corresponds to the JSON property selfLink
24162 24163 24164 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24162 def self_link @self_link end |
#unreachables ⇒ Array<String>
Unreachable resources.
end_interface: MixerListResponseWithEtagBuilder
Corresponds to the JSON property unreachables
24168 24169 24170 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24168 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::HostsListResponse::Warning
An informational warning message.
Corresponds to the JSON property warning
24173 24174 24175 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24173 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
24180 24181 24182 24183 24184 24185 24186 24187 24188 24189 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24180 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |