Class: Google::Apis::ComputeAlpha::HostsListResponse
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::HostsListResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
The unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::Host>
A list of host resources.
-
#kind ⇒ String
The type of resource.
-
#next_page_token ⇒ String
This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
The server-defined URL for this resource.
-
#unreachables ⇒ Array<String>
Unreachable resources.
-
#warning ⇒ Google::Apis::ComputeAlpha::HostsListResponse::Warning
An informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HostsListResponse
constructor
A new instance of HostsListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HostsListResponse
Returns a new instance of HostsListResponse.
23447 23448 23449 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 23447 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
23404 23405 23406 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 23404 def etag @etag end |
#id ⇒ String
The unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
23409 23410 23411 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 23409 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::Host>
A list of host resources.
Corresponds to the JSON property items
23414 23415 23416 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 23414 def items @items end |
#kind ⇒ String
The type of resource. Always compute#host for a list of hosts.
Corresponds to the JSON property kind
23419 23420 23421 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 23419 def kind @kind end |
#next_page_token ⇒ String
This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
23429 23430 23431 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 23429 def next_page_token @next_page_token end |
#self_link ⇒ String
The server-defined URL for this resource.
Corresponds to the JSON property selfLink
23434 23435 23436 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 23434 def self_link @self_link end |
#unreachables ⇒ Array<String>
Unreachable resources.
end_interface: MixerListResponseWithEtagBuilder
Corresponds to the JSON property unreachables
23440 23441 23442 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 23440 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::HostsListResponse::Warning
An informational warning message.
Corresponds to the JSON property warning
23445 23446 23447 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 23445 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
23452 23453 23454 23455 23456 23457 23458 23459 23460 23461 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 23452 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |