Class: Google::Apis::ComputeAlpha::HostsListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HostsListResponse

Returns a new instance of HostsListResponse.



23439
23440
23441
# File 'lib/google/apis/compute_alpha/classes.rb', line 23439

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


23396
23397
23398
# File 'lib/google/apis/compute_alpha/classes.rb', line 23396

def etag
  @etag
end

#idString

The unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


23401
23402
23403
# File 'lib/google/apis/compute_alpha/classes.rb', line 23401

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::Host>

A list of host resources. Corresponds to the JSON property items



23406
23407
23408
# File 'lib/google/apis/compute_alpha/classes.rb', line 23406

def items
  @items
end

#kindString

The type of resource. Always compute#host for a list of hosts. Corresponds to the JSON property kind

Returns:

  • (String)


23411
23412
23413
# File 'lib/google/apis/compute_alpha/classes.rb', line 23411

def kind
  @kind
end

#next_page_tokenString

This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


23421
23422
23423
# File 'lib/google/apis/compute_alpha/classes.rb', line 23421

def next_page_token
  @next_page_token
end

The server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


23426
23427
23428
# File 'lib/google/apis/compute_alpha/classes.rb', line 23426

def self_link
  @self_link
end

#unreachablesArray<String>

Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


23432
23433
23434
# File 'lib/google/apis/compute_alpha/classes.rb', line 23432

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::HostsListResponse::Warning

An informational warning message. Corresponds to the JSON property warning



23437
23438
23439
# File 'lib/google/apis/compute_alpha/classes.rb', line 23437

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



23444
23445
23446
23447
23448
23449
23450
23451
23452
23453
# File 'lib/google/apis/compute_alpha/classes.rb', line 23444

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end