Class: Google::Apis::ComputeAlpha::HostsListResponse
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::HostsListResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
The unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::Host>
A list of host resources.
-
#kind ⇒ String
The type of resource.
-
#next_page_token ⇒ String
This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
The server-defined URL for this resource.
-
#unreachables ⇒ Array<String>
Unreachable resources.
-
#warning ⇒ Google::Apis::ComputeAlpha::HostsListResponse::Warning
An informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HostsListResponse
constructor
A new instance of HostsListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HostsListResponse
Returns a new instance of HostsListResponse.
23439 23440 23441 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 23439 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
23396 23397 23398 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 23396 def etag @etag end |
#id ⇒ String
The unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
23401 23402 23403 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 23401 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::Host>
A list of host resources.
Corresponds to the JSON property items
23406 23407 23408 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 23406 def items @items end |
#kind ⇒ String
The type of resource. Always compute#host for a list of hosts.
Corresponds to the JSON property kind
23411 23412 23413 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 23411 def kind @kind end |
#next_page_token ⇒ String
This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
23421 23422 23423 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 23421 def next_page_token @next_page_token end |
#self_link ⇒ String
The server-defined URL for this resource.
Corresponds to the JSON property selfLink
23426 23427 23428 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 23426 def self_link @self_link end |
#unreachables ⇒ Array<String>
Unreachable resources.
end_interface: MixerListResponseWithEtagBuilder
Corresponds to the JSON property unreachables
23432 23433 23434 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 23432 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::HostsListResponse::Warning
An informational warning message.
Corresponds to the JSON property warning
23437 23438 23439 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 23437 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
23444 23445 23446 23447 23448 23449 23450 23451 23452 23453 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 23444 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |