Class: Google::Apis::ComputeAlpha::HostsListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HostsListResponse

Returns a new instance of HostsListResponse.



23234
23235
23236
# File 'lib/google/apis/compute_alpha/classes.rb', line 23234

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


23191
23192
23193
# File 'lib/google/apis/compute_alpha/classes.rb', line 23191

def etag
  @etag
end

#idString

The unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


23196
23197
23198
# File 'lib/google/apis/compute_alpha/classes.rb', line 23196

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::Host>

A list of host resources. Corresponds to the JSON property items



23201
23202
23203
# File 'lib/google/apis/compute_alpha/classes.rb', line 23201

def items
  @items
end

#kindString

The type of resource. Always compute#host for a list of hosts. Corresponds to the JSON property kind

Returns:

  • (String)


23206
23207
23208
# File 'lib/google/apis/compute_alpha/classes.rb', line 23206

def kind
  @kind
end

#next_page_tokenString

This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


23216
23217
23218
# File 'lib/google/apis/compute_alpha/classes.rb', line 23216

def next_page_token
  @next_page_token
end

The server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


23221
23222
23223
# File 'lib/google/apis/compute_alpha/classes.rb', line 23221

def self_link
  @self_link
end

#unreachablesArray<String>

Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


23227
23228
23229
# File 'lib/google/apis/compute_alpha/classes.rb', line 23227

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::HostsListResponse::Warning

An informational warning message. Corresponds to the JSON property warning



23232
23233
23234
# File 'lib/google/apis/compute_alpha/classes.rb', line 23232

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



23239
23240
23241
23242
23243
23244
23245
23246
23247
23248
# File 'lib/google/apis/compute_alpha/classes.rb', line 23239

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end