Class: Google::Apis::ComputeAlpha::HostsListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HostsListResponse

Returns a new instance of HostsListResponse.



23251
23252
23253
# File 'lib/google/apis/compute_alpha/classes.rb', line 23251

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


23208
23209
23210
# File 'lib/google/apis/compute_alpha/classes.rb', line 23208

def etag
  @etag
end

#idString

The unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


23213
23214
23215
# File 'lib/google/apis/compute_alpha/classes.rb', line 23213

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::Host>

A list of host resources. Corresponds to the JSON property items



23218
23219
23220
# File 'lib/google/apis/compute_alpha/classes.rb', line 23218

def items
  @items
end

#kindString

The type of resource. Always compute#host for a list of hosts. Corresponds to the JSON property kind

Returns:

  • (String)


23223
23224
23225
# File 'lib/google/apis/compute_alpha/classes.rb', line 23223

def kind
  @kind
end

#next_page_tokenString

This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


23233
23234
23235
# File 'lib/google/apis/compute_alpha/classes.rb', line 23233

def next_page_token
  @next_page_token
end

The server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


23238
23239
23240
# File 'lib/google/apis/compute_alpha/classes.rb', line 23238

def self_link
  @self_link
end

#unreachablesArray<String>

Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


23244
23245
23246
# File 'lib/google/apis/compute_alpha/classes.rb', line 23244

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::HostsListResponse::Warning

An informational warning message. Corresponds to the JSON property warning



23249
23250
23251
# File 'lib/google/apis/compute_alpha/classes.rb', line 23249

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



23256
23257
23258
23259
23260
23261
23262
23263
23264
23265
# File 'lib/google/apis/compute_alpha/classes.rb', line 23256

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end