Class: Google::Apis::ComputeAlpha::HttpFaultAbort
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::HttpFaultAbort
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Specification for how requests are aborted as part of fault injection.
Instance Attribute Summary collapse
-
#http_status ⇒ Fixnum
The HTTP status code used to abort the request.
-
#percentage ⇒ Float
The percentage of traffic for connections, operations, or requests that is aborted as part of fault injection.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HttpFaultAbort
constructor
A new instance of HttpFaultAbort.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HttpFaultAbort
Returns a new instance of HttpFaultAbort.
24556 24557 24558 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24556 def initialize(**args) update!(**args) end |
Instance Attribute Details
#http_status ⇒ Fixnum
The HTTP status code used to abort the request.
The value must be from 200 to 599 inclusive.
For gRPC protocol, the gRPC status code is mapped to HTTP status code
according to this
mapping table. HTTP status 200 is mapped to gRPC status
UNKNOWN. Injecting an OK status is currently not supported by
Traffic Director.
Corresponds to the JSON property httpStatus
24547 24548 24549 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24547 def http_status @http_status end |
#percentage ⇒ Float
The percentage of traffic for connections, operations, or requests
that is aborted as part of fault injection.
The value must be from 0.0 to 100.0 inclusive.
Corresponds to the JSON property percentage
24554 24555 24556 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24554 def percentage @percentage end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
24561 24562 24563 24564 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24561 def update!(**args) @http_status = args[:http_status] if args.key?(:http_status) @percentage = args[:percentage] if args.key?(:percentage) end |