Class: Google::Apis::ComputeAlpha::HttpFaultAbort

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Specification for how requests are aborted as part of fault injection.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HttpFaultAbort

Returns a new instance of HttpFaultAbort.



23343
23344
23345
# File 'lib/google/apis/compute_alpha/classes.rb', line 23343

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#http_statusFixnum

The HTTP status code used to abort the request. The value must be from 200 to 599 inclusive. For gRPC protocol, the gRPC status code is mapped to HTTP status code according to this mapping table. HTTP status 200 is mapped to gRPC status UNKNOWN. Injecting an OK status is currently not supported by Traffic Director. Corresponds to the JSON property httpStatus

Returns:

  • (Fixnum)


23334
23335
23336
# File 'lib/google/apis/compute_alpha/classes.rb', line 23334

def http_status
  @http_status
end

#percentageFloat

The percentage of traffic for connections, operations, or requests that is aborted as part of fault injection. The value must be from 0.0 to 100.0 inclusive. Corresponds to the JSON property percentage

Returns:

  • (Float)


23341
23342
23343
# File 'lib/google/apis/compute_alpha/classes.rb', line 23341

def percentage
  @percentage
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



23348
23349
23350
23351
# File 'lib/google/apis/compute_alpha/classes.rb', line 23348

def update!(**args)
  @http_status = args[:http_status] if args.key?(:http_status)
  @percentage = args[:percentage] if args.key?(:percentage)
end