Class: Google::Apis::ComputeAlpha::HttpFaultInjection
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::HttpFaultInjection
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
The specification for fault injection introduced into traffic to test the resiliency of clients to backend service failure. As part of fault injection, when clients send requests to a backend service, delays can be introduced by the load balancer on a percentage of requests before sending those request to the backend service. Similarly requests from clients can be aborted by the load balancer for a percentage of requests.
Instance Attribute Summary collapse
-
#abort ⇒ Google::Apis::ComputeAlpha::HttpFaultAbort
Specification for how requests are aborted as part of fault injection.
-
#delay ⇒ Google::Apis::ComputeAlpha::HttpFaultDelay
Specifies the delay introduced by the load balancer before forwarding the request to the backend service as part of fault injection.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HttpFaultInjection
constructor
A new instance of HttpFaultInjection.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HttpFaultInjection
Returns a new instance of HttpFaultInjection.
23405 23406 23407 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 23405 def initialize(**args) update!(**args) end |
Instance Attribute Details
#abort ⇒ Google::Apis::ComputeAlpha::HttpFaultAbort
Specification for how requests are aborted as part of fault injection.
Corresponds to the JSON property abort
23397 23398 23399 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 23397 def abort @abort end |
#delay ⇒ Google::Apis::ComputeAlpha::HttpFaultDelay
Specifies the delay introduced by the load balancer before forwarding the
request to the backend service as part of fault injection.
Corresponds to the JSON property delay
23403 23404 23405 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 23403 def delay @delay end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
23410 23411 23412 23413 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 23410 def update!(**args) @abort = args[:abort] if args.key?(:abort) @delay = args[:delay] if args.key?(:delay) end |