Class: Google::Apis::ComputeAlpha::HttpFilterConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

HttpFilterConfiguration supplies additional contextual settings for networkservices.HttpFilter resources enabled by Traffic Director.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HttpFilterConfig

Returns a new instance of HttpFilterConfig.



23657
23658
23659
# File 'lib/google/apis/compute_alpha/classes.rb', line 23657

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#configString

The configuration needed to enable thenetworkservices.HttpFilter resource. The configuration must be YAML formatted and only contain fields defined in the protobuf identified in configTypeUrl Corresponds to the JSON property config

Returns:

  • (String)


23641
23642
23643
# File 'lib/google/apis/compute_alpha/classes.rb', line 23641

def config
  @config
end

#config_type_urlString

The fully qualified versioned proto3 type url of the protobuf that the filter expects for its contextual settings, for example:type.googleapis.com/ google.protobuf.Struct Corresponds to the JSON property configTypeUrl

Returns:

  • (String)


23648
23649
23650
# File 'lib/google/apis/compute_alpha/classes.rb', line 23648

def config_type_url
  @config_type_url
end

#filter_nameString

Name of the networkservices.HttpFilter resource this configuration belongs to. This name must be known to the xDS client. Example: envoy.wasm Corresponds to the JSON property filterName

Returns:

  • (String)


23655
23656
23657
# File 'lib/google/apis/compute_alpha/classes.rb', line 23655

def filter_name
  @filter_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



23662
23663
23664
23665
23666
# File 'lib/google/apis/compute_alpha/classes.rb', line 23662

def update!(**args)
  @config = args[:config] if args.key?(:config)
  @config_type_url = args[:config_type_url] if args.key?(:config_type_url)
  @filter_name = args[:filter_name] if args.key?(:filter_name)
end