Class: Google::Apis::ComputeAlpha::HttpFilterConfig
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::HttpFilterConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
HttpFilterConfiguration supplies additional contextual settings for networkservices.HttpFilter resources enabled by Traffic Director.
Instance Attribute Summary collapse
-
#config ⇒ String
The configuration needed to enable thenetworkservices.HttpFilter resource.
-
#config_type_url ⇒ String
The fully qualified versioned proto3 type url of the protobuf that the filter expects for its contextual settings, for example:type.googleapis.com/ google.protobuf.Struct Corresponds to the JSON property
configTypeUrl. -
#filter_name ⇒ String
Name of the networkservices.HttpFilter resource this configuration belongs to.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HttpFilterConfig
constructor
A new instance of HttpFilterConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HttpFilterConfig
Returns a new instance of HttpFilterConfig.
23444 23445 23446 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 23444 def initialize(**args) update!(**args) end |
Instance Attribute Details
#config ⇒ String
The configuration needed to enable thenetworkservices.HttpFilter resource. The
configuration must be
YAML formatted and only contain fields defined in the protobuf identified
in configTypeUrl
Corresponds to the JSON property config
23428 23429 23430 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 23428 def config @config end |
#config_type_url ⇒ String
The fully qualified versioned proto3 type url of the protobuf that the
filter expects for its contextual settings, for example:type.googleapis.com/
google.protobuf.Struct
Corresponds to the JSON property configTypeUrl
23435 23436 23437 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 23435 def config_type_url @config_type_url end |
#filter_name ⇒ String
Name of the networkservices.HttpFilter resource this
configuration belongs to. This name must be known to the xDS client.
Example: envoy.wasm
Corresponds to the JSON property filterName
23442 23443 23444 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 23442 def filter_name @filter_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
23449 23450 23451 23452 23453 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 23449 def update!(**args) @config = args[:config] if args.key?(:config) @config_type_url = args[:config_type_url] if args.key?(:config_type_url) @filter_name = args[:filter_name] if args.key?(:filter_name) end |