Class: Google::Apis::ComputeAlpha::HttpHeaderAction
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::HttpHeaderAction
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
The request and response header transformations that take effect before the request is passed along to the selected backendService.
Instance Attribute Summary collapse
-
#request_headers_to_add ⇒ Array<Google::Apis::ComputeAlpha::HttpHeaderOption>
Headers to add to a matching request before forwarding the request to thebackendService.
-
#request_headers_to_remove ⇒ Array<String>
A list of header names for headers that need to be removed from the request before forwarding the request to the backendService.
-
#response_headers_to_add ⇒ Array<Google::Apis::ComputeAlpha::HttpHeaderOption>
Headers to add the response before sending the response back to the client.
-
#response_headers_to_remove ⇒ Array<String>
A list of header names for headers that need to be removed from the response before sending the response back to the client.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HttpHeaderAction
constructor
A new instance of HttpHeaderAction.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HttpHeaderAction
Returns a new instance of HttpHeaderAction.
24426 24427 24428 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24426 def initialize(**args) update!(**args) end |
Instance Attribute Details
#request_headers_to_add ⇒ Array<Google::Apis::ComputeAlpha::HttpHeaderOption>
Headers to add to a matching request before forwarding the request to
thebackendService.
Corresponds to the JSON property requestHeadersToAdd
24406 24407 24408 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24406 def request_headers_to_add @request_headers_to_add end |
#request_headers_to_remove ⇒ Array<String>
A list of header names for headers that need to be removed from the
request before forwarding the request to the backendService.
Corresponds to the JSON property requestHeadersToRemove
24412 24413 24414 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24412 def request_headers_to_remove @request_headers_to_remove end |
#response_headers_to_add ⇒ Array<Google::Apis::ComputeAlpha::HttpHeaderOption>
Headers to add the response before sending the response back to the
client.
Corresponds to the JSON property responseHeadersToAdd
24418 24419 24420 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24418 def response_headers_to_add @response_headers_to_add end |
#response_headers_to_remove ⇒ Array<String>
A list of header names for headers that need to be removed from the
response before sending the response back to the client.
Corresponds to the JSON property responseHeadersToRemove
24424 24425 24426 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24424 def response_headers_to_remove @response_headers_to_remove end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
24431 24432 24433 24434 24435 24436 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24431 def update!(**args) @request_headers_to_add = args[:request_headers_to_add] if args.key?(:request_headers_to_add) @request_headers_to_remove = args[:request_headers_to_remove] if args.key?(:request_headers_to_remove) @response_headers_to_add = args[:response_headers_to_add] if args.key?(:response_headers_to_add) @response_headers_to_remove = args[:response_headers_to_remove] if args.key?(:response_headers_to_remove) end |