Class: Google::Apis::ComputeAlpha::HttpHeaderAction

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

The request and response header transformations that take effect before the request is passed along to the selected backendService.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HttpHeaderAction

Returns a new instance of HttpHeaderAction.



23485
23486
23487
# File 'lib/google/apis/compute_alpha/classes.rb', line 23485

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#request_headers_to_addArray<Google::Apis::ComputeAlpha::HttpHeaderOption>

Headers to add to a matching request before forwarding the request to thebackendService. Corresponds to the JSON property requestHeadersToAdd



23465
23466
23467
# File 'lib/google/apis/compute_alpha/classes.rb', line 23465

def request_headers_to_add
  @request_headers_to_add
end

#request_headers_to_removeArray<String>

A list of header names for headers that need to be removed from the request before forwarding the request to the backendService. Corresponds to the JSON property requestHeadersToRemove

Returns:

  • (Array<String>)


23471
23472
23473
# File 'lib/google/apis/compute_alpha/classes.rb', line 23471

def request_headers_to_remove
  @request_headers_to_remove
end

#response_headers_to_addArray<Google::Apis::ComputeAlpha::HttpHeaderOption>

Headers to add the response before sending the response back to the client. Corresponds to the JSON property responseHeadersToAdd



23477
23478
23479
# File 'lib/google/apis/compute_alpha/classes.rb', line 23477

def response_headers_to_add
  @response_headers_to_add
end

#response_headers_to_removeArray<String>

A list of header names for headers that need to be removed from the response before sending the response back to the client. Corresponds to the JSON property responseHeadersToRemove

Returns:

  • (Array<String>)


23483
23484
23485
# File 'lib/google/apis/compute_alpha/classes.rb', line 23483

def response_headers_to_remove
  @response_headers_to_remove
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



23490
23491
23492
23493
23494
23495
# File 'lib/google/apis/compute_alpha/classes.rb', line 23490

def update!(**args)
  @request_headers_to_add = args[:request_headers_to_add] if args.key?(:request_headers_to_add)
  @request_headers_to_remove = args[:request_headers_to_remove] if args.key?(:request_headers_to_remove)
  @response_headers_to_add = args[:response_headers_to_add] if args.key?(:response_headers_to_add)
  @response_headers_to_remove = args[:response_headers_to_remove] if args.key?(:response_headers_to_remove)
end