Class: Google::Apis::ComputeAlpha::HttpHeaderMatch
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::HttpHeaderMatch
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
matchRule criteria for request header matches.
Instance Attribute Summary collapse
-
#exact_match ⇒ String
The value should exactly match contents of exactMatch.
-
#header_name ⇒ String
The name of the HTTP header to match.
-
#invert_match ⇒ Boolean
(also: #invert_match?)
If set to false, the headerMatch is considered a match if the preceding match criteria are met.
-
#prefix_match ⇒ String
The value of the header must start with the contents ofprefixMatch.
-
#present_match ⇒ Boolean
(also: #present_match?)
A header with the contents of headerName must exist.
-
#range_match ⇒ Google::Apis::ComputeAlpha::Int64RangeMatch
HttpRouteRuleMatch criteria for field values that must stay within the specified integer range.
-
#regex_match ⇒ String
The value of the header must match the regular expression specified inregexMatch.
-
#suffix_match ⇒ String
The value of the header must end with the contents ofsuffixMatch.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HttpHeaderMatch
constructor
A new instance of HttpHeaderMatch.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HttpHeaderMatch
Returns a new instance of HttpHeaderMatch.
24922 24923 24924 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24922 def initialize(**args) update!(**args) end |
Instance Attribute Details
#exact_match ⇒ String
The value should exactly match contents of exactMatch.
Only one of exactMatch, prefixMatch,suffixMatch, regexMatch,presentMatch or
rangeMatch must be set.
Corresponds to the JSON property exactMatch
24848 24849 24850 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24848 def exact_match @exact_match end |
#header_name ⇒ String
The name of the HTTP header to match.
For matching against the HTTP request's authority, use a headerMatch
with the header name ":authority".
For matching a request's method, use the headerName ":method".
When the URL map is bound to a target gRPC proxy that has
the validateForProxyless field set to true, only
non-binary
user-specified custom metadata and the content-type header are supported.
The following transport-level headers cannot be used in header matching
rules:
:authority, :method, :path, :scheme, user-agent,
accept-encoding, content-encoding, grpc-accept-encoding,
grpc-encoding, grpc-previous-rpc-attempts, grpc-tags-bin,
grpc-timeout and grpc-trace-bin.
Corresponds to the JSON property headerName
24866 24867 24868 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24866 def header_name @header_name end |
#invert_match ⇒ Boolean Also known as: invert_match?
If set to false, the headerMatch is considered a
match if the preceding match criteria are met. If set to true,
the headerMatch is considered a match if the preceding
match criteria are NOT met.
The default setting is false.
Corresponds to the JSON property invertMatch
24875 24876 24877 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24875 def invert_match @invert_match end |
#prefix_match ⇒ String
The value of the header must start with the contents ofprefixMatch.
Only one of exactMatch, prefixMatch,suffixMatch, regexMatch,presentMatch or
rangeMatch must be set.
Corresponds to the JSON property prefixMatch
24883 24884 24885 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24883 def prefix_match @prefix_match end |
#present_match ⇒ Boolean Also known as: present_match?
A header with the contents of headerName must exist. The
match takes place whether or not the request's header has a value.
Only one of exactMatch, prefixMatch,suffixMatch, regexMatch,presentMatch or
rangeMatch must be set.
Corresponds to the JSON property presentMatch
24891 24892 24893 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24891 def present_match @present_match end |
#range_match ⇒ Google::Apis::ComputeAlpha::Int64RangeMatch
HttpRouteRuleMatch criteria for field values that must stay
within the specified integer range.
Corresponds to the JSON property rangeMatch
24898 24899 24900 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24898 def range_match @range_match end |
#regex_match ⇒ String
The value of the header must match the regular expression specified
inregexMatch.
For more information about regular expression syntax, see Syntax.
For matching against a port specified in the HTTP request, use a
headerMatch with headerName set to PORT and a regular expression that
satisfies the RFC2616 Host header's port specifier.
Only one of exactMatch, prefixMatch,suffixMatch, regexMatch,presentMatch or
rangeMatch must be set.
Regular expressions can only be used when the loadBalancingScheme is
set to INTERNAL_SELF_MANAGED, EXTERNAL_MANAGED
(regional scope) or INTERNAL_MANAGED.
Corresponds to the JSON property regexMatch
24913 24914 24915 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24913 def regex_match @regex_match end |
#suffix_match ⇒ String
The value of the header must end with the contents ofsuffixMatch.
Only one of exactMatch, prefixMatch,suffixMatch, regexMatch,presentMatch or
rangeMatch must be set.
Corresponds to the JSON property suffixMatch
24920 24921 24922 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24920 def suffix_match @suffix_match end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
24927 24928 24929 24930 24931 24932 24933 24934 24935 24936 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24927 def update!(**args) @exact_match = args[:exact_match] if args.key?(:exact_match) @header_name = args[:header_name] if args.key?(:header_name) @invert_match = args[:invert_match] if args.key?(:invert_match) @prefix_match = args[:prefix_match] if args.key?(:prefix_match) @present_match = args[:present_match] if args.key?(:present_match) @range_match = args[:range_match] if args.key?(:range_match) @regex_match = args[:regex_match] if args.key?(:regex_match) @suffix_match = args[:suffix_match] if args.key?(:suffix_match) end |