Class: Google::Apis::ComputeAlpha::HttpHeaderMatch

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

matchRule criteria for request header matches.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HttpHeaderMatch

Returns a new instance of HttpHeaderMatch.



23786
23787
23788
# File 'lib/google/apis/compute_alpha/classes.rb', line 23786

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#exact_matchString

The value should exactly match contents of exactMatch. Only one of exactMatch, prefixMatch,suffixMatch, regexMatch,presentMatch or rangeMatch must be set. Corresponds to the JSON property exactMatch

Returns:

  • (String)


23712
23713
23714
# File 'lib/google/apis/compute_alpha/classes.rb', line 23712

def exact_match
  @exact_match
end

#header_nameString

The name of the HTTP header to match. For matching against the HTTP request's authority, use a headerMatch with the header name ":authority". For matching a request's method, use the headerName ":method". When the URL map is bound to a target gRPC proxy that has the validateForProxyless field set to true, only non-binary user-specified custom metadata and the content-type header are supported. The following transport-level headers cannot be used in header matching rules: :authority, :method, :path, :scheme, user-agent, accept-encoding, content-encoding, grpc-accept-encoding, grpc-encoding, grpc-previous-rpc-attempts, grpc-tags-bin, grpc-timeout and grpc-trace-bin. Corresponds to the JSON property headerName

Returns:

  • (String)


23730
23731
23732
# File 'lib/google/apis/compute_alpha/classes.rb', line 23730

def header_name
  @header_name
end

#invert_matchBoolean Also known as: invert_match?

If set to false, the headerMatch is considered a match if the preceding match criteria are met. If set to true, the headerMatch is considered a match if the preceding match criteria are NOT met. The default setting is false. Corresponds to the JSON property invertMatch

Returns:

  • (Boolean)


23739
23740
23741
# File 'lib/google/apis/compute_alpha/classes.rb', line 23739

def invert_match
  @invert_match
end

#prefix_matchString

The value of the header must start with the contents ofprefixMatch. Only one of exactMatch, prefixMatch,suffixMatch, regexMatch,presentMatch or rangeMatch must be set. Corresponds to the JSON property prefixMatch

Returns:

  • (String)


23747
23748
23749
# File 'lib/google/apis/compute_alpha/classes.rb', line 23747

def prefix_match
  @prefix_match
end

#present_matchBoolean Also known as: present_match?

A header with the contents of headerName must exist. The match takes place whether or not the request's header has a value. Only one of exactMatch, prefixMatch,suffixMatch, regexMatch,presentMatch or rangeMatch must be set. Corresponds to the JSON property presentMatch

Returns:

  • (Boolean)


23755
23756
23757
# File 'lib/google/apis/compute_alpha/classes.rb', line 23755

def present_match
  @present_match
end

#range_matchGoogle::Apis::ComputeAlpha::Int64RangeMatch

HttpRouteRuleMatch criteria for field values that must stay within the specified integer range. Corresponds to the JSON property rangeMatch



23762
23763
23764
# File 'lib/google/apis/compute_alpha/classes.rb', line 23762

def range_match
  @range_match
end

#regex_matchString

The value of the header must match the regular expression specified inregexMatch. For more information about regular expression syntax, see Syntax. For matching against a port specified in the HTTP request, use a headerMatch with headerName set to PORT and a regular expression that satisfies the RFC2616 Host header's port specifier. Only one of exactMatch, prefixMatch,suffixMatch, regexMatch,presentMatch or rangeMatch must be set. Regular expressions can only be used when the loadBalancingScheme is set to INTERNAL_SELF_MANAGED, EXTERNAL_MANAGED (regional scope) or INTERNAL_MANAGED. Corresponds to the JSON property regexMatch

Returns:

  • (String)


23777
23778
23779
# File 'lib/google/apis/compute_alpha/classes.rb', line 23777

def regex_match
  @regex_match
end

#suffix_matchString

The value of the header must end with the contents ofsuffixMatch. Only one of exactMatch, prefixMatch,suffixMatch, regexMatch,presentMatch or rangeMatch must be set. Corresponds to the JSON property suffixMatch

Returns:

  • (String)


23784
23785
23786
# File 'lib/google/apis/compute_alpha/classes.rb', line 23784

def suffix_match
  @suffix_match
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



23791
23792
23793
23794
23795
23796
23797
23798
23799
23800
# File 'lib/google/apis/compute_alpha/classes.rb', line 23791

def update!(**args)
  @exact_match = args[:exact_match] if args.key?(:exact_match)
  @header_name = args[:header_name] if args.key?(:header_name)
  @invert_match = args[:invert_match] if args.key?(:invert_match)
  @prefix_match = args[:prefix_match] if args.key?(:prefix_match)
  @present_match = args[:present_match] if args.key?(:present_match)
  @range_match = args[:range_match] if args.key?(:range_match)
  @regex_match = args[:regex_match] if args.key?(:regex_match)
  @suffix_match = args[:suffix_match] if args.key?(:suffix_match)
end