Class: Google::Apis::ComputeAlpha::HttpHeaderOption

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Specification determining how headers are added to requests or responses.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HttpHeaderOption

Returns a new instance of HttpHeaderOption.



24566
24567
24568
# File 'lib/google/apis/compute_alpha/classes.rb', line 24566

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#header_nameString

The name of the header. Corresponds to the JSON property headerName

Returns:

  • (String)


24546
24547
24548
# File 'lib/google/apis/compute_alpha/classes.rb', line 24546

def header_name
  @header_name
end

#header_valueString

The value of the header to add. Corresponds to the JSON property headerValue

Returns:

  • (String)


24551
24552
24553
# File 'lib/google/apis/compute_alpha/classes.rb', line 24551

def header_value
  @header_value
end

#replaceBoolean Also known as: replace?

If false, headerValue is appended to any values that already exist for the header. If true, headerValue is set for the header, discarding any values that were set for that header. The default value is true, unless a variable is present in headerValue, in which case the default value is false. . Corresponds to the JSON property replace

Returns:

  • (Boolean)


24563
24564
24565
# File 'lib/google/apis/compute_alpha/classes.rb', line 24563

def replace
  @replace
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



24571
24572
24573
24574
24575
# File 'lib/google/apis/compute_alpha/classes.rb', line 24571

def update!(**args)
  @header_name = args[:header_name] if args.key?(:header_name)
  @header_value = args[:header_value] if args.key?(:header_value)
  @replace = args[:replace] if args.key?(:replace)
end