Class: Google::Apis::ComputeAlpha::HttpHeaderOption
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::HttpHeaderOption
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Specification determining how headers are added to requests or responses.
Instance Attribute Summary collapse
-
#header_name ⇒ String
The name of the header.
-
#header_value ⇒ String
The value of the header to add.
-
#replace ⇒ Boolean
(also: #replace?)
If false, headerValue is appended to any values that already exist for the header.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HttpHeaderOption
constructor
A new instance of HttpHeaderOption.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HttpHeaderOption
Returns a new instance of HttpHeaderOption.
23651 23652 23653 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 23651 def initialize(**args) update!(**args) end |
Instance Attribute Details
#header_name ⇒ String
The name of the header.
Corresponds to the JSON property headerName
23631 23632 23633 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 23631 def header_name @header_name end |
#header_value ⇒ String
The value of the header to add.
Corresponds to the JSON property headerValue
23636 23637 23638 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 23636 def header_value @header_value end |
#replace ⇒ Boolean Also known as: replace?
If false, headerValue is appended to any values
that already
exist for the header. If true, headerValue is set for the
header, discarding any values that were set for that header.
The default value is true,
unless a variable is present in headerValue,
in which case the default value is false.
.
Corresponds to the JSON property replace
23648 23649 23650 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 23648 def replace @replace end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
23656 23657 23658 23659 23660 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 23656 def update!(**args) @header_name = args[:header_name] if args.key?(:header_name) @header_value = args[:header_value] if args.key?(:header_value) @replace = args[:replace] if args.key?(:replace) end |