Class: Google::Apis::ComputeAlpha::HttpHealthCheckList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::HttpHealthCheckList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Contains a list of HttpHealthCheck resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::HttpHealthCheck>
A list of HttpHealthCheck resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::HttpHealthCheckList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HttpHealthCheckList
constructor
A new instance of HttpHealthCheckList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HttpHealthCheckList
Returns a new instance of HttpHealthCheckList.
24011 24012 24013 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24011 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
23979 23980 23981 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 23979 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::HttpHealthCheck>
A list of HttpHealthCheck resources.
Corresponds to the JSON property items
23984 23985 23986 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 23984 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
23989 23990 23991 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 23989 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
23999 24000 24001 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 23999 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
24004 24005 24006 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24004 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::HttpHealthCheckList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
24009 24010 24011 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24009 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
24016 24017 24018 24019 24020 24021 24022 24023 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24016 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |