Class: Google::Apis::ComputeAlpha::HttpHealthCheckList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of HttpHealthCheck resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HttpHealthCheckList

Returns a new instance of HttpHealthCheckList.



24003
24004
24005
# File 'lib/google/apis/compute_alpha/classes.rb', line 24003

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


23971
23972
23973
# File 'lib/google/apis/compute_alpha/classes.rb', line 23971

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::HttpHealthCheck>

A list of HttpHealthCheck resources. Corresponds to the JSON property items



23976
23977
23978
# File 'lib/google/apis/compute_alpha/classes.rb', line 23976

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


23981
23982
23983
# File 'lib/google/apis/compute_alpha/classes.rb', line 23981

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


23991
23992
23993
# File 'lib/google/apis/compute_alpha/classes.rb', line 23991

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


23996
23997
23998
# File 'lib/google/apis/compute_alpha/classes.rb', line 23996

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::HttpHealthCheckList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



24001
24002
24003
# File 'lib/google/apis/compute_alpha/classes.rb', line 24001

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



24008
24009
24010
24011
24012
24013
24014
24015
# File 'lib/google/apis/compute_alpha/classes.rb', line 24008

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end