Class: Google::Apis::ComputeAlpha::HttpHealthCheckList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of HttpHealthCheck resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HttpHealthCheckList

Returns a new instance of HttpHealthCheckList.



23156
23157
23158
# File 'lib/google/apis/compute_alpha/classes.rb', line 23156

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


23124
23125
23126
# File 'lib/google/apis/compute_alpha/classes.rb', line 23124

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::HttpHealthCheck>

A list of HttpHealthCheck resources. Corresponds to the JSON property items



23129
23130
23131
# File 'lib/google/apis/compute_alpha/classes.rb', line 23129

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


23134
23135
23136
# File 'lib/google/apis/compute_alpha/classes.rb', line 23134

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


23144
23145
23146
# File 'lib/google/apis/compute_alpha/classes.rb', line 23144

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


23149
23150
23151
# File 'lib/google/apis/compute_alpha/classes.rb', line 23149

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::HttpHealthCheckList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



23154
23155
23156
# File 'lib/google/apis/compute_alpha/classes.rb', line 23154

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



23161
23162
23163
23164
23165
23166
23167
23168
# File 'lib/google/apis/compute_alpha/classes.rb', line 23161

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end