Class: Google::Apis::ComputeAlpha::HttpQueryParameterMatch
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::HttpQueryParameterMatch
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
HttpRouteRuleMatch criteria for a request's query parameter.
Instance Attribute Summary collapse
-
#exact_match ⇒ String
The queryParameterMatch matches if the value of the parameter exactly matches the contents of exactMatch.
-
#name ⇒ String
The name of the query parameter to match.
-
#present_match ⇒ Boolean
(also: #present_match?)
Specifies that the queryParameterMatch matches if the request contains the query parameter, irrespective of whether the parameter has a value or not.
-
#regex_match ⇒ String
The queryParameterMatch matches if the value of the parameter matches the regular expression specified byregexMatch.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HttpQueryParameterMatch
constructor
A new instance of HttpQueryParameterMatch.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HttpQueryParameterMatch
Returns a new instance of HttpQueryParameterMatch.
25261 25262 25263 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 25261 def initialize(**args) update!(**args) end |
Instance Attribute Details
#exact_match ⇒ String
The queryParameterMatch matches if the value of the
parameter exactly matches the contents of exactMatch.
Only one of presentMatch, exactMatch, orregexMatch must be set.
Corresponds to the JSON property exactMatch
25233 25234 25235 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 25233 def exact_match @exact_match end |
#name ⇒ String
The name of the query parameter to match. The query parameter must exist in
the request, in the absence of which the request match fails.
Corresponds to the JSON property name
25239 25240 25241 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 25239 def name @name end |
#present_match ⇒ Boolean Also known as: present_match?
Specifies that the queryParameterMatch matches if the
request contains the query parameter, irrespective of whether the
parameter has a value or not.
Only one of presentMatch, exactMatch, orregexMatch must be set.
Corresponds to the JSON property presentMatch
25247 25248 25249 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 25247 def present_match @present_match end |
#regex_match ⇒ String
The queryParameterMatch matches if the value of the
parameter matches the regular expression specified byregexMatch. For
more information about regular expression syntax, see Syntax.
Only one of presentMatch, exactMatch, orregexMatch must be set.
Regular expressions can only be used when the loadBalancingScheme is
set to INTERNAL_SELF_MANAGED, EXTERNAL_MANAGED
(regional scope) or INTERNAL_MANAGED.
Corresponds to the JSON property regexMatch
25259 25260 25261 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 25259 def regex_match @regex_match end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
25266 25267 25268 25269 25270 25271 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 25266 def update!(**args) @exact_match = args[:exact_match] if args.key?(:exact_match) @name = args[:name] if args.key?(:name) @present_match = args[:present_match] if args.key?(:present_match) @regex_match = args[:regex_match] if args.key?(:regex_match) end |