Class: Google::Apis::ComputeAlpha::HttpQueryParameterMatch

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

HttpRouteRuleMatch criteria for a request's query parameter.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HttpQueryParameterMatch

Returns a new instance of HttpQueryParameterMatch.



23278
23279
23280
# File 'lib/google/apis/compute_alpha/classes.rb', line 23278

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#exact_matchString

The queryParameterMatch matches if the value of the parameter exactly matches the contents of exactMatch. Only one of presentMatch, exactMatch, orregexMatch must be set. Corresponds to the JSON property exactMatch

Returns:

  • (String)


23250
23251
23252
# File 'lib/google/apis/compute_alpha/classes.rb', line 23250

def exact_match
  @exact_match
end

#nameString

The name of the query parameter to match. The query parameter must exist in the request, in the absence of which the request match fails. Corresponds to the JSON property name

Returns:

  • (String)


23256
23257
23258
# File 'lib/google/apis/compute_alpha/classes.rb', line 23256

def name
  @name
end

#present_matchBoolean Also known as: present_match?

Specifies that the queryParameterMatch matches if the request contains the query parameter, irrespective of whether the parameter has a value or not. Only one of presentMatch, exactMatch, orregexMatch must be set. Corresponds to the JSON property presentMatch

Returns:

  • (Boolean)


23264
23265
23266
# File 'lib/google/apis/compute_alpha/classes.rb', line 23264

def present_match
  @present_match
end

#regex_matchString

The queryParameterMatch matches if the value of the parameter matches the regular expression specified byregexMatch. For more information about regular expression syntax, see Syntax. Only one of presentMatch, exactMatch, orregexMatch must be set. Regular expressions can only be used when the loadBalancingScheme is set to INTERNAL_SELF_MANAGED, EXTERNAL_MANAGED (regional scope) or INTERNAL_MANAGED. Corresponds to the JSON property regexMatch

Returns:

  • (String)


23276
23277
23278
# File 'lib/google/apis/compute_alpha/classes.rb', line 23276

def regex_match
  @regex_match
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



23283
23284
23285
23286
23287
23288
# File 'lib/google/apis/compute_alpha/classes.rb', line 23283

def update!(**args)
  @exact_match = args[:exact_match] if args.key?(:exact_match)
  @name = args[:name] if args.key?(:name)
  @present_match = args[:present_match] if args.key?(:present_match)
  @regex_match = args[:regex_match] if args.key?(:regex_match)
end