Class: Google::Apis::ComputeAlpha::HttpRedirectAction
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::HttpRedirectAction
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Specifies settings for an HTTP redirect.
Instance Attribute Summary collapse
-
#host_redirect ⇒ String
The host that is used in the redirect response instead of the one that was supplied in the request.
-
#https_redirect ⇒ Boolean
(also: #https_redirect?)
If set to true, the URL scheme in the redirected request is set to HTTPS.
-
#path_redirect ⇒ String
The path that is used in the redirect response instead of the one that was supplied in the request.
-
#prefix_redirect ⇒ String
The prefix that replaces the prefixMatch specified in the HttpRouteRuleMatch, retaining the remaining portion of the URL before redirecting the request.
-
#redirect_response_code ⇒ String
The HTTP Status code to use for this RedirectAction.
-
#strip_query ⇒ Boolean
(also: #strip_query?)
If set to true, any accompanying query portion of the original URL is removed before redirecting the request.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HttpRedirectAction
constructor
A new instance of HttpRedirectAction.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HttpRedirectAction
Returns a new instance of HttpRedirectAction.
24003 24004 24005 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24003 def initialize(**args) update!(**args) end |
Instance Attribute Details
#host_redirect ⇒ String
The host that is used in the redirect response instead of the one that
was supplied in the request.
The value must be from 1 to 255
characters.
Corresponds to the JSON property hostRedirect
23943 23944 23945 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 23943 def host_redirect @host_redirect end |
#https_redirect ⇒ Boolean Also known as: https_redirect?
If set to true, the URL scheme in the redirected request is
set to HTTPS.
If set to false, the URL scheme of the redirected request
remains the same as that of the request.
This must only be set for URL maps used inTargetHttpProxys. Setting this true
forTargetHttpsProxy is not permitted.
The default is set to false.
Corresponds to the JSON property httpsRedirect
23954 23955 23956 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 23954 def https_redirect @https_redirect end |
#path_redirect ⇒ String
The path that is used in the redirect response instead of the one
that was supplied in the request.
pathRedirect cannot be supplied together withprefixRedirect. Supply one alone
or neither. If neither is
supplied, the path of the original request is used for the redirect.
The value must be from 1 to 1024 characters.
Corresponds to the JSON property pathRedirect
23965 23966 23967 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 23965 def path_redirect @path_redirect end |
#prefix_redirect ⇒ String
The prefix that replaces the prefixMatch specified in
the HttpRouteRuleMatch, retaining the remaining portion
of the URL before redirecting the request.
prefixRedirect cannot be supplied together withpathRedirect. Supply one alone
or neither. If neither is
supplied, the path of the original request is used for the redirect.
The value must be from 1 to 1024 characters.
Corresponds to the JSON property prefixRedirect
23976 23977 23978 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 23976 def prefix_redirect @prefix_redirect end |
#redirect_response_code ⇒ String
The HTTP Status code to use for this RedirectAction. Supported values are:
- MOVED_PERMANENTLY_DEFAULT, which is the default value and corresponds to 301.
- FOUND, which corresponds to 302.
- SEE_OTHER which corresponds to 303.
- TEMPORARY_REDIRECT, which corresponds to 307. In this case, the request method is retained.
- PERMANENT_REDIRECT, which corresponds to 308. In this case, the request
method is retained.
Corresponds to the JSON property
redirectResponseCode
23991 23992 23993 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 23991 def redirect_response_code @redirect_response_code end |
#strip_query ⇒ Boolean Also known as: strip_query?
If set to true, any accompanying query portion of the original
URL is
removed before redirecting the request. If set to false, the
query portion of the original URL is retained.
The default is set to false.
Corresponds to the JSON property stripQuery
24000 24001 24002 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24000 def strip_query @strip_query end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
24008 24009 24010 24011 24012 24013 24014 24015 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24008 def update!(**args) @host_redirect = args[:host_redirect] if args.key?(:host_redirect) @https_redirect = args[:https_redirect] if args.key?(:https_redirect) @path_redirect = args[:path_redirect] if args.key?(:path_redirect) @prefix_redirect = args[:prefix_redirect] if args.key?(:prefix_redirect) @redirect_response_code = args[:redirect_response_code] if args.key?(:redirect_response_code) @strip_query = args[:strip_query] if args.key?(:strip_query) end |