Class: Google::Apis::ComputeAlpha::HttpRedirectAction
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::HttpRedirectAction
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Specifies settings for an HTTP redirect.
Instance Attribute Summary collapse
-
#host_redirect ⇒ String
The host that is used in the redirect response instead of the one that was supplied in the request.
-
#https_redirect ⇒ Boolean
(also: #https_redirect?)
If set to true, the URL scheme in the redirected request is set to HTTPS.
-
#path_redirect ⇒ String
The path that is used in the redirect response instead of the one that was supplied in the request.
-
#prefix_redirect ⇒ String
The prefix that replaces the prefixMatch specified in the HttpRouteRuleMatch, retaining the remaining portion of the URL before redirecting the request.
-
#redirect_response_code ⇒ String
The HTTP Status code to use for this RedirectAction.
-
#strip_query ⇒ Boolean
(also: #strip_query?)
If set to true, any accompanying query portion of the original URL is removed before redirecting the request.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HttpRedirectAction
constructor
A new instance of HttpRedirectAction.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HttpRedirectAction
Returns a new instance of HttpRedirectAction.
23361 23362 23363 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 23361 def initialize(**args) update!(**args) end |
Instance Attribute Details
#host_redirect ⇒ String
The host that is used in the redirect response instead of the one that
was supplied in the request.
The value must be from 1 to 255
characters.
Corresponds to the JSON property hostRedirect
23301 23302 23303 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 23301 def host_redirect @host_redirect end |
#https_redirect ⇒ Boolean Also known as: https_redirect?
If set to true, the URL scheme in the redirected request is
set to HTTPS.
If set to false, the URL scheme of the redirected request
remains the same as that of the request.
This must only be set for URL maps used inTargetHttpProxys. Setting this true
forTargetHttpsProxy is not permitted.
The default is set to false.
Corresponds to the JSON property httpsRedirect
23312 23313 23314 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 23312 def https_redirect @https_redirect end |
#path_redirect ⇒ String
The path that is used in the redirect response instead of the one
that was supplied in the request.
pathRedirect cannot be supplied together withprefixRedirect. Supply one alone
or neither. If neither is
supplied, the path of the original request is used for the redirect.
The value must be from 1 to 1024 characters.
Corresponds to the JSON property pathRedirect
23323 23324 23325 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 23323 def path_redirect @path_redirect end |
#prefix_redirect ⇒ String
The prefix that replaces the prefixMatch specified in
the HttpRouteRuleMatch, retaining the remaining portion
of the URL before redirecting the request.
prefixRedirect cannot be supplied together withpathRedirect. Supply one alone
or neither. If neither is
supplied, the path of the original request is used for the redirect.
The value must be from 1 to 1024 characters.
Corresponds to the JSON property prefixRedirect
23334 23335 23336 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 23334 def prefix_redirect @prefix_redirect end |
#redirect_response_code ⇒ String
The HTTP Status code to use for this RedirectAction. Supported values are:
- MOVED_PERMANENTLY_DEFAULT, which is the default value and corresponds to 301.
- FOUND, which corresponds to 302.
- SEE_OTHER which corresponds to 303.
- TEMPORARY_REDIRECT, which corresponds to 307. In this case, the request method is retained.
- PERMANENT_REDIRECT, which corresponds to 308. In this case, the request
method is retained.
Corresponds to the JSON property
redirectResponseCode
23349 23350 23351 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 23349 def redirect_response_code @redirect_response_code end |
#strip_query ⇒ Boolean Also known as: strip_query?
If set to true, any accompanying query portion of the original
URL is
removed before redirecting the request. If set to false, the
query portion of the original URL is retained.
The default is set to false.
Corresponds to the JSON property stripQuery
23358 23359 23360 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 23358 def strip_query @strip_query end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
23366 23367 23368 23369 23370 23371 23372 23373 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 23366 def update!(**args) @host_redirect = args[:host_redirect] if args.key?(:host_redirect) @https_redirect = args[:https_redirect] if args.key?(:https_redirect) @path_redirect = args[:path_redirect] if args.key?(:path_redirect) @prefix_redirect = args[:prefix_redirect] if args.key?(:prefix_redirect) @redirect_response_code = args[:redirect_response_code] if args.key?(:redirect_response_code) @strip_query = args[:strip_query] if args.key?(:strip_query) end |