Class: Google::Apis::ComputeAlpha::HttpRouteAction
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::HttpRouteAction
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#cache_policy ⇒ Google::Apis::ComputeAlpha::CachePolicy
Message containing CachePolicy configuration for URL Map's Route Action.
-
#cors_policy ⇒ Google::Apis::ComputeAlpha::CorsPolicy
The specification for allowing client-side cross-origin requests.
-
#fault_injection_policy ⇒ Google::Apis::ComputeAlpha::HttpFaultInjection
The specification for fault injection introduced into traffic to test the resiliency of clients to backend service failure.
-
#image_optimization_policy ⇒ Google::Apis::ComputeAlpha::ImageOptimizationPolicy
The configuration for Cloud CDN's image optimization feature.
-
#max_stream_duration ⇒ Google::Apis::ComputeAlpha::Duration
A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution.
-
#request_mirror_policy ⇒ Google::Apis::ComputeAlpha::RequestMirrorPolicy
A policy that specifies how requests intended for the route's backends are shadowed to a separate mirrored backend service.
-
#retry_policy ⇒ Google::Apis::ComputeAlpha::HttpRetryPolicy
The retry policy associates with HttpRouteRule Corresponds to the JSON property
retryPolicy. -
#timeout ⇒ Google::Apis::ComputeAlpha::Duration
A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution.
-
#url_rewrite ⇒ Google::Apis::ComputeAlpha::UrlRewrite
The spec for modifying the path before sending the request to the matched backend service.
-
#weighted_backend_services ⇒ Array<Google::Apis::ComputeAlpha::WeightedBackendService>
A list of weighted backend services to send traffic to when a route match occurs.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HttpRouteAction
constructor
A new instance of HttpRouteAction.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HttpRouteAction
Returns a new instance of HttpRouteAction.
25515 25516 25517 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 25515 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cache_policy ⇒ Google::Apis::ComputeAlpha::CachePolicy
Message containing CachePolicy configuration for URL Map's Route Action.
Corresponds to the JSON property cachePolicy
25436 25437 25438 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 25436 def cache_policy @cache_policy end |
#cors_policy ⇒ Google::Apis::ComputeAlpha::CorsPolicy
The specification for allowing client-side cross-origin requests. For more
information about the W3C recommendation for cross-origin resource sharing
(CORS), see Fetch API Living
Standard.
Corresponds to the JSON property corsPolicy
25444 25445 25446 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 25444 def cors_policy @cors_policy end |
#fault_injection_policy ⇒ Google::Apis::ComputeAlpha::HttpFaultInjection
The specification for fault injection introduced into traffic to test
the resiliency of clients to backend service failure. As part of fault
injection, when clients send requests to a backend service, delays can be
introduced by the load balancer on a percentage of requests before sending
those request to the backend service. Similarly requests from clients can be
aborted by the load balancer for a percentage of requests.
Corresponds to the JSON property faultInjectionPolicy
25454 25455 25456 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 25454 def fault_injection_policy @fault_injection_policy end |
#image_optimization_policy ⇒ Google::Apis::ComputeAlpha::ImageOptimizationPolicy
The configuration for Cloud CDN's image optimization feature. This feature
dynamically processes and delivers images from the network edge.
Image Optimization is only available for Global External Application Load
Balancers.
Either Cloud CDN must be enabled on the backend service or backend bucket
serving the route, or cache policy must be configured on the same route.
Corresponds to the JSON property imageOptimizationPolicy
25464 25465 25466 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 25464 def image_optimization_policy @image_optimization_policy end |
#max_stream_duration ⇒ Google::Apis::ComputeAlpha::Duration
A Duration represents a fixed-length span of time represented
as a count of seconds and fractions of seconds at nanosecond
resolution. It is independent of any calendar and concepts like "day"
or "month". Range is approximately 10,000 years.
Corresponds to the JSON property maxStreamDuration
25472 25473 25474 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 25472 def max_stream_duration @max_stream_duration end |
#request_mirror_policy ⇒ Google::Apis::ComputeAlpha::RequestMirrorPolicy
A policy that specifies how requests intended for the route's backends
are shadowed to a separate mirrored backend service. The load balancer
doesn't wait for responses from the shadow service. Before sending traffic
to the shadow service, the host or authority header is suffixed with-shadow.
Corresponds to the JSON property requestMirrorPolicy
25480 25481 25482 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 25480 def request_mirror_policy @request_mirror_policy end |
#retry_policy ⇒ Google::Apis::ComputeAlpha::HttpRetryPolicy
The retry policy associates with HttpRouteRule
Corresponds to the JSON property retryPolicy
25485 25486 25487 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 25485 def retry_policy @retry_policy end |
#timeout ⇒ Google::Apis::ComputeAlpha::Duration
A Duration represents a fixed-length span of time represented
as a count of seconds and fractions of seconds at nanosecond
resolution. It is independent of any calendar and concepts like "day"
or "month". Range is approximately 10,000 years.
Corresponds to the JSON property timeout
25493 25494 25495 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 25493 def timeout @timeout end |
#url_rewrite ⇒ Google::Apis::ComputeAlpha::UrlRewrite
The spec for modifying the path before sending the request to the matched
backend service.
Corresponds to the JSON property urlRewrite
25499 25500 25501 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 25499 def url_rewrite @url_rewrite end |
#weighted_backend_services ⇒ Array<Google::Apis::ComputeAlpha::WeightedBackendService>
A list of weighted backend services to send traffic to when a route match
occurs. The weights determine the fraction of traffic that flows to
their corresponding backend service. If all traffic needs to
go to a single backend service, there must be oneweightedBackendService with
weight set to a non-zero number.
After a backend service is identified and before forwarding
the request to
the backend service, advanced routing actions such as URL rewrites and
header transformations are applied depending on additional settings
specified in this HttpRouteAction.
Corresponds to the JSON property weightedBackendServices
25513 25514 25515 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 25513 def weighted_backend_services @weighted_backend_services end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
25520 25521 25522 25523 25524 25525 25526 25527 25528 25529 25530 25531 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 25520 def update!(**args) @cache_policy = args[:cache_policy] if args.key?(:cache_policy) @cors_policy = args[:cors_policy] if args.key?(:cors_policy) @fault_injection_policy = args[:fault_injection_policy] if args.key?(:fault_injection_policy) @image_optimization_policy = args[:image_optimization_policy] if args.key?(:image_optimization_policy) @max_stream_duration = args[:max_stream_duration] if args.key?(:max_stream_duration) @request_mirror_policy = args[:request_mirror_policy] if args.key?(:request_mirror_policy) @retry_policy = args[:retry_policy] if args.key?(:retry_policy) @timeout = args[:timeout] if args.key?(:timeout) @url_rewrite = args[:url_rewrite] if args.key?(:url_rewrite) @weighted_backend_services = args[:weighted_backend_services] if args.key?(:weighted_backend_services) end |