Class: Google::Apis::ComputeAlpha::HttpRouteAction
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::HttpRouteAction
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#cache_policy ⇒ Google::Apis::ComputeAlpha::CachePolicy
Message containing CachePolicy configuration for URL Map's Route Action.
-
#cors_policy ⇒ Google::Apis::ComputeAlpha::CorsPolicy
The specification for allowing client-side cross-origin requests.
-
#fault_injection_policy ⇒ Google::Apis::ComputeAlpha::HttpFaultInjection
The specification for fault injection introduced into traffic to test the resiliency of clients to backend service failure.
-
#image_optimization_policy ⇒ Google::Apis::ComputeAlpha::ImageOptimizationPolicy
The configuration for Cloud CDN's image optimization feature.
-
#max_stream_duration ⇒ Google::Apis::ComputeAlpha::Duration
A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution.
-
#request_mirror_policy ⇒ Google::Apis::ComputeAlpha::RequestMirrorPolicy
A policy that specifies how requests intended for the route's backends are shadowed to a separate mirrored backend service.
-
#retry_policy ⇒ Google::Apis::ComputeAlpha::HttpRetryPolicy
The retry policy associates with HttpRouteRule Corresponds to the JSON property
retryPolicy. -
#timeout ⇒ Google::Apis::ComputeAlpha::Duration
A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution.
-
#url_rewrite ⇒ Google::Apis::ComputeAlpha::UrlRewrite
The spec for modifying the path before sending the request to the matched backend service.
-
#weighted_backend_services ⇒ Array<Google::Apis::ComputeAlpha::WeightedBackendService>
A list of weighted backend services to send traffic to when a route match occurs.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HttpRouteAction
constructor
A new instance of HttpRouteAction.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HttpRouteAction
Returns a new instance of HttpRouteAction.
24191 24192 24193 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24191 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cache_policy ⇒ Google::Apis::ComputeAlpha::CachePolicy
Message containing CachePolicy configuration for URL Map's Route Action.
Corresponds to the JSON property cachePolicy
24112 24113 24114 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24112 def cache_policy @cache_policy end |
#cors_policy ⇒ Google::Apis::ComputeAlpha::CorsPolicy
The specification for allowing client-side cross-origin requests. For more
information about the W3C recommendation for cross-origin resource sharing
(CORS), see Fetch API Living
Standard.
Corresponds to the JSON property corsPolicy
24120 24121 24122 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24120 def cors_policy @cors_policy end |
#fault_injection_policy ⇒ Google::Apis::ComputeAlpha::HttpFaultInjection
The specification for fault injection introduced into traffic to test
the resiliency of clients to backend service failure. As part of fault
injection, when clients send requests to a backend service, delays can be
introduced by the load balancer on a percentage of requests before sending
those request to the backend service. Similarly requests from clients can be
aborted by the load balancer for a percentage of requests.
Corresponds to the JSON property faultInjectionPolicy
24130 24131 24132 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24130 def fault_injection_policy @fault_injection_policy end |
#image_optimization_policy ⇒ Google::Apis::ComputeAlpha::ImageOptimizationPolicy
The configuration for Cloud CDN's image optimization feature. This feature
dynamically processes and delivers images from the network edge.
Image Optimization is only available for Global External Application Load
Balancers.
Either Cloud CDN must be enabled on the backend service or backend bucket
serving the route, or cache policy must be configured on the same route.
Corresponds to the JSON property imageOptimizationPolicy
24140 24141 24142 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24140 def image_optimization_policy @image_optimization_policy end |
#max_stream_duration ⇒ Google::Apis::ComputeAlpha::Duration
A Duration represents a fixed-length span of time represented
as a count of seconds and fractions of seconds at nanosecond
resolution. It is independent of any calendar and concepts like "day"
or "month". Range is approximately 10,000 years.
Corresponds to the JSON property maxStreamDuration
24148 24149 24150 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24148 def max_stream_duration @max_stream_duration end |
#request_mirror_policy ⇒ Google::Apis::ComputeAlpha::RequestMirrorPolicy
A policy that specifies how requests intended for the route's backends
are shadowed to a separate mirrored backend service. The load balancer
doesn't wait for responses from the shadow service. Before sending traffic
to the shadow service, the host or authority header is suffixed with-shadow.
Corresponds to the JSON property requestMirrorPolicy
24156 24157 24158 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24156 def request_mirror_policy @request_mirror_policy end |
#retry_policy ⇒ Google::Apis::ComputeAlpha::HttpRetryPolicy
The retry policy associates with HttpRouteRule
Corresponds to the JSON property retryPolicy
24161 24162 24163 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24161 def retry_policy @retry_policy end |
#timeout ⇒ Google::Apis::ComputeAlpha::Duration
A Duration represents a fixed-length span of time represented
as a count of seconds and fractions of seconds at nanosecond
resolution. It is independent of any calendar and concepts like "day"
or "month". Range is approximately 10,000 years.
Corresponds to the JSON property timeout
24169 24170 24171 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24169 def timeout @timeout end |
#url_rewrite ⇒ Google::Apis::ComputeAlpha::UrlRewrite
The spec for modifying the path before sending the request to the matched
backend service.
Corresponds to the JSON property urlRewrite
24175 24176 24177 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24175 def url_rewrite @url_rewrite end |
#weighted_backend_services ⇒ Array<Google::Apis::ComputeAlpha::WeightedBackendService>
A list of weighted backend services to send traffic to when a route match
occurs. The weights determine the fraction of traffic that flows to
their corresponding backend service. If all traffic needs to
go to a single backend service, there must be oneweightedBackendService with
weight set to a non-zero number.
After a backend service is identified and before forwarding
the request to
the backend service, advanced routing actions such as URL rewrites and
header transformations are applied depending on additional settings
specified in this HttpRouteAction.
Corresponds to the JSON property weightedBackendServices
24189 24190 24191 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24189 def weighted_backend_services @weighted_backend_services end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
24196 24197 24198 24199 24200 24201 24202 24203 24204 24205 24206 24207 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24196 def update!(**args) @cache_policy = args[:cache_policy] if args.key?(:cache_policy) @cors_policy = args[:cors_policy] if args.key?(:cors_policy) @fault_injection_policy = args[:fault_injection_policy] if args.key?(:fault_injection_policy) @image_optimization_policy = args[:image_optimization_policy] if args.key?(:image_optimization_policy) @max_stream_duration = args[:max_stream_duration] if args.key?(:max_stream_duration) @request_mirror_policy = args[:request_mirror_policy] if args.key?(:request_mirror_policy) @retry_policy = args[:retry_policy] if args.key?(:retry_policy) @timeout = args[:timeout] if args.key?(:timeout) @url_rewrite = args[:url_rewrite] if args.key?(:url_rewrite) @weighted_backend_services = args[:weighted_backend_services] if args.key?(:weighted_backend_services) end |