Class: Google::Apis::ComputeAlpha::HttpsHealthCheck
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::HttpsHealthCheck
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Represents a legacy HTTPS Health Check resource. Legacy HTTPS health checks have been deprecated. If you are using a target pool-based network load balancer, you must use a legacy HTTP (not HTTPS) health check. For all other load balancers, including backend service-based network load balancers, and for managed instance group auto-healing, you must use modern (non-legacy) health checks. For more information, seeHealth checks overview.
Instance Attribute Summary collapse
-
#check_interval_sec ⇒ Fixnum
How often (in seconds) to send a health check.
-
#creation_timestamp ⇒ String
[Output Only] Creation timestamp inRFC3339 text format.
-
#description ⇒ String
An optional description of this resource.
-
#healthy_threshold ⇒ Fixnum
A so-far unhealthy instance will be marked healthy after this many consecutive successes.
-
#host ⇒ String
The value of the host header in the HTTPS health check request.
-
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
Name of the resource.
-
#port ⇒ Fixnum
The TCP port number for the HTTPS health check request.
-
#port_name ⇒ String
Not supported.
-
#port_specification ⇒ String
Specifies how a port is selected for health checking.
-
#proxy_header ⇒ String
Specifies the type of proxy header to append before sending data to the backend, either NONE or PROXY_V1.
-
#request_path ⇒ String
The request path of the HTTPS health check request.
-
#response ⇒ String
Creates a content-based HTTPS health check.
-
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
-
#self_link_with_id ⇒ String
Output only.
-
#timeout_sec ⇒ Fixnum
How long (in seconds) to wait before claiming failure.
-
#unhealthy_threshold ⇒ Fixnum
A so-far healthy instance will be marked unhealthy after this many consecutive failures.
-
#weight_report_mode ⇒ String
Weight report mode.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HttpsHealthCheck
constructor
A new instance of HttpsHealthCheck.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HttpsHealthCheck
Returns a new instance of HttpsHealthCheck.
19449 19450 19451 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 19449 def initialize(**args) update!(**args) end |
Instance Attribute Details
#check_interval_sec ⇒ Fixnum
How often (in seconds) to send a health check. The default value is 5
seconds.
Corresponds to the JSON property checkIntervalSec
24483 24484 24485 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24483 def check_interval_sec @check_interval_sec end |
#creation_timestamp ⇒ String
[Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
24489 24490 24491 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24489 def @creation_timestamp end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
24495 24496 24497 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24495 def description @description end |
#healthy_threshold ⇒ Fixnum
A so-far unhealthy instance will be marked healthy after this
many consecutive successes. The default value is 2.
Corresponds to the JSON property healthyThreshold
24501 24502 24503 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24501 def healthy_threshold @healthy_threshold end |
#host ⇒ String
The value of the host header in the HTTPS health check request. If left
empty (default value), the public IP on behalf of which this health check
is performed will be used.
Corresponds to the JSON property host
19381 19382 19383 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 19381 def host @host end |
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
24514 24515 24516 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24514 def id @id end |
#kind ⇒ String
Output only. Type of the resource.
Corresponds to the JSON property kind
24519 24520 24521 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24519 def kind @kind end |
#name ⇒ String
Name of the resource. Provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must
be a dash, lowercase letter, or digit, except the last character, which
cannot be a dash.
Corresponds to the JSON property name
24530 24531 24532 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24530 def name @name end |
#port ⇒ Fixnum
The TCP port number for the HTTPS health check request. The default value
is 443.
Corresponds to the JSON property port
19387 19388 19389 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 19387 def port @port end |
#port_name ⇒ String
Not supported.
Corresponds to the JSON property portName
19392 19393 19394 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 19392 def port_name @port_name end |
#port_specification ⇒ String
Specifies how a port is selected for health checking. Can be one of the
following values:
USE_FIXED_PORT: Specifies a port number explicitly using theport field in the
health check. Supported by backend services
for passthrough load balancers and backend services for proxy load
balancers. Not supported by target pools. The health check supports all
backends supported by the backend service provided the backend can be
health checked. For example, GCE_VM_IP network endpoint
groups, GCE_VM_IP_PORT network endpoint groups, and instance
group backends.
USE_NAMED_PORT: Not supported.
USE_SERVING_PORT: Provides an indirect method of specifying
the health check port by referring to the backend service. Only supported
by backend services for proxy load balancers. Not supported by target
pools. Not supported by backend services for passthrough load balancers.
Supports all backends that can be health checked; for example,GCE_VM_IP_PORT
network endpoint groups and instance group
backends.
For GCE_VM_IP_PORT network endpoint group backends, the health
check uses the port number specified for each endpoint in the network
endpoint group. For instance group backends, the health check uses the
port number determined by looking up the backend service's named port in
the instance group's list of named ports.
Corresponds to the JSON property portSpecification
19419 19420 19421 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 19419 def port_specification @port_specification end |
#proxy_header ⇒ String
Specifies the type of proxy header to append before sending data to the
backend, either NONE or PROXY_V1. The default
is NONE.
Corresponds to the JSON property proxyHeader
19426 19427 19428 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 19426 def proxy_header @proxy_header end |
#request_path ⇒ String
The request path of the HTTPS health check request. The default value is
"/". Must comply withRFC3986.
Corresponds to the JSON property requestPath
19432 19433 19434 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 19432 def request_path @request_path end |
#response ⇒ String
Creates a content-based HTTPS health check. In addition to the required
HTTP 200 (OK) status code, you can configure the health check to pass only
when the backend sends this specific ASCII response string within the first
1024 bytes of the HTTP response body. For details, see:
https://cloud.google.com/load-balancing/docs/health-check-concepts#criteria-
protocol-http
Corresponds to the JSON property response
19442 19443 19444 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 19442 def response @response end |
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
24547 24548 24549 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24547 def self_link @self_link end |
#self_link_with_id ⇒ String
Output only. [Output Only] Server-defined URL for this resource with the
resource id.
Corresponds to the JSON property selfLinkWithId
24553 24554 24555 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24553 def self_link_with_id @self_link_with_id end |
#timeout_sec ⇒ Fixnum
How long (in seconds) to wait before claiming failure. The default value is
5 seconds. It is invalid for timeoutSec to have a greater value than
checkIntervalSec.
Corresponds to the JSON property timeoutSec
24560 24561 24562 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24560 def timeout_sec @timeout_sec end |
#unhealthy_threshold ⇒ Fixnum
A so-far healthy instance will be marked unhealthy after this
many consecutive failures. The default value is 2.
Corresponds to the JSON property unhealthyThreshold
24566 24567 24568 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24566 def unhealthy_threshold @unhealthy_threshold end |
#weight_report_mode ⇒ String
Weight report mode. used for weighted Load Balancing.
Corresponds to the JSON property weightReportMode
19447 19448 19449 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 19447 def weight_report_mode @weight_report_mode end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
19454 19455 19456 19457 19458 19459 19460 19461 19462 19463 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 19454 def update!(**args) @host = args[:host] if args.key?(:host) @port = args[:port] if args.key?(:port) @port_name = args[:port_name] if args.key?(:port_name) @port_specification = args[:port_specification] if args.key?(:port_specification) @proxy_header = args[:proxy_header] if args.key?(:proxy_header) @request_path = args[:request_path] if args.key?(:request_path) @response = args[:response] if args.key?(:response) @weight_report_mode = args[:weight_report_mode] if args.key?(:weight_report_mode) end |