Class: Google::Apis::ComputeAlpha::HttpsHealthCheckList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of HttpsHealthCheck resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HttpsHealthCheckList

Returns a new instance of HttpsHealthCheckList.



25817
25818
25819
# File 'lib/google/apis/compute_alpha/classes.rb', line 25817

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


25785
25786
25787
# File 'lib/google/apis/compute_alpha/classes.rb', line 25785

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::HttpsHealthCheck>

A list of HttpsHealthCheck resources. Corresponds to the JSON property items



25790
25791
25792
# File 'lib/google/apis/compute_alpha/classes.rb', line 25790

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


25795
25796
25797
# File 'lib/google/apis/compute_alpha/classes.rb', line 25795

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


25805
25806
25807
# File 'lib/google/apis/compute_alpha/classes.rb', line 25805

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


25810
25811
25812
# File 'lib/google/apis/compute_alpha/classes.rb', line 25810

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::HttpsHealthCheckList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



25815
25816
25817
# File 'lib/google/apis/compute_alpha/classes.rb', line 25815

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



25822
25823
25824
25825
25826
25827
25828
25829
# File 'lib/google/apis/compute_alpha/classes.rb', line 25822

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end