Class: Google::Apis::ComputeAlpha::HttpsHealthCheckList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::HttpsHealthCheckList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Contains a list of HttpsHealthCheck resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::HttpsHealthCheck>
A list of HttpsHealthCheck resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::HttpsHealthCheckList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HttpsHealthCheckList
constructor
A new instance of HttpsHealthCheckList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HttpsHealthCheckList
Returns a new instance of HttpsHealthCheckList.
25545 25546 25547 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 25545 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
25513 25514 25515 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 25513 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::HttpsHealthCheck>
A list of HttpsHealthCheck resources.
Corresponds to the JSON property items
25518 25519 25520 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 25518 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
25523 25524 25525 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 25523 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
25533 25534 25535 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 25533 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
25538 25539 25540 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 25538 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::HttpsHealthCheckList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
25543 25544 25545 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 25543 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
25550 25551 25552 25553 25554 25555 25556 25557 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 25550 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |