Class: Google::Apis::ComputeAlpha::HttpsHealthCheckList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of HttpsHealthCheck resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HttpsHealthCheckList

Returns a new instance of HttpsHealthCheckList.



24809
24810
24811
# File 'lib/google/apis/compute_alpha/classes.rb', line 24809

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


24777
24778
24779
# File 'lib/google/apis/compute_alpha/classes.rb', line 24777

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::HttpsHealthCheck>

A list of HttpsHealthCheck resources. Corresponds to the JSON property items



24782
24783
24784
# File 'lib/google/apis/compute_alpha/classes.rb', line 24782

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


24787
24788
24789
# File 'lib/google/apis/compute_alpha/classes.rb', line 24787

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


24797
24798
24799
# File 'lib/google/apis/compute_alpha/classes.rb', line 24797

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


24802
24803
24804
# File 'lib/google/apis/compute_alpha/classes.rb', line 24802

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::HttpsHealthCheckList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



24807
24808
24809
# File 'lib/google/apis/compute_alpha/classes.rb', line 24807

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



24814
24815
24816
24817
24818
24819
24820
24821
# File 'lib/google/apis/compute_alpha/classes.rb', line 24814

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end