Class: Google::Apis::ComputeAlpha::HttpsHealthCheckList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::HttpsHealthCheckList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Contains a list of HttpsHealthCheck resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::HttpsHealthCheck>
A list of HttpsHealthCheck resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::HttpsHealthCheckList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HttpsHealthCheckList
constructor
A new instance of HttpsHealthCheckList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HttpsHealthCheckList
Returns a new instance of HttpsHealthCheckList.
24604 24605 24606 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24604 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
24572 24573 24574 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24572 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::HttpsHealthCheck>
A list of HttpsHealthCheck resources.
Corresponds to the JSON property items
24577 24578 24579 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24577 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
24582 24583 24584 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24582 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
24592 24593 24594 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24592 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
24597 24598 24599 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24597 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::HttpsHealthCheckList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
24602 24603 24604 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24602 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
24609 24610 24611 24612 24613 24614 24615 24616 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24609 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |