Class: Google::Apis::ComputeAlpha::HttpsHealthCheckList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::HttpsHealthCheckList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Contains a list of HttpsHealthCheck resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::HttpsHealthCheck>
A list of HttpsHealthCheck resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::HttpsHealthCheckList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HttpsHealthCheckList
constructor
A new instance of HttpsHealthCheckList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HttpsHealthCheckList
Returns a new instance of HttpsHealthCheckList.
23951 23952 23953 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 23951 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
23919 23920 23921 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 23919 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::HttpsHealthCheck>
A list of HttpsHealthCheck resources.
Corresponds to the JSON property items
23924 23925 23926 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 23924 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
23929 23930 23931 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 23929 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
23939 23940 23941 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 23939 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
23944 23945 23946 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 23944 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::HttpsHealthCheckList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
23949 23950 23951 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 23949 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
23956 23957 23958 23959 23960 23961 23962 23963 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 23956 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |