Class: Google::Apis::ComputeAlpha::Image
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::Image
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Represents an Image resource. You can use images to create boot disks for your VM instances. For more information, read Images.
Defined Under Namespace
Classes: RawDisk
Instance Attribute Summary collapse
-
#architecture ⇒ String
The architecture of the image.
-
#archive_size_bytes ⇒ Fixnum
Size of the image tar.gz archive stored in Google Cloud Storage (in bytes).
-
#creation_timestamp ⇒ String
Output only.
-
#deprecated ⇒ Google::Apis::ComputeAlpha::DeprecationStatus
Deprecation status for a public resource.
-
#description ⇒ String
An optional description of this resource.
-
#disk_size_gb ⇒ Fixnum
Size of the image when restored onto a persistent disk (in GB).
-
#enable_confidential_compute ⇒ Boolean
(also: #enable_confidential_compute?)
Output only.
-
#family ⇒ String
The name of the image family to which this image belongs.
-
#guest_os_features ⇒ Array<Google::Apis::ComputeAlpha::GuestOsFeature>
A list of features to enable on the guest operating system.
-
#id ⇒ Fixnum
Output only.
-
#image_encryption_key ⇒ Google::Apis::ComputeAlpha::CustomerEncryptionKey
Encrypts the image using acustomer-supplied encryption key.
-
#kind ⇒ String
Output only.
-
#label_fingerprint ⇒ String
A fingerprint for the labels being applied to this image, which is essentially a hash of the labels used for optimistic locking.
-
#labels ⇒ Hash<String,String>
Labels to apply to this image.
-
#license_codes ⇒ Array<Fixnum>
Integer license codes indicating which licenses are attached to this image.
-
#licenses ⇒ Array<String>
Any applicable license URI.
-
#locked ⇒ Boolean
(also: #locked?)
A flag for marketplace VM disk created from the image, which is designed for marketplace VM disk to prevent the proprietary data on the disk from being accessed unwantedly.
-
#name ⇒ String
Name of the resource; provided by the client when the resource is created.
-
#params ⇒ Google::Apis::ComputeAlpha::ImageParams
Additional image params.
-
#raw_disk ⇒ Google::Apis::ComputeAlpha::Image::RawDisk
The parameters of the raw disk image.
-
#rollout_override ⇒ Google::Apis::ComputeAlpha::RolloutPolicy
A rollout policy configuration.
-
#satisfies_pzi ⇒ Boolean
(also: #satisfies_pzi?)
Output only.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
Output only.
-
#self_link ⇒ String
Output only.
-
#self_link_with_id ⇒ String
Output only.
-
#shielded_instance_initial_state ⇒ Google::Apis::ComputeAlpha::InitialStateConfig
Initial State for shielded instance, these are public keys which are safe to store in public Corresponds to the JSON property
shieldedInstanceInitialState. -
#source_disk ⇒ String
URL of the source disk used to create this image.
-
#source_disk_encryption_key ⇒ Google::Apis::ComputeAlpha::CustomerEncryptionKey
Thecustomer-supplied encryption key of the source disk.
-
#source_disk_id ⇒ String
Output only.
-
#source_image ⇒ String
URL of the source image used to create this image.
-
#source_image_encryption_key ⇒ Google::Apis::ComputeAlpha::CustomerEncryptionKey
The customer-supplied encryption key of the source image.
-
#source_image_id ⇒ String
Output only.
-
#source_snapshot ⇒ String
URL of the source snapshot used to create this image.
-
#source_snapshot_encryption_key ⇒ Google::Apis::ComputeAlpha::CustomerEncryptionKey
The customer-supplied encryption key of the source snapshot.
-
#source_snapshot_id ⇒ String
Output only.
-
#source_type ⇒ String
The type of the image used to create this disk.
-
#status ⇒ String
Output only.
-
#storage_locations ⇒ Array<String>
Cloud Storage bucket storage location of the image (regional or multi-regional).
Instance Method Summary collapse
-
#initialize(**args) ⇒ Image
constructor
A new instance of Image.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Image
Returns a new instance of Image.
25030 25031 25032 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 25030 def initialize(**args) update!(**args) end |
Instance Attribute Details
#architecture ⇒ String
The architecture of the image. Valid values are
ARM64 or X86_64.
Corresponds to the JSON property architecture
24716 24717 24718 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24716 def architecture @architecture end |
#archive_size_bytes ⇒ Fixnum
Size of the image tar.gz archive stored in Google Cloud
Storage (in bytes).
Corresponds to the JSON property archiveSizeBytes
24722 24723 24724 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24722 def archive_size_bytes @archive_size_bytes end |
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
24728 24729 24730 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24728 def @creation_timestamp end |
#deprecated ⇒ Google::Apis::ComputeAlpha::DeprecationStatus
Deprecation status for a public resource.
Corresponds to the JSON property deprecated
24733 24734 24735 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24733 def deprecated @deprecated end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
24739 24740 24741 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24739 def description @description end |
#disk_size_gb ⇒ Fixnum
Size of the image when restored onto a persistent disk (in GB).
Corresponds to the JSON property diskSizeGb
24744 24745 24746 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24744 def disk_size_gb @disk_size_gb end |
#enable_confidential_compute ⇒ Boolean Also known as: enable_confidential_compute?
Output only. Whether this image is created from a confidential compute mode
disk.
[Output Only]: This field is not set by user, but from source disk.
Corresponds to the JSON property enableConfidentialCompute
24751 24752 24753 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24751 def enable_confidential_compute @enable_confidential_compute end |
#family ⇒ String
The name of the image family to which this image belongs. The image
family name can be from a publicly managed image family provided by
Compute Engine, or from a custom image family you create. For example,centos-
stream-9 is a publicly available image family.
For more information, see Image
family best practices.
When creating disks, you can specify an image family instead of a specific
image name. The image family always returns its latest image that is not
deprecated. The name of the image family must comply with RFC1035.
Corresponds to the JSON property family
24765 24766 24767 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24765 def family @family end |
#guest_os_features ⇒ Array<Google::Apis::ComputeAlpha::GuestOsFeature>
A list of features to enable on the guest operating system. Applicable
only for bootable images. To see a list of available options, see
theguestOSfeatures[].type parameter.
Corresponds to the JSON property guestOsFeatures
24772 24773 24774 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24772 def guest_os_features @guest_os_features end |
#id ⇒ Fixnum
Output only. [Output Only] The unique identifier for the resource. This
identifier is
defined by the server.
Corresponds to the JSON property id
24779 24780 24781 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24779 def id @id end |
#image_encryption_key ⇒ Google::Apis::ComputeAlpha::CustomerEncryptionKey
Encrypts the image using acustomer-supplied
encryption key.
After you encrypt an image with a customer-supplied key, you must provide
the same key if you use the image later (e.g. to create a disk from
the image).
Customer-supplied encryption keys do not protect access to metadata
of the disk.
If you do not provide an encryption key when creating the image, then the
disk will be encrypted using an automatically generated key and you do not
need to provide a key to use the image later.
Corresponds to the JSON property imageEncryptionKey
24793 24794 24795 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24793 def image_encryption_key @image_encryption_key end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Always compute#image for
images.
Corresponds to the JSON property kind
24799 24800 24801 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24799 def kind @kind end |
#label_fingerprint ⇒ String
A fingerprint for the labels being applied to this image, which is
essentially a hash of the labels used for optimistic locking. The
fingerprint is initially generated by Compute Engine and changes after
every request to modify or update labels. You must always provide an
up-to-date fingerprint hash in order to update or change labels,
otherwise the request will fail with error412 conditionNotMet.
To see the latest fingerprint, make a get() request to
retrieve an image.
Corresponds to the JSON property labelFingerprint
NOTE: Values are automatically base64 encoded/decoded in the client library.
24812 24813 24814 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24812 def label_fingerprint @label_fingerprint end |
#labels ⇒ Hash<String,String>
Labels to apply to this image. These can be later modified by
the setLabels method.
Corresponds to the JSON property labels
24818 24819 24820 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24818 def labels @labels end |
#license_codes ⇒ Array<Fixnum>
Integer license codes indicating which licenses are attached to this image.
Corresponds to the JSON property licenseCodes
24823 24824 24825 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24823 def license_codes @license_codes end |
#licenses ⇒ Array<String>
Any applicable license URI.
Corresponds to the JSON property licenses
24828 24829 24830 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24828 def licenses @licenses end |
#locked ⇒ Boolean Also known as: locked?
A flag for marketplace VM disk created from the image, which is designed for marketplace VM disk to prevent the proprietary data on the disk from being accessed unwantedly. The flag will be inherited by the disk created from the image. The disk with locked flag set to true will be prohibited from performing the operations below:
- R/W or R/O disk attach
- Disk detach, if disk is created via create-on-create
- Create images
- Create snapshots
Create disk clone (create disk from the current disk) The image with the locked field set to true will be prohibited from performing the operations below:
Create images from the current image
Update the locked field for the current image The instance with at least one disk with locked flag set to true will be prohibited from performing the operations below:
Secondary disk attach
Create instant snapshot
Create machine images
Create instance template
Delete the instance with --keep-disk parameter set to true Corresponds to the JSON property
locked
24857 24858 24859 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24857 def locked @locked end |
#name ⇒ String
Name of the resource; provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must be
a dash, lowercase letter, or digit, except the last character, which cannot
be a dash.
Corresponds to the JSON property name
24869 24870 24871 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24869 def name @name end |
#params ⇒ Google::Apis::ComputeAlpha::ImageParams
Additional image params.
Corresponds to the JSON property params
24874 24875 24876 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24874 def params @params end |
#raw_disk ⇒ Google::Apis::ComputeAlpha::Image::RawDisk
The parameters of the raw disk image.
Corresponds to the JSON property rawDisk
24879 24880 24881 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24879 def raw_disk @raw_disk end |
#rollout_override ⇒ Google::Apis::ComputeAlpha::RolloutPolicy
A rollout policy configuration.
Corresponds to the JSON property rolloutOverride
24884 24885 24886 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24884 def rollout_override @rollout_override end |
#satisfies_pzi ⇒ Boolean Also known as: satisfies_pzi?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzi
24889 24890 24891 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24889 def satisfies_pzi @satisfies_pzi end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
Output only. [Output Only] Reserved for future use.
Corresponds to the JSON property satisfiesPzs
24895 24896 24897 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24895 def satisfies_pzs @satisfies_pzs end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
24901 24902 24903 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24901 def self_link @self_link end |
#self_link_with_id ⇒ String
Output only. [Output Only] Server-defined URL for this resource's resource id.
Corresponds to the JSON property selfLinkWithId
24906 24907 24908 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24906 def self_link_with_id @self_link_with_id end |
#shielded_instance_initial_state ⇒ Google::Apis::ComputeAlpha::InitialStateConfig
Initial State for shielded instance,
these are public keys which are safe to store in public
Corresponds to the JSON property shieldedInstanceInitialState
24912 24913 24914 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24912 def shielded_instance_initial_state @shielded_instance_initial_state end |
#source_disk ⇒ String
URL of the source disk used to create this image. For example, the following are valid values:
- https://www.googleapis.com/compute/v1/projects/project/zones/zone/disks/ disk
- projects/project/zones/zone/disks/disk
zones/zone/disks/disk In order to create an image, you must provide the full or partial URL of one of the following:
The rawDisk.source URL
The sourceDisk URL
The sourceImage URL
The sourceSnapshot URL Corresponds to the JSON property
sourceDisk
24930 24931 24932 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24930 def source_disk @source_disk end |
#source_disk_encryption_key ⇒ Google::Apis::ComputeAlpha::CustomerEncryptionKey
Thecustomer-supplied
encryption key of the source disk. Required if the source disk is
protected by a customer-supplied encryption key.
Corresponds to the JSON property sourceDiskEncryptionKey
24937 24938 24939 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24937 def source_disk_encryption_key @source_disk_encryption_key end |
#source_disk_id ⇒ String
Output only. [Output Only]
The ID value of the disk used to create this image. This value may be used
to determine whether the image was taken from the current or a previous
instance of a given disk name.
Corresponds to the JSON property sourceDiskId
24945 24946 24947 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24945 def source_disk_id @source_disk_id end |
#source_image ⇒ String
URL of the source image used to create this image. The following are valid formats for the URL:
- https://www.googleapis.com/compute/v1/projects/project_id/global/ images/image_name
projects/project_id/global/images/image_name In order to create an image, you must provide the full or partial URL of one of the following:
The rawDisk.source URL
The sourceDisk URL
The sourceImage URL
The sourceSnapshot URL Corresponds to the JSON property
sourceImage
24962 24963 24964 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24962 def source_image @source_image end |
#source_image_encryption_key ⇒ Google::Apis::ComputeAlpha::CustomerEncryptionKey
The customer-supplied encryption key of the source image. Required if the
source image is protected by a customer-supplied encryption key.
Corresponds to the JSON property sourceImageEncryptionKey
24968 24969 24970 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24968 def source_image_encryption_key @source_image_encryption_key end |
#source_image_id ⇒ String
Output only. [Output Only]
The ID value of the image used to create this image. This value may be used
to determine whether the image was taken from the current or a previous
instance of a given image name.
Corresponds to the JSON property sourceImageId
24976 24977 24978 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24976 def source_image_id @source_image_id end |
#source_snapshot ⇒ String
URL of the source snapshot used to create this image. The following are valid formats for the URL:
- https://www.googleapis.com/compute/v1/projects/project_id/global/ snapshots/snapshot_name
projects/project_id/global/snapshots/snapshot_name In order to create an image, you must provide the full or partial URL of one of the following:
The rawDisk.source URL
The sourceDisk URL
The sourceImage URL
The sourceSnapshot URL Corresponds to the JSON property
sourceSnapshot
24993 24994 24995 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24993 def source_snapshot @source_snapshot end |
#source_snapshot_encryption_key ⇒ Google::Apis::ComputeAlpha::CustomerEncryptionKey
The customer-supplied encryption key of the source snapshot. Required if
the source snapshot is protected by a customer-supplied encryption key.
Corresponds to the JSON property sourceSnapshotEncryptionKey
24999 25000 25001 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24999 def source_snapshot_encryption_key @source_snapshot_encryption_key end |
#source_snapshot_id ⇒ String
Output only. [Output Only]
The ID value of the snapshot used to create this image. This value may be
used to determine whether the snapshot was taken from the current or a
previous instance of a given snapshot name.
Corresponds to the JSON property sourceSnapshotId
25007 25008 25009 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 25007 def source_snapshot_id @source_snapshot_id end |
#source_type ⇒ String
The type of the image used to create this disk. The
default and only valid value is RAW.
Corresponds to the JSON property sourceType
25013 25014 25015 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 25013 def source_type @source_type end |
#status ⇒ String
Output only. [Output Only] The status of the image. An image can be used to
create other
resources, such as instances, only after the image has been successfully
created and the status is set to READY. Possible
values are FAILED, PENDING, orREADY.
Corresponds to the JSON property status
25022 25023 25024 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 25022 def status @status end |
#storage_locations ⇒ Array<String>
Cloud Storage bucket storage location of the image (regional or
multi-regional).
Corresponds to the JSON property storageLocations
25028 25029 25030 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 25028 def storage_locations @storage_locations end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
25035 25036 25037 25038 25039 25040 25041 25042 25043 25044 25045 25046 25047 25048 25049 25050 25051 25052 25053 25054 25055 25056 25057 25058 25059 25060 25061 25062 25063 25064 25065 25066 25067 25068 25069 25070 25071 25072 25073 25074 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 25035 def update!(**args) @architecture = args[:architecture] if args.key?(:architecture) @archive_size_bytes = args[:archive_size_bytes] if args.key?(:archive_size_bytes) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @deprecated = args[:deprecated] if args.key?(:deprecated) @description = args[:description] if args.key?(:description) @disk_size_gb = args[:disk_size_gb] if args.key?(:disk_size_gb) @enable_confidential_compute = args[:enable_confidential_compute] if args.key?(:enable_confidential_compute) @family = args[:family] if args.key?(:family) @guest_os_features = args[:guest_os_features] if args.key?(:guest_os_features) @id = args[:id] if args.key?(:id) @image_encryption_key = args[:image_encryption_key] if args.key?(:image_encryption_key) @kind = args[:kind] if args.key?(:kind) @label_fingerprint = args[:label_fingerprint] if args.key?(:label_fingerprint) @labels = args[:labels] if args.key?(:labels) @license_codes = args[:license_codes] if args.key?(:license_codes) @licenses = args[:licenses] if args.key?(:licenses) @locked = args[:locked] if args.key?(:locked) @name = args[:name] if args.key?(:name) @params = args[:params] if args.key?(:params) @raw_disk = args[:raw_disk] if args.key?(:raw_disk) @rollout_override = args[:rollout_override] if args.key?(:rollout_override) @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @self_link = args[:self_link] if args.key?(:self_link) @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id) @shielded_instance_initial_state = args[:shielded_instance_initial_state] if args.key?(:shielded_instance_initial_state) @source_disk = args[:source_disk] if args.key?(:source_disk) @source_disk_encryption_key = args[:source_disk_encryption_key] if args.key?(:source_disk_encryption_key) @source_disk_id = args[:source_disk_id] if args.key?(:source_disk_id) @source_image = args[:source_image] if args.key?(:source_image) @source_image_encryption_key = args[:source_image_encryption_key] if args.key?(:source_image_encryption_key) @source_image_id = args[:source_image_id] if args.key?(:source_image_id) @source_snapshot = args[:source_snapshot] if args.key?(:source_snapshot) @source_snapshot_encryption_key = args[:source_snapshot_encryption_key] if args.key?(:source_snapshot_encryption_key) @source_snapshot_id = args[:source_snapshot_id] if args.key?(:source_snapshot_id) @source_type = args[:source_type] if args.key?(:source_type) @status = args[:status] if args.key?(:status) @storage_locations = args[:storage_locations] if args.key?(:storage_locations) end |