Class: Google::Apis::ComputeAlpha::Image::RawDisk

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

The parameters of the raw disk image.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RawDisk

Returns a new instance of RawDisk.



26311
26312
26313
# File 'lib/google/apis/compute_alpha/classes.rb', line 26311

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#container_typeString

The format used to encode and transmit the block device, which should beTAR. This is just a container and transmission format and not a runtime format. Provided by the client when the disk image is created. Corresponds to the JSON property containerType

Returns:

  • (String)


26281
26282
26283
# File 'lib/google/apis/compute_alpha/classes.rb', line 26281

def container_type
  @container_type
end

#sha1_checksumString

[Deprecated] This field is deprecated. An optional SHA1 checksum of the disk image before unpackaging provided by the client when the disk image is created. Corresponds to the JSON property sha1Checksum

Returns:

  • (String)


26288
26289
26290
# File 'lib/google/apis/compute_alpha/classes.rb', line 26288

def sha1_checksum
  @sha1_checksum
end

#sourceString

The full Google Cloud Storage URL or Artifact Registry path where the raw disk image archive is stored. The following are valid formats:

Returns:

  • (String)


26309
26310
26311
# File 'lib/google/apis/compute_alpha/classes.rb', line 26309

def source
  @source
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



26316
26317
26318
26319
26320
# File 'lib/google/apis/compute_alpha/classes.rb', line 26316

def update!(**args)
  @container_type = args[:container_type] if args.key?(:container_type)
  @sha1_checksum = args[:sha1_checksum] if args.key?(:sha1_checksum)
  @source = args[:source] if args.key?(:source)
end