Class: Google::Apis::ComputeAlpha::Image::RawDisk
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::Image::RawDisk
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
The parameters of the raw disk image.
Instance Attribute Summary collapse
-
#container_type ⇒ String
The format used to encode and transmit the block device, which should beTAR.
-
#sha1_checksum ⇒ String
[Deprecated] This field is deprecated.
-
#source ⇒ String
The full Google Cloud Storage URL or Artifact Registry path where the raw disk image archive is stored.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RawDisk
constructor
A new instance of RawDisk.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RawDisk
Returns a new instance of RawDisk.
25098 25099 25100 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 25098 def initialize(**args) update!(**args) end |
Instance Attribute Details
#container_type ⇒ String
The format used to encode and transmit the block device, which should beTAR.
This is just a container and transmission format and not
a runtime format. Provided by the client when the disk image is created.
Corresponds to the JSON property containerType
25068 25069 25070 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 25068 def container_type @container_type end |
#sha1_checksum ⇒ String
[Deprecated] This field is deprecated.
An optional SHA1 checksum of the disk image before unpackaging provided
by the client when the disk image is created.
Corresponds to the JSON property sha1Checksum
25075 25076 25077 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 25075 def sha1_checksum @sha1_checksum end |
#source ⇒ String
The full Google Cloud Storage URL or Artifact Registry path where the raw disk image archive is stored. The following are valid formats:
- https://storage.googleapis.com/bucket_name/image_archive_name
- https://storage.googleapis.com/bucket_name/folder_name/image_archive_name
- projects/project/locations/location/repositories/repo/packages/package/ versions/version_id
projects/project/locations/location/repositories/repo/packages/package/ versions/version_id@dirsum_sha256:hex_value In order to create an image, you must provide the full or partial URL of one of the following:
The rawDisk.source URL
The sourceDisk URL
The sourceImage URL
The sourceSnapshot URL Corresponds to the JSON property
source
25096 25097 25098 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 25096 def source @source end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
25103 25104 25105 25106 25107 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 25103 def update!(**args) @container_type = args[:container_type] if args.key?(:container_type) @sha1_checksum = args[:sha1_checksum] if args.key?(:sha1_checksum) @source = args[:source] if args.key?(:source) end |