Class: Google::Apis::ComputeAlpha::Image::RawDisk

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

The parameters of the raw disk image.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RawDisk

Returns a new instance of RawDisk.



24441
24442
24443
# File 'lib/google/apis/compute_alpha/classes.rb', line 24441

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#container_typeString

The format used to encode and transmit the block device, which should beTAR. This is just a container and transmission format and not a runtime format. Provided by the client when the disk image is created. Corresponds to the JSON property containerType

Returns:

  • (String)


24415
24416
24417
# File 'lib/google/apis/compute_alpha/classes.rb', line 24415

def container_type
  @container_type
end

#sha1_checksumString

[Deprecated] This field is deprecated. An optional SHA1 checksum of the disk image before unpackaging provided by the client when the disk image is created. Corresponds to the JSON property sha1Checksum

Returns:

  • (String)


24422
24423
24424
# File 'lib/google/apis/compute_alpha/classes.rb', line 24422

def sha1_checksum
  @sha1_checksum
end

#sourceString

The full Google Cloud Storage URL where the raw disk image archive is stored. The following are valid formats for the URL:

Returns:

  • (String)


24439
24440
24441
# File 'lib/google/apis/compute_alpha/classes.rb', line 24439

def source
  @source
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



24446
24447
24448
24449
24450
# File 'lib/google/apis/compute_alpha/classes.rb', line 24446

def update!(**args)
  @container_type = args[:container_type] if args.key?(:container_type)
  @sha1_checksum = args[:sha1_checksum] if args.key?(:sha1_checksum)
  @source = args[:source] if args.key?(:source)
end