Class: Google::Apis::ComputeAlpha::ImageList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of images.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ImageList

Returns a new instance of ImageList.



26112
26113
26114
# File 'lib/google/apis/compute_alpha/classes.rb', line 26112

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


26080
26081
26082
# File 'lib/google/apis/compute_alpha/classes.rb', line 26080

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::Image>

A list of Image resources. Corresponds to the JSON property items



26085
26086
26087
# File 'lib/google/apis/compute_alpha/classes.rb', line 26085

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


26090
26091
26092
# File 'lib/google/apis/compute_alpha/classes.rb', line 26090

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


26100
26101
26102
# File 'lib/google/apis/compute_alpha/classes.rb', line 26100

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


26105
26106
26107
# File 'lib/google/apis/compute_alpha/classes.rb', line 26105

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::ImageList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



26110
26111
26112
# File 'lib/google/apis/compute_alpha/classes.rb', line 26110

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



26117
26118
26119
26120
26121
26122
26123
26124
# File 'lib/google/apis/compute_alpha/classes.rb', line 26117

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end