Class: Google::Apis::ComputeAlpha::ImageList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of images.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ImageList

Returns a new instance of ImageList.



25376
25377
25378
# File 'lib/google/apis/compute_alpha/classes.rb', line 25376

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


25344
25345
25346
# File 'lib/google/apis/compute_alpha/classes.rb', line 25344

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::Image>

A list of Image resources. Corresponds to the JSON property items



25349
25350
25351
# File 'lib/google/apis/compute_alpha/classes.rb', line 25349

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


25354
25355
25356
# File 'lib/google/apis/compute_alpha/classes.rb', line 25354

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


25364
25365
25366
# File 'lib/google/apis/compute_alpha/classes.rb', line 25364

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


25369
25370
25371
# File 'lib/google/apis/compute_alpha/classes.rb', line 25369

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::ImageList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



25374
25375
25376
# File 'lib/google/apis/compute_alpha/classes.rb', line 25374

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



25381
25382
25383
25384
25385
25386
25387
25388
# File 'lib/google/apis/compute_alpha/classes.rb', line 25381

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end