Class: Google::Apis::ComputeAlpha::ImageList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::ImageList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Contains a list of images.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::Image>
A list of Image resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::ImageList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ImageList
constructor
A new instance of ImageList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ImageList
Returns a new instance of ImageList.
25171 25172 25173 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 25171 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
25139 25140 25141 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 25139 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::Image>
A list of Image resources.
Corresponds to the JSON property items
25144 25145 25146 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 25144 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
25149 25150 25151 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 25149 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
25159 25160 25161 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 25159 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
25164 25165 25166 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 25164 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::ImageList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
25169 25170 25171 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 25169 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
25176 25177 25178 25179 25180 25181 25182 25183 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 25176 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |