Class: Google::Apis::ComputeAlpha::ImageList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of images.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ImageList

Returns a new instance of ImageList.



25188
25189
25190
# File 'lib/google/apis/compute_alpha/classes.rb', line 25188

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


25156
25157
25158
# File 'lib/google/apis/compute_alpha/classes.rb', line 25156

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::Image>

A list of Image resources. Corresponds to the JSON property items



25161
25162
25163
# File 'lib/google/apis/compute_alpha/classes.rb', line 25161

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


25166
25167
25168
# File 'lib/google/apis/compute_alpha/classes.rb', line 25166

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


25176
25177
25178
# File 'lib/google/apis/compute_alpha/classes.rb', line 25176

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


25181
25182
25183
# File 'lib/google/apis/compute_alpha/classes.rb', line 25181

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::ImageList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



25186
25187
25188
# File 'lib/google/apis/compute_alpha/classes.rb', line 25186

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



25193
25194
25195
25196
25197
25198
25199
25200
# File 'lib/google/apis/compute_alpha/classes.rb', line 25193

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end