Class: Google::Apis::ComputeAlpha::ImageList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::ImageList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Contains a list of images.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::Image>
A list of Image resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::ImageList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ImageList
constructor
A new instance of ImageList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ImageList
Returns a new instance of ImageList.
25197 25198 25199 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 25197 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
25165 25166 25167 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 25165 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::Image>
A list of Image resources.
Corresponds to the JSON property items
25170 25171 25172 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 25170 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
25175 25176 25177 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 25175 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
25185 25186 25187 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 25185 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
25190 25191 25192 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 25190 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::ImageList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
25195 25196 25197 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 25195 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
25202 25203 25204 25205 25206 25207 25208 25209 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 25202 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |