Class: Google::Apis::ComputeAlpha::ImageList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::ImageList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Contains a list of images.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::Image>
A list of Image resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::ImageList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ImageList
constructor
A new instance of ImageList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ImageList
Returns a new instance of ImageList.
24514 24515 24516 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24514 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
24482 24483 24484 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24482 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::Image>
A list of Image resources.
Corresponds to the JSON property items
24487 24488 24489 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24487 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
24492 24493 24494 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24492 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
24502 24503 24504 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24502 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
24507 24508 24509 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24507 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::ImageList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
24512 24513 24514 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24512 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
24519 24520 24521 24522 24523 24524 24525 24526 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 24519 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |