Class: Google::Apis::ComputeAlpha::ImageOptimizationPolicy

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

The configuration for Cloud CDN's image optimization feature. This feature dynamically processes and delivers images from the network edge. Image Optimization is only available for Global External Application Load Balancers. Either Cloud CDN must be enabled on the backend service or backend bucket serving the route, or cache policy must be configured on the same route.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ImageOptimizationPolicy

Returns a new instance of ImageOptimizationPolicy.



25296
25297
25298
# File 'lib/google/apis/compute_alpha/classes.rb', line 25296

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#query_parameter_interpretationString

Specifies whether to interpret query parameters for image optimization. Corresponds to the JSON property queryParameterInterpretation

Returns:

  • (String)


25294
25295
25296
# File 'lib/google/apis/compute_alpha/classes.rb', line 25294

def query_parameter_interpretation
  @query_parameter_interpretation
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



25301
25302
25303
# File 'lib/google/apis/compute_alpha/classes.rb', line 25301

def update!(**args)
  @query_parameter_interpretation = args[:query_parameter_interpretation] if args.key?(:query_parameter_interpretation)
end