Class: Google::Apis::ComputeAlpha::Instance

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Represents an Instance resource. An instance is a virtual machine that is hosted on Google Cloud Platform. For more information, readVirtual Machine Instances.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Instance

Returns a new instance of Instance.



26846
26847
26848
# File 'lib/google/apis/compute_alpha/classes.rb', line 26846

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#advanced_machine_featuresGoogle::Apis::ComputeAlpha::AdvancedMachineFeatures

Specifies options for controlling advanced machine features. Options that would traditionally be configured in a BIOS belong here. Features that require operating system support may have corresponding entries in the GuestOsFeatures of anImage (e.g., whether or not the OS in theImage supports nested virtualization being enabled or disabled). Corresponds to the JSON property advancedMachineFeatures



26451
26452
26453
# File 'lib/google/apis/compute_alpha/classes.rb', line 26451

def advanced_machine_features
  @advanced_machine_features
end

#can_ip_forwardBoolean Also known as: can_ip_forward?

Allows this instance to send and receive packets with non-matching destination or source IPs. This is required if you plan to use this instance to forward routes. For more information, seeEnabling IP Forwarding. Corresponds to the JSON property canIpForward

Returns:

  • (Boolean)


26458
26459
26460
# File 'lib/google/apis/compute_alpha/classes.rb', line 26458

def can_ip_forward
  @can_ip_forward
end

#confidential_instance_configGoogle::Apis::ComputeAlpha::ConfidentialInstanceConfig

A set of Confidential Instance options. Corresponds to the JSON property confidentialInstanceConfig



26464
26465
26466
# File 'lib/google/apis/compute_alpha/classes.rb', line 26464

def confidential_instance_config
  @confidential_instance_config
end

#cpu_platformString

Output only. [Output Only] The CPU platform used by this instance. Corresponds to the JSON property cpuPlatform

Returns:

  • (String)


26469
26470
26471
# File 'lib/google/apis/compute_alpha/classes.rb', line 26469

def cpu_platform
  @cpu_platform
end

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


26474
26475
26476
# File 'lib/google/apis/compute_alpha/classes.rb', line 26474

def creation_timestamp
  @creation_timestamp
end

#deletion_protectionBoolean Also known as: deletion_protection?

Whether the resource should be protected against deletion. Corresponds to the JSON property deletionProtection

Returns:

  • (Boolean)


26479
26480
26481
# File 'lib/google/apis/compute_alpha/classes.rb', line 26479

def deletion_protection
  @deletion_protection
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


26486
26487
26488
# File 'lib/google/apis/compute_alpha/classes.rb', line 26486

def description
  @description
end

#disksArray<Google::Apis::ComputeAlpha::AttachedDisk>

Array of disks associated with this instance. Persistent disks must be created before you can assign them. Corresponds to the JSON property disks



26492
26493
26494
# File 'lib/google/apis/compute_alpha/classes.rb', line 26492

def disks
  @disks
end

#display_deviceGoogle::Apis::ComputeAlpha::DisplayDevice

A set of Display Device options Corresponds to the JSON property displayDevice



26497
26498
26499
# File 'lib/google/apis/compute_alpha/classes.rb', line 26497

def display_device
  @display_device
end

#erase_windows_vss_signatureBoolean Also known as: erase_windows_vss_signature?

Specifies whether the disks restored from source snapshots or source machine image should erase Windows specific VSS signature. Corresponds to the JSON property eraseWindowsVssSignature

Returns:

  • (Boolean)


26503
26504
26505
# File 'lib/google/apis/compute_alpha/classes.rb', line 26503

def erase_windows_vss_signature
  @erase_windows_vss_signature
end

#fingerprintString

Specifies a fingerprint for this resource, which is essentially a hash of the instance's contents and used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update the instance. You must always provide an up-to-date fingerprint hash in order to update the instance. To see the latest fingerprint, make get() request to the instance. Corresponds to the JSON property fingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


26516
26517
26518
# File 'lib/google/apis/compute_alpha/classes.rb', line 26516

def fingerprint
  @fingerprint
end

#guest_acceleratorsArray<Google::Apis::ComputeAlpha::AcceleratorConfig>

A list of the type and count of accelerator cards attached to the instance. Corresponds to the JSON property guestAccelerators



26521
26522
26523
# File 'lib/google/apis/compute_alpha/classes.rb', line 26521

def guest_accelerators
  @guest_accelerators
end

#hostnameString

Specifies the hostname of the instance. The specified hostname must be RFC1035 compliant. If hostname is not specified, the default hostname is [INSTANCE_NAME].c.[PROJECT_ID].internal when using the global DNS, and [INSTANCE_NAME].[ZONE].c.[PROJECT_ID].internal when using zonal DNS. Corresponds to the JSON property hostname

Returns:

  • (String)


26529
26530
26531
# File 'lib/google/apis/compute_alpha/classes.rb', line 26529

def hostname
  @hostname
end

#idFixnum

Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


26536
26537
26538
# File 'lib/google/apis/compute_alpha/classes.rb', line 26536

def id
  @id
end

#identityString

Corresponds to the JSON property identity

Returns:

  • (String)


26541
26542
26543
# File 'lib/google/apis/compute_alpha/classes.rb', line 26541

def identity
  @identity
end

#identity_certificateBoolean Also known as: identity_certificate?

Corresponds to the JSON property identityCertificate

Returns:

  • (Boolean)


26546
26547
26548
# File 'lib/google/apis/compute_alpha/classes.rb', line 26546

def identity_certificate
  @identity_certificate
end

#instance_encryption_keyGoogle::Apis::ComputeAlpha::CustomerEncryptionKey

Encrypts suspended data for an instance with acustomer-managed encryption key. If you are creating a new instance, this field will encrypt the local SSD and in-memory contents of the instance during the suspend operation. If you do not provide an encryption key when creating the instance, then the local SSD and in-memory contents will be encrypted using an automatically generated key during the suspend operation. Corresponds to the JSON property instanceEncryptionKey



26558
26559
26560
# File 'lib/google/apis/compute_alpha/classes.rb', line 26558

def instance_encryption_key
  @instance_encryption_key
end

#key_revocation_action_typeString

KeyRevocationActionType of the instance. Supported options are "STOP" and "NONE". The default value is "NONE" if it is not specified. Corresponds to the JSON property keyRevocationActionType

Returns:

  • (String)


26564
26565
26566
# File 'lib/google/apis/compute_alpha/classes.rb', line 26564

def key_revocation_action_type
  @key_revocation_action_type
end

#kindString

Output only. [Output Only] Type of the resource. Always compute#instance for instances. Corresponds to the JSON property kind

Returns:

  • (String)


26570
26571
26572
# File 'lib/google/apis/compute_alpha/classes.rb', line 26570

def kind
  @kind
end

#label_fingerprintString

A fingerprint for this request, which is essentially a hash of the label's contents and used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update labels. You must always provide an up-to-date fingerprint hash in order to update or change labels. To see the latest fingerprint, make get() request to the instance. Corresponds to the JSON property labelFingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


26582
26583
26584
# File 'lib/google/apis/compute_alpha/classes.rb', line 26582

def label_fingerprint
  @label_fingerprint
end

#labelsHash<String,String>

Labels to apply to this instance. These can be later modified by the setLabels method. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


26588
26589
26590
# File 'lib/google/apis/compute_alpha/classes.rb', line 26588

def labels
  @labels
end

#last_start_timestampString

Output only. [Output Only] Last start timestamp inRFC3339 text format. Corresponds to the JSON property lastStartTimestamp

Returns:

  • (String)


26593
26594
26595
# File 'lib/google/apis/compute_alpha/classes.rb', line 26593

def last_start_timestamp
  @last_start_timestamp
end

#last_stop_timestampString

Output only. [Output Only] Last stop timestamp inRFC3339 text format. Corresponds to the JSON property lastStopTimestamp

Returns:

  • (String)


26598
26599
26600
# File 'lib/google/apis/compute_alpha/classes.rb', line 26598

def last_stop_timestamp
  @last_stop_timestamp
end

#last_suspended_timestampString

Output only. [Output Only] Last suspended timestamp inRFC3339 text format. Corresponds to the JSON property lastSuspendedTimestamp

Returns:

  • (String)


26603
26604
26605
# File 'lib/google/apis/compute_alpha/classes.rb', line 26603

def last_suspended_timestamp
  @last_suspended_timestamp
end

#local_ssd_encryption_modeString

Specifies which method should be used for encrypting the Local SSDs attached to the VM. Corresponds to the JSON property localSsdEncryptionMode

Returns:

  • (String)


26609
26610
26611
# File 'lib/google/apis/compute_alpha/classes.rb', line 26609

def local_ssd_encryption_mode
  @local_ssd_encryption_mode
end

#machine_typeString

Full or partial URL of the machine type resource to use for this instance, in the format:zones/zone/machineTypes/machine-type. This is provided by the client when the instance is created. For example, the following is a valid partial url to a predefined machine type: zones/us-central1-f/machineTypes/n1-standard-1 To create acustom machine type, provide a URL to a machine type in the following format, where CPUS is 1 or an even number up to 32 (2, 4, 6, ... 24, etc), and MEMORY is the total memory for this instance. Memory must be a multiple of 256 MB and must be supplied in MB (e.g. 5 GB of memory is 5120 MB): zones/zone/machineTypes/custom-CPUS-MEMORY For example: zones/us-central1-f/machineTypes/custom-4-5120 For a full list of restrictions, read theSpecifications for custom machine types. Corresponds to the JSON property machineType

Returns:

  • (String)


26630
26631
26632
# File 'lib/google/apis/compute_alpha/classes.rb', line 26630

def machine_type
  @machine_type
end

#metadataGoogle::Apis::ComputeAlpha::Metadata

A metadata key/value entry. Corresponds to the JSON property metadata



26635
26636
26637
# File 'lib/google/apis/compute_alpha/classes.rb', line 26635

def 
  @metadata
end

#min_cpu_platformString

Specifies aminimum CPU platform for the VM instance. Applicable values are the friendly names of CPU platforms, such as minCpuPlatform: "Intel Haswell" or minCpuPlatform: "Intel Sandy Bridge". Corresponds to the JSON property minCpuPlatform

Returns:

  • (String)


26644
26645
26646
# File 'lib/google/apis/compute_alpha/classes.rb', line 26644

def min_cpu_platform
  @min_cpu_platform
end

#nameString

The name of the resource, provided by the client when initially creating the resource. The resource name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


26656
26657
26658
# File 'lib/google/apis/compute_alpha/classes.rb', line 26656

def name
  @name
end

#network_interfacesArray<Google::Apis::ComputeAlpha::NetworkInterface>

An array of network configurations for this instance. These specify how interfaces are configured to interact with other network services, such as connecting to the internet. Multiple interfaces are supported per instance. Corresponds to the JSON property networkInterfaces



26664
26665
26666
# File 'lib/google/apis/compute_alpha/classes.rb', line 26664

def network_interfaces
  @network_interfaces
end

#network_performance_configGoogle::Apis::ComputeAlpha::NetworkPerformanceConfig

Corresponds to the JSON property networkPerformanceConfig



26669
26670
26671
# File 'lib/google/apis/compute_alpha/classes.rb', line 26669

def network_performance_config
  @network_performance_config
end

#paramsGoogle::Apis::ComputeAlpha::InstanceParams

Additional instance params. Corresponds to the JSON property params



26674
26675
26676
# File 'lib/google/apis/compute_alpha/classes.rb', line 26674

def params
  @params
end

#partner_metadataHash<String,Google::Apis::ComputeAlpha::StructuredEntries>

Partner Metadata assigned to the instance. A map from a subdomain (namespace) to entries map. Corresponds to the JSON property partnerMetadata



26680
26681
26682
# File 'lib/google/apis/compute_alpha/classes.rb', line 26680

def 
  @partner_metadata
end

#post_key_revocation_action_typeString

PostKeyRevocationActionType of the instance. Corresponds to the JSON property postKeyRevocationActionType

Returns:

  • (String)


26685
26686
26687
# File 'lib/google/apis/compute_alpha/classes.rb', line 26685

def post_key_revocation_action_type
  @post_key_revocation_action_type
end

#preserved_state_size_gbFixnum

Output only. Total amount of preserved state for SUSPENDED instances. Read-only in the api. Corresponds to the JSON property preservedStateSizeGb

Returns:

  • (Fixnum)


26691
26692
26693
# File 'lib/google/apis/compute_alpha/classes.rb', line 26691

def preserved_state_size_gb
  @preserved_state_size_gb
end

#private_ipv6_google_accessString

The private IPv6 google access type for the VM. If not specified, use INHERIT_FROM_SUBNETWORK as default. Corresponds to the JSON property privateIpv6GoogleAccess

Returns:

  • (String)


26697
26698
26699
# File 'lib/google/apis/compute_alpha/classes.rb', line 26697

def private_ipv6_google_access
  @private_ipv6_google_access
end

#reservation_affinityGoogle::Apis::ComputeAlpha::ReservationAffinity

Specifies the reservations that this instance can consume from. Corresponds to the JSON property reservationAffinity



26702
26703
26704
# File 'lib/google/apis/compute_alpha/classes.rb', line 26702

def reservation_affinity
  @reservation_affinity
end

#resource_policiesArray<String>

Resource policies applied to this instance. Corresponds to the JSON property resourcePolicies

Returns:

  • (Array<String>)


26707
26708
26709
# File 'lib/google/apis/compute_alpha/classes.rb', line 26707

def resource_policies
  @resource_policies
end

#resource_statusGoogle::Apis::ComputeAlpha::ResourceStatus

Contains output only fields. Use this sub-message for actual values set on Instance attributes as compared to the value requested by the user (intent) in their instance CRUD calls. Corresponds to the JSON property resourceStatus



26714
26715
26716
# File 'lib/google/apis/compute_alpha/classes.rb', line 26714

def resource_status
  @resource_status
end

#satisfies_pziBoolean Also known as: satisfies_pzi?

Output only. [Output Only] Reserved for future use. Corresponds to the JSON property satisfiesPzi

Returns:

  • (Boolean)


26719
26720
26721
# File 'lib/google/apis/compute_alpha/classes.rb', line 26719

def satisfies_pzi
  @satisfies_pzi
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

Output only. [Output Only] Reserved for future use. Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


26725
26726
26727
# File 'lib/google/apis/compute_alpha/classes.rb', line 26725

def satisfies_pzs
  @satisfies_pzs
end

#schedulingGoogle::Apis::ComputeAlpha::Scheduling

Sets the scheduling options for an Instance. Corresponds to the JSON property scheduling



26731
26732
26733
# File 'lib/google/apis/compute_alpha/classes.rb', line 26731

def scheduling
  @scheduling
end

#secure_tagsArray<String>

[Input Only] Secure tags to apply to this instance. These can be later modified by the update method. Maximum number of secure tags allowed is 50. Corresponds to the JSON property secureTags

Returns:

  • (Array<String>)


26738
26739
26740
# File 'lib/google/apis/compute_alpha/classes.rb', line 26738

def secure_tags
  @secure_tags
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


26743
26744
26745
# File 'lib/google/apis/compute_alpha/classes.rb', line 26743

def self_link
  @self_link
end

Output only. [Output Only] Server-defined URL for this resource with the resource id. Corresponds to the JSON property selfLinkWithId

Returns:

  • (String)


26749
26750
26751
# File 'lib/google/apis/compute_alpha/classes.rb', line 26749

def self_link_with_id
  @self_link_with_id
end

#service_accountsArray<Google::Apis::ComputeAlpha::ServiceAccount>

A list of service accounts, with their specified scopes, authorized for this instance. Only one service account per VM instance is supported. Service accounts generate access tokens that can be accessed through the metadata server and used to authenticate applications on the instance. SeeService Accounts for more information. Corresponds to the JSON property serviceAccounts



26759
26760
26761
# File 'lib/google/apis/compute_alpha/classes.rb', line 26759

def service_accounts
  @service_accounts
end

#service_integration_specsHash<String,Google::Apis::ComputeAlpha::ServiceIntegrationSpec>

Mapping of user-defined keys to specifications for service integrations. Currently only a single key-value pair is supported. Corresponds to the JSON property serviceIntegrationSpecs



26765
26766
26767
# File 'lib/google/apis/compute_alpha/classes.rb', line 26765

def service_integration_specs
  @service_integration_specs
end

#shielded_instance_configGoogle::Apis::ComputeAlpha::ShieldedInstanceConfig

A set of Shielded Instance options. Corresponds to the JSON property shieldedInstanceConfig



26770
26771
26772
# File 'lib/google/apis/compute_alpha/classes.rb', line 26770

def shielded_instance_config
  @shielded_instance_config
end

#shielded_instance_integrity_policyGoogle::Apis::ComputeAlpha::ShieldedInstanceIntegrityPolicy

The policy describes the baseline against which Instance boot integrity is measured. Corresponds to the JSON property shieldedInstanceIntegrityPolicy



26776
26777
26778
# File 'lib/google/apis/compute_alpha/classes.rb', line 26776

def shielded_instance_integrity_policy
  @shielded_instance_integrity_policy
end

#shielded_vm_configGoogle::Apis::ComputeAlpha::ShieldedVmConfig

A set of Shielded VM options. Corresponds to the JSON property shieldedVmConfig



26781
26782
26783
# File 'lib/google/apis/compute_alpha/classes.rb', line 26781

def shielded_vm_config
  @shielded_vm_config
end

#shielded_vm_integrity_policyGoogle::Apis::ComputeAlpha::ShieldedVmIntegrityPolicy

The policy describes the baseline against which VM instance boot integrity is measured. Corresponds to the JSON property shieldedVmIntegrityPolicy



26787
26788
26789
# File 'lib/google/apis/compute_alpha/classes.rb', line 26787

def shielded_vm_integrity_policy
  @shielded_vm_integrity_policy
end

#source_machine_imageString

Source machine image Corresponds to the JSON property sourceMachineImage

Returns:

  • (String)


26792
26793
26794
# File 'lib/google/apis/compute_alpha/classes.rb', line 26792

def source_machine_image
  @source_machine_image
end

#source_machine_image_encryption_keyGoogle::Apis::ComputeAlpha::CustomerEncryptionKey

Source machine image encryption key when creating an instance from a machine image. Corresponds to the JSON property sourceMachineImageEncryptionKey



26798
26799
26800
# File 'lib/google/apis/compute_alpha/classes.rb', line 26798

def source_machine_image_encryption_key
  @source_machine_image_encryption_key
end

#start_restrictedBoolean Also known as: start_restricted?

Output only. [Output Only] Whether a VM has been restricted for start because Compute Engine has detected suspicious activity. Corresponds to the JSON property startRestricted

Returns:

  • (Boolean)


26805
26806
26807
# File 'lib/google/apis/compute_alpha/classes.rb', line 26805

def start_restricted
  @start_restricted
end

#statusString

Output only. [Output Only] The status of the instance. One of the following values: PROVISIONING, STAGING,RUNNING, STOPPING, SUSPENDING, SUSPENDED, REPAIRING, andTERMINATED. For more information about the status of the instance, see Instance life cycle. Corresponds to the JSON property status

Returns:

  • (String)


26816
26817
26818
# File 'lib/google/apis/compute_alpha/classes.rb', line 26816

def status
  @status
end

#status_messageString

Output only. [Output Only] An optional, human-readable explanation of the status. Corresponds to the JSON property statusMessage

Returns:

  • (String)


26822
26823
26824
# File 'lib/google/apis/compute_alpha/classes.rb', line 26822

def status_message
  @status_message
end

#tagsGoogle::Apis::ComputeAlpha::Tags

A set of instance tags. Corresponds to the JSON property tags



26827
26828
26829
# File 'lib/google/apis/compute_alpha/classes.rb', line 26827

def tags
  @tags
end

#upcoming_maintenanceGoogle::Apis::ComputeAlpha::UpcomingMaintenance

Upcoming Maintenance notification information. Corresponds to the JSON property upcomingMaintenance



26832
26833
26834
# File 'lib/google/apis/compute_alpha/classes.rb', line 26832

def upcoming_maintenance
  @upcoming_maintenance
end

#workload_identity_configGoogle::Apis::ComputeAlpha::WorkloadIdentityConfig

Corresponds to the JSON property workloadIdentityConfig



26837
26838
26839
# File 'lib/google/apis/compute_alpha/classes.rb', line 26837

def workload_identity_config
  @workload_identity_config
end

#zoneString

Output only. [Output Only] URL of the zone where the instance resides. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body. Corresponds to the JSON property zone

Returns:

  • (String)


26844
26845
26846
# File 'lib/google/apis/compute_alpha/classes.rb', line 26844

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



26851
26852
26853
26854
26855
26856
26857
26858
26859
26860
26861
26862
26863
26864
26865
26866
26867
26868
26869
26870
26871
26872
26873
26874
26875
26876
26877
26878
26879
26880
26881
26882
26883
26884
26885
26886
26887
26888
26889
26890
26891
26892
26893
26894
26895
26896
26897
26898
26899
26900
26901
26902
26903
26904
26905
26906
26907
26908
26909
26910
26911
26912
# File 'lib/google/apis/compute_alpha/classes.rb', line 26851

def update!(**args)
  @advanced_machine_features = args[:advanced_machine_features] if args.key?(:advanced_machine_features)
  @can_ip_forward = args[:can_ip_forward] if args.key?(:can_ip_forward)
  @confidential_instance_config = args[:confidential_instance_config] if args.key?(:confidential_instance_config)
  @cpu_platform = args[:cpu_platform] if args.key?(:cpu_platform)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @deletion_protection = args[:deletion_protection] if args.key?(:deletion_protection)
  @description = args[:description] if args.key?(:description)
  @disks = args[:disks] if args.key?(:disks)
  @display_device = args[:display_device] if args.key?(:display_device)
  @erase_windows_vss_signature = args[:erase_windows_vss_signature] if args.key?(:erase_windows_vss_signature)
  @fingerprint = args[:fingerprint] if args.key?(:fingerprint)
  @guest_accelerators = args[:guest_accelerators] if args.key?(:guest_accelerators)
  @hostname = args[:hostname] if args.key?(:hostname)
  @id = args[:id] if args.key?(:id)
  @identity = args[:identity] if args.key?(:identity)
  @identity_certificate = args[:identity_certificate] if args.key?(:identity_certificate)
  @instance_encryption_key = args[:instance_encryption_key] if args.key?(:instance_encryption_key)
  @key_revocation_action_type = args[:key_revocation_action_type] if args.key?(:key_revocation_action_type)
  @kind = args[:kind] if args.key?(:kind)
  @label_fingerprint = args[:label_fingerprint] if args.key?(:label_fingerprint)
  @labels = args[:labels] if args.key?(:labels)
  @last_start_timestamp = args[:last_start_timestamp] if args.key?(:last_start_timestamp)
  @last_stop_timestamp = args[:last_stop_timestamp] if args.key?(:last_stop_timestamp)
  @last_suspended_timestamp = args[:last_suspended_timestamp] if args.key?(:last_suspended_timestamp)
  @local_ssd_encryption_mode = args[:local_ssd_encryption_mode] if args.key?(:local_ssd_encryption_mode)
  @machine_type = args[:machine_type] if args.key?(:machine_type)
  @metadata = args[:metadata] if args.key?(:metadata)
  @min_cpu_platform = args[:min_cpu_platform] if args.key?(:min_cpu_platform)
  @name = args[:name] if args.key?(:name)
  @network_interfaces = args[:network_interfaces] if args.key?(:network_interfaces)
  @network_performance_config = args[:network_performance_config] if args.key?(:network_performance_config)
  @params = args[:params] if args.key?(:params)
  @partner_metadata = args[:partner_metadata] if args.key?(:partner_metadata)
  @post_key_revocation_action_type = args[:post_key_revocation_action_type] if args.key?(:post_key_revocation_action_type)
  @preserved_state_size_gb = args[:preserved_state_size_gb] if args.key?(:preserved_state_size_gb)
  @private_ipv6_google_access = args[:private_ipv6_google_access] if args.key?(:private_ipv6_google_access)
  @reservation_affinity = args[:reservation_affinity] if args.key?(:reservation_affinity)
  @resource_policies = args[:resource_policies] if args.key?(:resource_policies)
  @resource_status = args[:resource_status] if args.key?(:resource_status)
  @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @scheduling = args[:scheduling] if args.key?(:scheduling)
  @secure_tags = args[:secure_tags] if args.key?(:secure_tags)
  @self_link = args[:self_link] if args.key?(:self_link)
  @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id)
  @service_accounts = args[:service_accounts] if args.key?(:service_accounts)
  @service_integration_specs = args[:service_integration_specs] if args.key?(:service_integration_specs)
  @shielded_instance_config = args[:shielded_instance_config] if args.key?(:shielded_instance_config)
  @shielded_instance_integrity_policy = args[:shielded_instance_integrity_policy] if args.key?(:shielded_instance_integrity_policy)
  @shielded_vm_config = args[:shielded_vm_config] if args.key?(:shielded_vm_config)
  @shielded_vm_integrity_policy = args[:shielded_vm_integrity_policy] if args.key?(:shielded_vm_integrity_policy)
  @source_machine_image = args[:source_machine_image] if args.key?(:source_machine_image)
  @source_machine_image_encryption_key = args[:source_machine_image_encryption_key] if args.key?(:source_machine_image_encryption_key)
  @start_restricted = args[:start_restricted] if args.key?(:start_restricted)
  @status = args[:status] if args.key?(:status)
  @status_message = args[:status_message] if args.key?(:status_message)
  @tags = args[:tags] if args.key?(:tags)
  @upcoming_maintenance = args[:upcoming_maintenance] if args.key?(:upcoming_maintenance)
  @workload_identity_config = args[:workload_identity_config] if args.key?(:workload_identity_config)
  @zone = args[:zone] if args.key?(:zone)
end