Class: Google::Apis::ComputeAlpha::Instance

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Represents an Instance resource. An instance is a virtual machine that is hosted on Google Cloud Platform. For more information, readVirtual Machine Instances.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Instance

Returns a new instance of Instance.



26104
26105
26106
# File 'lib/google/apis/compute_alpha/classes.rb', line 26104

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#advanced_machine_featuresGoogle::Apis::ComputeAlpha::AdvancedMachineFeatures

Specifies options for controlling advanced machine features. Options that would traditionally be configured in a BIOS belong here. Features that require operating system support may have corresponding entries in the GuestOsFeatures of anImage (e.g., whether or not the OS in theImage supports nested virtualization being enabled or disabled). Corresponds to the JSON property advancedMachineFeatures



25715
25716
25717
# File 'lib/google/apis/compute_alpha/classes.rb', line 25715

def advanced_machine_features
  @advanced_machine_features
end

#can_ip_forwardBoolean Also known as: can_ip_forward?

Allows this instance to send and receive packets with non-matching destination or source IPs. This is required if you plan to use this instance to forward routes. For more information, seeEnabling IP Forwarding. Corresponds to the JSON property canIpForward

Returns:

  • (Boolean)


25722
25723
25724
# File 'lib/google/apis/compute_alpha/classes.rb', line 25722

def can_ip_forward
  @can_ip_forward
end

#confidential_instance_configGoogle::Apis::ComputeAlpha::ConfidentialInstanceConfig

A set of Confidential Instance options. Corresponds to the JSON property confidentialInstanceConfig



25728
25729
25730
# File 'lib/google/apis/compute_alpha/classes.rb', line 25728

def confidential_instance_config
  @confidential_instance_config
end

#cpu_platformString

Output only. [Output Only] The CPU platform used by this instance. Corresponds to the JSON property cpuPlatform

Returns:

  • (String)


25733
25734
25735
# File 'lib/google/apis/compute_alpha/classes.rb', line 25733

def cpu_platform
  @cpu_platform
end

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


25738
25739
25740
# File 'lib/google/apis/compute_alpha/classes.rb', line 25738

def creation_timestamp
  @creation_timestamp
end

#deletion_protectionBoolean Also known as: deletion_protection?

Whether the resource should be protected against deletion. Corresponds to the JSON property deletionProtection

Returns:

  • (Boolean)


25743
25744
25745
# File 'lib/google/apis/compute_alpha/classes.rb', line 25743

def deletion_protection
  @deletion_protection
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


25750
25751
25752
# File 'lib/google/apis/compute_alpha/classes.rb', line 25750

def description
  @description
end

#disksArray<Google::Apis::ComputeAlpha::AttachedDisk>

Array of disks associated with this instance. Persistent disks must be created before you can assign them. Corresponds to the JSON property disks



25756
25757
25758
# File 'lib/google/apis/compute_alpha/classes.rb', line 25756

def disks
  @disks
end

#display_deviceGoogle::Apis::ComputeAlpha::DisplayDevice

A set of Display Device options Corresponds to the JSON property displayDevice



25761
25762
25763
# File 'lib/google/apis/compute_alpha/classes.rb', line 25761

def display_device
  @display_device
end

#erase_windows_vss_signatureBoolean Also known as: erase_windows_vss_signature?

Specifies whether the disks restored from source snapshots or source machine image should erase Windows specific VSS signature. Corresponds to the JSON property eraseWindowsVssSignature

Returns:

  • (Boolean)


25767
25768
25769
# File 'lib/google/apis/compute_alpha/classes.rb', line 25767

def erase_windows_vss_signature
  @erase_windows_vss_signature
end

#fingerprintString

Specifies a fingerprint for this resource, which is essentially a hash of the instance's contents and used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update the instance. You must always provide an up-to-date fingerprint hash in order to update the instance. To see the latest fingerprint, make get() request to the instance. Corresponds to the JSON property fingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


25780
25781
25782
# File 'lib/google/apis/compute_alpha/classes.rb', line 25780

def fingerprint
  @fingerprint
end

#guest_acceleratorsArray<Google::Apis::ComputeAlpha::AcceleratorConfig>

A list of the type and count of accelerator cards attached to the instance. Corresponds to the JSON property guestAccelerators



25785
25786
25787
# File 'lib/google/apis/compute_alpha/classes.rb', line 25785

def guest_accelerators
  @guest_accelerators
end

#hostnameString

Specifies the hostname of the instance. The specified hostname must be RFC1035 compliant. If hostname is not specified, the default hostname is [INSTANCE_NAME].c.[PROJECT_ID].internal when using the global DNS, and [INSTANCE_NAME].[ZONE].c.[PROJECT_ID].internal when using zonal DNS. Corresponds to the JSON property hostname

Returns:

  • (String)


25793
25794
25795
# File 'lib/google/apis/compute_alpha/classes.rb', line 25793

def hostname
  @hostname
end

#idFixnum

Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


25800
25801
25802
# File 'lib/google/apis/compute_alpha/classes.rb', line 25800

def id
  @id
end

#identityString

Corresponds to the JSON property identity

Returns:

  • (String)


25805
25806
25807
# File 'lib/google/apis/compute_alpha/classes.rb', line 25805

def identity
  @identity
end

#identity_certificateBoolean Also known as: identity_certificate?

Corresponds to the JSON property identityCertificate

Returns:

  • (Boolean)


25810
25811
25812
# File 'lib/google/apis/compute_alpha/classes.rb', line 25810

def identity_certificate
  @identity_certificate
end

#instance_encryption_keyGoogle::Apis::ComputeAlpha::CustomerEncryptionKey

Encrypts suspended data for an instance with acustomer-managed encryption key. If you are creating a new instance, this field will encrypt the local SSD and in-memory contents of the instance during the suspend operation. If you do not provide an encryption key when creating the instance, then the local SSD and in-memory contents will be encrypted using an automatically generated key during the suspend operation. Corresponds to the JSON property instanceEncryptionKey



25822
25823
25824
# File 'lib/google/apis/compute_alpha/classes.rb', line 25822

def instance_encryption_key
  @instance_encryption_key
end

#key_revocation_action_typeString

KeyRevocationActionType of the instance. Supported options are "STOP" and "NONE". The default value is "NONE" if it is not specified. Corresponds to the JSON property keyRevocationActionType

Returns:

  • (String)


25828
25829
25830
# File 'lib/google/apis/compute_alpha/classes.rb', line 25828

def key_revocation_action_type
  @key_revocation_action_type
end

#kindString

Output only. [Output Only] Type of the resource. Always compute#instance for instances. Corresponds to the JSON property kind

Returns:

  • (String)


25834
25835
25836
# File 'lib/google/apis/compute_alpha/classes.rb', line 25834

def kind
  @kind
end

#label_fingerprintString

A fingerprint for this request, which is essentially a hash of the label's contents and used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update labels. You must always provide an up-to-date fingerprint hash in order to update or change labels. To see the latest fingerprint, make get() request to the instance. Corresponds to the JSON property labelFingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


25846
25847
25848
# File 'lib/google/apis/compute_alpha/classes.rb', line 25846

def label_fingerprint
  @label_fingerprint
end

#labelsHash<String,String>

Labels to apply to this instance. These can be later modified by the setLabels method. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


25852
25853
25854
# File 'lib/google/apis/compute_alpha/classes.rb', line 25852

def labels
  @labels
end

#last_start_timestampString

Output only. [Output Only] Last start timestamp inRFC3339 text format. Corresponds to the JSON property lastStartTimestamp

Returns:

  • (String)


25857
25858
25859
# File 'lib/google/apis/compute_alpha/classes.rb', line 25857

def last_start_timestamp
  @last_start_timestamp
end

#last_stop_timestampString

Output only. [Output Only] Last stop timestamp inRFC3339 text format. Corresponds to the JSON property lastStopTimestamp

Returns:

  • (String)


25862
25863
25864
# File 'lib/google/apis/compute_alpha/classes.rb', line 25862

def last_stop_timestamp
  @last_stop_timestamp
end

#last_suspended_timestampString

Output only. [Output Only] Last suspended timestamp inRFC3339 text format. Corresponds to the JSON property lastSuspendedTimestamp

Returns:

  • (String)


25867
25868
25869
# File 'lib/google/apis/compute_alpha/classes.rb', line 25867

def last_suspended_timestamp
  @last_suspended_timestamp
end

#machine_typeString

Full or partial URL of the machine type resource to use for this instance, in the format:zones/zone/machineTypes/machine-type. This is provided by the client when the instance is created. For example, the following is a valid partial url to a predefined machine type: zones/us-central1-f/machineTypes/n1-standard-1 To create acustom machine type, provide a URL to a machine type in the following format, where CPUS is 1 or an even number up to 32 (2, 4, 6, ... 24, etc), and MEMORY is the total memory for this instance. Memory must be a multiple of 256 MB and must be supplied in MB (e.g. 5 GB of memory is 5120 MB): zones/zone/machineTypes/custom-CPUS-MEMORY For example: zones/us-central1-f/machineTypes/custom-4-5120 For a full list of restrictions, read theSpecifications for custom machine types. Corresponds to the JSON property machineType

Returns:

  • (String)


25888
25889
25890
# File 'lib/google/apis/compute_alpha/classes.rb', line 25888

def machine_type
  @machine_type
end

#metadataGoogle::Apis::ComputeAlpha::Metadata

A metadata key/value entry. Corresponds to the JSON property metadata



25893
25894
25895
# File 'lib/google/apis/compute_alpha/classes.rb', line 25893

def 
  @metadata
end

#min_cpu_platformString

Specifies aminimum CPU platform for the VM instance. Applicable values are the friendly names of CPU platforms, such as minCpuPlatform: "Intel Haswell" or minCpuPlatform: "Intel Sandy Bridge". Corresponds to the JSON property minCpuPlatform

Returns:

  • (String)


25902
25903
25904
# File 'lib/google/apis/compute_alpha/classes.rb', line 25902

def min_cpu_platform
  @min_cpu_platform
end

#nameString

The name of the resource, provided by the client when initially creating the resource. The resource name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


25914
25915
25916
# File 'lib/google/apis/compute_alpha/classes.rb', line 25914

def name
  @name
end

#network_interfacesArray<Google::Apis::ComputeAlpha::NetworkInterface>

An array of network configurations for this instance. These specify how interfaces are configured to interact with other network services, such as connecting to the internet. Multiple interfaces are supported per instance. Corresponds to the JSON property networkInterfaces



25922
25923
25924
# File 'lib/google/apis/compute_alpha/classes.rb', line 25922

def network_interfaces
  @network_interfaces
end

#network_performance_configGoogle::Apis::ComputeAlpha::NetworkPerformanceConfig

Corresponds to the JSON property networkPerformanceConfig



25927
25928
25929
# File 'lib/google/apis/compute_alpha/classes.rb', line 25927

def network_performance_config
  @network_performance_config
end

#paramsGoogle::Apis::ComputeAlpha::InstanceParams

Additional instance params. Corresponds to the JSON property params



25932
25933
25934
# File 'lib/google/apis/compute_alpha/classes.rb', line 25932

def params
  @params
end

#partner_metadataHash<String,Google::Apis::ComputeAlpha::StructuredEntries>

Partner Metadata assigned to the instance. A map from a subdomain (namespace) to entries map. Corresponds to the JSON property partnerMetadata



25938
25939
25940
# File 'lib/google/apis/compute_alpha/classes.rb', line 25938

def 
  @partner_metadata
end

#post_key_revocation_action_typeString

PostKeyRevocationActionType of the instance. Corresponds to the JSON property postKeyRevocationActionType

Returns:

  • (String)


25943
25944
25945
# File 'lib/google/apis/compute_alpha/classes.rb', line 25943

def post_key_revocation_action_type
  @post_key_revocation_action_type
end

#preserved_state_size_gbFixnum

Output only. Total amount of preserved state for SUSPENDED instances. Read-only in the api. Corresponds to the JSON property preservedStateSizeGb

Returns:

  • (Fixnum)


25949
25950
25951
# File 'lib/google/apis/compute_alpha/classes.rb', line 25949

def preserved_state_size_gb
  @preserved_state_size_gb
end

#private_ipv6_google_accessString

The private IPv6 google access type for the VM. If not specified, use INHERIT_FROM_SUBNETWORK as default. Corresponds to the JSON property privateIpv6GoogleAccess

Returns:

  • (String)


25955
25956
25957
# File 'lib/google/apis/compute_alpha/classes.rb', line 25955

def private_ipv6_google_access
  @private_ipv6_google_access
end

#reservation_affinityGoogle::Apis::ComputeAlpha::ReservationAffinity

Specifies the reservations that this instance can consume from. Corresponds to the JSON property reservationAffinity



25960
25961
25962
# File 'lib/google/apis/compute_alpha/classes.rb', line 25960

def reservation_affinity
  @reservation_affinity
end

#resource_policiesArray<String>

Resource policies applied to this instance. Corresponds to the JSON property resourcePolicies

Returns:

  • (Array<String>)


25965
25966
25967
# File 'lib/google/apis/compute_alpha/classes.rb', line 25965

def resource_policies
  @resource_policies
end

#resource_statusGoogle::Apis::ComputeAlpha::ResourceStatus

Contains output only fields. Use this sub-message for actual values set on Instance attributes as compared to the value requested by the user (intent) in their instance CRUD calls. Corresponds to the JSON property resourceStatus



25972
25973
25974
# File 'lib/google/apis/compute_alpha/classes.rb', line 25972

def resource_status
  @resource_status
end

#satisfies_pziBoolean Also known as: satisfies_pzi?

Output only. [Output Only] Reserved for future use. Corresponds to the JSON property satisfiesPzi

Returns:

  • (Boolean)


25977
25978
25979
# File 'lib/google/apis/compute_alpha/classes.rb', line 25977

def satisfies_pzi
  @satisfies_pzi
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

Output only. [Output Only] Reserved for future use. Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


25983
25984
25985
# File 'lib/google/apis/compute_alpha/classes.rb', line 25983

def satisfies_pzs
  @satisfies_pzs
end

#schedulingGoogle::Apis::ComputeAlpha::Scheduling

Sets the scheduling options for an Instance. Corresponds to the JSON property scheduling



25989
25990
25991
# File 'lib/google/apis/compute_alpha/classes.rb', line 25989

def scheduling
  @scheduling
end

#secure_tagsArray<String>

[Input Only] Secure tags to apply to this instance. These can be later modified by the update method. Maximum number of secure tags allowed is 50. Corresponds to the JSON property secureTags

Returns:

  • (Array<String>)


25996
25997
25998
# File 'lib/google/apis/compute_alpha/classes.rb', line 25996

def secure_tags
  @secure_tags
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


26001
26002
26003
# File 'lib/google/apis/compute_alpha/classes.rb', line 26001

def self_link
  @self_link
end

Output only. [Output Only] Server-defined URL for this resource with the resource id. Corresponds to the JSON property selfLinkWithId

Returns:

  • (String)


26007
26008
26009
# File 'lib/google/apis/compute_alpha/classes.rb', line 26007

def self_link_with_id
  @self_link_with_id
end

#service_accountsArray<Google::Apis::ComputeAlpha::ServiceAccount>

A list of service accounts, with their specified scopes, authorized for this instance. Only one service account per VM instance is supported. Service accounts generate access tokens that can be accessed through the metadata server and used to authenticate applications on the instance. SeeService Accounts for more information. Corresponds to the JSON property serviceAccounts



26017
26018
26019
# File 'lib/google/apis/compute_alpha/classes.rb', line 26017

def service_accounts
  @service_accounts
end

#service_integration_specsHash<String,Google::Apis::ComputeAlpha::ServiceIntegrationSpec>

Mapping of user-defined keys to specifications for service integrations. Currently only a single key-value pair is supported. Corresponds to the JSON property serviceIntegrationSpecs



26023
26024
26025
# File 'lib/google/apis/compute_alpha/classes.rb', line 26023

def service_integration_specs
  @service_integration_specs
end

#shielded_instance_configGoogle::Apis::ComputeAlpha::ShieldedInstanceConfig

A set of Shielded Instance options. Corresponds to the JSON property shieldedInstanceConfig



26028
26029
26030
# File 'lib/google/apis/compute_alpha/classes.rb', line 26028

def shielded_instance_config
  @shielded_instance_config
end

#shielded_instance_integrity_policyGoogle::Apis::ComputeAlpha::ShieldedInstanceIntegrityPolicy

The policy describes the baseline against which Instance boot integrity is measured. Corresponds to the JSON property shieldedInstanceIntegrityPolicy



26034
26035
26036
# File 'lib/google/apis/compute_alpha/classes.rb', line 26034

def shielded_instance_integrity_policy
  @shielded_instance_integrity_policy
end

#shielded_vm_configGoogle::Apis::ComputeAlpha::ShieldedVmConfig

A set of Shielded VM options. Corresponds to the JSON property shieldedVmConfig



26039
26040
26041
# File 'lib/google/apis/compute_alpha/classes.rb', line 26039

def shielded_vm_config
  @shielded_vm_config
end

#shielded_vm_integrity_policyGoogle::Apis::ComputeAlpha::ShieldedVmIntegrityPolicy

The policy describes the baseline against which VM instance boot integrity is measured. Corresponds to the JSON property shieldedVmIntegrityPolicy



26045
26046
26047
# File 'lib/google/apis/compute_alpha/classes.rb', line 26045

def shielded_vm_integrity_policy
  @shielded_vm_integrity_policy
end

#source_machine_imageString

Source machine image Corresponds to the JSON property sourceMachineImage

Returns:

  • (String)


26050
26051
26052
# File 'lib/google/apis/compute_alpha/classes.rb', line 26050

def source_machine_image
  @source_machine_image
end

#source_machine_image_encryption_keyGoogle::Apis::ComputeAlpha::CustomerEncryptionKey

Source machine image encryption key when creating an instance from a machine image. Corresponds to the JSON property sourceMachineImageEncryptionKey



26056
26057
26058
# File 'lib/google/apis/compute_alpha/classes.rb', line 26056

def source_machine_image_encryption_key
  @source_machine_image_encryption_key
end

#start_restrictedBoolean Also known as: start_restricted?

Output only. [Output Only] Whether a VM has been restricted for start because Compute Engine has detected suspicious activity. Corresponds to the JSON property startRestricted

Returns:

  • (Boolean)


26063
26064
26065
# File 'lib/google/apis/compute_alpha/classes.rb', line 26063

def start_restricted
  @start_restricted
end

#statusString

Output only. [Output Only] The status of the instance. One of the following values: PROVISIONING, STAGING,RUNNING, STOPPING, SUSPENDING, SUSPENDED, REPAIRING, andTERMINATED. For more information about the status of the instance, see Instance life cycle. Corresponds to the JSON property status

Returns:

  • (String)


26074
26075
26076
# File 'lib/google/apis/compute_alpha/classes.rb', line 26074

def status
  @status
end

#status_messageString

Output only. [Output Only] An optional, human-readable explanation of the status. Corresponds to the JSON property statusMessage

Returns:

  • (String)


26080
26081
26082
# File 'lib/google/apis/compute_alpha/classes.rb', line 26080

def status_message
  @status_message
end

#tagsGoogle::Apis::ComputeAlpha::Tags

A set of instance tags. Corresponds to the JSON property tags



26085
26086
26087
# File 'lib/google/apis/compute_alpha/classes.rb', line 26085

def tags
  @tags
end

#upcoming_maintenanceGoogle::Apis::ComputeAlpha::UpcomingMaintenance

Upcoming Maintenance notification information. Corresponds to the JSON property upcomingMaintenance



26090
26091
26092
# File 'lib/google/apis/compute_alpha/classes.rb', line 26090

def upcoming_maintenance
  @upcoming_maintenance
end

#workload_identity_configGoogle::Apis::ComputeAlpha::WorkloadIdentityConfig

Corresponds to the JSON property workloadIdentityConfig



26095
26096
26097
# File 'lib/google/apis/compute_alpha/classes.rb', line 26095

def workload_identity_config
  @workload_identity_config
end

#zoneString

Output only. [Output Only] URL of the zone where the instance resides. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body. Corresponds to the JSON property zone

Returns:

  • (String)


26102
26103
26104
# File 'lib/google/apis/compute_alpha/classes.rb', line 26102

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



26109
26110
26111
26112
26113
26114
26115
26116
26117
26118
26119
26120
26121
26122
26123
26124
26125
26126
26127
26128
26129
26130
26131
26132
26133
26134
26135
26136
26137
26138
26139
26140
26141
26142
26143
26144
26145
26146
26147
26148
26149
26150
26151
26152
26153
26154
26155
26156
26157
26158
26159
26160
26161
26162
26163
26164
26165
26166
26167
26168
26169
# File 'lib/google/apis/compute_alpha/classes.rb', line 26109

def update!(**args)
  @advanced_machine_features = args[:advanced_machine_features] if args.key?(:advanced_machine_features)
  @can_ip_forward = args[:can_ip_forward] if args.key?(:can_ip_forward)
  @confidential_instance_config = args[:confidential_instance_config] if args.key?(:confidential_instance_config)
  @cpu_platform = args[:cpu_platform] if args.key?(:cpu_platform)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @deletion_protection = args[:deletion_protection] if args.key?(:deletion_protection)
  @description = args[:description] if args.key?(:description)
  @disks = args[:disks] if args.key?(:disks)
  @display_device = args[:display_device] if args.key?(:display_device)
  @erase_windows_vss_signature = args[:erase_windows_vss_signature] if args.key?(:erase_windows_vss_signature)
  @fingerprint = args[:fingerprint] if args.key?(:fingerprint)
  @guest_accelerators = args[:guest_accelerators] if args.key?(:guest_accelerators)
  @hostname = args[:hostname] if args.key?(:hostname)
  @id = args[:id] if args.key?(:id)
  @identity = args[:identity] if args.key?(:identity)
  @identity_certificate = args[:identity_certificate] if args.key?(:identity_certificate)
  @instance_encryption_key = args[:instance_encryption_key] if args.key?(:instance_encryption_key)
  @key_revocation_action_type = args[:key_revocation_action_type] if args.key?(:key_revocation_action_type)
  @kind = args[:kind] if args.key?(:kind)
  @label_fingerprint = args[:label_fingerprint] if args.key?(:label_fingerprint)
  @labels = args[:labels] if args.key?(:labels)
  @last_start_timestamp = args[:last_start_timestamp] if args.key?(:last_start_timestamp)
  @last_stop_timestamp = args[:last_stop_timestamp] if args.key?(:last_stop_timestamp)
  @last_suspended_timestamp = args[:last_suspended_timestamp] if args.key?(:last_suspended_timestamp)
  @machine_type = args[:machine_type] if args.key?(:machine_type)
  @metadata = args[:metadata] if args.key?(:metadata)
  @min_cpu_platform = args[:min_cpu_platform] if args.key?(:min_cpu_platform)
  @name = args[:name] if args.key?(:name)
  @network_interfaces = args[:network_interfaces] if args.key?(:network_interfaces)
  @network_performance_config = args[:network_performance_config] if args.key?(:network_performance_config)
  @params = args[:params] if args.key?(:params)
  @partner_metadata = args[:partner_metadata] if args.key?(:partner_metadata)
  @post_key_revocation_action_type = args[:post_key_revocation_action_type] if args.key?(:post_key_revocation_action_type)
  @preserved_state_size_gb = args[:preserved_state_size_gb] if args.key?(:preserved_state_size_gb)
  @private_ipv6_google_access = args[:private_ipv6_google_access] if args.key?(:private_ipv6_google_access)
  @reservation_affinity = args[:reservation_affinity] if args.key?(:reservation_affinity)
  @resource_policies = args[:resource_policies] if args.key?(:resource_policies)
  @resource_status = args[:resource_status] if args.key?(:resource_status)
  @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @scheduling = args[:scheduling] if args.key?(:scheduling)
  @secure_tags = args[:secure_tags] if args.key?(:secure_tags)
  @self_link = args[:self_link] if args.key?(:self_link)
  @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id)
  @service_accounts = args[:service_accounts] if args.key?(:service_accounts)
  @service_integration_specs = args[:service_integration_specs] if args.key?(:service_integration_specs)
  @shielded_instance_config = args[:shielded_instance_config] if args.key?(:shielded_instance_config)
  @shielded_instance_integrity_policy = args[:shielded_instance_integrity_policy] if args.key?(:shielded_instance_integrity_policy)
  @shielded_vm_config = args[:shielded_vm_config] if args.key?(:shielded_vm_config)
  @shielded_vm_integrity_policy = args[:shielded_vm_integrity_policy] if args.key?(:shielded_vm_integrity_policy)
  @source_machine_image = args[:source_machine_image] if args.key?(:source_machine_image)
  @source_machine_image_encryption_key = args[:source_machine_image_encryption_key] if args.key?(:source_machine_image_encryption_key)
  @start_restricted = args[:start_restricted] if args.key?(:start_restricted)
  @status = args[:status] if args.key?(:status)
  @status_message = args[:status_message] if args.key?(:status_message)
  @tags = args[:tags] if args.key?(:tags)
  @upcoming_maintenance = args[:upcoming_maintenance] if args.key?(:upcoming_maintenance)
  @workload_identity_config = args[:workload_identity_config] if args.key?(:workload_identity_config)
  @zone = args[:zone] if args.key?(:zone)
end