Class: Google::Apis::ComputeAlpha::Instance
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::Instance
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Represents an Instance resource. An instance is a virtual machine that is hosted on Google Cloud Platform. For more information, readVirtual Machine Instances.
Instance Attribute Summary collapse
-
#advanced_machine_features ⇒ Google::Apis::ComputeAlpha::AdvancedMachineFeatures
Specifies options for controlling advanced machine features.
-
#can_ip_forward ⇒ Boolean
(also: #can_ip_forward?)
Allows this instance to send and receive packets with non-matching destination or source IPs.
-
#confidential_instance_config ⇒ Google::Apis::ComputeAlpha::ConfidentialInstanceConfig
A set of Confidential Instance options.
-
#cpu_platform ⇒ String
Output only.
-
#creation_timestamp ⇒ String
Output only.
-
#deletion_protection ⇒ Boolean
(also: #deletion_protection?)
Whether the resource should be protected against deletion.
-
#description ⇒ String
An optional description of this resource.
-
#disks ⇒ Array<Google::Apis::ComputeAlpha::AttachedDisk>
Array of disks associated with this instance.
-
#display_device ⇒ Google::Apis::ComputeAlpha::DisplayDevice
A set of Display Device options Corresponds to the JSON property
displayDevice. -
#erase_windows_vss_signature ⇒ Boolean
(also: #erase_windows_vss_signature?)
Specifies whether the disks restored from source snapshots or source machine image should erase Windows specific VSS signature.
-
#fingerprint ⇒ String
Specifies a fingerprint for this resource, which is essentially a hash of the instance's contents and used for optimistic locking.
-
#guest_accelerators ⇒ Array<Google::Apis::ComputeAlpha::AcceleratorConfig>
A list of the type and count of accelerator cards attached to the instance.
-
#hostname ⇒ String
Specifies the hostname of the instance.
-
#id ⇒ Fixnum
Output only.
-
#identity ⇒ String
Corresponds to the JSON property
identity. -
#identity_certificate ⇒ Boolean
(also: #identity_certificate?)
Corresponds to the JSON property
identityCertificate. -
#instance_encryption_key ⇒ Google::Apis::ComputeAlpha::CustomerEncryptionKey
Encrypts suspended data for an instance with acustomer-managed encryption key.
-
#key_revocation_action_type ⇒ String
KeyRevocationActionType of the instance.
-
#kind ⇒ String
Output only.
-
#label_fingerprint ⇒ String
A fingerprint for this request, which is essentially a hash of the label's contents and used for optimistic locking.
-
#labels ⇒ Hash<String,String>
Labels to apply to this instance.
-
#last_start_timestamp ⇒ String
Output only.
-
#last_stop_timestamp ⇒ String
Output only.
-
#last_suspended_timestamp ⇒ String
Output only.
-
#machine_type ⇒ String
Full or partial URL of the machine type resource to use for this instance, in the format:zones/zone/machineTypes/machine-type.
-
#metadata ⇒ Google::Apis::ComputeAlpha::Metadata
A metadata key/value entry.
-
#min_cpu_platform ⇒ String
Specifies aminimum CPU platform for the VM instance.
-
#name ⇒ String
The name of the resource, provided by the client when initially creating the resource.
-
#network_interfaces ⇒ Array<Google::Apis::ComputeAlpha::NetworkInterface>
An array of network configurations for this instance.
-
#network_performance_config ⇒ Google::Apis::ComputeAlpha::NetworkPerformanceConfig
Corresponds to the JSON property
networkPerformanceConfig. -
#params ⇒ Google::Apis::ComputeAlpha::InstanceParams
Additional instance params.
-
#partner_metadata ⇒ Hash<String,Google::Apis::ComputeAlpha::StructuredEntries>
Partner Metadata assigned to the instance.
-
#post_key_revocation_action_type ⇒ String
PostKeyRevocationActionType of the instance.
-
#preserved_state_size_gb ⇒ Fixnum
Output only.
-
#private_ipv6_google_access ⇒ String
The private IPv6 google access type for the VM.
-
#reservation_affinity ⇒ Google::Apis::ComputeAlpha::ReservationAffinity
Specifies the reservations that this instance can consume from.
-
#resource_policies ⇒ Array<String>
Resource policies applied to this instance.
-
#resource_status ⇒ Google::Apis::ComputeAlpha::ResourceStatus
Contains output only fields.
-
#satisfies_pzi ⇒ Boolean
(also: #satisfies_pzi?)
Output only.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
Output only.
-
#scheduling ⇒ Google::Apis::ComputeAlpha::Scheduling
Sets the scheduling options for an Instance.
-
#secure_tags ⇒ Array<String>
[Input Only] Secure tags to apply to this instance.
-
#self_link ⇒ String
Output only.
-
#self_link_with_id ⇒ String
Output only.
-
#service_accounts ⇒ Array<Google::Apis::ComputeAlpha::ServiceAccount>
A list of service accounts, with their specified scopes, authorized for this instance.
-
#service_integration_specs ⇒ Hash<String,Google::Apis::ComputeAlpha::ServiceIntegrationSpec>
Mapping of user-defined keys to specifications for service integrations.
-
#shielded_instance_config ⇒ Google::Apis::ComputeAlpha::ShieldedInstanceConfig
A set of Shielded Instance options.
-
#shielded_instance_integrity_policy ⇒ Google::Apis::ComputeAlpha::ShieldedInstanceIntegrityPolicy
The policy describes the baseline against which Instance boot integrity is measured.
-
#shielded_vm_config ⇒ Google::Apis::ComputeAlpha::ShieldedVmConfig
A set of Shielded VM options.
-
#shielded_vm_integrity_policy ⇒ Google::Apis::ComputeAlpha::ShieldedVmIntegrityPolicy
The policy describes the baseline against which VM instance boot integrity is measured.
-
#source_machine_image ⇒ String
Source machine image Corresponds to the JSON property
sourceMachineImage. -
#source_machine_image_encryption_key ⇒ Google::Apis::ComputeAlpha::CustomerEncryptionKey
Source machine image encryption key when creating an instance from a machine image.
-
#start_restricted ⇒ Boolean
(also: #start_restricted?)
Output only.
-
#status ⇒ String
Output only.
-
#status_message ⇒ String
Output only.
-
#tags ⇒ Google::Apis::ComputeAlpha::Tags
A set of instance tags.
-
#upcoming_maintenance ⇒ Google::Apis::ComputeAlpha::UpcomingMaintenance
Upcoming Maintenance notification information.
-
#workload_identity_config ⇒ Google::Apis::ComputeAlpha::WorkloadIdentityConfig
Corresponds to the JSON property
workloadIdentityConfig. -
#zone ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Instance
constructor
A new instance of Instance.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Instance
Returns a new instance of Instance.
25899 25900 25901 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 25899 def initialize(**args) update!(**args) end |
Instance Attribute Details
#advanced_machine_features ⇒ Google::Apis::ComputeAlpha::AdvancedMachineFeatures
Specifies options for controlling advanced machine features.
Options that would traditionally be configured in a BIOS belong
here. Features that require operating system support may have
corresponding entries in the GuestOsFeatures of anImage (e.g., whether or not
the OS in theImage supports nested virtualization being enabled or
disabled).
Corresponds to the JSON property advancedMachineFeatures
25510 25511 25512 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 25510 def advanced_machine_features @advanced_machine_features end |
#can_ip_forward ⇒ Boolean Also known as: can_ip_forward?
Allows this instance to send and receive packets with non-matching
destination or source IPs. This is required if you plan to use this
instance to forward routes. For more information, seeEnabling IP Forwarding.
Corresponds to the JSON property canIpForward
25517 25518 25519 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 25517 def can_ip_forward @can_ip_forward end |
#confidential_instance_config ⇒ Google::Apis::ComputeAlpha::ConfidentialInstanceConfig
A set of Confidential Instance options.
Corresponds to the JSON property confidentialInstanceConfig
25523 25524 25525 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 25523 def confidential_instance_config @confidential_instance_config end |
#cpu_platform ⇒ String
Output only. [Output Only] The CPU platform used by this instance.
Corresponds to the JSON property cpuPlatform
25528 25529 25530 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 25528 def cpu_platform @cpu_platform end |
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339 text format.
Corresponds to the JSON property creationTimestamp
25533 25534 25535 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 25533 def @creation_timestamp end |
#deletion_protection ⇒ Boolean Also known as: deletion_protection?
Whether the resource should be protected against deletion.
Corresponds to the JSON property deletionProtection
25538 25539 25540 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 25538 def deletion_protection @deletion_protection end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
25545 25546 25547 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 25545 def description @description end |
#disks ⇒ Array<Google::Apis::ComputeAlpha::AttachedDisk>
Array of disks associated with this instance. Persistent disks must be
created before you can assign them.
Corresponds to the JSON property disks
25551 25552 25553 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 25551 def disks @disks end |
#display_device ⇒ Google::Apis::ComputeAlpha::DisplayDevice
A set of Display Device options
Corresponds to the JSON property displayDevice
25556 25557 25558 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 25556 def display_device @display_device end |
#erase_windows_vss_signature ⇒ Boolean Also known as: erase_windows_vss_signature?
Specifies whether the disks restored from source snapshots or source
machine image should erase Windows specific VSS signature.
Corresponds to the JSON property eraseWindowsVssSignature
25562 25563 25564 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 25562 def erase_windows_vss_signature @erase_windows_vss_signature end |
#fingerprint ⇒ String
Specifies a fingerprint for this resource, which is essentially a hash of
the instance's contents and used for optimistic locking. The
fingerprint is initially generated by Compute Engine and changes after
every request to modify or update the instance. You must always provide an
up-to-date fingerprint hash in order to update the instance.
To see the latest fingerprint, make get() request to the
instance.
Corresponds to the JSON property fingerprint
NOTE: Values are automatically base64 encoded/decoded in the client library.
25575 25576 25577 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 25575 def fingerprint @fingerprint end |
#guest_accelerators ⇒ Array<Google::Apis::ComputeAlpha::AcceleratorConfig>
A list of the type and count of accelerator cards attached to the instance.
Corresponds to the JSON property guestAccelerators
25580 25581 25582 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 25580 def guest_accelerators @guest_accelerators end |
#hostname ⇒ String
Specifies the hostname of the instance. The specified hostname must be
RFC1035 compliant. If hostname is not specified, the default hostname is
[INSTANCE_NAME].c.[PROJECT_ID].internal when using the global DNS, and
[INSTANCE_NAME].[ZONE].c.[PROJECT_ID].internal when using zonal DNS.
Corresponds to the JSON property hostname
25588 25589 25590 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 25588 def hostname @hostname end |
#id ⇒ Fixnum
Output only. [Output Only] The unique identifier for the resource. This
identifier is
defined by the server.
Corresponds to the JSON property id
25595 25596 25597 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 25595 def id @id end |
#identity ⇒ String
Corresponds to the JSON property identity
25600 25601 25602 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 25600 def identity @identity end |
#identity_certificate ⇒ Boolean Also known as: identity_certificate?
Corresponds to the JSON property identityCertificate
25605 25606 25607 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 25605 def identity_certificate @identity_certificate end |
#instance_encryption_key ⇒ Google::Apis::ComputeAlpha::CustomerEncryptionKey
Encrypts suspended data for an instance with acustomer-managed
encryption key.
If you are creating a new instance, this field will encrypt the local SSD
and in-memory contents of the instance during the suspend operation.
If you do not provide an encryption key when creating the instance, then
the local SSD and in-memory contents will be encrypted using
an automatically generated key during the suspend operation.
Corresponds to the JSON property instanceEncryptionKey
25617 25618 25619 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 25617 def instance_encryption_key @instance_encryption_key end |
#key_revocation_action_type ⇒ String
KeyRevocationActionType of the instance. Supported options are "STOP" and
"NONE". The default value is "NONE" if it is not specified.
Corresponds to the JSON property keyRevocationActionType
25623 25624 25625 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 25623 def key_revocation_action_type @key_revocation_action_type end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Always compute#instance
for instances.
Corresponds to the JSON property kind
25629 25630 25631 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 25629 def kind @kind end |
#label_fingerprint ⇒ String
A fingerprint for this request, which is essentially a hash of
the label's contents and used for optimistic locking. The
fingerprint is initially generated by Compute Engine and changes after
every request to modify or update labels. You must always provide an
up-to-date fingerprint hash in order to update or change labels.
To see the latest fingerprint, make get() request to the
instance.
Corresponds to the JSON property labelFingerprint
NOTE: Values are automatically base64 encoded/decoded in the client library.
25641 25642 25643 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 25641 def label_fingerprint @label_fingerprint end |
#labels ⇒ Hash<String,String>
Labels to apply to this instance. These can be later modified by
the setLabels method.
Corresponds to the JSON property labels
25647 25648 25649 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 25647 def labels @labels end |
#last_start_timestamp ⇒ String
Output only. [Output Only] Last start timestamp inRFC3339 text format.
Corresponds to the JSON property lastStartTimestamp
25652 25653 25654 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 25652 def @last_start_timestamp end |
#last_stop_timestamp ⇒ String
Output only. [Output Only] Last stop timestamp inRFC3339 text format.
Corresponds to the JSON property lastStopTimestamp
25657 25658 25659 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 25657 def @last_stop_timestamp end |
#last_suspended_timestamp ⇒ String
Output only. [Output Only] Last suspended timestamp inRFC3339 text format.
Corresponds to the JSON property lastSuspendedTimestamp
25662 25663 25664 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 25662 def @last_suspended_timestamp end |
#machine_type ⇒ String
Full or partial URL of the machine type resource to use for this instance,
in the format:zones/zone/machineTypes/machine-type. This is provided by the
client
when the instance is created. For example, the following is a valid partial
url to a predefined
machine type:
zones/us-central1-f/machineTypes/n1-standard-1
To create acustom
machine type, provide a URL to a machine type in the following format,
where CPUS is 1 or an even number up to 32 (2,
4, 6, ... 24, etc), and MEMORY is the total
memory for this instance. Memory must be a multiple of 256 MB and must
be supplied in MB (e.g. 5 GB of memory is 5120 MB):
zones/zone/machineTypes/custom-CPUS-MEMORY
For example: zones/us-central1-f/machineTypes/custom-4-5120
For a full list of restrictions, read theSpecifications
for custom machine types.
Corresponds to the JSON property machineType
25683 25684 25685 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 25683 def machine_type @machine_type end |
#metadata ⇒ Google::Apis::ComputeAlpha::Metadata
A metadata key/value entry.
Corresponds to the JSON property metadata
25688 25689 25690 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 25688 def @metadata end |
#min_cpu_platform ⇒ String
Specifies aminimum CPU
platform for the VM instance. Applicable values are the friendly names
of CPU platforms, such as minCpuPlatform: "Intel
Haswell" or minCpuPlatform: "Intel Sandy
Bridge".
Corresponds to the JSON property minCpuPlatform
25697 25698 25699 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 25697 def min_cpu_platform @min_cpu_platform end |
#name ⇒ String
The name of the resource, provided by the client when initially creating
the resource. The resource name must be 1-63 characters long, and comply
withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must be
a dash, lowercase letter, or digit, except the last character, which cannot
be a dash.
Corresponds to the JSON property name
25709 25710 25711 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 25709 def name @name end |
#network_interfaces ⇒ Array<Google::Apis::ComputeAlpha::NetworkInterface>
An array of network configurations for this instance. These specify how
interfaces are configured to interact with other network services, such as
connecting to the internet. Multiple interfaces are supported
per instance.
Corresponds to the JSON property networkInterfaces
25717 25718 25719 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 25717 def network_interfaces @network_interfaces end |
#network_performance_config ⇒ Google::Apis::ComputeAlpha::NetworkPerformanceConfig
Corresponds to the JSON property networkPerformanceConfig
25722 25723 25724 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 25722 def network_performance_config @network_performance_config end |
#params ⇒ Google::Apis::ComputeAlpha::InstanceParams
Additional instance params.
Corresponds to the JSON property params
25727 25728 25729 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 25727 def params @params end |
#partner_metadata ⇒ Hash<String,Google::Apis::ComputeAlpha::StructuredEntries>
Partner Metadata assigned to the instance. A map from a subdomain
(namespace) to entries map.
Corresponds to the JSON property partnerMetadata
25733 25734 25735 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 25733 def @partner_metadata end |
#post_key_revocation_action_type ⇒ String
PostKeyRevocationActionType of the instance.
Corresponds to the JSON property postKeyRevocationActionType
25738 25739 25740 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 25738 def post_key_revocation_action_type @post_key_revocation_action_type end |
#preserved_state_size_gb ⇒ Fixnum
Output only. Total amount of preserved state for SUSPENDED instances.
Read-only in the api.
Corresponds to the JSON property preservedStateSizeGb
25744 25745 25746 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 25744 def preserved_state_size_gb @preserved_state_size_gb end |
#private_ipv6_google_access ⇒ String
The private IPv6 google access type for the VM.
If not specified, use INHERIT_FROM_SUBNETWORK as default.
Corresponds to the JSON property privateIpv6GoogleAccess
25750 25751 25752 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 25750 def private_ipv6_google_access @private_ipv6_google_access end |
#reservation_affinity ⇒ Google::Apis::ComputeAlpha::ReservationAffinity
Specifies the reservations that this instance can consume from.
Corresponds to the JSON property reservationAffinity
25755 25756 25757 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 25755 def reservation_affinity @reservation_affinity end |
#resource_policies ⇒ Array<String>
Resource policies applied to this instance.
Corresponds to the JSON property resourcePolicies
25760 25761 25762 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 25760 def resource_policies @resource_policies end |
#resource_status ⇒ Google::Apis::ComputeAlpha::ResourceStatus
Contains output only fields.
Use this sub-message for actual values set on Instance attributes as compared
to the value requested by the user (intent) in their instance CRUD calls.
Corresponds to the JSON property resourceStatus
25767 25768 25769 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 25767 def resource_status @resource_status end |
#satisfies_pzi ⇒ Boolean Also known as: satisfies_pzi?
Output only. [Output Only] Reserved for future use.
Corresponds to the JSON property satisfiesPzi
25772 25773 25774 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 25772 def satisfies_pzi @satisfies_pzi end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
Output only. [Output Only] Reserved for future use.
Corresponds to the JSON property satisfiesPzs
25778 25779 25780 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 25778 def satisfies_pzs @satisfies_pzs end |
#scheduling ⇒ Google::Apis::ComputeAlpha::Scheduling
Sets the scheduling options for an Instance.
Corresponds to the JSON property scheduling
25784 25785 25786 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 25784 def scheduling @scheduling end |
#secure_tags ⇒ Array<String>
[Input Only] Secure tags to apply to this instance. These can be later
modified by the update method.
Maximum number of secure tags allowed is 50.
Corresponds to the JSON property secureTags
25791 25792 25793 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 25791 def @secure_tags end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
25796 25797 25798 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 25796 def self_link @self_link end |
#self_link_with_id ⇒ String
Output only. [Output Only] Server-defined URL for this resource with the
resource id.
Corresponds to the JSON property selfLinkWithId
25802 25803 25804 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 25802 def self_link_with_id @self_link_with_id end |
#service_accounts ⇒ Array<Google::Apis::ComputeAlpha::ServiceAccount>
A list of service accounts, with their specified scopes, authorized for
this instance. Only one service account per VM instance is supported.
Service accounts generate access tokens that can be accessed
through the metadata server and used to authenticate applications on the
instance. SeeService Accounts
for more information.
Corresponds to the JSON property serviceAccounts
25812 25813 25814 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 25812 def service_accounts @service_accounts end |
#service_integration_specs ⇒ Hash<String,Google::Apis::ComputeAlpha::ServiceIntegrationSpec>
Mapping of user-defined keys to specifications for service integrations.
Currently only a single key-value pair is supported.
Corresponds to the JSON property serviceIntegrationSpecs
25818 25819 25820 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 25818 def service_integration_specs @service_integration_specs end |
#shielded_instance_config ⇒ Google::Apis::ComputeAlpha::ShieldedInstanceConfig
A set of Shielded Instance options.
Corresponds to the JSON property shieldedInstanceConfig
25823 25824 25825 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 25823 def shielded_instance_config @shielded_instance_config end |
#shielded_instance_integrity_policy ⇒ Google::Apis::ComputeAlpha::ShieldedInstanceIntegrityPolicy
The policy describes the baseline against which
Instance boot integrity is measured.
Corresponds to the JSON property shieldedInstanceIntegrityPolicy
25829 25830 25831 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 25829 def shielded_instance_integrity_policy @shielded_instance_integrity_policy end |
#shielded_vm_config ⇒ Google::Apis::ComputeAlpha::ShieldedVmConfig
A set of Shielded VM options.
Corresponds to the JSON property shieldedVmConfig
25834 25835 25836 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 25834 def shielded_vm_config @shielded_vm_config end |
#shielded_vm_integrity_policy ⇒ Google::Apis::ComputeAlpha::ShieldedVmIntegrityPolicy
The policy describes the baseline against which
VM instance boot integrity is measured.
Corresponds to the JSON property shieldedVmIntegrityPolicy
25840 25841 25842 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 25840 def shielded_vm_integrity_policy @shielded_vm_integrity_policy end |
#source_machine_image ⇒ String
Source machine image
Corresponds to the JSON property sourceMachineImage
25845 25846 25847 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 25845 def source_machine_image @source_machine_image end |
#source_machine_image_encryption_key ⇒ Google::Apis::ComputeAlpha::CustomerEncryptionKey
Source machine image encryption key when creating an instance from a
machine image.
Corresponds to the JSON property sourceMachineImageEncryptionKey
25851 25852 25853 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 25851 def source_machine_image_encryption_key @source_machine_image_encryption_key end |
#start_restricted ⇒ Boolean Also known as: start_restricted?
Output only. [Output Only] Whether a VM has been restricted for start because
Compute
Engine has detected suspicious activity.
Corresponds to the JSON property startRestricted
25858 25859 25860 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 25858 def start_restricted @start_restricted end |
#status ⇒ String
Output only. [Output Only] The status of the instance. One of the
following values: PROVISIONING, STAGING,RUNNING, STOPPING, SUSPENDING,
SUSPENDED, REPAIRING, andTERMINATED. For more information about the status of
the
instance, see
Instance life cycle.
Corresponds to the JSON property status
25869 25870 25871 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 25869 def status @status end |
#status_message ⇒ String
Output only. [Output Only] An optional, human-readable explanation of the
status.
Corresponds to the JSON property statusMessage
25875 25876 25877 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 25875 def @status_message end |
#tags ⇒ Google::Apis::ComputeAlpha::Tags
A set of instance tags.
Corresponds to the JSON property tags
25880 25881 25882 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 25880 def @tags end |
#upcoming_maintenance ⇒ Google::Apis::ComputeAlpha::UpcomingMaintenance
Upcoming Maintenance notification information.
Corresponds to the JSON property upcomingMaintenance
25885 25886 25887 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 25885 def upcoming_maintenance @upcoming_maintenance end |
#workload_identity_config ⇒ Google::Apis::ComputeAlpha::WorkloadIdentityConfig
Corresponds to the JSON property workloadIdentityConfig
25890 25891 25892 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 25890 def workload_identity_config @workload_identity_config end |
#zone ⇒ String
Output only. [Output Only] URL of the zone where the instance resides.
You must specify this field as part of the HTTP request URL. It is
not settable as a field in the request body.
Corresponds to the JSON property zone
25897 25898 25899 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 25897 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
25904 25905 25906 25907 25908 25909 25910 25911 25912 25913 25914 25915 25916 25917 25918 25919 25920 25921 25922 25923 25924 25925 25926 25927 25928 25929 25930 25931 25932 25933 25934 25935 25936 25937 25938 25939 25940 25941 25942 25943 25944 25945 25946 25947 25948 25949 25950 25951 25952 25953 25954 25955 25956 25957 25958 25959 25960 25961 25962 25963 25964 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 25904 def update!(**args) @advanced_machine_features = args[:advanced_machine_features] if args.key?(:advanced_machine_features) @can_ip_forward = args[:can_ip_forward] if args.key?(:can_ip_forward) @confidential_instance_config = args[:confidential_instance_config] if args.key?(:confidential_instance_config) @cpu_platform = args[:cpu_platform] if args.key?(:cpu_platform) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @deletion_protection = args[:deletion_protection] if args.key?(:deletion_protection) @description = args[:description] if args.key?(:description) @disks = args[:disks] if args.key?(:disks) @display_device = args[:display_device] if args.key?(:display_device) @erase_windows_vss_signature = args[:erase_windows_vss_signature] if args.key?(:erase_windows_vss_signature) @fingerprint = args[:fingerprint] if args.key?(:fingerprint) @guest_accelerators = args[:guest_accelerators] if args.key?(:guest_accelerators) @hostname = args[:hostname] if args.key?(:hostname) @id = args[:id] if args.key?(:id) @identity = args[:identity] if args.key?(:identity) @identity_certificate = args[:identity_certificate] if args.key?(:identity_certificate) @instance_encryption_key = args[:instance_encryption_key] if args.key?(:instance_encryption_key) @key_revocation_action_type = args[:key_revocation_action_type] if args.key?(:key_revocation_action_type) @kind = args[:kind] if args.key?(:kind) @label_fingerprint = args[:label_fingerprint] if args.key?(:label_fingerprint) @labels = args[:labels] if args.key?(:labels) @last_start_timestamp = args[:last_start_timestamp] if args.key?(:last_start_timestamp) @last_stop_timestamp = args[:last_stop_timestamp] if args.key?(:last_stop_timestamp) @last_suspended_timestamp = args[:last_suspended_timestamp] if args.key?(:last_suspended_timestamp) @machine_type = args[:machine_type] if args.key?(:machine_type) @metadata = args[:metadata] if args.key?(:metadata) @min_cpu_platform = args[:min_cpu_platform] if args.key?(:min_cpu_platform) @name = args[:name] if args.key?(:name) @network_interfaces = args[:network_interfaces] if args.key?(:network_interfaces) @network_performance_config = args[:network_performance_config] if args.key?(:network_performance_config) @params = args[:params] if args.key?(:params) @partner_metadata = args[:partner_metadata] if args.key?(:partner_metadata) @post_key_revocation_action_type = args[:post_key_revocation_action_type] if args.key?(:post_key_revocation_action_type) @preserved_state_size_gb = args[:preserved_state_size_gb] if args.key?(:preserved_state_size_gb) @private_ipv6_google_access = args[:private_ipv6_google_access] if args.key?(:private_ipv6_google_access) @reservation_affinity = args[:reservation_affinity] if args.key?(:reservation_affinity) @resource_policies = args[:resource_policies] if args.key?(:resource_policies) @resource_status = args[:resource_status] if args.key?(:resource_status) @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @scheduling = args[:scheduling] if args.key?(:scheduling) @secure_tags = args[:secure_tags] if args.key?(:secure_tags) @self_link = args[:self_link] if args.key?(:self_link) @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id) @service_accounts = args[:service_accounts] if args.key?(:service_accounts) @service_integration_specs = args[:service_integration_specs] if args.key?(:service_integration_specs) @shielded_instance_config = args[:shielded_instance_config] if args.key?(:shielded_instance_config) @shielded_instance_integrity_policy = args[:shielded_instance_integrity_policy] if args.key?(:shielded_instance_integrity_policy) @shielded_vm_config = args[:shielded_vm_config] if args.key?(:shielded_vm_config) @shielded_vm_integrity_policy = args[:shielded_vm_integrity_policy] if args.key?(:shielded_vm_integrity_policy) @source_machine_image = args[:source_machine_image] if args.key?(:source_machine_image) @source_machine_image_encryption_key = args[:source_machine_image_encryption_key] if args.key?(:source_machine_image_encryption_key) @start_restricted = args[:start_restricted] if args.key?(:start_restricted) @status = args[:status] if args.key?(:status) @status_message = args[:status_message] if args.key?(:status_message) @tags = args[:tags] if args.key?(:tags) @upcoming_maintenance = args[:upcoming_maintenance] if args.key?(:upcoming_maintenance) @workload_identity_config = args[:workload_identity_config] if args.key?(:workload_identity_config) @zone = args[:zone] if args.key?(:zone) end |