Class: Google::Apis::ComputeAlpha::Instance

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Represents an Instance resource. An instance is a virtual machine that is hosted on Google Cloud Platform. For more information, readVirtual Machine Instances.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Instance

Returns a new instance of Instance.



25773
25774
25775
# File 'lib/google/apis/compute_alpha/classes.rb', line 25773

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#advanced_machine_featuresGoogle::Apis::ComputeAlpha::AdvancedMachineFeatures

Specifies options for controlling advanced machine features. Options that would traditionally be configured in a BIOS belong here. Features that require operating system support may have corresponding entries in the GuestOsFeatures of anImage (e.g., whether or not the OS in theImage supports nested virtualization being enabled or disabled). Corresponds to the JSON property advancedMachineFeatures



25384
25385
25386
# File 'lib/google/apis/compute_alpha/classes.rb', line 25384

def advanced_machine_features
  @advanced_machine_features
end

#can_ip_forwardBoolean Also known as: can_ip_forward?

Allows this instance to send and receive packets with non-matching destination or source IPs. This is required if you plan to use this instance to forward routes. For more information, seeEnabling IP Forwarding. Corresponds to the JSON property canIpForward

Returns:

  • (Boolean)


25391
25392
25393
# File 'lib/google/apis/compute_alpha/classes.rb', line 25391

def can_ip_forward
  @can_ip_forward
end

#confidential_instance_configGoogle::Apis::ComputeAlpha::ConfidentialInstanceConfig

A set of Confidential Instance options. Corresponds to the JSON property confidentialInstanceConfig



25397
25398
25399
# File 'lib/google/apis/compute_alpha/classes.rb', line 25397

def confidential_instance_config
  @confidential_instance_config
end

#cpu_platformString

Output only. [Output Only] The CPU platform used by this instance. Corresponds to the JSON property cpuPlatform

Returns:

  • (String)


25402
25403
25404
# File 'lib/google/apis/compute_alpha/classes.rb', line 25402

def cpu_platform
  @cpu_platform
end

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


25407
25408
25409
# File 'lib/google/apis/compute_alpha/classes.rb', line 25407

def creation_timestamp
  @creation_timestamp
end

#deletion_protectionBoolean Also known as: deletion_protection?

Whether the resource should be protected against deletion. Corresponds to the JSON property deletionProtection

Returns:

  • (Boolean)


25412
25413
25414
# File 'lib/google/apis/compute_alpha/classes.rb', line 25412

def deletion_protection
  @deletion_protection
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


25419
25420
25421
# File 'lib/google/apis/compute_alpha/classes.rb', line 25419

def description
  @description
end

#disksArray<Google::Apis::ComputeAlpha::AttachedDisk>

Array of disks associated with this instance. Persistent disks must be created before you can assign them. Corresponds to the JSON property disks



25425
25426
25427
# File 'lib/google/apis/compute_alpha/classes.rb', line 25425

def disks
  @disks
end

#display_deviceGoogle::Apis::ComputeAlpha::DisplayDevice

A set of Display Device options Corresponds to the JSON property displayDevice



25430
25431
25432
# File 'lib/google/apis/compute_alpha/classes.rb', line 25430

def display_device
  @display_device
end

#erase_windows_vss_signatureBoolean Also known as: erase_windows_vss_signature?

Specifies whether the disks restored from source snapshots or source machine image should erase Windows specific VSS signature. Corresponds to the JSON property eraseWindowsVssSignature

Returns:

  • (Boolean)


25436
25437
25438
# File 'lib/google/apis/compute_alpha/classes.rb', line 25436

def erase_windows_vss_signature
  @erase_windows_vss_signature
end

#fingerprintString

Specifies a fingerprint for this resource, which is essentially a hash of the instance's contents and used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update the instance. You must always provide an up-to-date fingerprint hash in order to update the instance. To see the latest fingerprint, make get() request to the instance. Corresponds to the JSON property fingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


25449
25450
25451
# File 'lib/google/apis/compute_alpha/classes.rb', line 25449

def fingerprint
  @fingerprint
end

#guest_acceleratorsArray<Google::Apis::ComputeAlpha::AcceleratorConfig>

A list of the type and count of accelerator cards attached to the instance. Corresponds to the JSON property guestAccelerators



25454
25455
25456
# File 'lib/google/apis/compute_alpha/classes.rb', line 25454

def guest_accelerators
  @guest_accelerators
end

#hostnameString

Specifies the hostname of the instance. The specified hostname must be RFC1035 compliant. If hostname is not specified, the default hostname is [INSTANCE_NAME].c.[PROJECT_ID].internal when using the global DNS, and [INSTANCE_NAME].[ZONE].c.[PROJECT_ID].internal when using zonal DNS. Corresponds to the JSON property hostname

Returns:

  • (String)


25462
25463
25464
# File 'lib/google/apis/compute_alpha/classes.rb', line 25462

def hostname
  @hostname
end

#idFixnum

Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


25469
25470
25471
# File 'lib/google/apis/compute_alpha/classes.rb', line 25469

def id
  @id
end

#identityString

Corresponds to the JSON property identity

Returns:

  • (String)


25474
25475
25476
# File 'lib/google/apis/compute_alpha/classes.rb', line 25474

def identity
  @identity
end

#identity_certificateBoolean Also known as: identity_certificate?

Corresponds to the JSON property identityCertificate

Returns:

  • (Boolean)


25479
25480
25481
# File 'lib/google/apis/compute_alpha/classes.rb', line 25479

def identity_certificate
  @identity_certificate
end

#instance_encryption_keyGoogle::Apis::ComputeAlpha::CustomerEncryptionKey

Encrypts suspended data for an instance with acustomer-managed encryption key. If you are creating a new instance, this field will encrypt the local SSD and in-memory contents of the instance during the suspend operation. If you do not provide an encryption key when creating the instance, then the local SSD and in-memory contents will be encrypted using an automatically generated key during the suspend operation. Corresponds to the JSON property instanceEncryptionKey



25491
25492
25493
# File 'lib/google/apis/compute_alpha/classes.rb', line 25491

def instance_encryption_key
  @instance_encryption_key
end

#key_revocation_action_typeString

KeyRevocationActionType of the instance. Supported options are "STOP" and "NONE". The default value is "NONE" if it is not specified. Corresponds to the JSON property keyRevocationActionType

Returns:

  • (String)


25497
25498
25499
# File 'lib/google/apis/compute_alpha/classes.rb', line 25497

def key_revocation_action_type
  @key_revocation_action_type
end

#kindString

Output only. [Output Only] Type of the resource. Always compute#instance for instances. Corresponds to the JSON property kind

Returns:

  • (String)


25503
25504
25505
# File 'lib/google/apis/compute_alpha/classes.rb', line 25503

def kind
  @kind
end

#label_fingerprintString

A fingerprint for this request, which is essentially a hash of the label's contents and used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update labels. You must always provide an up-to-date fingerprint hash in order to update or change labels. To see the latest fingerprint, make get() request to the instance. Corresponds to the JSON property labelFingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


25515
25516
25517
# File 'lib/google/apis/compute_alpha/classes.rb', line 25515

def label_fingerprint
  @label_fingerprint
end

#labelsHash<String,String>

Labels to apply to this instance. These can be later modified by the setLabels method. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


25521
25522
25523
# File 'lib/google/apis/compute_alpha/classes.rb', line 25521

def labels
  @labels
end

#last_start_timestampString

Output only. [Output Only] Last start timestamp inRFC3339 text format. Corresponds to the JSON property lastStartTimestamp

Returns:

  • (String)


25526
25527
25528
# File 'lib/google/apis/compute_alpha/classes.rb', line 25526

def last_start_timestamp
  @last_start_timestamp
end

#last_stop_timestampString

Output only. [Output Only] Last stop timestamp inRFC3339 text format. Corresponds to the JSON property lastStopTimestamp

Returns:

  • (String)


25531
25532
25533
# File 'lib/google/apis/compute_alpha/classes.rb', line 25531

def last_stop_timestamp
  @last_stop_timestamp
end

#last_suspended_timestampString

Output only. [Output Only] Last suspended timestamp inRFC3339 text format. Corresponds to the JSON property lastSuspendedTimestamp

Returns:

  • (String)


25536
25537
25538
# File 'lib/google/apis/compute_alpha/classes.rb', line 25536

def last_suspended_timestamp
  @last_suspended_timestamp
end

#machine_typeString

Full or partial URL of the machine type resource to use for this instance, in the format:zones/zone/machineTypes/machine-type. This is provided by the client when the instance is created. For example, the following is a valid partial url to a predefined machine type: zones/us-central1-f/machineTypes/n1-standard-1 To create acustom machine type, provide a URL to a machine type in the following format, where CPUS is 1 or an even number up to 32 (2, 4, 6, ... 24, etc), and MEMORY is the total memory for this instance. Memory must be a multiple of 256 MB and must be supplied in MB (e.g. 5 GB of memory is 5120 MB): zones/zone/machineTypes/custom-CPUS-MEMORY For example: zones/us-central1-f/machineTypes/custom-4-5120 For a full list of restrictions, read theSpecifications for custom machine types. Corresponds to the JSON property machineType

Returns:

  • (String)


25557
25558
25559
# File 'lib/google/apis/compute_alpha/classes.rb', line 25557

def machine_type
  @machine_type
end

#metadataGoogle::Apis::ComputeAlpha::Metadata

A metadata key/value entry. Corresponds to the JSON property metadata



25562
25563
25564
# File 'lib/google/apis/compute_alpha/classes.rb', line 25562

def 
  @metadata
end

#min_cpu_platformString

Specifies aminimum CPU platform for the VM instance. Applicable values are the friendly names of CPU platforms, such as minCpuPlatform: "Intel Haswell" or minCpuPlatform: "Intel Sandy Bridge". Corresponds to the JSON property minCpuPlatform

Returns:

  • (String)


25571
25572
25573
# File 'lib/google/apis/compute_alpha/classes.rb', line 25571

def min_cpu_platform
  @min_cpu_platform
end

#nameString

The name of the resource, provided by the client when initially creating the resource. The resource name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


25583
25584
25585
# File 'lib/google/apis/compute_alpha/classes.rb', line 25583

def name
  @name
end

#network_interfacesArray<Google::Apis::ComputeAlpha::NetworkInterface>

An array of network configurations for this instance. These specify how interfaces are configured to interact with other network services, such as connecting to the internet. Multiple interfaces are supported per instance. Corresponds to the JSON property networkInterfaces



25591
25592
25593
# File 'lib/google/apis/compute_alpha/classes.rb', line 25591

def network_interfaces
  @network_interfaces
end

#network_performance_configGoogle::Apis::ComputeAlpha::NetworkPerformanceConfig

Corresponds to the JSON property networkPerformanceConfig



25596
25597
25598
# File 'lib/google/apis/compute_alpha/classes.rb', line 25596

def network_performance_config
  @network_performance_config
end

#paramsGoogle::Apis::ComputeAlpha::InstanceParams

Additional instance params. Corresponds to the JSON property params



25601
25602
25603
# File 'lib/google/apis/compute_alpha/classes.rb', line 25601

def params
  @params
end

#partner_metadataHash<String,Google::Apis::ComputeAlpha::StructuredEntries>

Partner Metadata assigned to the instance. A map from a subdomain (namespace) to entries map. Corresponds to the JSON property partnerMetadata



25607
25608
25609
# File 'lib/google/apis/compute_alpha/classes.rb', line 25607

def 
  @partner_metadata
end

#post_key_revocation_action_typeString

PostKeyRevocationActionType of the instance. Corresponds to the JSON property postKeyRevocationActionType

Returns:

  • (String)


25612
25613
25614
# File 'lib/google/apis/compute_alpha/classes.rb', line 25612

def post_key_revocation_action_type
  @post_key_revocation_action_type
end

#preserved_state_size_gbFixnum

Output only. Total amount of preserved state for SUSPENDED instances. Read-only in the api. Corresponds to the JSON property preservedStateSizeGb

Returns:

  • (Fixnum)


25618
25619
25620
# File 'lib/google/apis/compute_alpha/classes.rb', line 25618

def preserved_state_size_gb
  @preserved_state_size_gb
end

#private_ipv6_google_accessString

The private IPv6 google access type for the VM. If not specified, use INHERIT_FROM_SUBNETWORK as default. Corresponds to the JSON property privateIpv6GoogleAccess

Returns:

  • (String)


25624
25625
25626
# File 'lib/google/apis/compute_alpha/classes.rb', line 25624

def private_ipv6_google_access
  @private_ipv6_google_access
end

#reservation_affinityGoogle::Apis::ComputeAlpha::ReservationAffinity

Specifies the reservations that this instance can consume from. Corresponds to the JSON property reservationAffinity



25629
25630
25631
# File 'lib/google/apis/compute_alpha/classes.rb', line 25629

def reservation_affinity
  @reservation_affinity
end

#resource_policiesArray<String>

Resource policies applied to this instance. Corresponds to the JSON property resourcePolicies

Returns:

  • (Array<String>)


25634
25635
25636
# File 'lib/google/apis/compute_alpha/classes.rb', line 25634

def resource_policies
  @resource_policies
end

#resource_statusGoogle::Apis::ComputeAlpha::ResourceStatus

Contains output only fields. Use this sub-message for actual values set on Instance attributes as compared to the value requested by the user (intent) in their instance CRUD calls. Corresponds to the JSON property resourceStatus



25641
25642
25643
# File 'lib/google/apis/compute_alpha/classes.rb', line 25641

def resource_status
  @resource_status
end

#satisfies_pziBoolean Also known as: satisfies_pzi?

Output only. [Output Only] Reserved for future use. Corresponds to the JSON property satisfiesPzi

Returns:

  • (Boolean)


25646
25647
25648
# File 'lib/google/apis/compute_alpha/classes.rb', line 25646

def satisfies_pzi
  @satisfies_pzi
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

Output only. [Output Only] Reserved for future use. Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


25652
25653
25654
# File 'lib/google/apis/compute_alpha/classes.rb', line 25652

def satisfies_pzs
  @satisfies_pzs
end

#schedulingGoogle::Apis::ComputeAlpha::Scheduling

Sets the scheduling options for an Instance. Corresponds to the JSON property scheduling



25658
25659
25660
# File 'lib/google/apis/compute_alpha/classes.rb', line 25658

def scheduling
  @scheduling
end

#secure_tagsArray<String>

[Input Only] Secure tags to apply to this instance. These can be later modified by the update method. Maximum number of secure tags allowed is 50. Corresponds to the JSON property secureTags

Returns:

  • (Array<String>)


25665
25666
25667
# File 'lib/google/apis/compute_alpha/classes.rb', line 25665

def secure_tags
  @secure_tags
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


25670
25671
25672
# File 'lib/google/apis/compute_alpha/classes.rb', line 25670

def self_link
  @self_link
end

Output only. [Output Only] Server-defined URL for this resource with the resource id. Corresponds to the JSON property selfLinkWithId

Returns:

  • (String)


25676
25677
25678
# File 'lib/google/apis/compute_alpha/classes.rb', line 25676

def self_link_with_id
  @self_link_with_id
end

#service_accountsArray<Google::Apis::ComputeAlpha::ServiceAccount>

A list of service accounts, with their specified scopes, authorized for this instance. Only one service account per VM instance is supported. Service accounts generate access tokens that can be accessed through the metadata server and used to authenticate applications on the instance. SeeService Accounts for more information. Corresponds to the JSON property serviceAccounts



25686
25687
25688
# File 'lib/google/apis/compute_alpha/classes.rb', line 25686

def service_accounts
  @service_accounts
end

#service_integration_specsHash<String,Google::Apis::ComputeAlpha::ServiceIntegrationSpec>

Mapping of user-defined keys to specifications for service integrations. Currently only a single key-value pair is supported. Corresponds to the JSON property serviceIntegrationSpecs



25692
25693
25694
# File 'lib/google/apis/compute_alpha/classes.rb', line 25692

def service_integration_specs
  @service_integration_specs
end

#shielded_instance_configGoogle::Apis::ComputeAlpha::ShieldedInstanceConfig

A set of Shielded Instance options. Corresponds to the JSON property shieldedInstanceConfig



25697
25698
25699
# File 'lib/google/apis/compute_alpha/classes.rb', line 25697

def shielded_instance_config
  @shielded_instance_config
end

#shielded_instance_integrity_policyGoogle::Apis::ComputeAlpha::ShieldedInstanceIntegrityPolicy

The policy describes the baseline against which Instance boot integrity is measured. Corresponds to the JSON property shieldedInstanceIntegrityPolicy



25703
25704
25705
# File 'lib/google/apis/compute_alpha/classes.rb', line 25703

def shielded_instance_integrity_policy
  @shielded_instance_integrity_policy
end

#shielded_vm_configGoogle::Apis::ComputeAlpha::ShieldedVmConfig

A set of Shielded VM options. Corresponds to the JSON property shieldedVmConfig



25708
25709
25710
# File 'lib/google/apis/compute_alpha/classes.rb', line 25708

def shielded_vm_config
  @shielded_vm_config
end

#shielded_vm_integrity_policyGoogle::Apis::ComputeAlpha::ShieldedVmIntegrityPolicy

The policy describes the baseline against which VM instance boot integrity is measured. Corresponds to the JSON property shieldedVmIntegrityPolicy



25714
25715
25716
# File 'lib/google/apis/compute_alpha/classes.rb', line 25714

def shielded_vm_integrity_policy
  @shielded_vm_integrity_policy
end

#source_machine_imageString

Source machine image Corresponds to the JSON property sourceMachineImage

Returns:

  • (String)


25719
25720
25721
# File 'lib/google/apis/compute_alpha/classes.rb', line 25719

def source_machine_image
  @source_machine_image
end

#source_machine_image_encryption_keyGoogle::Apis::ComputeAlpha::CustomerEncryptionKey

Source machine image encryption key when creating an instance from a machine image. Corresponds to the JSON property sourceMachineImageEncryptionKey



25725
25726
25727
# File 'lib/google/apis/compute_alpha/classes.rb', line 25725

def source_machine_image_encryption_key
  @source_machine_image_encryption_key
end

#start_restrictedBoolean Also known as: start_restricted?

Output only. [Output Only] Whether a VM has been restricted for start because Compute Engine has detected suspicious activity. Corresponds to the JSON property startRestricted

Returns:

  • (Boolean)


25732
25733
25734
# File 'lib/google/apis/compute_alpha/classes.rb', line 25732

def start_restricted
  @start_restricted
end

#statusString

Output only. [Output Only] The status of the instance. One of the following values: PROVISIONING, STAGING,RUNNING, STOPPING, SUSPENDING, SUSPENDED, REPAIRING, andTERMINATED. For more information about the status of the instance, see Instance life cycle. Corresponds to the JSON property status

Returns:

  • (String)


25743
25744
25745
# File 'lib/google/apis/compute_alpha/classes.rb', line 25743

def status
  @status
end

#status_messageString

Output only. [Output Only] An optional, human-readable explanation of the status. Corresponds to the JSON property statusMessage

Returns:

  • (String)


25749
25750
25751
# File 'lib/google/apis/compute_alpha/classes.rb', line 25749

def status_message
  @status_message
end

#tagsGoogle::Apis::ComputeAlpha::Tags

A set of instance tags. Corresponds to the JSON property tags



25754
25755
25756
# File 'lib/google/apis/compute_alpha/classes.rb', line 25754

def tags
  @tags
end

#upcoming_maintenanceGoogle::Apis::ComputeAlpha::UpcomingMaintenance

Upcoming Maintenance notification information. Corresponds to the JSON property upcomingMaintenance



25759
25760
25761
# File 'lib/google/apis/compute_alpha/classes.rb', line 25759

def upcoming_maintenance
  @upcoming_maintenance
end

#workload_identity_configGoogle::Apis::ComputeAlpha::WorkloadIdentityConfig

Corresponds to the JSON property workloadIdentityConfig



25764
25765
25766
# File 'lib/google/apis/compute_alpha/classes.rb', line 25764

def workload_identity_config
  @workload_identity_config
end

#zoneString

Output only. [Output Only] URL of the zone where the instance resides. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body. Corresponds to the JSON property zone

Returns:

  • (String)


25771
25772
25773
# File 'lib/google/apis/compute_alpha/classes.rb', line 25771

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



25778
25779
25780
25781
25782
25783
25784
25785
25786
25787
25788
25789
25790
25791
25792
25793
25794
25795
25796
25797
25798
25799
25800
25801
25802
25803
25804
25805
25806
25807
25808
25809
25810
25811
25812
25813
25814
25815
25816
25817
25818
25819
25820
25821
25822
25823
25824
25825
25826
25827
25828
25829
25830
25831
25832
25833
25834
25835
25836
25837
25838
# File 'lib/google/apis/compute_alpha/classes.rb', line 25778

def update!(**args)
  @advanced_machine_features = args[:advanced_machine_features] if args.key?(:advanced_machine_features)
  @can_ip_forward = args[:can_ip_forward] if args.key?(:can_ip_forward)
  @confidential_instance_config = args[:confidential_instance_config] if args.key?(:confidential_instance_config)
  @cpu_platform = args[:cpu_platform] if args.key?(:cpu_platform)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @deletion_protection = args[:deletion_protection] if args.key?(:deletion_protection)
  @description = args[:description] if args.key?(:description)
  @disks = args[:disks] if args.key?(:disks)
  @display_device = args[:display_device] if args.key?(:display_device)
  @erase_windows_vss_signature = args[:erase_windows_vss_signature] if args.key?(:erase_windows_vss_signature)
  @fingerprint = args[:fingerprint] if args.key?(:fingerprint)
  @guest_accelerators = args[:guest_accelerators] if args.key?(:guest_accelerators)
  @hostname = args[:hostname] if args.key?(:hostname)
  @id = args[:id] if args.key?(:id)
  @identity = args[:identity] if args.key?(:identity)
  @identity_certificate = args[:identity_certificate] if args.key?(:identity_certificate)
  @instance_encryption_key = args[:instance_encryption_key] if args.key?(:instance_encryption_key)
  @key_revocation_action_type = args[:key_revocation_action_type] if args.key?(:key_revocation_action_type)
  @kind = args[:kind] if args.key?(:kind)
  @label_fingerprint = args[:label_fingerprint] if args.key?(:label_fingerprint)
  @labels = args[:labels] if args.key?(:labels)
  @last_start_timestamp = args[:last_start_timestamp] if args.key?(:last_start_timestamp)
  @last_stop_timestamp = args[:last_stop_timestamp] if args.key?(:last_stop_timestamp)
  @last_suspended_timestamp = args[:last_suspended_timestamp] if args.key?(:last_suspended_timestamp)
  @machine_type = args[:machine_type] if args.key?(:machine_type)
  @metadata = args[:metadata] if args.key?(:metadata)
  @min_cpu_platform = args[:min_cpu_platform] if args.key?(:min_cpu_platform)
  @name = args[:name] if args.key?(:name)
  @network_interfaces = args[:network_interfaces] if args.key?(:network_interfaces)
  @network_performance_config = args[:network_performance_config] if args.key?(:network_performance_config)
  @params = args[:params] if args.key?(:params)
  @partner_metadata = args[:partner_metadata] if args.key?(:partner_metadata)
  @post_key_revocation_action_type = args[:post_key_revocation_action_type] if args.key?(:post_key_revocation_action_type)
  @preserved_state_size_gb = args[:preserved_state_size_gb] if args.key?(:preserved_state_size_gb)
  @private_ipv6_google_access = args[:private_ipv6_google_access] if args.key?(:private_ipv6_google_access)
  @reservation_affinity = args[:reservation_affinity] if args.key?(:reservation_affinity)
  @resource_policies = args[:resource_policies] if args.key?(:resource_policies)
  @resource_status = args[:resource_status] if args.key?(:resource_status)
  @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @scheduling = args[:scheduling] if args.key?(:scheduling)
  @secure_tags = args[:secure_tags] if args.key?(:secure_tags)
  @self_link = args[:self_link] if args.key?(:self_link)
  @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id)
  @service_accounts = args[:service_accounts] if args.key?(:service_accounts)
  @service_integration_specs = args[:service_integration_specs] if args.key?(:service_integration_specs)
  @shielded_instance_config = args[:shielded_instance_config] if args.key?(:shielded_instance_config)
  @shielded_instance_integrity_policy = args[:shielded_instance_integrity_policy] if args.key?(:shielded_instance_integrity_policy)
  @shielded_vm_config = args[:shielded_vm_config] if args.key?(:shielded_vm_config)
  @shielded_vm_integrity_policy = args[:shielded_vm_integrity_policy] if args.key?(:shielded_vm_integrity_policy)
  @source_machine_image = args[:source_machine_image] if args.key?(:source_machine_image)
  @source_machine_image_encryption_key = args[:source_machine_image_encryption_key] if args.key?(:source_machine_image_encryption_key)
  @start_restricted = args[:start_restricted] if args.key?(:start_restricted)
  @status = args[:status] if args.key?(:status)
  @status_message = args[:status_message] if args.key?(:status_message)
  @tags = args[:tags] if args.key?(:tags)
  @upcoming_maintenance = args[:upcoming_maintenance] if args.key?(:upcoming_maintenance)
  @workload_identity_config = args[:workload_identity_config] if args.key?(:workload_identity_config)
  @zone = args[:zone] if args.key?(:zone)
end