Class: Google::Apis::ComputeAlpha::InstanceAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::InstanceAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::InstancesScopedList>
An object that contains a list of instances scoped by zone.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::InstanceAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceAggregatedList
constructor
A new instance of InstanceAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceAggregatedList
Returns a new instance of InstanceAggregatedList.
27233 27234 27235 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27233 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
27194 27195 27196 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27194 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::InstancesScopedList>
An object that contains a list of instances scoped by zone.
Corresponds to the JSON property items
27199 27200 27201 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27199 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
instanceAggregatedList for aggregated lists of
Instance resources.
Corresponds to the JSON property kind
27206 27207 27208 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27206 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
27216 27217 27218 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27216 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
27221 27222 27223 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27221 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
27226 27227 27228 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27226 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::InstanceAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
27231 27232 27233 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27231 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
27238 27239 27240 27241 27242 27243 27244 27245 27246 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27238 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |