Class: Google::Apis::ComputeAlpha::InstanceAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceAggregatedList

Returns a new instance of InstanceAggregatedList.



26218
26219
26220
# File 'lib/google/apis/compute_alpha/classes.rb', line 26218

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


26179
26180
26181
# File 'lib/google/apis/compute_alpha/classes.rb', line 26179

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::InstancesScopedList>

An object that contains a list of instances scoped by zone. Corresponds to the JSON property items



26184
26185
26186
# File 'lib/google/apis/compute_alpha/classes.rb', line 26184

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# instanceAggregatedList for aggregated lists of Instance resources. Corresponds to the JSON property kind

Returns:

  • (String)


26191
26192
26193
# File 'lib/google/apis/compute_alpha/classes.rb', line 26191

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


26201
26202
26203
# File 'lib/google/apis/compute_alpha/classes.rb', line 26201

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


26206
26207
26208
# File 'lib/google/apis/compute_alpha/classes.rb', line 26206

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


26211
26212
26213
# File 'lib/google/apis/compute_alpha/classes.rb', line 26211

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::InstanceAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



26216
26217
26218
# File 'lib/google/apis/compute_alpha/classes.rb', line 26216

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



26223
26224
26225
26226
26227
26228
26229
26230
26231
# File 'lib/google/apis/compute_alpha/classes.rb', line 26223

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end