Class: Google::Apis::ComputeAlpha::InstanceAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::InstanceAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::InstancesScopedList>
An object that contains a list of instances scoped by zone.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::InstanceAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceAggregatedList
constructor
A new instance of InstanceAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceAggregatedList
Returns a new instance of InstanceAggregatedList.
26013 26014 26015 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 26013 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
25974 25975 25976 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 25974 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::InstancesScopedList>
An object that contains a list of instances scoped by zone.
Corresponds to the JSON property items
25979 25980 25981 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 25979 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
instanceAggregatedList for aggregated lists of
Instance resources.
Corresponds to the JSON property kind
25986 25987 25988 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 25986 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
25996 25997 25998 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 25996 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
26001 26002 26003 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 26001 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
26006 26007 26008 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 26006 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::InstanceAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
26011 26012 26013 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 26011 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
26018 26019 26020 26021 26022 26023 26024 26025 26026 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 26018 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |