Class: Google::Apis::ComputeAlpha::InstanceAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::InstanceAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::InstancesScopedList>
An object that contains a list of instances scoped by zone.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::InstanceAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceAggregatedList
constructor
A new instance of InstanceAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceAggregatedList
Returns a new instance of InstanceAggregatedList.
26030 26031 26032 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 26030 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
25991 25992 25993 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 25991 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::InstancesScopedList>
An object that contains a list of instances scoped by zone.
Corresponds to the JSON property items
25996 25997 25998 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 25996 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
instanceAggregatedList for aggregated lists of
Instance resources.
Corresponds to the JSON property kind
26003 26004 26005 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 26003 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
26013 26014 26015 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 26013 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
26018 26019 26020 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 26018 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
26023 26024 26025 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 26023 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::InstanceAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
26028 26029 26030 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 26028 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
26035 26036 26037 26038 26039 26040 26041 26042 26043 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 26035 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |