Class: Google::Apis::ComputeAlpha::InstanceAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceAggregatedList

Returns a new instance of InstanceAggregatedList.



25180
25181
25182
# File 'lib/google/apis/compute_alpha/classes.rb', line 25180

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


25141
25142
25143
# File 'lib/google/apis/compute_alpha/classes.rb', line 25141

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::InstancesScopedList>

An object that contains a list of instances scoped by zone. Corresponds to the JSON property items



25146
25147
25148
# File 'lib/google/apis/compute_alpha/classes.rb', line 25146

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# instanceAggregatedList for aggregated lists of Instance resources. Corresponds to the JSON property kind

Returns:

  • (String)


25153
25154
25155
# File 'lib/google/apis/compute_alpha/classes.rb', line 25153

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


25163
25164
25165
# File 'lib/google/apis/compute_alpha/classes.rb', line 25163

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


25168
25169
25170
# File 'lib/google/apis/compute_alpha/classes.rb', line 25168

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


25173
25174
25175
# File 'lib/google/apis/compute_alpha/classes.rb', line 25173

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::InstanceAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



25178
25179
25180
# File 'lib/google/apis/compute_alpha/classes.rb', line 25178

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



25185
25186
25187
25188
25189
25190
25191
25192
25193
# File 'lib/google/apis/compute_alpha/classes.rb', line 25185

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end