Class: Google::Apis::ComputeAlpha::InstanceConsumptionInfo

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceConsumptionInfo

Returns a new instance of InstanceConsumptionInfo.



27098
27099
27100
# File 'lib/google/apis/compute_alpha/classes.rb', line 27098

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#guest_cpusFixnum

Output only. The number of virtual CPUs that are available to the instance. Corresponds to the JSON property guestCpus

Returns:

  • (Fixnum)


27079
27080
27081
# File 'lib/google/apis/compute_alpha/classes.rb', line 27079

def guest_cpus
  @guest_cpus
end

#local_ssd_gbFixnum

Output only. The amount of local SSD storage available to the instance, defined in GiB. Corresponds to the JSON property localSsdGb

Returns:

  • (Fixnum)


27085
27086
27087
# File 'lib/google/apis/compute_alpha/classes.rb', line 27085

def local_ssd_gb
  @local_ssd_gb
end

#memory_mbFixnum

Output only. The amount of physical memory available to the instance, defined in MiB. Corresponds to the JSON property memoryMb

Returns:

  • (Fixnum)


27091
27092
27093
# File 'lib/google/apis/compute_alpha/classes.rb', line 27091

def memory_mb
  @memory_mb
end

#min_node_cpusFixnum

Output only. The minimal guaranteed number of virtual CPUs that are reserved. Corresponds to the JSON property minNodeCpus

Returns:

  • (Fixnum)


27096
27097
27098
# File 'lib/google/apis/compute_alpha/classes.rb', line 27096

def min_node_cpus
  @min_node_cpus
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



27103
27104
27105
27106
27107
27108
# File 'lib/google/apis/compute_alpha/classes.rb', line 27103

def update!(**args)
  @guest_cpus = args[:guest_cpus] if args.key?(:guest_cpus)
  @local_ssd_gb = args[:local_ssd_gb] if args.key?(:local_ssd_gb)
  @memory_mb = args[:memory_mb] if args.key?(:memory_mb)
  @min_node_cpus = args[:min_node_cpus] if args.key?(:min_node_cpus)
end