Class: Google::Apis::ComputeAlpha::InstanceFlexibilityPolicy

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

A flexible specification of machine types for instances to create.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceFlexibilityPolicy

Returns a new instance of InstanceFlexibilityPolicy.



26056
26057
26058
# File 'lib/google/apis/compute_alpha/classes.rb', line 26056

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#instance_selectionsHash<String,Google::Apis::ComputeAlpha::InstanceFlexibilityPolicyInstanceSelection>

Specification of alternative, flexible instance subsets. One of them will be selected to create the instances based on various criteria, like:

  • ranks,
  • location policy,
  • current capacity,
  • available reservations (you can specify affinity in InstanceProperties),
  • SWAN/GOOSE limitations. Key is an arbitrary, unique RFC1035 string that identifies the instance selection. Corresponds to the JSON property instanceSelections


26054
26055
26056
# File 'lib/google/apis/compute_alpha/classes.rb', line 26054

def instance_selections
  @instance_selections
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



26061
26062
26063
# File 'lib/google/apis/compute_alpha/classes.rb', line 26061

def update!(**args)
  @instance_selections = args[:instance_selections] if args.key?(:instance_selections)
end