Class: Google::Apis::ComputeAlpha::InstanceGroup
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::InstanceGroup
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Represents an Instance Group resource. Instance Groups can be used to configure a target forload balancing. Instance groups can either be managed or unmanaged. To create managed instance groups, use the instanceGroupManager orregionInstanceGroupManager resource instead. Use zonal unmanaged instance groups if you need to applyload balancing to groups of heterogeneous instances or if you need to manage the instances yourself. You cannot create regional unmanaged instance groups. For more information, readInstance groups.
Instance Attribute Summary collapse
-
#creation_timestamp ⇒ String
Output only.
-
#description ⇒ String
An optional description of this resource.
-
#fingerprint ⇒ String
Output only.
-
#id ⇒ Fixnum
Output only.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
The name of the instance group.
-
#named_ports ⇒ Array<Google::Apis::ComputeAlpha::NamedPort>
Optional.
-
#network ⇒ String
[Output Only] The URL of the network to which all instances in the instance group belong.
-
#region ⇒ String
Output only.
-
#self_link ⇒ String
Output only.
-
#self_link_with_id ⇒ String
Output only.
-
#size ⇒ Fixnum
Output only.
-
#subnetwork ⇒ String
Output only.
-
#zone ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceGroup
constructor
A new instance of InstanceGroup.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceGroup
Returns a new instance of InstanceGroup.
26559 26560 26561 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 26559 def initialize(**args) update!(**args) end |
Instance Attribute Details
#creation_timestamp ⇒ String
Output only. [Output Only] The creation timestamp for this instance group
inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
26465 26466 26467 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 26465 def @creation_timestamp end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
26471 26472 26473 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 26471 def description @description end |
#fingerprint ⇒ String
Output only. [Output Only] The fingerprint of the named ports. The system
uses this fingerprint to detect conflicts when multiple users change the
named ports concurrently.
Corresponds to the JSON property fingerprint
NOTE: Values are automatically base64 encoded/decoded in the client library.
26479 26480 26481 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 26479 def fingerprint @fingerprint end |
#id ⇒ Fixnum
Output only. [Output Only] A unique identifier for this instance group,
generated
by the server.
Corresponds to the JSON property id
26486 26487 26488 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 26486 def id @id end |
#kind ⇒ String
Output only. [Output Only] The resource type, which is alwayscompute#
instanceGroup for instance groups.
Corresponds to the JSON property kind
26492 26493 26494 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 26492 def kind @kind end |
#name ⇒ String
The name of the instance group. The name must be 1-63 characters
long, and comply withRFC1035.
Corresponds to the JSON property name
26498 26499 26500 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 26498 def name @name end |
#named_ports ⇒ Array<Google::Apis::ComputeAlpha::NamedPort>
Optional. Assigns a name to a port number. For example:name: "http", port: 80
This
allows the system to reference ports by the assigned name instead of a
port number. Named ports can also contain multiple ports. For example:[name: "
app1", port: 8080, name:
"app1", port: 8081, name: "app2", port:
8082]
Named ports apply to all instances in this instance group.
Corresponds to the JSON property namedPorts
26510 26511 26512 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 26510 def named_ports @named_ports end |
#network ⇒ String
[Output Only] The URL of the network to which all instances in the
instance group belong. If your instance has multiple network interfaces,
then the network and subnetwork fields only refer to the
network and subnet used by your primary interface (nic0).
Corresponds to the JSON property network
26518 26519 26520 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 26518 def network @network end |
#region ⇒ String
Output only. [Output Only] The URL of theregion
where the instance group is located (for regional resources).
Corresponds to the JSON property region
26524 26525 26526 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 26524 def region @region end |
#self_link ⇒ String
Output only. [Output Only] The URL for this instance group. The server
generates
this URL.
Corresponds to the JSON property selfLink
26531 26532 26533 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 26531 def self_link @self_link end |
#self_link_with_id ⇒ String
Output only. [Output Only] Server-defined URL for this resource with the
resource id.
Corresponds to the JSON property selfLinkWithId
26537 26538 26539 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 26537 def self_link_with_id @self_link_with_id end |
#size ⇒ Fixnum
Output only. [Output Only] The total number of instances in the instance group.
Corresponds to the JSON property size
26542 26543 26544 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 26542 def size @size end |
#subnetwork ⇒ String
Output only. [Output Only] The URL of the subnetwork to which all instances in
the
instance group belong. If your instance has multiple network interfaces,
then the network and subnetwork fields only refer to the
network and subnet used by your primary interface (nic0).
Corresponds to the JSON property subnetwork
26551 26552 26553 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 26551 def subnetwork @subnetwork end |
#zone ⇒ String
Output only. [Output Only] The URL of thezone
where the instance group is located (for zonal resources).
Corresponds to the JSON property zone
26557 26558 26559 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 26557 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
26564 26565 26566 26567 26568 26569 26570 26571 26572 26573 26574 26575 26576 26577 26578 26579 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 26564 def update!(**args) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @fingerprint = args[:fingerprint] if args.key?(:fingerprint) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @named_ports = args[:named_ports] if args.key?(:named_ports) @network = args[:network] if args.key?(:network) @region = args[:region] if args.key?(:region) @self_link = args[:self_link] if args.key?(:self_link) @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id) @size = args[:size] if args.key?(:size) @subnetwork = args[:subnetwork] if args.key?(:subnetwork) @zone = args[:zone] if args.key?(:zone) end |