Class: Google::Apis::ComputeAlpha::InstanceGroupAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupAggregatedList

Returns a new instance of InstanceGroupAggregatedList.



27373
27374
27375
# File 'lib/google/apis/compute_alpha/classes.rb', line 27373

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Output only. [Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


27333
27334
27335
# File 'lib/google/apis/compute_alpha/classes.rb', line 27333

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::InstanceGroupsScopedList>

A list of InstanceGroupsScopedList resources. Corresponds to the JSON property items



27338
27339
27340
# File 'lib/google/apis/compute_alpha/classes.rb', line 27338

def items
  @items
end

#kindString

Output only. [Output Only] The resource type, which is alwayscompute# instanceGroupAggregatedList for aggregated lists of instance groups. Corresponds to the JSON property kind

Returns:

  • (String)


27345
27346
27347
# File 'lib/google/apis/compute_alpha/classes.rb', line 27345

def kind
  @kind
end

#next_page_tokenString

Output only. [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


27356
27357
27358
# File 'lib/google/apis/compute_alpha/classes.rb', line 27356

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


27361
27362
27363
# File 'lib/google/apis/compute_alpha/classes.rb', line 27361

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


27366
27367
27368
# File 'lib/google/apis/compute_alpha/classes.rb', line 27366

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::InstanceGroupAggregatedList::Warning

Output only. [Output Only] Informational warning message. Corresponds to the JSON property warning



27371
27372
27373
# File 'lib/google/apis/compute_alpha/classes.rb', line 27371

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



27378
27379
27380
27381
27382
27383
27384
27385
27386
# File 'lib/google/apis/compute_alpha/classes.rb', line 27378

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end