Class: Google::Apis::ComputeAlpha::InstanceGroupAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupAggregatedList

Returns a new instance of InstanceGroupAggregatedList.



26435
26436
26437
# File 'lib/google/apis/compute_alpha/classes.rb', line 26435

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Output only. [Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


26395
26396
26397
# File 'lib/google/apis/compute_alpha/classes.rb', line 26395

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::InstanceGroupsScopedList>

A list of InstanceGroupsScopedList resources. Corresponds to the JSON property items



26400
26401
26402
# File 'lib/google/apis/compute_alpha/classes.rb', line 26400

def items
  @items
end

#kindString

Output only. [Output Only] The resource type, which is alwayscompute# instanceGroupAggregatedList for aggregated lists of instance groups. Corresponds to the JSON property kind

Returns:

  • (String)


26407
26408
26409
# File 'lib/google/apis/compute_alpha/classes.rb', line 26407

def kind
  @kind
end

#next_page_tokenString

Output only. [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


26418
26419
26420
# File 'lib/google/apis/compute_alpha/classes.rb', line 26418

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


26423
26424
26425
# File 'lib/google/apis/compute_alpha/classes.rb', line 26423

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


26428
26429
26430
# File 'lib/google/apis/compute_alpha/classes.rb', line 26428

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::InstanceGroupAggregatedList::Warning

Output only. [Output Only] Informational warning message. Corresponds to the JSON property warning



26433
26434
26435
# File 'lib/google/apis/compute_alpha/classes.rb', line 26433

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



26440
26441
26442
26443
26444
26445
26446
26447
26448
# File 'lib/google/apis/compute_alpha/classes.rb', line 26440

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end