Class: Google::Apis::ComputeAlpha::InstanceGroupList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

A list of InstanceGroup resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupList

Returns a new instance of InstanceGroupList.



27773
27774
27775
# File 'lib/google/apis/compute_alpha/classes.rb', line 27773

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Output only. [Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


27739
27740
27741
# File 'lib/google/apis/compute_alpha/classes.rb', line 27739

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::InstanceGroup>

A list of InstanceGroup resources. Corresponds to the JSON property items



27744
27745
27746
# File 'lib/google/apis/compute_alpha/classes.rb', line 27744

def items
  @items
end

#kindString

Output only. [Output Only] The resource type, which is alwayscompute# instanceGroupList for instance group lists. Corresponds to the JSON property kind

Returns:

  • (String)


27750
27751
27752
# File 'lib/google/apis/compute_alpha/classes.rb', line 27750

def kind
  @kind
end

#next_page_tokenString

Output only. [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


27761
27762
27763
# File 'lib/google/apis/compute_alpha/classes.rb', line 27761

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


27766
27767
27768
# File 'lib/google/apis/compute_alpha/classes.rb', line 27766

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::InstanceGroupList::Warning

Output only. [Output Only] Informational warning message. Corresponds to the JSON property warning



27771
27772
27773
# File 'lib/google/apis/compute_alpha/classes.rb', line 27771

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



27778
27779
27780
27781
27782
27783
27784
27785
# File 'lib/google/apis/compute_alpha/classes.rb', line 27778

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end