Class: Google::Apis::ComputeAlpha::InstanceGroupList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

A list of InstanceGroup resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupList

Returns a new instance of InstanceGroupList.



26758
26759
26760
# File 'lib/google/apis/compute_alpha/classes.rb', line 26758

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Output only. [Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


26724
26725
26726
# File 'lib/google/apis/compute_alpha/classes.rb', line 26724

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::InstanceGroup>

A list of InstanceGroup resources. Corresponds to the JSON property items



26729
26730
26731
# File 'lib/google/apis/compute_alpha/classes.rb', line 26729

def items
  @items
end

#kindString

Output only. [Output Only] The resource type, which is alwayscompute# instanceGroupList for instance group lists. Corresponds to the JSON property kind

Returns:

  • (String)


26735
26736
26737
# File 'lib/google/apis/compute_alpha/classes.rb', line 26735

def kind
  @kind
end

#next_page_tokenString

Output only. [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


26746
26747
26748
# File 'lib/google/apis/compute_alpha/classes.rb', line 26746

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


26751
26752
26753
# File 'lib/google/apis/compute_alpha/classes.rb', line 26751

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::InstanceGroupList::Warning

Output only. [Output Only] Informational warning message. Corresponds to the JSON property warning



26756
26757
26758
# File 'lib/google/apis/compute_alpha/classes.rb', line 26756

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



26763
26764
26765
26766
26767
26768
26769
26770
# File 'lib/google/apis/compute_alpha/classes.rb', line 26763

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end