Class: Google::Apis::ComputeAlpha::InstanceGroupList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

A list of InstanceGroup resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupList

Returns a new instance of InstanceGroupList.



26553
26554
26555
# File 'lib/google/apis/compute_alpha/classes.rb', line 26553

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Output only. [Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


26519
26520
26521
# File 'lib/google/apis/compute_alpha/classes.rb', line 26519

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::InstanceGroup>

A list of InstanceGroup resources. Corresponds to the JSON property items



26524
26525
26526
# File 'lib/google/apis/compute_alpha/classes.rb', line 26524

def items
  @items
end

#kindString

Output only. [Output Only] The resource type, which is alwayscompute# instanceGroupList for instance group lists. Corresponds to the JSON property kind

Returns:

  • (String)


26530
26531
26532
# File 'lib/google/apis/compute_alpha/classes.rb', line 26530

def kind
  @kind
end

#next_page_tokenString

Output only. [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


26541
26542
26543
# File 'lib/google/apis/compute_alpha/classes.rb', line 26541

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


26546
26547
26548
# File 'lib/google/apis/compute_alpha/classes.rb', line 26546

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::InstanceGroupList::Warning

Output only. [Output Only] Informational warning message. Corresponds to the JSON property warning



26551
26552
26553
# File 'lib/google/apis/compute_alpha/classes.rb', line 26551

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



26558
26559
26560
26561
26562
26563
26564
26565
# File 'lib/google/apis/compute_alpha/classes.rb', line 26558

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end