Class: Google::Apis::ComputeAlpha::InstanceGroupManager

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Represents a Managed Instance Group resource. An instance group is a collection of VM instances that you can manage as a single entity. For more information, readInstance groups. For zonal Managed Instance Group, use the instanceGroupManagers resource. For regional Managed Instance Group, use theregionInstanceGroupManagers resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupManager

Returns a new instance of InstanceGroupManager.



28136
28137
28138
# File 'lib/google/apis/compute_alpha/classes.rb', line 28136

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#all_instances_configGoogle::Apis::ComputeAlpha::InstanceGroupManagerAllInstancesConfig

Specifies configuration that overrides the instance template configuration for the group. Corresponds to the JSON property allInstancesConfig



27872
27873
27874
# File 'lib/google/apis/compute_alpha/classes.rb', line 27872

def all_instances_config
  @all_instances_config
end

#auto_healing_policiesArray<Google::Apis::ComputeAlpha::InstanceGroupManagerAutoHealingPolicy>

The autohealing policy for this managed instance group. You can specify only one value. Corresponds to the JSON property autoHealingPolicies



27878
27879
27880
# File 'lib/google/apis/compute_alpha/classes.rb', line 27878

def auto_healing_policies
  @auto_healing_policies
end

#base_instance_nameString

The base instance name is a prefix that you want to attach to the names of all VMs in a MIG. The maximum character length is 58 and the name must comply with RFC1035 format. When a VM is created in the group, the MIG appends a hyphen and a random four-character string to the base instance name. If you want the MIG to assign sequential numbers instead of a random string, then end the base instance name with a hyphen followed by one or more hash symbols. The hash symbols indicate the number of digits. For example, a base instance name of "vm-###" results in "vm-001" as a VM name. a-z Corresponds to the JSON property baseInstanceName

Returns:

  • (String)


27893
27894
27895
# File 'lib/google/apis/compute_alpha/classes.rb', line 27893

def base_instance_name
  @base_instance_name
end

#creation_timestampString

Output only. The creation timestamp for this managed instance group inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


27899
27900
27901
# File 'lib/google/apis/compute_alpha/classes.rb', line 27899

def creation_timestamp
  @creation_timestamp
end

#current_actionsGoogle::Apis::ComputeAlpha::InstanceGroupManagerActionsSummary

Output only. The list of instance actions and the number of instances in this managed instance group that are scheduled for each of those actions. Corresponds to the JSON property currentActions



27906
27907
27908
# File 'lib/google/apis/compute_alpha/classes.rb', line 27906

def current_actions
  @current_actions
end

#descriptionString

An optional description of this resource. Corresponds to the JSON property description

Returns:

  • (String)


27911
27912
27913
# File 'lib/google/apis/compute_alpha/classes.rb', line 27911

def description
  @description
end

#distribution_policyGoogle::Apis::ComputeAlpha::DistributionPolicy

Policy specifying the intended distribution of managed instances across zones in a regional managed instance group. Corresponds to the JSON property distributionPolicy



27917
27918
27919
# File 'lib/google/apis/compute_alpha/classes.rb', line 27917

def distribution_policy
  @distribution_policy
end

#failover_actionString

The action to perform in case of zone failure. Only one value is supported, NO_FAILOVER. The default is NO_FAILOVER. Corresponds to the JSON property failoverAction

Returns:

  • (String)


27923
27924
27925
# File 'lib/google/apis/compute_alpha/classes.rb', line 27923

def failover_action
  @failover_action
end

#fingerprintString

Fingerprint of this resource. This field may be used in optimistic locking. It will be ignored when inserting an InstanceGroupManager. An up-to-date fingerprint must be provided in order to update the InstanceGroupManager, otherwise the request will fail with error412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve an InstanceGroupManager. Corresponds to the JSON property fingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


27934
27935
27936
# File 'lib/google/apis/compute_alpha/classes.rb', line 27934

def fingerprint
  @fingerprint
end

#idFixnum

Output only. A unique identifier for this resource type. The server generates this identifier. Corresponds to the JSON property id

Returns:

  • (Fixnum)


27940
27941
27942
# File 'lib/google/apis/compute_alpha/classes.rb', line 27940

def id
  @id
end

#instance_flexibility_policyGoogle::Apis::ComputeAlpha::InstanceGroupManagerInstanceFlexibilityPolicy

Instance flexibility allowing MIG to create VMs from multiple types of machines. Instance flexibility configuration on MIG overrides instance template configuration. Corresponds to the JSON property instanceFlexibilityPolicy



27948
27949
27950
# File 'lib/google/apis/compute_alpha/classes.rb', line 27948

def instance_flexibility_policy
  @instance_flexibility_policy
end

#instance_groupString

Output only. The URL of the Instance Group resource. Corresponds to the JSON property instanceGroup

Returns:

  • (String)


27953
27954
27955
# File 'lib/google/apis/compute_alpha/classes.rb', line 27953

def instance_group
  @instance_group
end

#instance_lifecycle_policyGoogle::Apis::ComputeAlpha::InstanceGroupManagerInstanceLifecyclePolicy

The repair policy for this managed instance group. Corresponds to the JSON property instanceLifecyclePolicy



27958
27959
27960
# File 'lib/google/apis/compute_alpha/classes.rb', line 27958

def instance_lifecycle_policy
  @instance_lifecycle_policy
end

#instance_templateString

The URL of the instance template that is specified for this managed instance group. The group uses this template to create all new instances in the managed instance group. The templates for existing instances in the group do not change unless you run recreateInstances, runapplyUpdatesToInstances, or set the group'supdatePolicy.type to PROACTIVE. Corresponds to the JSON property instanceTemplate

Returns:

  • (String)


27967
27968
27969
# File 'lib/google/apis/compute_alpha/classes.rb', line 27967

def instance_template
  @instance_template
end

#kindString

Output only. The resource type, which is alwayscompute#instanceGroupManager for managed instance groups. Corresponds to the JSON property kind

Returns:

  • (String)


27973
27974
27975
# File 'lib/google/apis/compute_alpha/classes.rb', line 27973

def kind
  @kind
end

#list_managed_instances_resultsString

Pagination behavior of the listManagedInstances API method for this managed instance group. Corresponds to the JSON property listManagedInstancesResults

Returns:

  • (String)


27979
27980
27981
# File 'lib/google/apis/compute_alpha/classes.rb', line 27979

def list_managed_instances_results
  @list_managed_instances_results
end

#multi_migString

URL to the multi-MIG that this Managed Instance Group belongs to. Corresponds to the JSON property multiMig

Returns:

  • (String)


27984
27985
27986
# File 'lib/google/apis/compute_alpha/classes.rb', line 27984

def multi_mig
  @multi_mig
end

#nameString

The name of the managed instance group. The name must be 1-63 characters long, and comply withRFC1035. Corresponds to the JSON property name

Returns:

  • (String)


27990
27991
27992
# File 'lib/google/apis/compute_alpha/classes.rb', line 27990

def name
  @name
end

#named_portsArray<Google::Apis::ComputeAlpha::NamedPort>

[Output Only] Named ports configured on the Instance Groups complementary to this Instance Group Manager. Corresponds to the JSON property namedPorts



27996
27997
27998
# File 'lib/google/apis/compute_alpha/classes.rb', line 27996

def named_ports
  @named_ports
end

#paramsGoogle::Apis::ComputeAlpha::InstanceGroupManagerParams

Input only additional params for instance group manager creation. Corresponds to the JSON property params



28001
28002
28003
# File 'lib/google/apis/compute_alpha/classes.rb', line 28001

def params
  @params
end

#regionString

Output only. [Output Only] The URL of theregion where the managed instance group resides (for regional resources). Corresponds to the JSON property region

Returns:

  • (String)


28007
28008
28009
# File 'lib/google/apis/compute_alpha/classes.rb', line 28007

def region
  @region
end

#resource_policiesGoogle::Apis::ComputeAlpha::InstanceGroupManagerResourcePolicies

Resource policies for this managed instance group. Corresponds to the JSON property resourcePolicies



28012
28013
28014
# File 'lib/google/apis/compute_alpha/classes.rb', line 28012

def resource_policies
  @resource_policies
end

#satisfies_pziBoolean Also known as: satisfies_pzi?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzi

Returns:

  • (Boolean)


28017
28018
28019
# File 'lib/google/apis/compute_alpha/classes.rb', line 28017

def satisfies_pzi
  @satisfies_pzi
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


28023
28024
28025
# File 'lib/google/apis/compute_alpha/classes.rb', line 28023

def satisfies_pzs
  @satisfies_pzs
end

Output only. The URL for this managed instance group. The server defines this URL. Corresponds to the JSON property selfLink

Returns:

  • (String)


28030
28031
28032
# File 'lib/google/apis/compute_alpha/classes.rb', line 28030

def self_link
  @self_link
end

Output only. Server-defined URL for this resource with the resource id. Corresponds to the JSON property selfLinkWithId

Returns:

  • (String)


28035
28036
28037
# File 'lib/google/apis/compute_alpha/classes.rb', line 28035

def self_link_with_id
  @self_link_with_id
end

#service_accountString

The service account to be used as credentials for all operations performed by the managed instance group on instances. The service accounts needs all permissions required to create and delete instances. By default, the service account projectNumber@cloudservices.gserviceaccount.com is used. Corresponds to the JSON property serviceAccount

Returns:

  • (String)


28044
28045
28046
# File 'lib/google/apis/compute_alpha/classes.rb', line 28044

def 
  @service_account
end

#standby_policyGoogle::Apis::ComputeAlpha::InstanceGroupManagerStandbyPolicy

Standby policy for stopped and suspended instances. Corresponds to the JSON property standbyPolicy



28049
28050
28051
# File 'lib/google/apis/compute_alpha/classes.rb', line 28049

def standby_policy
  @standby_policy
end

#stateful_policyGoogle::Apis::ComputeAlpha::StatefulPolicy

Stateful configuration for this Instanced Group Manager Corresponds to the JSON property statefulPolicy



28054
28055
28056
# File 'lib/google/apis/compute_alpha/classes.rb', line 28054

def stateful_policy
  @stateful_policy
end

#statusGoogle::Apis::ComputeAlpha::InstanceGroupManagerStatus

Output only. The status of this managed instance group. Corresponds to the JSON property status



28059
28060
28061
# File 'lib/google/apis/compute_alpha/classes.rb', line 28059

def status
  @status
end

#target_poolsArray<String>

The URLs for all TargetPool resources to which instances in theinstanceGroup field are added. The target pools automatically apply to all of the instances in the managed instance group. Corresponds to the JSON property targetPools

Returns:

  • (Array<String>)


28066
28067
28068
# File 'lib/google/apis/compute_alpha/classes.rb', line 28066

def target_pools
  @target_pools
end

#target_sizeFixnum

The target number of running instances for this managed instance group. You can reduce this number by using the instanceGroupManager deleteInstances or abandonInstances methods. Resizing the group also changes this number. Corresponds to the JSON property targetSize

Returns:

  • (Fixnum)


28074
28075
28076
# File 'lib/google/apis/compute_alpha/classes.rb', line 28074

def target_size
  @target_size
end

#target_size_policyGoogle::Apis::ComputeAlpha::InstanceGroupManagerTargetSizePolicy

The policy that specifies how the MIG creates its VMs to achieve the target size. Corresponds to the JSON property targetSizePolicy



28080
28081
28082
# File 'lib/google/apis/compute_alpha/classes.rb', line 28080

def target_size_policy
  @target_size_policy
end

#target_size_unitString

The unit of measure for the target size. Corresponds to the JSON property targetSizeUnit

Returns:

  • (String)


28085
28086
28087
# File 'lib/google/apis/compute_alpha/classes.rb', line 28085

def target_size_unit
  @target_size_unit
end

#target_stopped_sizeFixnum

The target number of stopped instances for this managed instance group. This number changes when you:

  • Stop instance using the stopInstances method or start instances using the startInstances method.
  • Manually change the targetStoppedSize using the update method. Corresponds to the JSON property targetStoppedSize

Returns:

  • (Fixnum)


28097
28098
28099
# File 'lib/google/apis/compute_alpha/classes.rb', line 28097

def target_stopped_size
  @target_stopped_size
end

#target_suspended_sizeFixnum

The target number of suspended instances for this managed instance group. This number changes when you:

  • Suspend instance using the suspendInstances method or resume instances using the resumeInstances method.
  • Manually change the targetSuspendedSize using the update method. Corresponds to the JSON property targetSuspendedSize

Returns:

  • (Fixnum)


28109
28110
28111
# File 'lib/google/apis/compute_alpha/classes.rb', line 28109

def target_suspended_size
  @target_suspended_size
end

#update_policyGoogle::Apis::ComputeAlpha::InstanceGroupManagerUpdatePolicy

The update policy for this managed instance group. Corresponds to the JSON property updatePolicy



28114
28115
28116
# File 'lib/google/apis/compute_alpha/classes.rb', line 28114

def update_policy
  @update_policy
end

#versionsArray<Google::Apis::ComputeAlpha::InstanceGroupManagerVersion>

Specifies the instance templates used by this managed instance group to create instances. Each version is defined by an instanceTemplate and aname. Every version can appear at most once per instance group. This field overrides the top-level instanceTemplate field. Read more about therelationships between these fields. Exactly one version must leave thetargetSize field unset. That version will be applied to all remaining instances. For more information, read aboutcanary updates. Corresponds to the JSON property versions



28128
28129
28130
# File 'lib/google/apis/compute_alpha/classes.rb', line 28128

def versions
  @versions
end

#zoneString

Output only. The URL of azone where the managed instance group is located (for zonal resources). Corresponds to the JSON property zone

Returns:

  • (String)


28134
28135
28136
# File 'lib/google/apis/compute_alpha/classes.rb', line 28134

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



28141
28142
28143
28144
28145
28146
28147
28148
28149
28150
28151
28152
28153
28154
28155
28156
28157
28158
28159
28160
28161
28162
28163
28164
28165
28166
28167
28168
28169
28170
28171
28172
28173
28174
28175
28176
28177
28178
28179
28180
28181
# File 'lib/google/apis/compute_alpha/classes.rb', line 28141

def update!(**args)
  @all_instances_config = args[:all_instances_config] if args.key?(:all_instances_config)
  @auto_healing_policies = args[:auto_healing_policies] if args.key?(:auto_healing_policies)
  @base_instance_name = args[:base_instance_name] if args.key?(:base_instance_name)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @current_actions = args[:current_actions] if args.key?(:current_actions)
  @description = args[:description] if args.key?(:description)
  @distribution_policy = args[:distribution_policy] if args.key?(:distribution_policy)
  @failover_action = args[:failover_action] if args.key?(:failover_action)
  @fingerprint = args[:fingerprint] if args.key?(:fingerprint)
  @id = args[:id] if args.key?(:id)
  @instance_flexibility_policy = args[:instance_flexibility_policy] if args.key?(:instance_flexibility_policy)
  @instance_group = args[:instance_group] if args.key?(:instance_group)
  @instance_lifecycle_policy = args[:instance_lifecycle_policy] if args.key?(:instance_lifecycle_policy)
  @instance_template = args[:instance_template] if args.key?(:instance_template)
  @kind = args[:kind] if args.key?(:kind)
  @list_managed_instances_results = args[:list_managed_instances_results] if args.key?(:list_managed_instances_results)
  @multi_mig = args[:multi_mig] if args.key?(:multi_mig)
  @name = args[:name] if args.key?(:name)
  @named_ports = args[:named_ports] if args.key?(:named_ports)
  @params = args[:params] if args.key?(:params)
  @region = args[:region] if args.key?(:region)
  @resource_policies = args[:resource_policies] if args.key?(:resource_policies)
  @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @self_link = args[:self_link] if args.key?(:self_link)
  @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id)
  @service_account = args[:service_account] if args.key?(:service_account)
  @standby_policy = args[:standby_policy] if args.key?(:standby_policy)
  @stateful_policy = args[:stateful_policy] if args.key?(:stateful_policy)
  @status = args[:status] if args.key?(:status)
  @target_pools = args[:target_pools] if args.key?(:target_pools)
  @target_size = args[:target_size] if args.key?(:target_size)
  @target_size_policy = args[:target_size_policy] if args.key?(:target_size_policy)
  @target_size_unit = args[:target_size_unit] if args.key?(:target_size_unit)
  @target_stopped_size = args[:target_stopped_size] if args.key?(:target_stopped_size)
  @target_suspended_size = args[:target_suspended_size] if args.key?(:target_suspended_size)
  @update_policy = args[:update_policy] if args.key?(:update_policy)
  @versions = args[:versions] if args.key?(:versions)
  @zone = args[:zone] if args.key?(:zone)
end