Class: Google::Apis::ComputeAlpha::InstanceGroupManager
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::InstanceGroupManager
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Represents a Managed Instance Group resource. An instance group is a collection of VM instances that you can manage as a single entity. For more information, readInstance groups. For zonal Managed Instance Group, use the instanceGroupManagers resource. For regional Managed Instance Group, use theregionInstanceGroupManagers resource.
Instance Attribute Summary collapse
-
#all_instances_config ⇒ Google::Apis::ComputeAlpha::InstanceGroupManagerAllInstancesConfig
Specifies configuration that overrides the instance template configuration for the group.
-
#auto_healing_policies ⇒ Array<Google::Apis::ComputeAlpha::InstanceGroupManagerAutoHealingPolicy>
The autohealing policy for this managed instance group.
-
#base_instance_name ⇒ String
The base instance name is a prefix that you want to attach to the names of all VMs in a MIG.
-
#creation_timestamp ⇒ String
Output only.
-
#current_actions ⇒ Google::Apis::ComputeAlpha::InstanceGroupManagerActionsSummary
Output only.
-
#description ⇒ String
An optional description of this resource.
-
#distribution_policy ⇒ Google::Apis::ComputeAlpha::DistributionPolicy
Policy specifying the intended distribution of managed instances across zones in a regional managed instance group.
-
#failover_action ⇒ String
The action to perform in case of zone failure.
-
#fingerprint ⇒ String
Fingerprint of this resource.
-
#id ⇒ Fixnum
Output only.
-
#instance_flexibility_policy ⇒ Google::Apis::ComputeAlpha::InstanceGroupManagerInstanceFlexibilityPolicy
Instance flexibility allowing MIG to create VMs from multiple types of machines.
-
#instance_group ⇒ String
Output only.
-
#instance_lifecycle_policy ⇒ Google::Apis::ComputeAlpha::InstanceGroupManagerInstanceLifecyclePolicy
The repair policy for this managed instance group.
-
#instance_template ⇒ String
The URL of the instance template that is specified for this managed instance group.
-
#kind ⇒ String
Output only.
-
#list_managed_instances_results ⇒ String
Pagination behavior of the listManagedInstances API method for this managed instance group.
-
#multi_mig ⇒ String
URL to the multi-MIG that this Managed Instance Group belongs to.
-
#name ⇒ String
The name of the managed instance group.
-
#named_ports ⇒ Array<Google::Apis::ComputeAlpha::NamedPort>
[Output Only] Named ports configured on the Instance Groups complementary to this Instance Group Manager.
-
#params ⇒ Google::Apis::ComputeAlpha::InstanceGroupManagerParams
Input only additional params for instance group manager creation.
-
#region ⇒ String
Output only.
-
#resource_policies ⇒ Google::Apis::ComputeAlpha::InstanceGroupManagerResourcePolicies
Resource policies for this managed instance group.
-
#satisfies_pzi ⇒ Boolean
(also: #satisfies_pzi?)
Output only.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
Output only.
-
#self_link ⇒ String
Output only.
-
#self_link_with_id ⇒ String
Output only.
-
#service_account ⇒ String
The service account to be used as credentials for all operations performed by the managed instance group on instances.
-
#standby_policy ⇒ Google::Apis::ComputeAlpha::InstanceGroupManagerStandbyPolicy
Standby policy for stopped and suspended instances.
-
#stateful_policy ⇒ Google::Apis::ComputeAlpha::StatefulPolicy
Stateful configuration for this Instanced Group Manager Corresponds to the JSON property
statefulPolicy. -
#status ⇒ Google::Apis::ComputeAlpha::InstanceGroupManagerStatus
Output only.
-
#target_pools ⇒ Array<String>
The URLs for all TargetPool resources to which instances in theinstanceGroup field are added.
-
#target_size ⇒ Fixnum
The target number of running instances for this managed instance group.
-
#target_size_policy ⇒ Google::Apis::ComputeAlpha::InstanceGroupManagerTargetSizePolicy
The policy that specifies how the MIG creates its VMs to achieve the target size.
-
#target_size_unit ⇒ String
The unit of measure for the target size.
-
#target_stopped_size ⇒ Fixnum
The target number of stopped instances for this managed instance group.
-
#target_suspended_size ⇒ Fixnum
The target number of suspended instances for this managed instance group.
-
#update_policy ⇒ Google::Apis::ComputeAlpha::InstanceGroupManagerUpdatePolicy
The update policy for this managed instance group.
-
#versions ⇒ Array<Google::Apis::ComputeAlpha::InstanceGroupManagerVersion>
Specifies the instance templates used by this managed instance group to create instances.
-
#zone ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceGroupManager
constructor
A new instance of InstanceGroupManager.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceGroupManager
Returns a new instance of InstanceGroupManager.
27864 27865 27866 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27864 def initialize(**args) update!(**args) end |
Instance Attribute Details
#all_instances_config ⇒ Google::Apis::ComputeAlpha::InstanceGroupManagerAllInstancesConfig
Specifies configuration that overrides the instance template configuration
for the group.
Corresponds to the JSON property allInstancesConfig
27600 27601 27602 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27600 def all_instances_config @all_instances_config end |
#auto_healing_policies ⇒ Array<Google::Apis::ComputeAlpha::InstanceGroupManagerAutoHealingPolicy>
The autohealing policy for this managed instance group. You can specify
only one value.
Corresponds to the JSON property autoHealingPolicies
27606 27607 27608 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27606 def auto_healing_policies @auto_healing_policies end |
#base_instance_name ⇒ String
The base instance name is a prefix that you want to attach to the names of
all VMs in a MIG. The maximum character length is 58 and the name must
comply with RFC1035 format.
When a VM is created in the group, the MIG appends a hyphen and a random
four-character string to the base instance name. If you want the MIG to
assign sequential numbers instead of a random string, then end the base
instance name with a hyphen followed by one or more hash symbols. The hash
symbols indicate the number of digits. For example, a base instance name of
"vm-###" results in "vm-001" as a VM name.
a-z
Corresponds to the JSON property baseInstanceName
27621 27622 27623 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27621 def base_instance_name @base_instance_name end |
#creation_timestamp ⇒ String
Output only. The creation timestamp for this managed instance group inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
27627 27628 27629 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27627 def @creation_timestamp end |
#current_actions ⇒ Google::Apis::ComputeAlpha::InstanceGroupManagerActionsSummary
Output only. The list of instance actions and the number of instances
in this managed instance group that are scheduled for each of those
actions.
Corresponds to the JSON property currentActions
27634 27635 27636 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27634 def current_actions @current_actions end |
#description ⇒ String
An optional description of this resource.
Corresponds to the JSON property description
27639 27640 27641 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27639 def description @description end |
#distribution_policy ⇒ Google::Apis::ComputeAlpha::DistributionPolicy
Policy specifying the intended distribution of managed instances across
zones in a regional managed instance group.
Corresponds to the JSON property distributionPolicy
27645 27646 27647 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27645 def distribution_policy @distribution_policy end |
#failover_action ⇒ String
The action to perform in case of zone failure. Only one value is supported,
NO_FAILOVER. The default is NO_FAILOVER.
Corresponds to the JSON property failoverAction
27651 27652 27653 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27651 def failover_action @failover_action end |
#fingerprint ⇒ String
Fingerprint of this resource. This field may be used in optimistic locking.
It will be ignored when inserting an InstanceGroupManager. An up-to-date
fingerprint must be provided in order to update the InstanceGroupManager,
otherwise the request will fail with error412 conditionNotMet.
To see the latest fingerprint, make a get() request to
retrieve an InstanceGroupManager.
Corresponds to the JSON property fingerprint
NOTE: Values are automatically base64 encoded/decoded in the client library.
27662 27663 27664 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27662 def fingerprint @fingerprint end |
#id ⇒ Fixnum
Output only. A unique identifier for this resource type. The server
generates this identifier.
Corresponds to the JSON property id
27668 27669 27670 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27668 def id @id end |
#instance_flexibility_policy ⇒ Google::Apis::ComputeAlpha::InstanceGroupManagerInstanceFlexibilityPolicy
Instance flexibility allowing MIG to create VMs from multiple
types of machines.
Instance flexibility configuration on MIG overrides instance
template configuration.
Corresponds to the JSON property instanceFlexibilityPolicy
27676 27677 27678 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27676 def instance_flexibility_policy @instance_flexibility_policy end |
#instance_group ⇒ String
Output only. The URL of the Instance Group resource.
Corresponds to the JSON property instanceGroup
27681 27682 27683 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27681 def instance_group @instance_group end |
#instance_lifecycle_policy ⇒ Google::Apis::ComputeAlpha::InstanceGroupManagerInstanceLifecyclePolicy
The repair policy for this managed instance group.
Corresponds to the JSON property instanceLifecyclePolicy
27686 27687 27688 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27686 def instance_lifecycle_policy @instance_lifecycle_policy end |
#instance_template ⇒ String
The URL of the instance template that is specified for this managed
instance group. The group uses this template to create all new instances
in the managed instance group. The templates for existing instances in the
group do not change unless you run recreateInstances,
runapplyUpdatesToInstances, or set the group'supdatePolicy.type to PROACTIVE.
Corresponds to the JSON property instanceTemplate
27695 27696 27697 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27695 def instance_template @instance_template end |
#kind ⇒ String
Output only. The resource type, which is alwayscompute#instanceGroupManager
for managed instance groups.
Corresponds to the JSON property kind
27701 27702 27703 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27701 def kind @kind end |
#list_managed_instances_results ⇒ String
Pagination behavior of the listManagedInstances API method for
this managed instance group.
Corresponds to the JSON property listManagedInstancesResults
27707 27708 27709 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27707 def list_managed_instances_results @list_managed_instances_results end |
#multi_mig ⇒ String
URL to the multi-MIG that this Managed Instance Group belongs to.
Corresponds to the JSON property multiMig
27712 27713 27714 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27712 def multi_mig @multi_mig end |
#name ⇒ String
The name of the managed instance group. The name must be 1-63 characters
long, and comply withRFC1035.
Corresponds to the JSON property name
27718 27719 27720 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27718 def name @name end |
#named_ports ⇒ Array<Google::Apis::ComputeAlpha::NamedPort>
[Output Only] Named ports configured on the Instance Groups complementary
to this Instance Group Manager.
Corresponds to the JSON property namedPorts
27724 27725 27726 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27724 def named_ports @named_ports end |
#params ⇒ Google::Apis::ComputeAlpha::InstanceGroupManagerParams
Input only additional params for instance group manager creation.
Corresponds to the JSON property params
27729 27730 27731 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27729 def params @params end |
#region ⇒ String
Output only. [Output Only] The URL of theregion
where the managed instance group resides (for regional resources).
Corresponds to the JSON property region
27735 27736 27737 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27735 def region @region end |
#resource_policies ⇒ Google::Apis::ComputeAlpha::InstanceGroupManagerResourcePolicies
Resource policies for this managed instance group.
Corresponds to the JSON property resourcePolicies
27740 27741 27742 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27740 def resource_policies @resource_policies end |
#satisfies_pzi ⇒ Boolean Also known as: satisfies_pzi?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzi
27745 27746 27747 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27745 def satisfies_pzi @satisfies_pzi end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzs
27751 27752 27753 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27751 def satisfies_pzs @satisfies_pzs end |
#self_link ⇒ String
Output only. The URL for this managed instance group. The server defines
this URL.
Corresponds to the JSON property selfLink
27758 27759 27760 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27758 def self_link @self_link end |
#self_link_with_id ⇒ String
Output only. Server-defined URL for this resource with the resource id.
Corresponds to the JSON property selfLinkWithId
27763 27764 27765 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27763 def self_link_with_id @self_link_with_id end |
#service_account ⇒ String
The service account to be used as credentials for all operations performed
by the managed instance group on instances. The service accounts needs all
permissions required to create and delete instances.
By default, the service account
projectNumber@cloudservices.gserviceaccount.com is used.
Corresponds to the JSON property serviceAccount
27772 27773 27774 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27772 def service_account @service_account end |
#standby_policy ⇒ Google::Apis::ComputeAlpha::InstanceGroupManagerStandbyPolicy
Standby policy for stopped and suspended instances.
Corresponds to the JSON property standbyPolicy
27777 27778 27779 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27777 def standby_policy @standby_policy end |
#stateful_policy ⇒ Google::Apis::ComputeAlpha::StatefulPolicy
Stateful configuration for this Instanced Group Manager
Corresponds to the JSON property statefulPolicy
27782 27783 27784 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27782 def stateful_policy @stateful_policy end |
#status ⇒ Google::Apis::ComputeAlpha::InstanceGroupManagerStatus
Output only. The status of this managed instance group.
Corresponds to the JSON property status
27787 27788 27789 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27787 def status @status end |
#target_pools ⇒ Array<String>
The URLs for all TargetPool resources to which instances in theinstanceGroup
field are added. The target pools automatically
apply to all of the instances in the managed instance group.
Corresponds to the JSON property targetPools
27794 27795 27796 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27794 def target_pools @target_pools end |
#target_size ⇒ Fixnum
The target number of running instances for this managed instance group.
You can reduce this number by using the instanceGroupManager
deleteInstances or abandonInstances methods. Resizing the group also
changes this number.
Corresponds to the JSON property targetSize
27802 27803 27804 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27802 def target_size @target_size end |
#target_size_policy ⇒ Google::Apis::ComputeAlpha::InstanceGroupManagerTargetSizePolicy
The policy that specifies how the MIG creates its VMs to achieve the target
size.
Corresponds to the JSON property targetSizePolicy
27808 27809 27810 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27808 def target_size_policy @target_size_policy end |
#target_size_unit ⇒ String
The unit of measure for the target size.
Corresponds to the JSON property targetSizeUnit
27813 27814 27815 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27813 def target_size_unit @target_size_unit end |
#target_stopped_size ⇒ Fixnum
The target number of stopped instances for this managed instance group. This number changes when you:
- Stop instance using the stopInstances method or start instances using the startInstances method.
- Manually change the targetStoppedSize using the update
method.
Corresponds to the JSON property
targetStoppedSize
27825 27826 27827 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27825 def target_stopped_size @target_stopped_size end |
#target_suspended_size ⇒ Fixnum
The target number of suspended instances for this managed instance group. This number changes when you:
- Suspend instance using the suspendInstances method or resume instances using the resumeInstances method.
- Manually change the targetSuspendedSize using the update
method.
Corresponds to the JSON property
targetSuspendedSize
27837 27838 27839 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27837 def target_suspended_size @target_suspended_size end |
#update_policy ⇒ Google::Apis::ComputeAlpha::InstanceGroupManagerUpdatePolicy
The update policy for this managed instance group.
Corresponds to the JSON property updatePolicy
27842 27843 27844 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27842 def update_policy @update_policy end |
#versions ⇒ Array<Google::Apis::ComputeAlpha::InstanceGroupManagerVersion>
Specifies the instance templates used by this managed instance group to
create instances.
Each version is defined by an instanceTemplate and aname. Every version can
appear at most once per instance
group. This field overrides the top-level instanceTemplate
field. Read more about therelationships
between these fields. Exactly one version must leave thetargetSize field unset.
That version will be applied to all
remaining instances. For more information, read aboutcanary
updates.
Corresponds to the JSON property versions
27856 27857 27858 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27856 def versions @versions end |
#zone ⇒ String
Output only. The URL of azone
where the managed instance group is located (for zonal resources).
Corresponds to the JSON property zone
27862 27863 27864 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27862 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
27869 27870 27871 27872 27873 27874 27875 27876 27877 27878 27879 27880 27881 27882 27883 27884 27885 27886 27887 27888 27889 27890 27891 27892 27893 27894 27895 27896 27897 27898 27899 27900 27901 27902 27903 27904 27905 27906 27907 27908 27909 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27869 def update!(**args) @all_instances_config = args[:all_instances_config] if args.key?(:all_instances_config) @auto_healing_policies = args[:auto_healing_policies] if args.key?(:auto_healing_policies) @base_instance_name = args[:base_instance_name] if args.key?(:base_instance_name) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @current_actions = args[:current_actions] if args.key?(:current_actions) @description = args[:description] if args.key?(:description) @distribution_policy = args[:distribution_policy] if args.key?(:distribution_policy) @failover_action = args[:failover_action] if args.key?(:failover_action) @fingerprint = args[:fingerprint] if args.key?(:fingerprint) @id = args[:id] if args.key?(:id) @instance_flexibility_policy = args[:instance_flexibility_policy] if args.key?(:instance_flexibility_policy) @instance_group = args[:instance_group] if args.key?(:instance_group) @instance_lifecycle_policy = args[:instance_lifecycle_policy] if args.key?(:instance_lifecycle_policy) @instance_template = args[:instance_template] if args.key?(:instance_template) @kind = args[:kind] if args.key?(:kind) @list_managed_instances_results = args[:list_managed_instances_results] if args.key?(:list_managed_instances_results) @multi_mig = args[:multi_mig] if args.key?(:multi_mig) @name = args[:name] if args.key?(:name) @named_ports = args[:named_ports] if args.key?(:named_ports) @params = args[:params] if args.key?(:params) @region = args[:region] if args.key?(:region) @resource_policies = args[:resource_policies] if args.key?(:resource_policies) @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @self_link = args[:self_link] if args.key?(:self_link) @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id) @service_account = args[:service_account] if args.key?(:service_account) @standby_policy = args[:standby_policy] if args.key?(:standby_policy) @stateful_policy = args[:stateful_policy] if args.key?(:stateful_policy) @status = args[:status] if args.key?(:status) @target_pools = args[:target_pools] if args.key?(:target_pools) @target_size = args[:target_size] if args.key?(:target_size) @target_size_policy = args[:target_size_policy] if args.key?(:target_size_policy) @target_size_unit = args[:target_size_unit] if args.key?(:target_size_unit) @target_stopped_size = args[:target_stopped_size] if args.key?(:target_stopped_size) @target_suspended_size = args[:target_suspended_size] if args.key?(:target_suspended_size) @update_policy = args[:update_policy] if args.key?(:update_policy) @versions = args[:versions] if args.key?(:versions) @zone = args[:zone] if args.key?(:zone) end |