Class: Google::Apis::ComputeAlpha::InstanceGroupManager
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::InstanceGroupManager
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Represents a Managed Instance Group resource. An instance group is a collection of VM instances that you can manage as a single entity. For more information, readInstance groups. For zonal Managed Instance Group, use the instanceGroupManagers resource. For regional Managed Instance Group, use theregionInstanceGroupManagers resource.
Instance Attribute Summary collapse
-
#all_instances_config ⇒ Google::Apis::ComputeAlpha::InstanceGroupManagerAllInstancesConfig
Specifies configuration that overrides the instance template configuration for the group.
-
#auto_healing_policies ⇒ Array<Google::Apis::ComputeAlpha::InstanceGroupManagerAutoHealingPolicy>
The autohealing policy for this managed instance group.
-
#base_instance_name ⇒ String
The base instance name is a prefix that you want to attach to the names of all VMs in a MIG.
-
#creation_timestamp ⇒ String
Output only.
-
#current_actions ⇒ Google::Apis::ComputeAlpha::InstanceGroupManagerActionsSummary
Output only.
-
#description ⇒ String
An optional description of this resource.
-
#distribution_policy ⇒ Google::Apis::ComputeAlpha::DistributionPolicy
Policy specifying the intended distribution of managed instances across zones in a regional managed instance group.
-
#failover_action ⇒ String
The action to perform in case of zone failure.
-
#fingerprint ⇒ String
Fingerprint of this resource.
-
#id ⇒ Fixnum
Output only.
-
#instance_flexibility_policy ⇒ Google::Apis::ComputeAlpha::InstanceGroupManagerInstanceFlexibilityPolicy
Instance flexibility allowing MIG to create VMs from multiple types of machines.
-
#instance_group ⇒ String
Output only.
-
#instance_lifecycle_policy ⇒ Google::Apis::ComputeAlpha::InstanceGroupManagerInstanceLifecyclePolicy
The repair policy for this managed instance group.
-
#instance_template ⇒ String
The URL of the instance template that is specified for this managed instance group.
-
#kind ⇒ String
Output only.
-
#list_managed_instances_results ⇒ String
Pagination behavior of the listManagedInstances API method for this managed instance group.
-
#multi_mig ⇒ String
URL to the multi-MIG that this Managed Instance Group belongs to.
-
#name ⇒ String
The name of the managed instance group.
-
#named_ports ⇒ Array<Google::Apis::ComputeAlpha::NamedPort>
[Output Only] Named ports configured on the Instance Groups complementary to this Instance Group Manager.
-
#params ⇒ Google::Apis::ComputeAlpha::InstanceGroupManagerParams
Input only additional params for instance group manager creation.
-
#region ⇒ String
Output only.
-
#resource_policies ⇒ Google::Apis::ComputeAlpha::InstanceGroupManagerResourcePolicies
Resource policies for this managed instance group.
-
#satisfies_pzi ⇒ Boolean
(also: #satisfies_pzi?)
Output only.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
Output only.
-
#self_link ⇒ String
Output only.
-
#self_link_with_id ⇒ String
Output only.
-
#service_account ⇒ String
The service account to be used as credentials for all operations performed by the managed instance group on instances.
-
#standby_policy ⇒ Google::Apis::ComputeAlpha::InstanceGroupManagerStandbyPolicy
Standby policy for stopped and suspended instances.
-
#stateful_policy ⇒ Google::Apis::ComputeAlpha::StatefulPolicy
Stateful configuration for this Instanced Group Manager Corresponds to the JSON property
statefulPolicy. -
#status ⇒ Google::Apis::ComputeAlpha::InstanceGroupManagerStatus
Output only.
-
#target_pools ⇒ Array<String>
The URLs for all TargetPool resources to which instances in theinstanceGroup field are added.
-
#target_size ⇒ Fixnum
The target number of running instances for this managed instance group.
-
#target_size_policy ⇒ Google::Apis::ComputeAlpha::InstanceGroupManagerTargetSizePolicy
The policy that specifies how the MIG creates its VMs to achieve the target size.
-
#target_size_unit ⇒ String
The unit of measure for the target size.
-
#target_stopped_size ⇒ Fixnum
The target number of stopped instances for this managed instance group.
-
#target_suspended_size ⇒ Fixnum
The target number of suspended instances for this managed instance group.
-
#update_policy ⇒ Google::Apis::ComputeAlpha::InstanceGroupManagerUpdatePolicy
The update policy for this managed instance group.
-
#versions ⇒ Array<Google::Apis::ComputeAlpha::InstanceGroupManagerVersion>
Specifies the instance templates used by this managed instance group to create instances.
-
#zone ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceGroupManager
constructor
A new instance of InstanceGroupManager.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceGroupManager
Returns a new instance of InstanceGroupManager.
26926 26927 26928 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 26926 def initialize(**args) update!(**args) end |
Instance Attribute Details
#all_instances_config ⇒ Google::Apis::ComputeAlpha::InstanceGroupManagerAllInstancesConfig
Specifies configuration that overrides the instance template configuration
for the group.
Corresponds to the JSON property allInstancesConfig
26662 26663 26664 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 26662 def all_instances_config @all_instances_config end |
#auto_healing_policies ⇒ Array<Google::Apis::ComputeAlpha::InstanceGroupManagerAutoHealingPolicy>
The autohealing policy for this managed instance group. You can specify
only one value.
Corresponds to the JSON property autoHealingPolicies
26668 26669 26670 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 26668 def auto_healing_policies @auto_healing_policies end |
#base_instance_name ⇒ String
The base instance name is a prefix that you want to attach to the names of
all VMs in a MIG. The maximum character length is 58 and the name must
comply with RFC1035 format.
When a VM is created in the group, the MIG appends a hyphen and a random
four-character string to the base instance name. If you want the MIG to
assign sequential numbers instead of a random string, then end the base
instance name with a hyphen followed by one or more hash symbols. The hash
symbols indicate the number of digits. For example, a base instance name of
"vm-###" results in "vm-001" as a VM name.
a-z
Corresponds to the JSON property baseInstanceName
26683 26684 26685 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 26683 def base_instance_name @base_instance_name end |
#creation_timestamp ⇒ String
Output only. The creation timestamp for this managed instance group inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
26689 26690 26691 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 26689 def @creation_timestamp end |
#current_actions ⇒ Google::Apis::ComputeAlpha::InstanceGroupManagerActionsSummary
Output only. The list of instance actions and the number of instances
in this managed instance group that are scheduled for each of those
actions.
Corresponds to the JSON property currentActions
26696 26697 26698 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 26696 def current_actions @current_actions end |
#description ⇒ String
An optional description of this resource.
Corresponds to the JSON property description
26701 26702 26703 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 26701 def description @description end |
#distribution_policy ⇒ Google::Apis::ComputeAlpha::DistributionPolicy
Policy specifying the intended distribution of managed instances across
zones in a regional managed instance group.
Corresponds to the JSON property distributionPolicy
26707 26708 26709 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 26707 def distribution_policy @distribution_policy end |
#failover_action ⇒ String
The action to perform in case of zone failure. Only one value is supported,
NO_FAILOVER. The default is NO_FAILOVER.
Corresponds to the JSON property failoverAction
26713 26714 26715 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 26713 def failover_action @failover_action end |
#fingerprint ⇒ String
Fingerprint of this resource. This field may be used in optimistic locking.
It will be ignored when inserting an InstanceGroupManager. An up-to-date
fingerprint must be provided in order to update the InstanceGroupManager,
otherwise the request will fail with error412 conditionNotMet.
To see the latest fingerprint, make a get() request to
retrieve an InstanceGroupManager.
Corresponds to the JSON property fingerprint
NOTE: Values are automatically base64 encoded/decoded in the client library.
26724 26725 26726 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 26724 def fingerprint @fingerprint end |
#id ⇒ Fixnum
Output only. A unique identifier for this resource type. The server
generates this identifier.
Corresponds to the JSON property id
26730 26731 26732 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 26730 def id @id end |
#instance_flexibility_policy ⇒ Google::Apis::ComputeAlpha::InstanceGroupManagerInstanceFlexibilityPolicy
Instance flexibility allowing MIG to create VMs from multiple
types of machines.
Instance flexibility configuration on MIG overrides instance
template configuration.
Corresponds to the JSON property instanceFlexibilityPolicy
26738 26739 26740 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 26738 def instance_flexibility_policy @instance_flexibility_policy end |
#instance_group ⇒ String
Output only. The URL of the Instance Group resource.
Corresponds to the JSON property instanceGroup
26743 26744 26745 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 26743 def instance_group @instance_group end |
#instance_lifecycle_policy ⇒ Google::Apis::ComputeAlpha::InstanceGroupManagerInstanceLifecyclePolicy
The repair policy for this managed instance group.
Corresponds to the JSON property instanceLifecyclePolicy
26748 26749 26750 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 26748 def instance_lifecycle_policy @instance_lifecycle_policy end |
#instance_template ⇒ String
The URL of the instance template that is specified for this managed
instance group. The group uses this template to create all new instances
in the managed instance group. The templates for existing instances in the
group do not change unless you run recreateInstances,
runapplyUpdatesToInstances, or set the group'supdatePolicy.type to PROACTIVE.
Corresponds to the JSON property instanceTemplate
26757 26758 26759 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 26757 def instance_template @instance_template end |
#kind ⇒ String
Output only. The resource type, which is alwayscompute#instanceGroupManager
for managed instance groups.
Corresponds to the JSON property kind
26763 26764 26765 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 26763 def kind @kind end |
#list_managed_instances_results ⇒ String
Pagination behavior of the listManagedInstances API method for
this managed instance group.
Corresponds to the JSON property listManagedInstancesResults
26769 26770 26771 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 26769 def list_managed_instances_results @list_managed_instances_results end |
#multi_mig ⇒ String
URL to the multi-MIG that this Managed Instance Group belongs to.
Corresponds to the JSON property multiMig
26774 26775 26776 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 26774 def multi_mig @multi_mig end |
#name ⇒ String
The name of the managed instance group. The name must be 1-63 characters
long, and comply withRFC1035.
Corresponds to the JSON property name
26780 26781 26782 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 26780 def name @name end |
#named_ports ⇒ Array<Google::Apis::ComputeAlpha::NamedPort>
[Output Only] Named ports configured on the Instance Groups complementary
to this Instance Group Manager.
Corresponds to the JSON property namedPorts
26786 26787 26788 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 26786 def named_ports @named_ports end |
#params ⇒ Google::Apis::ComputeAlpha::InstanceGroupManagerParams
Input only additional params for instance group manager creation.
Corresponds to the JSON property params
26791 26792 26793 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 26791 def params @params end |
#region ⇒ String
Output only. [Output Only] The URL of theregion
where the managed instance group resides (for regional resources).
Corresponds to the JSON property region
26797 26798 26799 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 26797 def region @region end |
#resource_policies ⇒ Google::Apis::ComputeAlpha::InstanceGroupManagerResourcePolicies
Resource policies for this managed instance group.
Corresponds to the JSON property resourcePolicies
26802 26803 26804 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 26802 def resource_policies @resource_policies end |
#satisfies_pzi ⇒ Boolean Also known as: satisfies_pzi?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzi
26807 26808 26809 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 26807 def satisfies_pzi @satisfies_pzi end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzs
26813 26814 26815 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 26813 def satisfies_pzs @satisfies_pzs end |
#self_link ⇒ String
Output only. The URL for this managed instance group. The server defines
this URL.
Corresponds to the JSON property selfLink
26820 26821 26822 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 26820 def self_link @self_link end |
#self_link_with_id ⇒ String
Output only. Server-defined URL for this resource with the resource id.
Corresponds to the JSON property selfLinkWithId
26825 26826 26827 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 26825 def self_link_with_id @self_link_with_id end |
#service_account ⇒ String
The service account to be used as credentials for all operations performed
by the managed instance group on instances. The service accounts needs all
permissions required to create and delete instances.
By default, the service account
projectNumber@cloudservices.gserviceaccount.com is used.
Corresponds to the JSON property serviceAccount
26834 26835 26836 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 26834 def service_account @service_account end |
#standby_policy ⇒ Google::Apis::ComputeAlpha::InstanceGroupManagerStandbyPolicy
Standby policy for stopped and suspended instances.
Corresponds to the JSON property standbyPolicy
26839 26840 26841 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 26839 def standby_policy @standby_policy end |
#stateful_policy ⇒ Google::Apis::ComputeAlpha::StatefulPolicy
Stateful configuration for this Instanced Group Manager
Corresponds to the JSON property statefulPolicy
26844 26845 26846 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 26844 def stateful_policy @stateful_policy end |
#status ⇒ Google::Apis::ComputeAlpha::InstanceGroupManagerStatus
Output only. The status of this managed instance group.
Corresponds to the JSON property status
26849 26850 26851 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 26849 def status @status end |
#target_pools ⇒ Array<String>
The URLs for all TargetPool resources to which instances in theinstanceGroup
field are added. The target pools automatically
apply to all of the instances in the managed instance group.
Corresponds to the JSON property targetPools
26856 26857 26858 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 26856 def target_pools @target_pools end |
#target_size ⇒ Fixnum
The target number of running instances for this managed instance group.
You can reduce this number by using the instanceGroupManager
deleteInstances or abandonInstances methods. Resizing the group also
changes this number.
Corresponds to the JSON property targetSize
26864 26865 26866 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 26864 def target_size @target_size end |
#target_size_policy ⇒ Google::Apis::ComputeAlpha::InstanceGroupManagerTargetSizePolicy
The policy that specifies how the MIG creates its VMs to achieve the target
size.
Corresponds to the JSON property targetSizePolicy
26870 26871 26872 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 26870 def target_size_policy @target_size_policy end |
#target_size_unit ⇒ String
The unit of measure for the target size.
Corresponds to the JSON property targetSizeUnit
26875 26876 26877 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 26875 def target_size_unit @target_size_unit end |
#target_stopped_size ⇒ Fixnum
The target number of stopped instances for this managed instance group. This number changes when you:
- Stop instance using the stopInstances method or start instances using the startInstances method.
- Manually change the targetStoppedSize using the update
method.
Corresponds to the JSON property
targetStoppedSize
26887 26888 26889 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 26887 def target_stopped_size @target_stopped_size end |
#target_suspended_size ⇒ Fixnum
The target number of suspended instances for this managed instance group. This number changes when you:
- Suspend instance using the suspendInstances method or resume instances using the resumeInstances method.
- Manually change the targetSuspendedSize using the update
method.
Corresponds to the JSON property
targetSuspendedSize
26899 26900 26901 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 26899 def target_suspended_size @target_suspended_size end |
#update_policy ⇒ Google::Apis::ComputeAlpha::InstanceGroupManagerUpdatePolicy
The update policy for this managed instance group.
Corresponds to the JSON property updatePolicy
26904 26905 26906 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 26904 def update_policy @update_policy end |
#versions ⇒ Array<Google::Apis::ComputeAlpha::InstanceGroupManagerVersion>
Specifies the instance templates used by this managed instance group to
create instances.
Each version is defined by an instanceTemplate and aname. Every version can
appear at most once per instance
group. This field overrides the top-level instanceTemplate
field. Read more about therelationships
between these fields. Exactly one version must leave thetargetSize field unset.
That version will be applied to all
remaining instances. For more information, read aboutcanary
updates.
Corresponds to the JSON property versions
26918 26919 26920 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 26918 def versions @versions end |
#zone ⇒ String
Output only. The URL of azone
where the managed instance group is located (for zonal resources).
Corresponds to the JSON property zone
26924 26925 26926 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 26924 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
26931 26932 26933 26934 26935 26936 26937 26938 26939 26940 26941 26942 26943 26944 26945 26946 26947 26948 26949 26950 26951 26952 26953 26954 26955 26956 26957 26958 26959 26960 26961 26962 26963 26964 26965 26966 26967 26968 26969 26970 26971 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 26931 def update!(**args) @all_instances_config = args[:all_instances_config] if args.key?(:all_instances_config) @auto_healing_policies = args[:auto_healing_policies] if args.key?(:auto_healing_policies) @base_instance_name = args[:base_instance_name] if args.key?(:base_instance_name) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @current_actions = args[:current_actions] if args.key?(:current_actions) @description = args[:description] if args.key?(:description) @distribution_policy = args[:distribution_policy] if args.key?(:distribution_policy) @failover_action = args[:failover_action] if args.key?(:failover_action) @fingerprint = args[:fingerprint] if args.key?(:fingerprint) @id = args[:id] if args.key?(:id) @instance_flexibility_policy = args[:instance_flexibility_policy] if args.key?(:instance_flexibility_policy) @instance_group = args[:instance_group] if args.key?(:instance_group) @instance_lifecycle_policy = args[:instance_lifecycle_policy] if args.key?(:instance_lifecycle_policy) @instance_template = args[:instance_template] if args.key?(:instance_template) @kind = args[:kind] if args.key?(:kind) @list_managed_instances_results = args[:list_managed_instances_results] if args.key?(:list_managed_instances_results) @multi_mig = args[:multi_mig] if args.key?(:multi_mig) @name = args[:name] if args.key?(:name) @named_ports = args[:named_ports] if args.key?(:named_ports) @params = args[:params] if args.key?(:params) @region = args[:region] if args.key?(:region) @resource_policies = args[:resource_policies] if args.key?(:resource_policies) @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @self_link = args[:self_link] if args.key?(:self_link) @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id) @service_account = args[:service_account] if args.key?(:service_account) @standby_policy = args[:standby_policy] if args.key?(:standby_policy) @stateful_policy = args[:stateful_policy] if args.key?(:stateful_policy) @status = args[:status] if args.key?(:status) @target_pools = args[:target_pools] if args.key?(:target_pools) @target_size = args[:target_size] if args.key?(:target_size) @target_size_policy = args[:target_size_policy] if args.key?(:target_size_policy) @target_size_unit = args[:target_size_unit] if args.key?(:target_size_unit) @target_stopped_size = args[:target_stopped_size] if args.key?(:target_stopped_size) @target_suspended_size = args[:target_suspended_size] if args.key?(:target_suspended_size) @update_policy = args[:update_policy] if args.key?(:update_policy) @versions = args[:versions] if args.key?(:versions) @zone = args[:zone] if args.key?(:zone) end |