Class: Google::Apis::ComputeAlpha::InstanceGroupManagerActionsSummary

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupManagerActionsSummary

Returns a new instance of InstanceGroupManagerActionsSummary.



27298
27299
27300
# File 'lib/google/apis/compute_alpha/classes.rb', line 27298

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#abandoningFixnum

Output only. The total number of instances in the managed instance group that are scheduled to be abandoned. Abandoning an instance removes it from the managed instance group without deleting it. Corresponds to the JSON property abandoning

Returns:

  • (Fixnum)


27186
27187
27188
# File 'lib/google/apis/compute_alpha/classes.rb', line 27186

def abandoning
  @abandoning
end

#adoptingFixnum

Output only. The number of instances in the managed instance group that are scheduled to be adopted or are currently being adopted. Corresponds to the JSON property adopting

Returns:

  • (Fixnum)


27192
27193
27194
# File 'lib/google/apis/compute_alpha/classes.rb', line 27192

def adopting
  @adopting
end

#creatingFixnum

Output only. The number of instances in the managed instance group that are scheduled to be created or are currently being created. If the group fails to create any of these instances, it tries again until it creates the instance successfully. If you have disabled creation retries, this field will not be populated; instead, the creatingWithoutRetries field will be populated. Corresponds to the JSON property creating

Returns:

  • (Fixnum)


27202
27203
27204
# File 'lib/google/apis/compute_alpha/classes.rb', line 27202

def creating
  @creating
end

#creating_atomicallyFixnum

Output only. The number of instances that the managed instance group will attempt to create atomically, in a batch mode. If the desired count of instances can not be created, entire batch will be deleted and the group will decrease its targetSize value accordingly. Corresponds to the JSON property creatingAtomically

Returns:

  • (Fixnum)


27210
27211
27212
# File 'lib/google/apis/compute_alpha/classes.rb', line 27210

def creating_atomically
  @creating_atomically
end

#creating_without_retriesFixnum

Output only. The number of instances that the managed instance group will attempt to create. The group attempts to create each instance only once. If the group fails to create any of these instances, it decreases the group's targetSize value accordingly. Corresponds to the JSON property creatingWithoutRetries

Returns:

  • (Fixnum)


27218
27219
27220
# File 'lib/google/apis/compute_alpha/classes.rb', line 27218

def creating_without_retries
  @creating_without_retries
end

#deletingFixnum

Output only. The number of instances in the managed instance group that are scheduled to be deleted or are currently being deleted. Corresponds to the JSON property deleting

Returns:

  • (Fixnum)


27224
27225
27226
# File 'lib/google/apis/compute_alpha/classes.rb', line 27224

def deleting
  @deleting
end

#noneFixnum

Output only. The number of instances in the managed instance group that are running and have no scheduled actions. Corresponds to the JSON property none

Returns:

  • (Fixnum)


27230
27231
27232
# File 'lib/google/apis/compute_alpha/classes.rb', line 27230

def none
  @none
end

#queuingFixnum

Output only. The number of instances that the managed instance group is currently queuing. Corresponds to the JSON property queuing

Returns:

  • (Fixnum)


27236
27237
27238
# File 'lib/google/apis/compute_alpha/classes.rb', line 27236

def queuing
  @queuing
end

#recreatingFixnum

Output only. The number of instances in the managed instance group that are scheduled to be recreated or are currently being being recreated. Recreating an instance deletes the existing root persistent disk and creates a new disk from the image that is defined in the instance template. Corresponds to the JSON property recreating

Returns:

  • (Fixnum)


27245
27246
27247
# File 'lib/google/apis/compute_alpha/classes.rb', line 27245

def recreating
  @recreating
end

#refreshingFixnum

Output only. The number of instances in the managed instance group that are being reconfigured with properties that do not require a restart or a recreate action. For example, setting or removing target pools for the instance. Corresponds to the JSON property refreshing

Returns:

  • (Fixnum)


27253
27254
27255
# File 'lib/google/apis/compute_alpha/classes.rb', line 27253

def refreshing
  @refreshing
end

#restartingFixnum

Output only. The number of instances in the managed instance group that are scheduled to be restarted or are currently being restarted. Corresponds to the JSON property restarting

Returns:

  • (Fixnum)


27259
27260
27261
# File 'lib/google/apis/compute_alpha/classes.rb', line 27259

def restarting
  @restarting
end

#restarting_in_placeFixnum

Output only. The number of instances in the managed instance group that are scheduled to be restarted or are currently being restarted. Corresponds to the JSON property restartingInPlace

Returns:

  • (Fixnum)


27265
27266
27267
# File 'lib/google/apis/compute_alpha/classes.rb', line 27265

def restarting_in_place
  @restarting_in_place
end

#resumingFixnum

Output only. The number of instances in the managed instance group that are scheduled to be resumed or are currently being resumed. Corresponds to the JSON property resuming

Returns:

  • (Fixnum)


27271
27272
27273
# File 'lib/google/apis/compute_alpha/classes.rb', line 27271

def resuming
  @resuming
end

#startingFixnum

Output only. The number of instances in the managed instance group that are scheduled to be started or are currently being started. Corresponds to the JSON property starting

Returns:

  • (Fixnum)


27277
27278
27279
# File 'lib/google/apis/compute_alpha/classes.rb', line 27277

def starting
  @starting
end

#stoppingFixnum

Output only. The number of instances in the managed instance group that are scheduled to be stopped or are currently being stopped. Corresponds to the JSON property stopping

Returns:

  • (Fixnum)


27283
27284
27285
# File 'lib/google/apis/compute_alpha/classes.rb', line 27283

def stopping
  @stopping
end

#suspendingFixnum

Output only. The number of instances in the managed instance group that are scheduled to be suspended or are currently being suspended. Corresponds to the JSON property suspending

Returns:

  • (Fixnum)


27289
27290
27291
# File 'lib/google/apis/compute_alpha/classes.rb', line 27289

def suspending
  @suspending
end

#verifyingFixnum

Output only. The number of instances in the managed instance group that are being verified. See the managedInstances[].currentAction property in the listManagedInstances method documentation. Corresponds to the JSON property verifying

Returns:

  • (Fixnum)


27296
27297
27298
# File 'lib/google/apis/compute_alpha/classes.rb', line 27296

def verifying
  @verifying
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



27303
27304
27305
27306
27307
27308
27309
27310
27311
27312
27313
27314
27315
27316
27317
27318
27319
27320
27321
# File 'lib/google/apis/compute_alpha/classes.rb', line 27303

def update!(**args)
  @abandoning = args[:abandoning] if args.key?(:abandoning)
  @adopting = args[:adopting] if args.key?(:adopting)
  @creating = args[:creating] if args.key?(:creating)
  @creating_atomically = args[:creating_atomically] if args.key?(:creating_atomically)
  @creating_without_retries = args[:creating_without_retries] if args.key?(:creating_without_retries)
  @deleting = args[:deleting] if args.key?(:deleting)
  @none = args[:none] if args.key?(:none)
  @queuing = args[:queuing] if args.key?(:queuing)
  @recreating = args[:recreating] if args.key?(:recreating)
  @refreshing = args[:refreshing] if args.key?(:refreshing)
  @restarting = args[:restarting] if args.key?(:restarting)
  @restarting_in_place = args[:restarting_in_place] if args.key?(:restarting_in_place)
  @resuming = args[:resuming] if args.key?(:resuming)
  @starting = args[:starting] if args.key?(:starting)
  @stopping = args[:stopping] if args.key?(:stopping)
  @suspending = args[:suspending] if args.key?(:suspending)
  @verifying = args[:verifying] if args.key?(:verifying)
end