Class: Google::Apis::ComputeAlpha::InstanceGroupManagerActionsSummary
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::InstanceGroupManagerActionsSummary
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#abandoning ⇒ Fixnum
Output only.
-
#adopting ⇒ Fixnum
Output only.
-
#creating ⇒ Fixnum
Output only.
-
#creating_atomically ⇒ Fixnum
Output only.
-
#creating_without_retries ⇒ Fixnum
Output only.
-
#deleting ⇒ Fixnum
Output only.
-
#none ⇒ Fixnum
Output only.
-
#queuing ⇒ Fixnum
Output only.
-
#recreating ⇒ Fixnum
Output only.
-
#refreshing ⇒ Fixnum
Output only.
-
#restarting ⇒ Fixnum
Output only.
-
#restarting_in_place ⇒ Fixnum
Output only.
-
#resuming ⇒ Fixnum
Output only.
-
#starting ⇒ Fixnum
Output only.
-
#stopping ⇒ Fixnum
Output only.
-
#suspending ⇒ Fixnum
Output only.
-
#verifying ⇒ Fixnum
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceGroupManagerActionsSummary
constructor
A new instance of InstanceGroupManagerActionsSummary.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceGroupManagerActionsSummary
Returns a new instance of InstanceGroupManagerActionsSummary.
27298 27299 27300 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27298 def initialize(**args) update!(**args) end |
Instance Attribute Details
#abandoning ⇒ Fixnum
Output only. The total number of instances in the managed instance group
that are scheduled to be abandoned. Abandoning an instance removes it
from the managed instance group without deleting it.
Corresponds to the JSON property abandoning
27186 27187 27188 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27186 def abandoning @abandoning end |
#adopting ⇒ Fixnum
Output only. The number of instances in the managed instance group that
are scheduled to be adopted or are currently being adopted.
Corresponds to the JSON property adopting
27192 27193 27194 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27192 def adopting @adopting end |
#creating ⇒ Fixnum
Output only. The number of instances in the managed instance group that
are scheduled to be created or are currently being created. If the group
fails to create any of these instances, it tries again until it creates
the instance successfully.
If you have disabled creation retries, this field will not be populated;
instead, the creatingWithoutRetries field will be populated.
Corresponds to the JSON property creating
27202 27203 27204 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27202 def creating @creating end |
#creating_atomically ⇒ Fixnum
Output only. The number of instances that the managed instance group
will attempt to create atomically, in a batch mode. If the desired count
of instances can not be created, entire batch will be deleted and the
group will decrease its targetSize value accordingly.
Corresponds to the JSON property creatingAtomically
27210 27211 27212 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27210 def creating_atomically @creating_atomically end |
#creating_without_retries ⇒ Fixnum
Output only. The number of instances that the managed instance group
will attempt to create. The group attempts to create each instance
only once. If the group fails to create any of these instances, it
decreases the group's targetSize value accordingly.
Corresponds to the JSON property creatingWithoutRetries
27218 27219 27220 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27218 def creating_without_retries @creating_without_retries end |
#deleting ⇒ Fixnum
Output only. The number of instances in the managed instance group that
are scheduled to be deleted or are currently being deleted.
Corresponds to the JSON property deleting
27224 27225 27226 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27224 def deleting @deleting end |
#none ⇒ Fixnum
Output only. The number of instances in the managed instance group that
are running and have no scheduled actions.
Corresponds to the JSON property none
27230 27231 27232 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27230 def none @none end |
#queuing ⇒ Fixnum
Output only. The number of instances that the managed instance group
is currently queuing.
Corresponds to the JSON property queuing
27236 27237 27238 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27236 def queuing @queuing end |
#recreating ⇒ Fixnum
Output only. The number of instances in the managed instance group that
are scheduled to be recreated or are currently being being recreated.
Recreating an instance deletes the existing root persistent disk
and creates a new disk from the image that is defined in the
instance template.
Corresponds to the JSON property recreating
27245 27246 27247 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27245 def recreating @recreating end |
#refreshing ⇒ Fixnum
Output only. The number of instances in the managed instance group that
are being reconfigured with properties that do not require a restart
or a recreate action. For example, setting or removing target
pools for the instance.
Corresponds to the JSON property refreshing
27253 27254 27255 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27253 def refreshing @refreshing end |
#restarting ⇒ Fixnum
Output only. The number of instances in the managed instance group that
are scheduled to be restarted or are currently being restarted.
Corresponds to the JSON property restarting
27259 27260 27261 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27259 def restarting @restarting end |
#restarting_in_place ⇒ Fixnum
Output only. The number of instances in the managed instance group that
are scheduled to be restarted or are currently being restarted.
Corresponds to the JSON property restartingInPlace
27265 27266 27267 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27265 def restarting_in_place @restarting_in_place end |
#resuming ⇒ Fixnum
Output only. The number of instances in the managed instance group that
are scheduled to be resumed or are currently being resumed.
Corresponds to the JSON property resuming
27271 27272 27273 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27271 def resuming @resuming end |
#starting ⇒ Fixnum
Output only. The number of instances in the managed instance group that
are scheduled to be started or are currently being started.
Corresponds to the JSON property starting
27277 27278 27279 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27277 def starting @starting end |
#stopping ⇒ Fixnum
Output only. The number of instances in the managed instance group that
are scheduled to be stopped or are currently being stopped.
Corresponds to the JSON property stopping
27283 27284 27285 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27283 def stopping @stopping end |
#suspending ⇒ Fixnum
Output only. The number of instances in the managed instance group that
are scheduled to be suspended or are currently being suspended.
Corresponds to the JSON property suspending
27289 27290 27291 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27289 def suspending @suspending end |
#verifying ⇒ Fixnum
Output only. The number of instances in the managed instance group that
are being verified. See the managedInstances[].currentAction
property in the listManagedInstances method documentation.
Corresponds to the JSON property verifying
27296 27297 27298 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27296 def @verifying end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
27303 27304 27305 27306 27307 27308 27309 27310 27311 27312 27313 27314 27315 27316 27317 27318 27319 27320 27321 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27303 def update!(**args) @abandoning = args[:abandoning] if args.key?(:abandoning) @adopting = args[:adopting] if args.key?(:adopting) @creating = args[:creating] if args.key?(:creating) @creating_atomically = args[:creating_atomically] if args.key?(:creating_atomically) @creating_without_retries = args[:creating_without_retries] if args.key?(:creating_without_retries) @deleting = args[:deleting] if args.key?(:deleting) @none = args[:none] if args.key?(:none) @queuing = args[:queuing] if args.key?(:queuing) @recreating = args[:recreating] if args.key?(:recreating) @refreshing = args[:refreshing] if args.key?(:refreshing) @restarting = args[:restarting] if args.key?(:restarting) @restarting_in_place = args[:restarting_in_place] if args.key?(:restarting_in_place) @resuming = args[:resuming] if args.key?(:resuming) @starting = args[:starting] if args.key?(:starting) @stopping = args[:stopping] if args.key?(:stopping) @suspending = args[:suspending] if args.key?(:suspending) @verifying = args[:verifying] if args.key?(:verifying) end |