Class: Google::Apis::ComputeAlpha::InstanceGroupManagerActionsSummary
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::InstanceGroupManagerActionsSummary
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#abandoning ⇒ Fixnum
Output only.
-
#adopting ⇒ Fixnum
Output only.
-
#creating ⇒ Fixnum
Output only.
-
#creating_atomically ⇒ Fixnum
Output only.
-
#creating_without_retries ⇒ Fixnum
Output only.
-
#deleting ⇒ Fixnum
Output only.
-
#none ⇒ Fixnum
Output only.
-
#queuing ⇒ Fixnum
Output only.
-
#recreating ⇒ Fixnum
Output only.
-
#refreshing ⇒ Fixnum
Output only.
-
#restarting ⇒ Fixnum
Output only.
-
#restarting_in_place ⇒ Fixnum
Output only.
-
#resuming ⇒ Fixnum
Output only.
-
#starting ⇒ Fixnum
Output only.
-
#stopping ⇒ Fixnum
Output only.
-
#suspending ⇒ Fixnum
Output only.
-
#verifying ⇒ Fixnum
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceGroupManagerActionsSummary
constructor
A new instance of InstanceGroupManagerActionsSummary.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceGroupManagerActionsSummary
Returns a new instance of InstanceGroupManagerActionsSummary.
27290 27291 27292 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27290 def initialize(**args) update!(**args) end |
Instance Attribute Details
#abandoning ⇒ Fixnum
Output only. The total number of instances in the managed instance group
that are scheduled to be abandoned. Abandoning an instance removes it
from the managed instance group without deleting it.
Corresponds to the JSON property abandoning
27178 27179 27180 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27178 def abandoning @abandoning end |
#adopting ⇒ Fixnum
Output only. The number of instances in the managed instance group that
are scheduled to be adopted or are currently being adopted.
Corresponds to the JSON property adopting
27184 27185 27186 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27184 def adopting @adopting end |
#creating ⇒ Fixnum
Output only. The number of instances in the managed instance group that
are scheduled to be created or are currently being created. If the group
fails to create any of these instances, it tries again until it creates
the instance successfully.
If you have disabled creation retries, this field will not be populated;
instead, the creatingWithoutRetries field will be populated.
Corresponds to the JSON property creating
27194 27195 27196 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27194 def creating @creating end |
#creating_atomically ⇒ Fixnum
Output only. The number of instances that the managed instance group
will attempt to create atomically, in a batch mode. If the desired count
of instances can not be created, entire batch will be deleted and the
group will decrease its targetSize value accordingly.
Corresponds to the JSON property creatingAtomically
27202 27203 27204 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27202 def creating_atomically @creating_atomically end |
#creating_without_retries ⇒ Fixnum
Output only. The number of instances that the managed instance group
will attempt to create. The group attempts to create each instance
only once. If the group fails to create any of these instances, it
decreases the group's targetSize value accordingly.
Corresponds to the JSON property creatingWithoutRetries
27210 27211 27212 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27210 def creating_without_retries @creating_without_retries end |
#deleting ⇒ Fixnum
Output only. The number of instances in the managed instance group that
are scheduled to be deleted or are currently being deleted.
Corresponds to the JSON property deleting
27216 27217 27218 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27216 def deleting @deleting end |
#none ⇒ Fixnum
Output only. The number of instances in the managed instance group that
are running and have no scheduled actions.
Corresponds to the JSON property none
27222 27223 27224 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27222 def none @none end |
#queuing ⇒ Fixnum
Output only. The number of instances that the managed instance group
is currently queuing.
Corresponds to the JSON property queuing
27228 27229 27230 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27228 def queuing @queuing end |
#recreating ⇒ Fixnum
Output only. The number of instances in the managed instance group that
are scheduled to be recreated or are currently being being recreated.
Recreating an instance deletes the existing root persistent disk
and creates a new disk from the image that is defined in the
instance template.
Corresponds to the JSON property recreating
27237 27238 27239 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27237 def recreating @recreating end |
#refreshing ⇒ Fixnum
Output only. The number of instances in the managed instance group that
are being reconfigured with properties that do not require a restart
or a recreate action. For example, setting or removing target
pools for the instance.
Corresponds to the JSON property refreshing
27245 27246 27247 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27245 def refreshing @refreshing end |
#restarting ⇒ Fixnum
Output only. The number of instances in the managed instance group that
are scheduled to be restarted or are currently being restarted.
Corresponds to the JSON property restarting
27251 27252 27253 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27251 def restarting @restarting end |
#restarting_in_place ⇒ Fixnum
Output only. The number of instances in the managed instance group that
are scheduled to be restarted or are currently being restarted.
Corresponds to the JSON property restartingInPlace
27257 27258 27259 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27257 def restarting_in_place @restarting_in_place end |
#resuming ⇒ Fixnum
Output only. The number of instances in the managed instance group that
are scheduled to be resumed or are currently being resumed.
Corresponds to the JSON property resuming
27263 27264 27265 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27263 def resuming @resuming end |
#starting ⇒ Fixnum
Output only. The number of instances in the managed instance group that
are scheduled to be started or are currently being started.
Corresponds to the JSON property starting
27269 27270 27271 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27269 def starting @starting end |
#stopping ⇒ Fixnum
Output only. The number of instances in the managed instance group that
are scheduled to be stopped or are currently being stopped.
Corresponds to the JSON property stopping
27275 27276 27277 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27275 def stopping @stopping end |
#suspending ⇒ Fixnum
Output only. The number of instances in the managed instance group that
are scheduled to be suspended or are currently being suspended.
Corresponds to the JSON property suspending
27281 27282 27283 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27281 def suspending @suspending end |
#verifying ⇒ Fixnum
Output only. The number of instances in the managed instance group that
are being verified. See the managedInstances[].currentAction
property in the listManagedInstances method documentation.
Corresponds to the JSON property verifying
27288 27289 27290 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27288 def @verifying end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
27295 27296 27297 27298 27299 27300 27301 27302 27303 27304 27305 27306 27307 27308 27309 27310 27311 27312 27313 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27295 def update!(**args) @abandoning = args[:abandoning] if args.key?(:abandoning) @adopting = args[:adopting] if args.key?(:adopting) @creating = args[:creating] if args.key?(:creating) @creating_atomically = args[:creating_atomically] if args.key?(:creating_atomically) @creating_without_retries = args[:creating_without_retries] if args.key?(:creating_without_retries) @deleting = args[:deleting] if args.key?(:deleting) @none = args[:none] if args.key?(:none) @queuing = args[:queuing] if args.key?(:queuing) @recreating = args[:recreating] if args.key?(:recreating) @refreshing = args[:refreshing] if args.key?(:refreshing) @restarting = args[:restarting] if args.key?(:restarting) @restarting_in_place = args[:restarting_in_place] if args.key?(:restarting_in_place) @resuming = args[:resuming] if args.key?(:resuming) @starting = args[:starting] if args.key?(:starting) @stopping = args[:stopping] if args.key?(:stopping) @suspending = args[:suspending] if args.key?(:suspending) @verifying = args[:verifying] if args.key?(:verifying) end |