Class: Google::Apis::ComputeAlpha::InstanceGroupManagerActionsSummary
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::InstanceGroupManagerActionsSummary
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#abandoning ⇒ Fixnum
Output only.
-
#adopting ⇒ Fixnum
Output only.
-
#creating ⇒ Fixnum
Output only.
-
#creating_atomically ⇒ Fixnum
Output only.
-
#creating_without_retries ⇒ Fixnum
Output only.
-
#deleting ⇒ Fixnum
Output only.
-
#none ⇒ Fixnum
Output only.
-
#queuing ⇒ Fixnum
Output only.
-
#recreating ⇒ Fixnum
Output only.
-
#refreshing ⇒ Fixnum
Output only.
-
#restarting ⇒ Fixnum
Output only.
-
#restarting_in_place ⇒ Fixnum
Output only.
-
#resuming ⇒ Fixnum
Output only.
-
#starting ⇒ Fixnum
Output only.
-
#stopping ⇒ Fixnum
Output only.
-
#suspending ⇒ Fixnum
Output only.
-
#verifying ⇒ Fixnum
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceGroupManagerActionsSummary
constructor
A new instance of InstanceGroupManagerActionsSummary.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceGroupManagerActionsSummary
Returns a new instance of InstanceGroupManagerActionsSummary.
27085 27086 27087 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27085 def initialize(**args) update!(**args) end |
Instance Attribute Details
#abandoning ⇒ Fixnum
Output only. The total number of instances in the managed instance group
that are scheduled to be abandoned. Abandoning an instance removes it
from the managed instance group without deleting it.
Corresponds to the JSON property abandoning
26973 26974 26975 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 26973 def abandoning @abandoning end |
#adopting ⇒ Fixnum
Output only. The number of instances in the managed instance group that
are scheduled to be adopted or are currently being adopted.
Corresponds to the JSON property adopting
26979 26980 26981 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 26979 def adopting @adopting end |
#creating ⇒ Fixnum
Output only. The number of instances in the managed instance group that
are scheduled to be created or are currently being created. If the group
fails to create any of these instances, it tries again until it creates
the instance successfully.
If you have disabled creation retries, this field will not be populated;
instead, the creatingWithoutRetries field will be populated.
Corresponds to the JSON property creating
26989 26990 26991 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 26989 def creating @creating end |
#creating_atomically ⇒ Fixnum
Output only. The number of instances that the managed instance group
will attempt to create atomically, in a batch mode. If the desired count
of instances can not be created, entire batch will be deleted and the
group will decrease its targetSize value accordingly.
Corresponds to the JSON property creatingAtomically
26997 26998 26999 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 26997 def creating_atomically @creating_atomically end |
#creating_without_retries ⇒ Fixnum
Output only. The number of instances that the managed instance group
will attempt to create. The group attempts to create each instance
only once. If the group fails to create any of these instances, it
decreases the group's targetSize value accordingly.
Corresponds to the JSON property creatingWithoutRetries
27005 27006 27007 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27005 def creating_without_retries @creating_without_retries end |
#deleting ⇒ Fixnum
Output only. The number of instances in the managed instance group that
are scheduled to be deleted or are currently being deleted.
Corresponds to the JSON property deleting
27011 27012 27013 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27011 def deleting @deleting end |
#none ⇒ Fixnum
Output only. The number of instances in the managed instance group that
are running and have no scheduled actions.
Corresponds to the JSON property none
27017 27018 27019 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27017 def none @none end |
#queuing ⇒ Fixnum
Output only. The number of instances that the managed instance group
is currently queuing.
Corresponds to the JSON property queuing
27023 27024 27025 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27023 def queuing @queuing end |
#recreating ⇒ Fixnum
Output only. The number of instances in the managed instance group that
are scheduled to be recreated or are currently being being recreated.
Recreating an instance deletes the existing root persistent disk
and creates a new disk from the image that is defined in the
instance template.
Corresponds to the JSON property recreating
27032 27033 27034 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27032 def recreating @recreating end |
#refreshing ⇒ Fixnum
Output only. The number of instances in the managed instance group that
are being reconfigured with properties that do not require a restart
or a recreate action. For example, setting or removing target
pools for the instance.
Corresponds to the JSON property refreshing
27040 27041 27042 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27040 def refreshing @refreshing end |
#restarting ⇒ Fixnum
Output only. The number of instances in the managed instance group that
are scheduled to be restarted or are currently being restarted.
Corresponds to the JSON property restarting
27046 27047 27048 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27046 def restarting @restarting end |
#restarting_in_place ⇒ Fixnum
Output only. The number of instances in the managed instance group that
are scheduled to be restarted or are currently being restarted.
Corresponds to the JSON property restartingInPlace
27052 27053 27054 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27052 def restarting_in_place @restarting_in_place end |
#resuming ⇒ Fixnum
Output only. The number of instances in the managed instance group that
are scheduled to be resumed or are currently being resumed.
Corresponds to the JSON property resuming
27058 27059 27060 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27058 def resuming @resuming end |
#starting ⇒ Fixnum
Output only. The number of instances in the managed instance group that
are scheduled to be started or are currently being started.
Corresponds to the JSON property starting
27064 27065 27066 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27064 def starting @starting end |
#stopping ⇒ Fixnum
Output only. The number of instances in the managed instance group that
are scheduled to be stopped or are currently being stopped.
Corresponds to the JSON property stopping
27070 27071 27072 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27070 def stopping @stopping end |
#suspending ⇒ Fixnum
Output only. The number of instances in the managed instance group that
are scheduled to be suspended or are currently being suspended.
Corresponds to the JSON property suspending
27076 27077 27078 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27076 def suspending @suspending end |
#verifying ⇒ Fixnum
Output only. The number of instances in the managed instance group that
are being verified. See the managedInstances[].currentAction
property in the listManagedInstances method documentation.
Corresponds to the JSON property verifying
27083 27084 27085 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27083 def @verifying end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
27090 27091 27092 27093 27094 27095 27096 27097 27098 27099 27100 27101 27102 27103 27104 27105 27106 27107 27108 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27090 def update!(**args) @abandoning = args[:abandoning] if args.key?(:abandoning) @adopting = args[:adopting] if args.key?(:adopting) @creating = args[:creating] if args.key?(:creating) @creating_atomically = args[:creating_atomically] if args.key?(:creating_atomically) @creating_without_retries = args[:creating_without_retries] if args.key?(:creating_without_retries) @deleting = args[:deleting] if args.key?(:deleting) @none = args[:none] if args.key?(:none) @queuing = args[:queuing] if args.key?(:queuing) @recreating = args[:recreating] if args.key?(:recreating) @refreshing = args[:refreshing] if args.key?(:refreshing) @restarting = args[:restarting] if args.key?(:restarting) @restarting_in_place = args[:restarting_in_place] if args.key?(:restarting_in_place) @resuming = args[:resuming] if args.key?(:resuming) @starting = args[:starting] if args.key?(:starting) @stopping = args[:stopping] if args.key?(:stopping) @suspending = args[:suspending] if args.key?(:suspending) @verifying = args[:verifying] if args.key?(:verifying) end |