Class: Google::Apis::ComputeAlpha::InstanceGroupManagerActionsSummary

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupManagerActionsSummary

Returns a new instance of InstanceGroupManagerActionsSummary.



27095
27096
27097
# File 'lib/google/apis/compute_alpha/classes.rb', line 27095

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#abandoningFixnum

Output only. The total number of instances in the managed instance group that are scheduled to be abandoned. Abandoning an instance removes it from the managed instance group without deleting it. Corresponds to the JSON property abandoning

Returns:

  • (Fixnum)


26983
26984
26985
# File 'lib/google/apis/compute_alpha/classes.rb', line 26983

def abandoning
  @abandoning
end

#adoptingFixnum

Output only. The number of instances in the managed instance group that are scheduled to be adopted or are currently being adopted. Corresponds to the JSON property adopting

Returns:

  • (Fixnum)


26989
26990
26991
# File 'lib/google/apis/compute_alpha/classes.rb', line 26989

def adopting
  @adopting
end

#creatingFixnum

Output only. The number of instances in the managed instance group that are scheduled to be created or are currently being created. If the group fails to create any of these instances, it tries again until it creates the instance successfully. If you have disabled creation retries, this field will not be populated; instead, the creatingWithoutRetries field will be populated. Corresponds to the JSON property creating

Returns:

  • (Fixnum)


26999
27000
27001
# File 'lib/google/apis/compute_alpha/classes.rb', line 26999

def creating
  @creating
end

#creating_atomicallyFixnum

Output only. The number of instances that the managed instance group will attempt to create atomically, in a batch mode. If the desired count of instances can not be created, entire batch will be deleted and the group will decrease its targetSize value accordingly. Corresponds to the JSON property creatingAtomically

Returns:

  • (Fixnum)


27007
27008
27009
# File 'lib/google/apis/compute_alpha/classes.rb', line 27007

def creating_atomically
  @creating_atomically
end

#creating_without_retriesFixnum

Output only. The number of instances that the managed instance group will attempt to create. The group attempts to create each instance only once. If the group fails to create any of these instances, it decreases the group's targetSize value accordingly. Corresponds to the JSON property creatingWithoutRetries

Returns:

  • (Fixnum)


27015
27016
27017
# File 'lib/google/apis/compute_alpha/classes.rb', line 27015

def creating_without_retries
  @creating_without_retries
end

#deletingFixnum

Output only. The number of instances in the managed instance group that are scheduled to be deleted or are currently being deleted. Corresponds to the JSON property deleting

Returns:

  • (Fixnum)


27021
27022
27023
# File 'lib/google/apis/compute_alpha/classes.rb', line 27021

def deleting
  @deleting
end

#noneFixnum

Output only. The number of instances in the managed instance group that are running and have no scheduled actions. Corresponds to the JSON property none

Returns:

  • (Fixnum)


27027
27028
27029
# File 'lib/google/apis/compute_alpha/classes.rb', line 27027

def none
  @none
end

#queuingFixnum

Output only. The number of instances that the managed instance group is currently queuing. Corresponds to the JSON property queuing

Returns:

  • (Fixnum)


27033
27034
27035
# File 'lib/google/apis/compute_alpha/classes.rb', line 27033

def queuing
  @queuing
end

#recreatingFixnum

Output only. The number of instances in the managed instance group that are scheduled to be recreated or are currently being being recreated. Recreating an instance deletes the existing root persistent disk and creates a new disk from the image that is defined in the instance template. Corresponds to the JSON property recreating

Returns:

  • (Fixnum)


27042
27043
27044
# File 'lib/google/apis/compute_alpha/classes.rb', line 27042

def recreating
  @recreating
end

#refreshingFixnum

Output only. The number of instances in the managed instance group that are being reconfigured with properties that do not require a restart or a recreate action. For example, setting or removing target pools for the instance. Corresponds to the JSON property refreshing

Returns:

  • (Fixnum)


27050
27051
27052
# File 'lib/google/apis/compute_alpha/classes.rb', line 27050

def refreshing
  @refreshing
end

#restartingFixnum

Output only. The number of instances in the managed instance group that are scheduled to be restarted or are currently being restarted. Corresponds to the JSON property restarting

Returns:

  • (Fixnum)


27056
27057
27058
# File 'lib/google/apis/compute_alpha/classes.rb', line 27056

def restarting
  @restarting
end

#restarting_in_placeFixnum

Output only. The number of instances in the managed instance group that are scheduled to be restarted or are currently being restarted. Corresponds to the JSON property restartingInPlace

Returns:

  • (Fixnum)


27062
27063
27064
# File 'lib/google/apis/compute_alpha/classes.rb', line 27062

def restarting_in_place
  @restarting_in_place
end

#resumingFixnum

Output only. The number of instances in the managed instance group that are scheduled to be resumed or are currently being resumed. Corresponds to the JSON property resuming

Returns:

  • (Fixnum)


27068
27069
27070
# File 'lib/google/apis/compute_alpha/classes.rb', line 27068

def resuming
  @resuming
end

#startingFixnum

Output only. The number of instances in the managed instance group that are scheduled to be started or are currently being started. Corresponds to the JSON property starting

Returns:

  • (Fixnum)


27074
27075
27076
# File 'lib/google/apis/compute_alpha/classes.rb', line 27074

def starting
  @starting
end

#stoppingFixnum

Output only. The number of instances in the managed instance group that are scheduled to be stopped or are currently being stopped. Corresponds to the JSON property stopping

Returns:

  • (Fixnum)


27080
27081
27082
# File 'lib/google/apis/compute_alpha/classes.rb', line 27080

def stopping
  @stopping
end

#suspendingFixnum

Output only. The number of instances in the managed instance group that are scheduled to be suspended or are currently being suspended. Corresponds to the JSON property suspending

Returns:

  • (Fixnum)


27086
27087
27088
# File 'lib/google/apis/compute_alpha/classes.rb', line 27086

def suspending
  @suspending
end

#verifyingFixnum

Output only. The number of instances in the managed instance group that are being verified. See the managedInstances[].currentAction property in the listManagedInstances method documentation. Corresponds to the JSON property verifying

Returns:

  • (Fixnum)


27093
27094
27095
# File 'lib/google/apis/compute_alpha/classes.rb', line 27093

def verifying
  @verifying
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



27100
27101
27102
27103
27104
27105
27106
27107
27108
27109
27110
27111
27112
27113
27114
27115
27116
27117
27118
# File 'lib/google/apis/compute_alpha/classes.rb', line 27100

def update!(**args)
  @abandoning = args[:abandoning] if args.key?(:abandoning)
  @adopting = args[:adopting] if args.key?(:adopting)
  @creating = args[:creating] if args.key?(:creating)
  @creating_atomically = args[:creating_atomically] if args.key?(:creating_atomically)
  @creating_without_retries = args[:creating_without_retries] if args.key?(:creating_without_retries)
  @deleting = args[:deleting] if args.key?(:deleting)
  @none = args[:none] if args.key?(:none)
  @queuing = args[:queuing] if args.key?(:queuing)
  @recreating = args[:recreating] if args.key?(:recreating)
  @refreshing = args[:refreshing] if args.key?(:refreshing)
  @restarting = args[:restarting] if args.key?(:restarting)
  @restarting_in_place = args[:restarting_in_place] if args.key?(:restarting_in_place)
  @resuming = args[:resuming] if args.key?(:resuming)
  @starting = args[:starting] if args.key?(:starting)
  @stopping = args[:stopping] if args.key?(:stopping)
  @suspending = args[:suspending] if args.key?(:suspending)
  @verifying = args[:verifying] if args.key?(:verifying)
end