Class: Google::Apis::ComputeAlpha::InstanceGroupManagerActionsSummary
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::InstanceGroupManagerActionsSummary
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#abandoning ⇒ Fixnum
Output only.
-
#adopting ⇒ Fixnum
Output only.
-
#creating ⇒ Fixnum
Output only.
-
#creating_atomically ⇒ Fixnum
Output only.
-
#creating_without_retries ⇒ Fixnum
Output only.
-
#deleting ⇒ Fixnum
Output only.
-
#none ⇒ Fixnum
Output only.
-
#queuing ⇒ Fixnum
Output only.
-
#recreating ⇒ Fixnum
Output only.
-
#refreshing ⇒ Fixnum
Output only.
-
#restarting ⇒ Fixnum
Output only.
-
#restarting_in_place ⇒ Fixnum
Output only.
-
#resuming ⇒ Fixnum
Output only.
-
#starting ⇒ Fixnum
Output only.
-
#stopping ⇒ Fixnum
Output only.
-
#suspending ⇒ Fixnum
Output only.
-
#verifying ⇒ Fixnum
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceGroupManagerActionsSummary
constructor
A new instance of InstanceGroupManagerActionsSummary.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceGroupManagerActionsSummary
Returns a new instance of InstanceGroupManagerActionsSummary.
26952 26953 26954 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 26952 def initialize(**args) update!(**args) end |
Instance Attribute Details
#abandoning ⇒ Fixnum
Output only. The total number of instances in the managed instance group
that are scheduled to be abandoned. Abandoning an instance removes it
from the managed instance group without deleting it.
Corresponds to the JSON property abandoning
26840 26841 26842 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 26840 def abandoning @abandoning end |
#adopting ⇒ Fixnum
Output only. The number of instances in the managed instance group that
are scheduled to be adopted or are currently being adopted.
Corresponds to the JSON property adopting
26846 26847 26848 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 26846 def adopting @adopting end |
#creating ⇒ Fixnum
Output only. The number of instances in the managed instance group that
are scheduled to be created or are currently being created. If the group
fails to create any of these instances, it tries again until it creates
the instance successfully.
If you have disabled creation retries, this field will not be populated;
instead, the creatingWithoutRetries field will be populated.
Corresponds to the JSON property creating
26856 26857 26858 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 26856 def creating @creating end |
#creating_atomically ⇒ Fixnum
Output only. The number of instances that the managed instance group
will attempt to create atomically, in a batch mode. If the desired count
of instances can not be created, entire batch will be deleted and the
group will decrease its targetSize value accordingly.
Corresponds to the JSON property creatingAtomically
26864 26865 26866 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 26864 def creating_atomically @creating_atomically end |
#creating_without_retries ⇒ Fixnum
Output only. The number of instances that the managed instance group
will attempt to create. The group attempts to create each instance
only once. If the group fails to create any of these instances, it
decreases the group's targetSize value accordingly.
Corresponds to the JSON property creatingWithoutRetries
26872 26873 26874 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 26872 def creating_without_retries @creating_without_retries end |
#deleting ⇒ Fixnum
Output only. The number of instances in the managed instance group that
are scheduled to be deleted or are currently being deleted.
Corresponds to the JSON property deleting
26878 26879 26880 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 26878 def deleting @deleting end |
#none ⇒ Fixnum
Output only. The number of instances in the managed instance group that
are running and have no scheduled actions.
Corresponds to the JSON property none
26884 26885 26886 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 26884 def none @none end |
#queuing ⇒ Fixnum
Output only. The number of instances that the managed instance group
is currently queuing.
Corresponds to the JSON property queuing
26890 26891 26892 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 26890 def queuing @queuing end |
#recreating ⇒ Fixnum
Output only. The number of instances in the managed instance group that
are scheduled to be recreated or are currently being being recreated.
Recreating an instance deletes the existing root persistent disk
and creates a new disk from the image that is defined in the
instance template.
Corresponds to the JSON property recreating
26899 26900 26901 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 26899 def recreating @recreating end |
#refreshing ⇒ Fixnum
Output only. The number of instances in the managed instance group that
are being reconfigured with properties that do not require a restart
or a recreate action. For example, setting or removing target
pools for the instance.
Corresponds to the JSON property refreshing
26907 26908 26909 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 26907 def refreshing @refreshing end |
#restarting ⇒ Fixnum
Output only. The number of instances in the managed instance group that
are scheduled to be restarted or are currently being restarted.
Corresponds to the JSON property restarting
26913 26914 26915 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 26913 def restarting @restarting end |
#restarting_in_place ⇒ Fixnum
Output only. The number of instances in the managed instance group that
are scheduled to be restarted or are currently being restarted.
Corresponds to the JSON property restartingInPlace
26919 26920 26921 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 26919 def restarting_in_place @restarting_in_place end |
#resuming ⇒ Fixnum
Output only. The number of instances in the managed instance group that
are scheduled to be resumed or are currently being resumed.
Corresponds to the JSON property resuming
26925 26926 26927 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 26925 def resuming @resuming end |
#starting ⇒ Fixnum
Output only. The number of instances in the managed instance group that
are scheduled to be started or are currently being started.
Corresponds to the JSON property starting
26931 26932 26933 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 26931 def starting @starting end |
#stopping ⇒ Fixnum
Output only. The number of instances in the managed instance group that
are scheduled to be stopped or are currently being stopped.
Corresponds to the JSON property stopping
26937 26938 26939 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 26937 def stopping @stopping end |
#suspending ⇒ Fixnum
Output only. The number of instances in the managed instance group that
are scheduled to be suspended or are currently being suspended.
Corresponds to the JSON property suspending
26943 26944 26945 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 26943 def suspending @suspending end |
#verifying ⇒ Fixnum
Output only. The number of instances in the managed instance group that
are being verified. See the managedInstances[].currentAction
property in the listManagedInstances method documentation.
Corresponds to the JSON property verifying
26950 26951 26952 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 26950 def @verifying end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
26957 26958 26959 26960 26961 26962 26963 26964 26965 26966 26967 26968 26969 26970 26971 26972 26973 26974 26975 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 26957 def update!(**args) @abandoning = args[:abandoning] if args.key?(:abandoning) @adopting = args[:adopting] if args.key?(:adopting) @creating = args[:creating] if args.key?(:creating) @creating_atomically = args[:creating_atomically] if args.key?(:creating_atomically) @creating_without_retries = args[:creating_without_retries] if args.key?(:creating_without_retries) @deleting = args[:deleting] if args.key?(:deleting) @none = args[:none] if args.key?(:none) @queuing = args[:queuing] if args.key?(:queuing) @recreating = args[:recreating] if args.key?(:recreating) @refreshing = args[:refreshing] if args.key?(:refreshing) @restarting = args[:restarting] if args.key?(:restarting) @restarting_in_place = args[:restarting_in_place] if args.key?(:restarting_in_place) @resuming = args[:resuming] if args.key?(:resuming) @starting = args[:starting] if args.key?(:starting) @stopping = args[:stopping] if args.key?(:stopping) @suspending = args[:suspending] if args.key?(:suspending) @verifying = args[:verifying] if args.key?(:verifying) end |