Class: Google::Apis::ComputeAlpha::InstanceGroupManagerActionsSummary

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupManagerActionsSummary

Returns a new instance of InstanceGroupManagerActionsSummary.



26266
26267
26268
# File 'lib/google/apis/compute_alpha/classes.rb', line 26266

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#abandoningFixnum

Output only. [Output Only] The total number of instances in the managed instance group that are scheduled to be abandoned. Abandoning an instance removes it from the managed instance group without deleting it. Corresponds to the JSON property abandoning

Returns:

  • (Fixnum)


26139
26140
26141
# File 'lib/google/apis/compute_alpha/classes.rb', line 26139

def abandoning
  @abandoning
end

#adoptingFixnum

[Output Only] The number of instances in the managed instance group that are scheduled to be adopted or are currently being adopted. Corresponds to the JSON property adopting

Returns:

  • (Fixnum)


26145
26146
26147
# File 'lib/google/apis/compute_alpha/classes.rb', line 26145

def adopting
  @adopting
end

#creatingFixnum

Output only. [Output Only] The number of instances in the managed instance group that are scheduled to be created or are currently being created. If the group fails to create any of these instances, it tries again until it creates the instance successfully. If you have disabled creation retries, this field will not be populated; instead, the creatingWithoutRetries field will be populated. Corresponds to the JSON property creating

Returns:

  • (Fixnum)


26156
26157
26158
# File 'lib/google/apis/compute_alpha/classes.rb', line 26156

def creating
  @creating
end

#creating_atomicallyFixnum

Output only. [Output Only] The number of instances that the managed instance group will attempt to create atomically, in a batch mode. If the desired count of instances can not be created, entire batch will be deleted and the group will decrease its targetSize value accordingly. Corresponds to the JSON property creatingAtomically

Returns:

  • (Fixnum)


26165
26166
26167
# File 'lib/google/apis/compute_alpha/classes.rb', line 26165

def creating_atomically
  @creating_atomically
end

#creating_without_retriesFixnum

Output only. [Output Only] The number of instances that the managed instance group will attempt to create. The group attempts to create each instance only once. If the group fails to create any of these instances, it decreases the group's targetSize value accordingly. Corresponds to the JSON property creatingWithoutRetries

Returns:

  • (Fixnum)


26174
26175
26176
# File 'lib/google/apis/compute_alpha/classes.rb', line 26174

def creating_without_retries
  @creating_without_retries
end

#deletingFixnum

Output only. [Output Only] The number of instances in the managed instance group that are scheduled to be deleted or are currently being deleted. Corresponds to the JSON property deleting

Returns:

  • (Fixnum)


26181
26182
26183
# File 'lib/google/apis/compute_alpha/classes.rb', line 26181

def deleting
  @deleting
end

#noneFixnum

Output only. [Output Only] The number of instances in the managed instance group that are running and have no scheduled actions. Corresponds to the JSON property none

Returns:

  • (Fixnum)


26188
26189
26190
# File 'lib/google/apis/compute_alpha/classes.rb', line 26188

def none
  @none
end

#queuingFixnum

Output only. [Output Only] The number of instances that the managed instance group is currently queuing. Corresponds to the JSON property queuing

Returns:

  • (Fixnum)


26195
26196
26197
# File 'lib/google/apis/compute_alpha/classes.rb', line 26195

def queuing
  @queuing
end

#recreatingFixnum

Output only. [Output Only] The number of instances in the managed instance group that are scheduled to be recreated or are currently being being recreated. Recreating an instance deletes the existing root persistent disk and creates a new disk from the image that is defined in the instance template. Corresponds to the JSON property recreating

Returns:

  • (Fixnum)


26205
26206
26207
# File 'lib/google/apis/compute_alpha/classes.rb', line 26205

def recreating
  @recreating
end

#refreshingFixnum

Output only. [Output Only] The number of instances in the managed instance group that are being reconfigured with properties that do not require a restart or a recreate action. For example, setting or removing target pools for the instance. Corresponds to the JSON property refreshing

Returns:

  • (Fixnum)


26214
26215
26216
# File 'lib/google/apis/compute_alpha/classes.rb', line 26214

def refreshing
  @refreshing
end

#restartingFixnum

Output only. [Output Only] The number of instances in the managed instance group that are scheduled to be restarted or are currently being restarted. Corresponds to the JSON property restarting

Returns:

  • (Fixnum)


26221
26222
26223
# File 'lib/google/apis/compute_alpha/classes.rb', line 26221

def restarting
  @restarting
end

#restarting_in_placeFixnum

Output only. [Output Only] The number of instances in the managed instance group that are scheduled to be restarted or are currently being restarted. Corresponds to the JSON property restartingInPlace

Returns:

  • (Fixnum)


26228
26229
26230
# File 'lib/google/apis/compute_alpha/classes.rb', line 26228

def restarting_in_place
  @restarting_in_place
end

#resumingFixnum

Output only. [Output Only] The number of instances in the managed instance group that are scheduled to be resumed or are currently being resumed. Corresponds to the JSON property resuming

Returns:

  • (Fixnum)


26235
26236
26237
# File 'lib/google/apis/compute_alpha/classes.rb', line 26235

def resuming
  @resuming
end

#startingFixnum

Output only. [Output Only] The number of instances in the managed instance group that are scheduled to be started or are currently being started. Corresponds to the JSON property starting

Returns:

  • (Fixnum)


26242
26243
26244
# File 'lib/google/apis/compute_alpha/classes.rb', line 26242

def starting
  @starting
end

#stoppingFixnum

Output only. [Output Only] The number of instances in the managed instance group that are scheduled to be stopped or are currently being stopped. Corresponds to the JSON property stopping

Returns:

  • (Fixnum)


26249
26250
26251
# File 'lib/google/apis/compute_alpha/classes.rb', line 26249

def stopping
  @stopping
end

#suspendingFixnum

Output only. [Output Only] The number of instances in the managed instance group that are scheduled to be suspended or are currently being suspended. Corresponds to the JSON property suspending

Returns:

  • (Fixnum)


26256
26257
26258
# File 'lib/google/apis/compute_alpha/classes.rb', line 26256

def suspending
  @suspending
end

#verifyingFixnum

Output only. [Output Only] The number of instances in the managed instance group that are being verified. See the managedInstances[].currentAction property in the listManagedInstances method documentation. Corresponds to the JSON property verifying

Returns:

  • (Fixnum)


26264
26265
26266
# File 'lib/google/apis/compute_alpha/classes.rb', line 26264

def verifying
  @verifying
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



26271
26272
26273
26274
26275
26276
26277
26278
26279
26280
26281
26282
26283
26284
26285
26286
26287
26288
26289
# File 'lib/google/apis/compute_alpha/classes.rb', line 26271

def update!(**args)
  @abandoning = args[:abandoning] if args.key?(:abandoning)
  @adopting = args[:adopting] if args.key?(:adopting)
  @creating = args[:creating] if args.key?(:creating)
  @creating_atomically = args[:creating_atomically] if args.key?(:creating_atomically)
  @creating_without_retries = args[:creating_without_retries] if args.key?(:creating_without_retries)
  @deleting = args[:deleting] if args.key?(:deleting)
  @none = args[:none] if args.key?(:none)
  @queuing = args[:queuing] if args.key?(:queuing)
  @recreating = args[:recreating] if args.key?(:recreating)
  @refreshing = args[:refreshing] if args.key?(:refreshing)
  @restarting = args[:restarting] if args.key?(:restarting)
  @restarting_in_place = args[:restarting_in_place] if args.key?(:restarting_in_place)
  @resuming = args[:resuming] if args.key?(:resuming)
  @starting = args[:starting] if args.key?(:starting)
  @stopping = args[:stopping] if args.key?(:stopping)
  @suspending = args[:suspending] if args.key?(:suspending)
  @verifying = args[:verifying] if args.key?(:verifying)
end