Class: Google::Apis::ComputeAlpha::InstanceGroupManagerAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupManagerAggregatedList

Returns a new instance of InstanceGroupManagerAggregatedList.



28377
28378
28379
# File 'lib/google/apis/compute_alpha/classes.rb', line 28377

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Output only. Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


28338
28339
28340
# File 'lib/google/apis/compute_alpha/classes.rb', line 28338

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::InstanceGroupManagersScopedList>

A list of InstanceGroupManagersScopedList resources. Corresponds to the JSON property items



28343
28344
28345
# File 'lib/google/apis/compute_alpha/classes.rb', line 28343

def items
  @items
end

#kindString

Output only. The resource type, which is alwayscompute# instanceGroupManagerAggregatedList for an aggregated list of managed instance groups. Corresponds to the JSON property kind

Returns:

  • (String)


28350
28351
28352
# File 'lib/google/apis/compute_alpha/classes.rb', line 28350

def kind
  @kind
end

#next_page_tokenString

Output only. This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


28360
28361
28362
# File 'lib/google/apis/compute_alpha/classes.rb', line 28360

def next_page_token
  @next_page_token
end

Output only. Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


28365
28366
28367
# File 'lib/google/apis/compute_alpha/classes.rb', line 28365

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


28370
28371
28372
# File 'lib/google/apis/compute_alpha/classes.rb', line 28370

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::InstanceGroupManagerAggregatedList::Warning

Output only. Informational warning message. Corresponds to the JSON property warning



28375
28376
28377
# File 'lib/google/apis/compute_alpha/classes.rb', line 28375

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



28382
28383
28384
28385
28386
28387
28388
28389
28390
# File 'lib/google/apis/compute_alpha/classes.rb', line 28382

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end