Class: Google::Apis::ComputeAlpha::InstanceGroupManagerAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupManagerAggregatedList

Returns a new instance of InstanceGroupManagerAggregatedList.



27362
27363
27364
# File 'lib/google/apis/compute_alpha/classes.rb', line 27362

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Output only. Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


27323
27324
27325
# File 'lib/google/apis/compute_alpha/classes.rb', line 27323

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::InstanceGroupManagersScopedList>

A list of InstanceGroupManagersScopedList resources. Corresponds to the JSON property items



27328
27329
27330
# File 'lib/google/apis/compute_alpha/classes.rb', line 27328

def items
  @items
end

#kindString

Output only. The resource type, which is alwayscompute# instanceGroupManagerAggregatedList for an aggregated list of managed instance groups. Corresponds to the JSON property kind

Returns:

  • (String)


27335
27336
27337
# File 'lib/google/apis/compute_alpha/classes.rb', line 27335

def kind
  @kind
end

#next_page_tokenString

Output only. This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


27345
27346
27347
# File 'lib/google/apis/compute_alpha/classes.rb', line 27345

def next_page_token
  @next_page_token
end

Output only. Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


27350
27351
27352
# File 'lib/google/apis/compute_alpha/classes.rb', line 27350

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


27355
27356
27357
# File 'lib/google/apis/compute_alpha/classes.rb', line 27355

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::InstanceGroupManagerAggregatedList::Warning

Output only. Informational warning message. Corresponds to the JSON property warning



27360
27361
27362
# File 'lib/google/apis/compute_alpha/classes.rb', line 27360

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



27367
27368
27369
27370
27371
27372
27373
27374
27375
# File 'lib/google/apis/compute_alpha/classes.rb', line 27367

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end