Class: Google::Apis::ComputeAlpha::InstanceGroupManagerAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupManagerAggregatedList

Returns a new instance of InstanceGroupManagerAggregatedList.



27167
27168
27169
# File 'lib/google/apis/compute_alpha/classes.rb', line 27167

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Output only. Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


27128
27129
27130
# File 'lib/google/apis/compute_alpha/classes.rb', line 27128

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::InstanceGroupManagersScopedList>

A list of InstanceGroupManagersScopedList resources. Corresponds to the JSON property items



27133
27134
27135
# File 'lib/google/apis/compute_alpha/classes.rb', line 27133

def items
  @items
end

#kindString

Output only. The resource type, which is alwayscompute# instanceGroupManagerAggregatedList for an aggregated list of managed instance groups. Corresponds to the JSON property kind

Returns:

  • (String)


27140
27141
27142
# File 'lib/google/apis/compute_alpha/classes.rb', line 27140

def kind
  @kind
end

#next_page_tokenString

Output only. This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


27150
27151
27152
# File 'lib/google/apis/compute_alpha/classes.rb', line 27150

def next_page_token
  @next_page_token
end

Output only. Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


27155
27156
27157
# File 'lib/google/apis/compute_alpha/classes.rb', line 27155

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


27160
27161
27162
# File 'lib/google/apis/compute_alpha/classes.rb', line 27160

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::InstanceGroupManagerAggregatedList::Warning

Output only. Informational warning message. Corresponds to the JSON property warning



27165
27166
27167
# File 'lib/google/apis/compute_alpha/classes.rb', line 27165

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



27172
27173
27174
27175
27176
27177
27178
27179
27180
# File 'lib/google/apis/compute_alpha/classes.rb', line 27172

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end