Class: Google::Apis::ComputeAlpha::InstanceGroupManagerAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupManagerAggregatedList

Returns a new instance of InstanceGroupManagerAggregatedList.



27026
27027
27028
# File 'lib/google/apis/compute_alpha/classes.rb', line 27026

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Output only. [Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


26986
26987
26988
# File 'lib/google/apis/compute_alpha/classes.rb', line 26986

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::InstanceGroupManagersScopedList>

A list of InstanceGroupManagersScopedList resources. Corresponds to the JSON property items



26991
26992
26993
# File 'lib/google/apis/compute_alpha/classes.rb', line 26991

def items
  @items
end

#kindString

Output only. [Output Only] The resource type, which is alwayscompute# instanceGroupManagerAggregatedList for an aggregated list of managed instance groups. Corresponds to the JSON property kind

Returns:

  • (String)


26998
26999
27000
# File 'lib/google/apis/compute_alpha/classes.rb', line 26998

def kind
  @kind
end

#next_page_tokenString

Output only. [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


27009
27010
27011
# File 'lib/google/apis/compute_alpha/classes.rb', line 27009

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


27014
27015
27016
# File 'lib/google/apis/compute_alpha/classes.rb', line 27014

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


27019
27020
27021
# File 'lib/google/apis/compute_alpha/classes.rb', line 27019

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::InstanceGroupManagerAggregatedList::Warning

Output only. [Output Only] Informational warning message. Corresponds to the JSON property warning



27024
27025
27026
# File 'lib/google/apis/compute_alpha/classes.rb', line 27024

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



27031
27032
27033
27034
27035
27036
27037
27038
27039
# File 'lib/google/apis/compute_alpha/classes.rb', line 27031

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end