Class: Google::Apis::ComputeAlpha::InstanceGroupManagerInstanceFlexibilityPolicyInstanceSelection
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::InstanceGroupManagerInstanceFlexibilityPolicyInstanceSelection
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#disks ⇒ Array<Google::Apis::ComputeAlpha::AttachedDisk>
List of disks to be attached to the instances created from this selection.
-
#machine_types ⇒ Array<String>
Full machine-type names, e.g.
-
#min_cpu_platform ⇒ String
Name of the minimum CPU platform to be used by this instance selection.
-
#rank ⇒ Fixnum
Preference of this instance selection.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceGroupManagerInstanceFlexibilityPolicyInstanceSelection
constructor
A new instance of InstanceGroupManagerInstanceFlexibilityPolicyInstanceSelection.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceGroupManagerInstanceFlexibilityPolicyInstanceSelection
Returns a new instance of InstanceGroupManagerInstanceFlexibilityPolicyInstanceSelection.
28753 28754 28755 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 28753 def initialize(**args) update!(**args) end |
Instance Attribute Details
#disks ⇒ Array<Google::Apis::ComputeAlpha::AttachedDisk>
List of disks to be attached to the instances created from this
selection.
Corresponds to the JSON property disks
28731 28732 28733 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 28731 def disks @disks end |
#machine_types ⇒ Array<String>
Full machine-type names, e.g. "n1-standard-16".
Corresponds to the JSON property machineTypes
28736 28737 28738 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 28736 def machine_types @machine_types end |
#min_cpu_platform ⇒ String
Name of the minimum CPU platform to be used by this instance selection.
e.g. 'Intel Ice Lake'.
Corresponds to the JSON property minCpuPlatform
28742 28743 28744 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 28742 def min_cpu_platform @min_cpu_platform end |
#rank ⇒ Fixnum
Preference of this instance selection. Lower number means higher
preference. MIG will first try to create a VM based on the machine-type
with lowest rank and fallback to next rank based on availability.
Machine types and instance selections with the same rank have the same
preference.
Corresponds to the JSON property rank
28751 28752 28753 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 28751 def rank @rank end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
28758 28759 28760 28761 28762 28763 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 28758 def update!(**args) @disks = args[:disks] if args.key?(:disks) @machine_types = args[:machine_types] if args.key?(:machine_types) @min_cpu_platform = args[:min_cpu_platform] if args.key?(:min_cpu_platform) @rank = args[:rank] if args.key?(:rank) end |