Class: Google::Apis::ComputeAlpha::InstanceGroupManagerInstanceFlexibilityPolicyInstanceSelection

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupManagerInstanceFlexibilityPolicyInstanceSelection

Returns a new instance of InstanceGroupManagerInstanceFlexibilityPolicyInstanceSelection.



28618
28619
28620
# File 'lib/google/apis/compute_alpha/classes.rb', line 28618

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#disksArray<Google::Apis::ComputeAlpha::AttachedDisk>

List of disks to be attached to the instances created from this selection. Corresponds to the JSON property disks



28596
28597
28598
# File 'lib/google/apis/compute_alpha/classes.rb', line 28596

def disks
  @disks
end

#machine_typesArray<String>

Full machine-type names, e.g. "n1-standard-16". Corresponds to the JSON property machineTypes

Returns:

  • (Array<String>)


28601
28602
28603
# File 'lib/google/apis/compute_alpha/classes.rb', line 28601

def machine_types
  @machine_types
end

#min_cpu_platformString

Name of the minimum CPU platform to be used by this instance selection. e.g. 'Intel Ice Lake'. Corresponds to the JSON property minCpuPlatform

Returns:

  • (String)


28607
28608
28609
# File 'lib/google/apis/compute_alpha/classes.rb', line 28607

def min_cpu_platform
  @min_cpu_platform
end

#rankFixnum

Preference of this instance selection. Lower number means higher preference. MIG will first try to create a VM based on the machine-type with lowest rank and fallback to next rank based on availability. Machine types and instance selections with the same rank have the same preference. Corresponds to the JSON property rank

Returns:

  • (Fixnum)


28616
28617
28618
# File 'lib/google/apis/compute_alpha/classes.rb', line 28616

def rank
  @rank
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



28623
28624
28625
28626
28627
28628
# File 'lib/google/apis/compute_alpha/classes.rb', line 28623

def update!(**args)
  @disks = args[:disks] if args.key?(:disks)
  @machine_types = args[:machine_types] if args.key?(:machine_types)
  @min_cpu_platform = args[:min_cpu_platform] if args.key?(:min_cpu_platform)
  @rank = args[:rank] if args.key?(:rank)
end