Class: Google::Apis::ComputeAlpha::InstanceGroupManagerInstanceFlexibilityPolicyInstanceSelection

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupManagerInstanceFlexibilityPolicyInstanceSelection

Returns a new instance of InstanceGroupManagerInstanceFlexibilityPolicyInstanceSelection.



27611
27612
27613
# File 'lib/google/apis/compute_alpha/classes.rb', line 27611

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#disksArray<Google::Apis::ComputeAlpha::AttachedDisk>

List of disks to be attached to the instances created from this selection. Corresponds to the JSON property disks



27589
27590
27591
# File 'lib/google/apis/compute_alpha/classes.rb', line 27589

def disks
  @disks
end

#machine_typesArray<String>

Full machine-type names, e.g. "n1-standard-16". Corresponds to the JSON property machineTypes

Returns:

  • (Array<String>)


27594
27595
27596
# File 'lib/google/apis/compute_alpha/classes.rb', line 27594

def machine_types
  @machine_types
end

#min_cpu_platformString

Name of the minimum CPU platform to be used by this instance selection. e.g. 'Intel Ice Lake'. Corresponds to the JSON property minCpuPlatform

Returns:

  • (String)


27600
27601
27602
# File 'lib/google/apis/compute_alpha/classes.rb', line 27600

def min_cpu_platform
  @min_cpu_platform
end

#rankFixnum

Preference of this instance selection. Lower number means higher preference. MIG will first try to create a VM based on the machine-type with lowest rank and fallback to next rank based on availability. Machine types and instance selections with the same rank have the same preference. Corresponds to the JSON property rank

Returns:

  • (Fixnum)


27609
27610
27611
# File 'lib/google/apis/compute_alpha/classes.rb', line 27609

def rank
  @rank
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



27616
27617
27618
27619
27620
27621
# File 'lib/google/apis/compute_alpha/classes.rb', line 27616

def update!(**args)
  @disks = args[:disks] if args.key?(:disks)
  @machine_types = args[:machine_types] if args.key?(:machine_types)
  @min_cpu_platform = args[:min_cpu_platform] if args.key?(:min_cpu_platform)
  @rank = args[:rank] if args.key?(:rank)
end