Class: Google::Apis::ComputeAlpha::InstanceGroupManagerList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

[Output Only] A list of managed instance groups.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupManagerList

Returns a new instance of InstanceGroupManagerList.



28829
28830
28831
# File 'lib/google/apis/compute_alpha/classes.rb', line 28829

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Output only. Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


28795
28796
28797
# File 'lib/google/apis/compute_alpha/classes.rb', line 28795

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::InstanceGroupManager>

A list of InstanceGroupManager resources. Corresponds to the JSON property items



28800
28801
28802
# File 'lib/google/apis/compute_alpha/classes.rb', line 28800

def items
  @items
end

#kindString

Output only. The resource type, which is always compute# instanceGroupManagerList for a list of managed instance groups. Corresponds to the JSON property kind

Returns:

  • (String)


28807
28808
28809
# File 'lib/google/apis/compute_alpha/classes.rb', line 28807

def kind
  @kind
end

#next_page_tokenString

Output only. This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


28817
28818
28819
# File 'lib/google/apis/compute_alpha/classes.rb', line 28817

def next_page_token
  @next_page_token
end

Output only. Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


28822
28823
28824
# File 'lib/google/apis/compute_alpha/classes.rb', line 28822

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::InstanceGroupManagerList::Warning

Output only. Informational warning message. Corresponds to the JSON property warning



28827
28828
28829
# File 'lib/google/apis/compute_alpha/classes.rb', line 28827

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



28834
28835
28836
28837
28838
28839
28840
28841
# File 'lib/google/apis/compute_alpha/classes.rb', line 28834

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end