Class: Google::Apis::ComputeAlpha::InstanceGroupManagerList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

[Output Only] A list of managed instance groups.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupManagerList

Returns a new instance of InstanceGroupManagerList.



28557
28558
28559
# File 'lib/google/apis/compute_alpha/classes.rb', line 28557

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Output only. Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


28523
28524
28525
# File 'lib/google/apis/compute_alpha/classes.rb', line 28523

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::InstanceGroupManager>

A list of InstanceGroupManager resources. Corresponds to the JSON property items



28528
28529
28530
# File 'lib/google/apis/compute_alpha/classes.rb', line 28528

def items
  @items
end

#kindString

Output only. The resource type, which is always compute# instanceGroupManagerList for a list of managed instance groups. Corresponds to the JSON property kind

Returns:

  • (String)


28535
28536
28537
# File 'lib/google/apis/compute_alpha/classes.rb', line 28535

def kind
  @kind
end

#next_page_tokenString

Output only. This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


28545
28546
28547
# File 'lib/google/apis/compute_alpha/classes.rb', line 28545

def next_page_token
  @next_page_token
end

Output only. Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


28550
28551
28552
# File 'lib/google/apis/compute_alpha/classes.rb', line 28550

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::InstanceGroupManagerList::Warning

Output only. Informational warning message. Corresponds to the JSON property warning



28555
28556
28557
# File 'lib/google/apis/compute_alpha/classes.rb', line 28555

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



28562
28563
28564
28565
28566
28567
28568
28569
# File 'lib/google/apis/compute_alpha/classes.rb', line 28562

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end