Class: Google::Apis::ComputeAlpha::InstanceGroupManagerList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

[Output Only] A list of managed instance groups.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupManagerList

Returns a new instance of InstanceGroupManagerList.



27814
27815
27816
# File 'lib/google/apis/compute_alpha/classes.rb', line 27814

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Output only. Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


27780
27781
27782
# File 'lib/google/apis/compute_alpha/classes.rb', line 27780

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::InstanceGroupManager>

A list of InstanceGroupManager resources. Corresponds to the JSON property items



27785
27786
27787
# File 'lib/google/apis/compute_alpha/classes.rb', line 27785

def items
  @items
end

#kindString

Output only. The resource type, which is always compute# instanceGroupManagerList for a list of managed instance groups. Corresponds to the JSON property kind

Returns:

  • (String)


27792
27793
27794
# File 'lib/google/apis/compute_alpha/classes.rb', line 27792

def kind
  @kind
end

#next_page_tokenString

Output only. This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


27802
27803
27804
# File 'lib/google/apis/compute_alpha/classes.rb', line 27802

def next_page_token
  @next_page_token
end

Output only. Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


27807
27808
27809
# File 'lib/google/apis/compute_alpha/classes.rb', line 27807

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::InstanceGroupManagerList::Warning

Output only. Informational warning message. Corresponds to the JSON property warning



27812
27813
27814
# File 'lib/google/apis/compute_alpha/classes.rb', line 27812

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



27819
27820
27821
27822
27823
27824
27825
27826
# File 'lib/google/apis/compute_alpha/classes.rb', line 27819

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end