Class: Google::Apis::ComputeAlpha::InstanceGroupManagerList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

[Output Only] A list of managed instance groups.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupManagerList

Returns a new instance of InstanceGroupManagerList.



27619
27620
27621
# File 'lib/google/apis/compute_alpha/classes.rb', line 27619

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Output only. Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


27585
27586
27587
# File 'lib/google/apis/compute_alpha/classes.rb', line 27585

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::InstanceGroupManager>

A list of InstanceGroupManager resources. Corresponds to the JSON property items



27590
27591
27592
# File 'lib/google/apis/compute_alpha/classes.rb', line 27590

def items
  @items
end

#kindString

Output only. The resource type, which is always compute# instanceGroupManagerList for a list of managed instance groups. Corresponds to the JSON property kind

Returns:

  • (String)


27597
27598
27599
# File 'lib/google/apis/compute_alpha/classes.rb', line 27597

def kind
  @kind
end

#next_page_tokenString

Output only. This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


27607
27608
27609
# File 'lib/google/apis/compute_alpha/classes.rb', line 27607

def next_page_token
  @next_page_token
end

Output only. Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


27612
27613
27614
# File 'lib/google/apis/compute_alpha/classes.rb', line 27612

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::InstanceGroupManagerList::Warning

Output only. Informational warning message. Corresponds to the JSON property warning



27617
27618
27619
# File 'lib/google/apis/compute_alpha/classes.rb', line 27617

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



27624
27625
27626
27627
27628
27629
27630
27631
# File 'lib/google/apis/compute_alpha/classes.rb', line 27624

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end