Class: Google::Apis::ComputeAlpha::InstanceGroupManagerList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

[Output Only] A list of managed instance groups.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupManagerList

Returns a new instance of InstanceGroupManagerList.



26793
26794
26795
# File 'lib/google/apis/compute_alpha/classes.rb', line 26793

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Output only. [Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


26759
26760
26761
# File 'lib/google/apis/compute_alpha/classes.rb', line 26759

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::InstanceGroupManager>

A list of InstanceGroupManager resources. Corresponds to the JSON property items



26764
26765
26766
# File 'lib/google/apis/compute_alpha/classes.rb', line 26764

def items
  @items
end

#kindString

Output only. [Output Only] The resource type, which is always compute#instanceGroupManagerList for a list of managed instance groups. Corresponds to the JSON property kind

Returns:

  • (String)


26770
26771
26772
# File 'lib/google/apis/compute_alpha/classes.rb', line 26770

def kind
  @kind
end

#next_page_tokenString

Output only. [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


26781
26782
26783
# File 'lib/google/apis/compute_alpha/classes.rb', line 26781

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


26786
26787
26788
# File 'lib/google/apis/compute_alpha/classes.rb', line 26786

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::InstanceGroupManagerList::Warning

Output only. [Output Only] Informational warning message. Corresponds to the JSON property warning



26791
26792
26793
# File 'lib/google/apis/compute_alpha/classes.rb', line 26791

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



26798
26799
26800
26801
26802
26803
26804
26805
# File 'lib/google/apis/compute_alpha/classes.rb', line 26798

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end