Class: Google::Apis::ComputeAlpha::InstanceGroupManagerResizeRequest
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::InstanceGroupManagerResizeRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
InstanceGroupManagerResizeRequest represents a request to create a number of VMs: either immediately or by queuing the request for the specified time. This resize request is nested under InstanceGroupManager and the VMs created by this request are added to the owning InstanceGroupManager.
Instance Attribute Summary collapse
-
#count ⇒ Fixnum
This field is deprecated, please use resize_by instead.
-
#creation_timestamp ⇒ String
Output only.
-
#description ⇒ String
An optional description of this resource.
-
#id ⇒ Fixnum
Output only.
-
#instances ⇒ Array<Google::Apis::ComputeAlpha::PerInstanceConfig>
The names of instances to be created by this resize request.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
The name of this resize request.
-
#queuing_policy ⇒ Google::Apis::ComputeAlpha::QueuingPolicy
Queuing parameters for the requested deferred capacity.
-
#region ⇒ String
Output only.
-
#requested_run_duration ⇒ Google::Apis::ComputeAlpha::Duration
A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution.
-
#resize_by ⇒ Fixnum
The number of instances to be created by this resize request.
-
#self_link ⇒ String
Output only.
-
#self_link_with_id ⇒ String
Output only.
-
#state ⇒ String
Output only.
-
#status ⇒ Google::Apis::ComputeAlpha::InstanceGroupManagerResizeRequestStatus
Output only.
-
#zone ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceGroupManagerResizeRequest
constructor
A new instance of InstanceGroupManagerResizeRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceGroupManagerResizeRequest
Returns a new instance of InstanceGroupManagerResizeRequest.
27825 27826 27827 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27825 def initialize(**args) update!(**args) end |
Instance Attribute Details
#count ⇒ Fixnum
This field is deprecated, please use resize_by instead.
The count of instances to create as part of this resize request.
Corresponds to the JSON property count
27731 27732 27733 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27731 def count @count end |
#creation_timestamp ⇒ String
Output only. The creation timestamp for this resize request inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
27737 27738 27739 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27737 def @creation_timestamp end |
#description ⇒ String
An optional description of this resource.
Corresponds to the JSON property description
27742 27743 27744 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27742 def description @description end |
#id ⇒ Fixnum
Output only. A unique identifier for this resource type. The server generates
this
identifier.
Corresponds to the JSON property id
27749 27750 27751 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27749 def id @id end |
#instances ⇒ Array<Google::Apis::ComputeAlpha::PerInstanceConfig>
The names of instances to be created by this resize request. The number of
names specified determines the number of instances to create. The group's
target size will be increased by this number. This field cannot be used
together with 'resize_by'.
Corresponds to the JSON property instances
27757 27758 27759 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27757 def instances @instances end |
#kind ⇒ String
Output only. The resource type, which is alwayscompute#
instanceGroupManagerResizeRequest for resize requests.
Corresponds to the JSON property kind
27763 27764 27765 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27763 def kind @kind end |
#name ⇒ String
The name of this resize request. The name must be 1-63 characters
long, and comply withRFC1035.
Corresponds to the JSON property name
27769 27770 27771 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27769 def name @name end |
#queuing_policy ⇒ Google::Apis::ComputeAlpha::QueuingPolicy
Queuing parameters for the requested deferred capacity.
Corresponds to the JSON property queuingPolicy
27774 27775 27776 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27774 def queuing_policy @queuing_policy end |
#region ⇒ String
Output only. The URL of a region
where the resize request is located. Populated only for regional resize
requests.
Corresponds to the JSON property region
27781 27782 27783 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27781 def region @region end |
#requested_run_duration ⇒ Google::Apis::ComputeAlpha::Duration
A Duration represents a fixed-length span of time represented
as a count of seconds and fractions of seconds at nanosecond
resolution. It is independent of any calendar and concepts like "day"
or "month". Range is approximately 10,000 years.
Corresponds to the JSON property requestedRunDuration
27789 27790 27791 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27789 def requested_run_duration @requested_run_duration end |
#resize_by ⇒ Fixnum
The number of instances to be created by this resize request. The group's
target size will be increased by this number. This field cannot be used
together with 'instances'.
Corresponds to the JSON property resizeBy
27796 27797 27798 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27796 def resize_by @resize_by end |
#self_link ⇒ String
Output only. The URL for this resize request. The server defines this URL.
Corresponds to the JSON property selfLink
27801 27802 27803 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27801 def self_link @self_link end |
#self_link_with_id ⇒ String
Output only. Server-defined URL for this resource with the resource id.
Corresponds to the JSON property selfLinkWithId
27806 27807 27808 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27806 def self_link_with_id @self_link_with_id end |
#state ⇒ String
Output only. Current state of the request.
Corresponds to the JSON property state
27811 27812 27813 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27811 def state @state end |
#status ⇒ Google::Apis::ComputeAlpha::InstanceGroupManagerResizeRequestStatus
Output only. Status of the request.
Corresponds to the JSON property status
27816 27817 27818 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27816 def status @status end |
#zone ⇒ String
Output only. The URL of a zone
where the resize request is located. Populated only for zonal resize
requests.
Corresponds to the JSON property zone
27823 27824 27825 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27823 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
27830 27831 27832 27833 27834 27835 27836 27837 27838 27839 27840 27841 27842 27843 27844 27845 27846 27847 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27830 def update!(**args) @count = args[:count] if args.key?(:count) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @id = args[:id] if args.key?(:id) @instances = args[:instances] if args.key?(:instances) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @queuing_policy = args[:queuing_policy] if args.key?(:queuing_policy) @region = args[:region] if args.key?(:region) @requested_run_duration = args[:requested_run_duration] if args.key?(:requested_run_duration) @resize_by = args[:resize_by] if args.key?(:resize_by) @self_link = args[:self_link] if args.key?(:self_link) @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id) @state = args[:state] if args.key?(:state) @status = args[:status] if args.key?(:status) @zone = args[:zone] if args.key?(:zone) end |