Class: Google::Apis::ComputeAlpha::InstanceGroupManagerResizeRequest
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::InstanceGroupManagerResizeRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
InstanceGroupManagerResizeRequest represents a request to create a number of VMs: either immediately or by queuing the request for the specified time. This resize request is nested under InstanceGroupManager and the VMs created by this request are added to the owning InstanceGroupManager.
Instance Attribute Summary collapse
-
#count ⇒ Fixnum
This field is deprecated, please use resize_by instead.
-
#creation_timestamp ⇒ String
Output only.
-
#description ⇒ String
An optional description of this resource.
-
#id ⇒ Fixnum
Output only.
-
#instances ⇒ Array<Google::Apis::ComputeAlpha::PerInstanceConfig>
The names of instances to be created by this resize request.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
The name of this resize request.
-
#queuing_policy ⇒ Google::Apis::ComputeAlpha::QueuingPolicy
Queuing parameters for the requested deferred capacity.
-
#region ⇒ String
Output only.
-
#requested_run_duration ⇒ Google::Apis::ComputeAlpha::Duration
A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution.
-
#resize_by ⇒ Fixnum
The number of instances to be created by this resize request.
-
#self_link ⇒ String
Output only.
-
#self_link_with_id ⇒ String
Output only.
-
#state ⇒ String
Output only.
-
#status ⇒ Google::Apis::ComputeAlpha::InstanceGroupManagerResizeRequestStatus
Output only.
-
#zone ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceGroupManagerResizeRequest
constructor
A new instance of InstanceGroupManagerResizeRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceGroupManagerResizeRequest
Returns a new instance of InstanceGroupManagerResizeRequest.
27013 27014 27015 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27013 def initialize(**args) update!(**args) end |
Instance Attribute Details
#count ⇒ Fixnum
This field is deprecated, please use resize_by instead.
The count of instances to create as part of this resize request.
Corresponds to the JSON property count
26915 26916 26917 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 26915 def count @count end |
#creation_timestamp ⇒ String
Output only. [Output Only] The creation timestamp for this resize request
inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
26922 26923 26924 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 26922 def @creation_timestamp end |
#description ⇒ String
An optional description of this resource.
Corresponds to the JSON property description
26927 26928 26929 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 26927 def description @description end |
#id ⇒ Fixnum
Output only. [Output Only] A unique identifier for this resource type. The
server
generates this identifier.
Corresponds to the JSON property id
26934 26935 26936 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 26934 def id @id end |
#instances ⇒ Array<Google::Apis::ComputeAlpha::PerInstanceConfig>
The names of instances to be created by this resize request. The number of
names specified determines the number of instances to create. The group's
target size will be increased by this number. This field cannot be used
together with 'resize_by'.
Corresponds to the JSON property instances
26942 26943 26944 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 26942 def instances @instances end |
#kind ⇒ String
Output only. [Output Only] The resource type, which is alwayscompute#
instanceGroupManagerResizeRequest for
resize requests.
Corresponds to the JSON property kind
26949 26950 26951 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 26949 def kind @kind end |
#name ⇒ String
The name of this resize request. The name must be 1-63 characters
long, and comply withRFC1035.
Corresponds to the JSON property name
26955 26956 26957 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 26955 def name @name end |
#queuing_policy ⇒ Google::Apis::ComputeAlpha::QueuingPolicy
Queuing parameters for the requested deferred capacity.
Corresponds to the JSON property queuingPolicy
26960 26961 26962 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 26960 def queuing_policy @queuing_policy end |
#region ⇒ String
Output only. [Output Only] The URL of aregion
where the resize request is located. Populated only for regional resize
requests.
Corresponds to the JSON property region
26967 26968 26969 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 26967 def region @region end |
#requested_run_duration ⇒ Google::Apis::ComputeAlpha::Duration
A Duration represents a fixed-length span of time represented
as a count of seconds and fractions of seconds at nanosecond
resolution. It is independent of any calendar and concepts like "day"
or "month". Range is approximately 10,000 years.
Corresponds to the JSON property requestedRunDuration
26975 26976 26977 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 26975 def requested_run_duration @requested_run_duration end |
#resize_by ⇒ Fixnum
The number of instances to be created by this resize request. The group's
target size will be increased by this number. This field cannot be used
together with 'instances'.
Corresponds to the JSON property resizeBy
26982 26983 26984 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 26982 def resize_by @resize_by end |
#self_link ⇒ String
Output only. [Output Only] The URL for this resize request. The server defines
this URL.
Corresponds to the JSON property selfLink
26988 26989 26990 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 26988 def self_link @self_link end |
#self_link_with_id ⇒ String
Output only. [Output Only] Server-defined URL for this resource with the
resource id.
Corresponds to the JSON property selfLinkWithId
26994 26995 26996 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 26994 def self_link_with_id @self_link_with_id end |
#state ⇒ String
Output only. [Output only] Current state of the request.
Corresponds to the JSON property state
26999 27000 27001 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 26999 def state @state end |
#status ⇒ Google::Apis::ComputeAlpha::InstanceGroupManagerResizeRequestStatus
Output only. [Output only] Status of the request.
Corresponds to the JSON property status
27004 27005 27006 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27004 def status @status end |
#zone ⇒ String
Output only. [Output Only] The URL of azone
where the resize request is located. Populated only for zonal resize
requests.
Corresponds to the JSON property zone
27011 27012 27013 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27011 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
27018 27019 27020 27021 27022 27023 27024 27025 27026 27027 27028 27029 27030 27031 27032 27033 27034 27035 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27018 def update!(**args) @count = args[:count] if args.key?(:count) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @id = args[:id] if args.key?(:id) @instances = args[:instances] if args.key?(:instances) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @queuing_policy = args[:queuing_policy] if args.key?(:queuing_policy) @region = args[:region] if args.key?(:region) @requested_run_duration = args[:requested_run_duration] if args.key?(:requested_run_duration) @resize_by = args[:resize_by] if args.key?(:resize_by) @self_link = args[:self_link] if args.key?(:self_link) @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id) @state = args[:state] if args.key?(:state) @status = args[:status] if args.key?(:status) @zone = args[:zone] if args.key?(:zone) end |