Class: Google::Apis::ComputeAlpha::InstanceGroupManagerResizeRequestStatus
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::InstanceGroupManagerResizeRequestStatus
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Error
Instance Attribute Summary collapse
-
#error ⇒ Google::Apis::ComputeAlpha::InstanceGroupManagerResizeRequestStatus::Error
Output only.
-
#last_attempt ⇒ Google::Apis::ComputeAlpha::InstanceGroupManagerResizeRequestStatusLastAttempt
Output only.
-
#queuing_policy ⇒ Google::Apis::ComputeAlpha::QueuingPolicy
Queuing parameters for the requested deferred capacity.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceGroupManagerResizeRequestStatus
constructor
A new instance of InstanceGroupManagerResizeRequestStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceGroupManagerResizeRequestStatus
Returns a new instance of InstanceGroupManagerResizeRequestStatus.
27891 27892 27893 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27891 def initialize(**args) update!(**args) end |
Instance Attribute Details
#error ⇒ Google::Apis::ComputeAlpha::InstanceGroupManagerResizeRequestStatus::Error
Output only. Fatal errors encountered during the queueing or provisioning
phases of
the ResizeRequest that caused the transition to the FAILED state.
Contrary to the last_attempt errors, this field is final and errors are
never removed from here, as the ResizeRequest is not going to retry.
Corresponds to the JSON property error
27871 27872 27873 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27871 def error @error end |
#last_attempt ⇒ Google::Apis::ComputeAlpha::InstanceGroupManagerResizeRequestStatusLastAttempt
Output only. Information about the last attempt to fulfill the request. The
value is
temporary since the ResizeRequest can retry, as long as it's still active
and the last attempt value can either be cleared or replaced with a
different error. Since ResizeRequest retries infrequently, the value may
be stale and no longer show an active problem. The value is cleared when
ResizeRequest transitions to the final state (becomes inactive). If the
final state is FAILED the error describing it will be stored in the
"error" field only.
Corresponds to the JSON property lastAttempt
27884 27885 27886 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27884 def last_attempt @last_attempt end |
#queuing_policy ⇒ Google::Apis::ComputeAlpha::QueuingPolicy
Queuing parameters for the requested deferred capacity.
Corresponds to the JSON property queuingPolicy
27889 27890 27891 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27889 def queuing_policy @queuing_policy end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
27896 27897 27898 27899 27900 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27896 def update!(**args) @error = args[:error] if args.key?(:error) @last_attempt = args[:last_attempt] if args.key?(:last_attempt) @queuing_policy = args[:queuing_policy] if args.key?(:queuing_policy) end |