Class: Google::Apis::ComputeAlpha::InstanceGroupManagerResizeRequestStatus

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Error

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupManagerResizeRequestStatus

Returns a new instance of InstanceGroupManagerResizeRequestStatus.



27069
27070
27071
# File 'lib/google/apis/compute_alpha/classes.rb', line 27069

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#errorGoogle::Apis::ComputeAlpha::InstanceGroupManagerResizeRequestStatus::Error

Output only. [Output only] Fatal errors encountered during the queueing or provisioning phases of the ResizeRequest that caused the transition to the FAILED state. Contrary to the last_attempt errors, this field is final and errors are never removed from here, as the ResizeRequest is not going to retry. Corresponds to the JSON property error



27049
27050
27051
# File 'lib/google/apis/compute_alpha/classes.rb', line 27049

def error
  @error
end

#last_attemptGoogle::Apis::ComputeAlpha::InstanceGroupManagerResizeRequestStatusLastAttempt

Output only. [Output only] Information about the last attempt to fulfill the request. The value is temporary since the ResizeRequest can retry, as long as it's still active and the last attempt value can either be cleared or replaced with a different error. Since ResizeRequest retries infrequently, the value may be stale and no longer show an active problem. The value is cleared when ResizeRequest transitions to the final state (becomes inactive). If the final state is FAILED the error describing it will be storred in the "error" field only. Corresponds to the JSON property lastAttempt



27062
27063
27064
# File 'lib/google/apis/compute_alpha/classes.rb', line 27062

def last_attempt
  @last_attempt
end

#queuing_policyGoogle::Apis::ComputeAlpha::QueuingPolicy

Queuing parameters for the requested deferred capacity. Corresponds to the JSON property queuingPolicy



27067
27068
27069
# File 'lib/google/apis/compute_alpha/classes.rb', line 27067

def queuing_policy
  @queuing_policy
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



27074
27075
27076
27077
27078
# File 'lib/google/apis/compute_alpha/classes.rb', line 27074

def update!(**args)
  @error = args[:error] if args.key?(:error)
  @last_attempt = args[:last_attempt] if args.key?(:last_attempt)
  @queuing_policy = args[:queuing_policy] if args.key?(:queuing_policy)
end