Class: Google::Apis::ComputeAlpha::InstanceGroupManagerResizeRequestStatus::Error
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::InstanceGroupManagerResizeRequestStatus::Error
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Output only. [Output only] Fatal errors encountered during the queueing or provisioning phases of the ResizeRequest that caused the transition to the FAILED state. Contrary to the last_attempt errors, this field is final and errors are never removed from here, as the ResizeRequest is not going to retry.
Defined Under Namespace
Classes: Error
Instance Attribute Summary collapse
-
#errors ⇒ Array<Google::Apis::ComputeAlpha::InstanceGroupManagerResizeRequestStatus::Error::Error>
[Output Only] The array of errors encountered while processing this operation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Error
constructor
A new instance of Error.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Error
Returns a new instance of Error.
27094 27095 27096 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27094 def initialize(**args) update!(**args) end |
Instance Attribute Details
#errors ⇒ Array<Google::Apis::ComputeAlpha::InstanceGroupManagerResizeRequestStatus::Error::Error>
[Output Only] The array of errors encountered while processing this
operation.
Corresponds to the JSON property errors
27092 27093 27094 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27092 def errors @errors end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
27099 27100 27101 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27099 def update!(**args) @errors = args[:errors] if args.key?(:errors) end |