Class: Google::Apis::ComputeAlpha::InstanceGroupManagerResizeRequestsListResponse
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::InstanceGroupManagerResizeRequestsListResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
[Output Only] A list of resize requests.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
Output only.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::InstanceGroupManagerResizeRequest>
A list of resize request resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
Output only.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::InstanceGroupManagerResizeRequestsListResponse::Warning
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceGroupManagerResizeRequestsListResponse
constructor
A new instance of InstanceGroupManagerResizeRequestsListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceGroupManagerResizeRequestsListResponse
Returns a new instance of InstanceGroupManagerResizeRequestsListResponse.
29423 29424 29425 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 29423 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
Output only. Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
29389 29390 29391 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 29389 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::InstanceGroupManagerResizeRequest>
A list of resize request resources.
Corresponds to the JSON property items
29394 29395 29396 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 29394 def items @items end |
#kind ⇒ String
Output only. Type of the resource. Alwayscompute#
instanceGroupManagerResizeRequestList for
a list of resize requests.
Corresponds to the JSON property kind
29401 29402 29403 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 29401 def kind @kind end |
#next_page_token ⇒ String
Output only. This token allows you to get the next page of results for list
requests.
If the number of results is larger than maxResults, use thenextPageToken as a
value for the query parameterpageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
29411 29412 29413 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 29411 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. Server-defined URL for this resource.
Corresponds to the JSON property selfLink
29416 29417 29418 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 29416 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::InstanceGroupManagerResizeRequestsListResponse::Warning
Output only. Informational warning message.
Corresponds to the JSON property warning
29421 29422 29423 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 29421 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
29428 29429 29430 29431 29432 29433 29434 29435 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 29428 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |