Class: Google::Apis::ComputeAlpha::InstanceGroupManagerResizeRequestsListResponse
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::InstanceGroupManagerResizeRequestsListResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
[Output Only] A list of resize requests.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
Output only.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::InstanceGroupManagerResizeRequest>
A list of resize request resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
Output only.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::InstanceGroupManagerResizeRequestsListResponse::Warning
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceGroupManagerResizeRequestsListResponse
constructor
A new instance of InstanceGroupManagerResizeRequestsListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceGroupManagerResizeRequestsListResponse
Returns a new instance of InstanceGroupManagerResizeRequestsListResponse.
28412 28413 28414 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 28412 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
Output only. Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
28378 28379 28380 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 28378 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::InstanceGroupManagerResizeRequest>
A list of resize request resources.
Corresponds to the JSON property items
28383 28384 28385 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 28383 def items @items end |
#kind ⇒ String
Output only. Type of the resource. Alwayscompute#
instanceGroupManagerResizeRequestList for
a list of resize requests.
Corresponds to the JSON property kind
28390 28391 28392 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 28390 def kind @kind end |
#next_page_token ⇒ String
Output only. This token allows you to get the next page of results for list
requests.
If the number of results is larger than maxResults, use thenextPageToken as a
value for the query parameterpageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
28400 28401 28402 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 28400 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. Server-defined URL for this resource.
Corresponds to the JSON property selfLink
28405 28406 28407 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 28405 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::InstanceGroupManagerResizeRequestsListResponse::Warning
Output only. Informational warning message.
Corresponds to the JSON property warning
28410 28411 28412 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 28410 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
28417 28418 28419 28420 28421 28422 28423 28424 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 28417 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |