Class: Google::Apis::ComputeAlpha::InstanceGroupManagerResizeRequestsListResponse
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::InstanceGroupManagerResizeRequestsListResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
[Output Only] A list of resize requests.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
Output only.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::InstanceGroupManagerResizeRequest>
A list of resize request resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
Output only.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::InstanceGroupManagerResizeRequestsListResponse::Warning
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceGroupManagerResizeRequestsListResponse
constructor
A new instance of InstanceGroupManagerResizeRequestsListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceGroupManagerResizeRequestsListResponse
Returns a new instance of InstanceGroupManagerResizeRequestsListResponse.
28199 28200 28201 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 28199 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
Output only. Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
28165 28166 28167 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 28165 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::InstanceGroupManagerResizeRequest>
A list of resize request resources.
Corresponds to the JSON property items
28170 28171 28172 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 28170 def items @items end |
#kind ⇒ String
Output only. Type of the resource. Alwayscompute#
instanceGroupManagerResizeRequestList for
a list of resize requests.
Corresponds to the JSON property kind
28177 28178 28179 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 28177 def kind @kind end |
#next_page_token ⇒ String
Output only. This token allows you to get the next page of results for list
requests.
If the number of results is larger than maxResults, use thenextPageToken as a
value for the query parameterpageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
28187 28188 28189 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 28187 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. Server-defined URL for this resource.
Corresponds to the JSON property selfLink
28192 28193 28194 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 28192 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::InstanceGroupManagerResizeRequestsListResponse::Warning
Output only. Informational warning message.
Corresponds to the JSON property warning
28197 28198 28199 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 28197 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
28204 28205 28206 28207 28208 28209 28210 28211 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 28204 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |