Class: Google::Apis::ComputeAlpha::InstanceGroupManagerResizeRequestsListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

[Output Only] A list of resize requests.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupManagerResizeRequestsListResponse

Returns a new instance of InstanceGroupManagerResizeRequestsListResponse.



28071
28072
28073
# File 'lib/google/apis/compute_alpha/classes.rb', line 28071

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Output only. [Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


28036
28037
28038
# File 'lib/google/apis/compute_alpha/classes.rb', line 28036

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::InstanceGroupManagerResizeRequest>

A list of resize request resources. Corresponds to the JSON property items



28041
28042
28043
# File 'lib/google/apis/compute_alpha/classes.rb', line 28041

def items
  @items
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# instanceGroupManagerResizeRequestList for a list of resize requests. Corresponds to the JSON property kind

Returns:

  • (String)


28048
28049
28050
# File 'lib/google/apis/compute_alpha/classes.rb', line 28048

def kind
  @kind
end

#next_page_tokenString

Output only. [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


28059
28060
28061
# File 'lib/google/apis/compute_alpha/classes.rb', line 28059

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


28064
28065
28066
# File 'lib/google/apis/compute_alpha/classes.rb', line 28064

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::InstanceGroupManagerResizeRequestsListResponse::Warning

Output only. [Output Only] Informational warning message. Corresponds to the JSON property warning



28069
28070
28071
# File 'lib/google/apis/compute_alpha/classes.rb', line 28069

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



28076
28077
28078
28079
28080
28081
28082
28083
# File 'lib/google/apis/compute_alpha/classes.rb', line 28076

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end