Class: Google::Apis::ComputeAlpha::InstanceGroupManagerResizeRequestsListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

[Output Only] A list of resize requests.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupManagerResizeRequestsListResponse

Returns a new instance of InstanceGroupManagerResizeRequestsListResponse.



27389
27390
27391
# File 'lib/google/apis/compute_alpha/classes.rb', line 27389

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Output only. [Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


27354
27355
27356
# File 'lib/google/apis/compute_alpha/classes.rb', line 27354

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::InstanceGroupManagerResizeRequest>

A list of resize request resources. Corresponds to the JSON property items



27359
27360
27361
# File 'lib/google/apis/compute_alpha/classes.rb', line 27359

def items
  @items
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# instanceGroupManagerResizeRequestList for a list of resize requests. Corresponds to the JSON property kind

Returns:

  • (String)


27366
27367
27368
# File 'lib/google/apis/compute_alpha/classes.rb', line 27366

def kind
  @kind
end

#next_page_tokenString

Output only. [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


27377
27378
27379
# File 'lib/google/apis/compute_alpha/classes.rb', line 27377

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


27382
27383
27384
# File 'lib/google/apis/compute_alpha/classes.rb', line 27382

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::InstanceGroupManagerResizeRequestsListResponse::Warning

Output only. [Output Only] Informational warning message. Corresponds to the JSON property warning



27387
27388
27389
# File 'lib/google/apis/compute_alpha/classes.rb', line 27387

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



27394
27395
27396
27397
27398
27399
27400
27401
# File 'lib/google/apis/compute_alpha/classes.rb', line 27394

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end