Class: Google::Apis::ComputeAlpha::InstanceGroupManagerStandbyPolicy
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::InstanceGroupManagerStandbyPolicy
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#initial_delay_sec ⇒ Fixnum
Specifies the number of seconds that the MIG should wait to suspend or stop a VM after that VM was created.
-
#mode ⇒ String
Defines how a MIG resumes or starts VMs from a standby pool when the group scales out.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceGroupManagerStandbyPolicy
constructor
A new instance of InstanceGroupManagerStandbyPolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceGroupManagerStandbyPolicy
Returns a new instance of InstanceGroupManagerStandbyPolicy.
27521 27522 27523 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27521 def initialize(**args) update!(**args) end |
Instance Attribute Details
#initial_delay_sec ⇒ Fixnum
Specifies the number of seconds that the MIG should wait to suspend or
stop a VM after that VM was created. The initial delay gives the
initialization script the time to prepare your VM for a quick scale out.
The value of initial delay must be between 0 and 3600 seconds. The
default value is 0.
Corresponds to the JSON property initialDelaySec
27513 27514 27515 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27513 def initial_delay_sec @initial_delay_sec end |
#mode ⇒ String
Defines how a MIG resumes or starts VMs from a standby pool when the
group scales out. The default mode is MANUAL.
Corresponds to the JSON property mode
27519 27520 27521 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27519 def mode @mode end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
27526 27527 27528 27529 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27526 def update!(**args) @initial_delay_sec = args[:initial_delay_sec] if args.key?(:initial_delay_sec) @mode = args[:mode] if args.key?(:mode) end |