Class: Google::Apis::ComputeAlpha::InstanceGroupManagerStatus
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::InstanceGroupManagerStatus
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#all_instances_config ⇒ Google::Apis::ComputeAlpha::InstanceGroupManagerStatusAllInstancesConfig
Output only.
-
#applied_accelerator_topologies ⇒ Array<Google::Apis::ComputeAlpha::InstanceGroupManagerStatusAcceleratorTopology>
Output only.
-
#autoscaler ⇒ String
Output only.
-
#bulk_instance_operation ⇒ Google::Apis::ComputeAlpha::InstanceGroupManagerStatusBulkInstanceOperation
Bulk instance operation is the creation of VMs in a MIG when the targetSizePolicy.mode is set to BULK.
-
#current_instance_statuses ⇒ Google::Apis::ComputeAlpha::InstanceGroupManagerStatusInstanceStatusSummary
The list of instance statuses and the number of instances in this managed instance group that have the status.
-
#is_stable ⇒ Boolean
(also: #is_stable?)
Output only.
-
#stateful ⇒ Google::Apis::ComputeAlpha::InstanceGroupManagerStatusStateful
Output only.
-
#version_target ⇒ Google::Apis::ComputeAlpha::InstanceGroupManagerStatusVersionTarget
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceGroupManagerStatus
constructor
A new instance of InstanceGroupManagerStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceGroupManagerStatus
Returns a new instance of InstanceGroupManagerStatus.
27592 27593 27594 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27592 def initialize(**args) update!(**args) end |
Instance Attribute Details
#all_instances_config ⇒ Google::Apis::ComputeAlpha::InstanceGroupManagerStatusAllInstancesConfig
Output only. [Output only] Status of all-instances configuration on the group.
Corresponds to the JSON property allInstancesConfig
27539 27540 27541 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27539 def all_instances_config @all_instances_config end |
#applied_accelerator_topologies ⇒ Array<Google::Apis::ComputeAlpha::InstanceGroupManagerStatusAcceleratorTopology>
Output only. [Output Only] The accelerator topology applied to this MIG.
Currently only one accelerator topology is supported.
Corresponds to the JSON property appliedAcceleratorTopologies
27545 27546 27547 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27545 def applied_accelerator_topologies @applied_accelerator_topologies end |
#autoscaler ⇒ String
Output only. [Output Only] The URL of theAutoscaler
that targets this instance group manager.
Corresponds to the JSON property autoscaler
27551 27552 27553 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27551 def autoscaler @autoscaler end |
#bulk_instance_operation ⇒ Google::Apis::ComputeAlpha::InstanceGroupManagerStatusBulkInstanceOperation
Bulk instance operation is the creation of VMs in a MIG when the
targetSizePolicy.mode is set to BULK.
Corresponds to the JSON property bulkInstanceOperation
27557 27558 27559 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27557 def bulk_instance_operation @bulk_instance_operation end |
#current_instance_statuses ⇒ Google::Apis::ComputeAlpha::InstanceGroupManagerStatusInstanceStatusSummary
The list of instance statuses and the number of instances in this managed
instance group that have the status. For more information about how to
interpret each status check the instance lifecycle documentation.
Currently only shown for TPU MIGs.
Corresponds to the JSON property currentInstanceStatuses
27565 27566 27567 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27565 def current_instance_statuses @current_instance_statuses end |
#is_stable ⇒ Boolean Also known as: is_stable?
Output only. [Output Only] A bit indicating whether the managed instance group
is in a
stable state. A stable state means that: none of the instances in the
managed instance group is currently undergoing any type of change (for
example, creation, restart, or deletion); no future changes are scheduled
for instances in the managed instance group; and the managed instance
group itself is not being modified.
Corresponds to the JSON property isStable
27576 27577 27578 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27576 def is_stable @is_stable end |
#stateful ⇒ Google::Apis::ComputeAlpha::InstanceGroupManagerStatusStateful
Output only. [Output Only] Stateful status of the given Instance Group Manager.
Corresponds to the JSON property stateful
27582 27583 27584 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27582 def stateful @stateful end |
#version_target ⇒ Google::Apis::ComputeAlpha::InstanceGroupManagerStatusVersionTarget
Output only. [Output Only] A status of consistency of Instances' versions with
their
target version specified by version field on Instance Group
Manager.
Corresponds to the JSON property versionTarget
27590 27591 27592 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27590 def version_target @version_target end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
27597 27598 27599 27600 27601 27602 27603 27604 27605 27606 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 27597 def update!(**args) @all_instances_config = args[:all_instances_config] if args.key?(:all_instances_config) @applied_accelerator_topologies = args[:applied_accelerator_topologies] if args.key?(:applied_accelerator_topologies) @autoscaler = args[:autoscaler] if args.key?(:autoscaler) @bulk_instance_operation = args[:bulk_instance_operation] if args.key?(:bulk_instance_operation) @current_instance_statuses = args[:current_instance_statuses] if args.key?(:current_instance_statuses) @is_stable = args[:is_stable] if args.key?(:is_stable) @stateful = args[:stateful] if args.key?(:stateful) @version_target = args[:version_target] if args.key?(:version_target) end |