Class: Google::Apis::ComputeAlpha::InstanceGroupManagerStatusAcceleratorTopology

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupManagerStatusAcceleratorTopology

Returns a new instance of InstanceGroupManagerStatusAcceleratorTopology.



28651
28652
28653
# File 'lib/google/apis/compute_alpha/classes.rb', line 28651

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#accelerator_topologyString

Output only. Topology in the format of: "16x16", "4x4x4", etc. The value is the same as configured in the WorkloadPolicy. Corresponds to the JSON property acceleratorTopology

Returns:

  • (String)


28638
28639
28640
# File 'lib/google/apis/compute_alpha/classes.rb', line 28638

def accelerator_topology
  @accelerator_topology
end

#stateString

Output only. The state of the accelerator topology. Corresponds to the JSON property state

Returns:

  • (String)


28643
28644
28645
# File 'lib/google/apis/compute_alpha/classes.rb', line 28643

def state
  @state
end

#state_detailsGoogle::Apis::ComputeAlpha::InstanceGroupManagerStatusAcceleratorTopologyAcceleratorTopologyStateDetails

Output only. The result of the latest accelerator topology state check. Corresponds to the JSON property stateDetails



28649
28650
28651
# File 'lib/google/apis/compute_alpha/classes.rb', line 28649

def state_details
  @state_details
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



28656
28657
28658
28659
28660
# File 'lib/google/apis/compute_alpha/classes.rb', line 28656

def update!(**args)
  @accelerator_topology = args[:accelerator_topology] if args.key?(:accelerator_topology)
  @state = args[:state] if args.key?(:state)
  @state_details = args[:state_details] if args.key?(:state_details)
end