Class: Google::Apis::ComputeAlpha::InstanceGroupManagerStatusAcceleratorTopology

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupManagerStatusAcceleratorTopology

Returns a new instance of InstanceGroupManagerStatusAcceleratorTopology.



28310
28311
28312
# File 'lib/google/apis/compute_alpha/classes.rb', line 28310

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#accelerator_topologyString

Output only. Topology in the format of: "16x16", "4x4x4", etc. The value is the same as configured in the WorkloadPolicy. Corresponds to the JSON property acceleratorTopology

Returns:

  • (String)


28297
28298
28299
# File 'lib/google/apis/compute_alpha/classes.rb', line 28297

def accelerator_topology
  @accelerator_topology
end

#stateString

Output only. The state of the accelerator topology. Corresponds to the JSON property state

Returns:

  • (String)


28302
28303
28304
# File 'lib/google/apis/compute_alpha/classes.rb', line 28302

def state
  @state
end

#state_detailsGoogle::Apis::ComputeAlpha::InstanceGroupManagerStatusAcceleratorTopologyAcceleratorTopologyStateDetails

Output only. The result of the latest accelerator topology state check. Corresponds to the JSON property stateDetails



28308
28309
28310
# File 'lib/google/apis/compute_alpha/classes.rb', line 28308

def state_details
  @state_details
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



28315
28316
28317
28318
28319
# File 'lib/google/apis/compute_alpha/classes.rb', line 28315

def update!(**args)
  @accelerator_topology = args[:accelerator_topology] if args.key?(:accelerator_topology)
  @state = args[:state] if args.key?(:state)
  @state_details = args[:state_details] if args.key?(:state_details)
end