Class: Google::Apis::ComputeAlpha::InstanceGroupManagerStatusAcceleratorTopology

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupManagerStatusAcceleratorTopology

Returns a new instance of InstanceGroupManagerStatusAcceleratorTopology.



27630
27631
27632
# File 'lib/google/apis/compute_alpha/classes.rb', line 27630

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#accelerator_topologyString

Output only. [Output Only] Topology in the format of: "16x16", "4x4x4", etc. The value is the same as configured in the WorkloadPolicy. Corresponds to the JSON property acceleratorTopology

Returns:

  • (String)


27617
27618
27619
# File 'lib/google/apis/compute_alpha/classes.rb', line 27617

def accelerator_topology
  @accelerator_topology
end

#stateString

Output only. [Output Only] The state of the accelerator topology. Corresponds to the JSON property state

Returns:

  • (String)


27622
27623
27624
# File 'lib/google/apis/compute_alpha/classes.rb', line 27622

def state
  @state
end

#state_detailsGoogle::Apis::ComputeAlpha::InstanceGroupManagerStatusAcceleratorTopologyAcceleratorTopologyStateDetails

Output only. [Output Only] The result of the latest accelerator topology state check. Corresponds to the JSON property stateDetails



27628
27629
27630
# File 'lib/google/apis/compute_alpha/classes.rb', line 27628

def state_details
  @state_details
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



27635
27636
27637
27638
27639
# File 'lib/google/apis/compute_alpha/classes.rb', line 27635

def update!(**args)
  @accelerator_topology = args[:accelerator_topology] if args.key?(:accelerator_topology)
  @state = args[:state] if args.key?(:state)
  @state_details = args[:state_details] if args.key?(:state_details)
end