Class: Google::Apis::ComputeAlpha::InstanceGroupManagerStatusInstanceStatusSummary
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::InstanceGroupManagerStatusInstanceStatusSummary
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
The list of instance statuses and the number of instances in this managed instance group that have the status. For more information about how to interpret each status check the instance lifecycle documentation. Currently only shown for TPU MIGs.
Instance Attribute Summary collapse
-
#deprovisioning ⇒ Fixnum
Output only.
-
#non_existent ⇒ Fixnum
Output only.
-
#pending ⇒ Fixnum
Output only.
-
#pending_stop ⇒ Fixnum
Output only.
-
#provisioning ⇒ Fixnum
Output only.
-
#repairing ⇒ Fixnum
Output only.
-
#running ⇒ Fixnum
Output only.
-
#staging ⇒ Fixnum
Output only.
-
#stopped ⇒ Fixnum
Output only.
-
#stopping ⇒ Fixnum
Output only.
-
#suspended ⇒ Fixnum
Output only.
-
#suspending ⇒ Fixnum
Output only.
-
#terminated ⇒ Fixnum
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceGroupManagerStatusInstanceStatusSummary
constructor
A new instance of InstanceGroupManagerStatusInstanceStatusSummary.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceGroupManagerStatusInstanceStatusSummary
Returns a new instance of InstanceGroupManagerStatusInstanceStatusSummary.
30120 30121 30122 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 30120 def initialize(**args) update!(**args) end |
Instance Attribute Details
#deprovisioning ⇒ Fixnum
Output only. The number of instances in the managed instance group
that have DEPROVISIONING status.
Corresponds to the JSON property deprovisioning
30040 30041 30042 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 30040 def deprovisioning @deprovisioning end |
#non_existent ⇒ Fixnum
Output only. The number of instances that have not been created yet or
have been deleted. Includes only instances that would be shown in the
listManagedInstances method and not all instances that have been
deleted in the lifetime of the MIG.
Does not include FlexStart instances that are waiting for the resources
availability, they are considered as 'pending'.
Corresponds to the JSON property nonExistent
30050 30051 30052 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 30050 def non_existent @non_existent end |
#pending ⇒ Fixnum
Output only. The number of instances in the managed instance group
that have PENDING status, that is FlexStart instances that are waiting
for resources. Instances that do not exist because of the other reasons
are counted as 'non_existent'.
Corresponds to the JSON property pending
30058 30059 30060 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 30058 def pending @pending end |
#pending_stop ⇒ Fixnum
Output only. The number of instances in the managed instance group
that have PENDING_STOP status.
Corresponds to the JSON property pendingStop
30064 30065 30066 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 30064 def pending_stop @pending_stop end |
#provisioning ⇒ Fixnum
Output only. The number of instances in the managed instance group
that have PROVISIONING status.
Corresponds to the JSON property provisioning
30070 30071 30072 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 30070 def provisioning @provisioning end |
#repairing ⇒ Fixnum
Output only. The number of instances in the managed instance group
that have REPAIRING status.
Corresponds to the JSON property repairing
30076 30077 30078 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 30076 def repairing @repairing end |
#running ⇒ Fixnum
Output only. The number of instances in the managed instance group
that have RUNNING status.
Corresponds to the JSON property running
30082 30083 30084 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 30082 def running @running end |
#staging ⇒ Fixnum
Output only. The number of instances in the managed instance group
that have STAGING status.
Corresponds to the JSON property staging
30088 30089 30090 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 30088 def staging @staging end |
#stopped ⇒ Fixnum
Output only. The number of instances in the managed instance group
that have STOPPED status.
Corresponds to the JSON property stopped
30094 30095 30096 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 30094 def stopped @stopped end |
#stopping ⇒ Fixnum
Output only. The number of instances in the managed instance group
that have STOPPING status.
Corresponds to the JSON property stopping
30100 30101 30102 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 30100 def stopping @stopping end |
#suspended ⇒ Fixnum
Output only. The number of instances in the managed instance group
that have SUSPENDED status.
Corresponds to the JSON property suspended
30106 30107 30108 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 30106 def suspended @suspended end |
#suspending ⇒ Fixnum
Output only. The number of instances in the managed instance group
that have SUSPENDING status.
Corresponds to the JSON property suspending
30112 30113 30114 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 30112 def suspending @suspending end |
#terminated ⇒ Fixnum
Output only. The number of instances in the managed instance group
that have TERMINATED status.
Corresponds to the JSON property terminated
30118 30119 30120 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 30118 def terminated @terminated end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
30125 30126 30127 30128 30129 30130 30131 30132 30133 30134 30135 30136 30137 30138 30139 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 30125 def update!(**args) @deprovisioning = args[:deprovisioning] if args.key?(:deprovisioning) @non_existent = args[:non_existent] if args.key?(:non_existent) @pending = args[:pending] if args.key?(:pending) @pending_stop = args[:pending_stop] if args.key?(:pending_stop) @provisioning = args[:provisioning] if args.key?(:provisioning) @repairing = args[:repairing] if args.key?(:repairing) @running = args[:running] if args.key?(:running) @staging = args[:staging] if args.key?(:staging) @stopped = args[:stopped] if args.key?(:stopped) @stopping = args[:stopping] if args.key?(:stopping) @suspended = args[:suspended] if args.key?(:suspended) @suspending = args[:suspending] if args.key?(:suspending) @terminated = args[:terminated] if args.key?(:terminated) end |