Class: Google::Apis::ComputeAlpha::InstanceGroupManagerStatusInstanceStatusSummary

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

The list of instance statuses and the number of instances in this managed instance group that have the status. For more information about how to interpret each status check the instance lifecycle documentation. Currently only shown for TPU MIGs.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupManagerStatusInstanceStatusSummary

Returns a new instance of InstanceGroupManagerStatusInstanceStatusSummary.



29848
29849
29850
# File 'lib/google/apis/compute_alpha/classes.rb', line 29848

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#deprovisioningFixnum

Output only. The number of instances in the managed instance group that have DEPROVISIONING status. Corresponds to the JSON property deprovisioning

Returns:

  • (Fixnum)


29768
29769
29770
# File 'lib/google/apis/compute_alpha/classes.rb', line 29768

def deprovisioning
  @deprovisioning
end

#non_existentFixnum

Output only. The number of instances that have not been created yet or have been deleted. Includes only instances that would be shown in the listManagedInstances method and not all instances that have been deleted in the lifetime of the MIG. Does not include FlexStart instances that are waiting for the resources availability, they are considered as 'pending'. Corresponds to the JSON property nonExistent

Returns:

  • (Fixnum)


29778
29779
29780
# File 'lib/google/apis/compute_alpha/classes.rb', line 29778

def non_existent
  @non_existent
end

#pendingFixnum

Output only. The number of instances in the managed instance group that have PENDING status, that is FlexStart instances that are waiting for resources. Instances that do not exist because of the other reasons are counted as 'non_existent'. Corresponds to the JSON property pending

Returns:

  • (Fixnum)


29786
29787
29788
# File 'lib/google/apis/compute_alpha/classes.rb', line 29786

def pending
  @pending
end

#pending_stopFixnum

Output only. The number of instances in the managed instance group that have PENDING_STOP status. Corresponds to the JSON property pendingStop

Returns:

  • (Fixnum)


29792
29793
29794
# File 'lib/google/apis/compute_alpha/classes.rb', line 29792

def pending_stop
  @pending_stop
end

#provisioningFixnum

Output only. The number of instances in the managed instance group that have PROVISIONING status. Corresponds to the JSON property provisioning

Returns:

  • (Fixnum)


29798
29799
29800
# File 'lib/google/apis/compute_alpha/classes.rb', line 29798

def provisioning
  @provisioning
end

#repairingFixnum

Output only. The number of instances in the managed instance group that have REPAIRING status. Corresponds to the JSON property repairing

Returns:

  • (Fixnum)


29804
29805
29806
# File 'lib/google/apis/compute_alpha/classes.rb', line 29804

def repairing
  @repairing
end

#runningFixnum

Output only. The number of instances in the managed instance group that have RUNNING status. Corresponds to the JSON property running

Returns:

  • (Fixnum)


29810
29811
29812
# File 'lib/google/apis/compute_alpha/classes.rb', line 29810

def running
  @running
end

#stagingFixnum

Output only. The number of instances in the managed instance group that have STAGING status. Corresponds to the JSON property staging

Returns:

  • (Fixnum)


29816
29817
29818
# File 'lib/google/apis/compute_alpha/classes.rb', line 29816

def staging
  @staging
end

#stoppedFixnum

Output only. The number of instances in the managed instance group that have STOPPED status. Corresponds to the JSON property stopped

Returns:

  • (Fixnum)


29822
29823
29824
# File 'lib/google/apis/compute_alpha/classes.rb', line 29822

def stopped
  @stopped
end

#stoppingFixnum

Output only. The number of instances in the managed instance group that have STOPPING status. Corresponds to the JSON property stopping

Returns:

  • (Fixnum)


29828
29829
29830
# File 'lib/google/apis/compute_alpha/classes.rb', line 29828

def stopping
  @stopping
end

#suspendedFixnum

Output only. The number of instances in the managed instance group that have SUSPENDED status. Corresponds to the JSON property suspended

Returns:

  • (Fixnum)


29834
29835
29836
# File 'lib/google/apis/compute_alpha/classes.rb', line 29834

def suspended
  @suspended
end

#suspendingFixnum

Output only. The number of instances in the managed instance group that have SUSPENDING status. Corresponds to the JSON property suspending

Returns:

  • (Fixnum)


29840
29841
29842
# File 'lib/google/apis/compute_alpha/classes.rb', line 29840

def suspending
  @suspending
end

#terminatedFixnum

Output only. The number of instances in the managed instance group that have TERMINATED status. Corresponds to the JSON property terminated

Returns:

  • (Fixnum)


29846
29847
29848
# File 'lib/google/apis/compute_alpha/classes.rb', line 29846

def terminated
  @terminated
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



29853
29854
29855
29856
29857
29858
29859
29860
29861
29862
29863
29864
29865
29866
29867
# File 'lib/google/apis/compute_alpha/classes.rb', line 29853

def update!(**args)
  @deprovisioning = args[:deprovisioning] if args.key?(:deprovisioning)
  @non_existent = args[:non_existent] if args.key?(:non_existent)
  @pending = args[:pending] if args.key?(:pending)
  @pending_stop = args[:pending_stop] if args.key?(:pending_stop)
  @provisioning = args[:provisioning] if args.key?(:provisioning)
  @repairing = args[:repairing] if args.key?(:repairing)
  @running = args[:running] if args.key?(:running)
  @staging = args[:staging] if args.key?(:staging)
  @stopped = args[:stopped] if args.key?(:stopped)
  @stopping = args[:stopping] if args.key?(:stopping)
  @suspended = args[:suspended] if args.key?(:suspended)
  @suspending = args[:suspending] if args.key?(:suspending)
  @terminated = args[:terminated] if args.key?(:terminated)
end