Class: Google::Apis::ComputeAlpha::InstanceGroupManagerStatusInstanceStatusSummary

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

The list of instance statuses and the number of instances in this managed instance group that have the status. For more information about how to interpret each status check the instance lifecycle documentation. Currently only shown for TPU MIGs.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupManagerStatusInstanceStatusSummary

Returns a new instance of InstanceGroupManagerStatusInstanceStatusSummary.



28902
28903
28904
# File 'lib/google/apis/compute_alpha/classes.rb', line 28902

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#deprovisioningFixnum

Output only. The number of instances in the managed instance group that have DEPROVISIONING status. Corresponds to the JSON property deprovisioning

Returns:

  • (Fixnum)


28822
28823
28824
# File 'lib/google/apis/compute_alpha/classes.rb', line 28822

def deprovisioning
  @deprovisioning
end

#non_existentFixnum

Output only. The number of instances that have not been created yet or have been deleted. Includes only instances that would be shown in the listManagedInstances method and not all instances that have been deleted in the lifetime of the MIG. Does not include FlexStart instances that are waiting for the resources availability, they are considered as 'pending'. Corresponds to the JSON property nonExistent

Returns:

  • (Fixnum)


28832
28833
28834
# File 'lib/google/apis/compute_alpha/classes.rb', line 28832

def non_existent
  @non_existent
end

#pendingFixnum

Output only. The number of instances in the managed instance group that have PENDING status, that is FlexStart instances that are waiting for resources. Instances that do not exist because of the other reasons are counted as 'non_existent'. Corresponds to the JSON property pending

Returns:

  • (Fixnum)


28840
28841
28842
# File 'lib/google/apis/compute_alpha/classes.rb', line 28840

def pending
  @pending
end

#pending_stopFixnum

Output only. The number of instances in the managed instance group that have PENDING_STOP status. Corresponds to the JSON property pendingStop

Returns:

  • (Fixnum)


28846
28847
28848
# File 'lib/google/apis/compute_alpha/classes.rb', line 28846

def pending_stop
  @pending_stop
end

#provisioningFixnum

Output only. The number of instances in the managed instance group that have PROVISIONING status. Corresponds to the JSON property provisioning

Returns:

  • (Fixnum)


28852
28853
28854
# File 'lib/google/apis/compute_alpha/classes.rb', line 28852

def provisioning
  @provisioning
end

#repairingFixnum

Output only. The number of instances in the managed instance group that have REPAIRING status. Corresponds to the JSON property repairing

Returns:

  • (Fixnum)


28858
28859
28860
# File 'lib/google/apis/compute_alpha/classes.rb', line 28858

def repairing
  @repairing
end

#runningFixnum

Output only. The number of instances in the managed instance group that have RUNNING status. Corresponds to the JSON property running

Returns:

  • (Fixnum)


28864
28865
28866
# File 'lib/google/apis/compute_alpha/classes.rb', line 28864

def running
  @running
end

#stagingFixnum

Output only. The number of instances in the managed instance group that have STAGING status. Corresponds to the JSON property staging

Returns:

  • (Fixnum)


28870
28871
28872
# File 'lib/google/apis/compute_alpha/classes.rb', line 28870

def staging
  @staging
end

#stoppedFixnum

Output only. The number of instances in the managed instance group that have STOPPED status. Corresponds to the JSON property stopped

Returns:

  • (Fixnum)


28876
28877
28878
# File 'lib/google/apis/compute_alpha/classes.rb', line 28876

def stopped
  @stopped
end

#stoppingFixnum

Output only. The number of instances in the managed instance group that have STOPPING status. Corresponds to the JSON property stopping

Returns:

  • (Fixnum)


28882
28883
28884
# File 'lib/google/apis/compute_alpha/classes.rb', line 28882

def stopping
  @stopping
end

#suspendedFixnum

Output only. The number of instances in the managed instance group that have SUSPENDED status. Corresponds to the JSON property suspended

Returns:

  • (Fixnum)


28888
28889
28890
# File 'lib/google/apis/compute_alpha/classes.rb', line 28888

def suspended
  @suspended
end

#suspendingFixnum

Output only. The number of instances in the managed instance group that have SUSPENDING status. Corresponds to the JSON property suspending

Returns:

  • (Fixnum)


28894
28895
28896
# File 'lib/google/apis/compute_alpha/classes.rb', line 28894

def suspending
  @suspending
end

#terminatedFixnum

Output only. The number of instances in the managed instance group that have TERMINATED status. Corresponds to the JSON property terminated

Returns:

  • (Fixnum)


28900
28901
28902
# File 'lib/google/apis/compute_alpha/classes.rb', line 28900

def terminated
  @terminated
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



28907
28908
28909
28910
28911
28912
28913
28914
28915
28916
28917
28918
28919
28920
28921
# File 'lib/google/apis/compute_alpha/classes.rb', line 28907

def update!(**args)
  @deprovisioning = args[:deprovisioning] if args.key?(:deprovisioning)
  @non_existent = args[:non_existent] if args.key?(:non_existent)
  @pending = args[:pending] if args.key?(:pending)
  @pending_stop = args[:pending_stop] if args.key?(:pending_stop)
  @provisioning = args[:provisioning] if args.key?(:provisioning)
  @repairing = args[:repairing] if args.key?(:repairing)
  @running = args[:running] if args.key?(:running)
  @staging = args[:staging] if args.key?(:staging)
  @stopped = args[:stopped] if args.key?(:stopped)
  @stopping = args[:stopping] if args.key?(:stopping)
  @suspended = args[:suspended] if args.key?(:suspended)
  @suspending = args[:suspending] if args.key?(:suspending)
  @terminated = args[:terminated] if args.key?(:terminated)
end