Class: Google::Apis::ComputeAlpha::InstanceGroupManagerStatusInstanceStatusSummary

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

The list of instance statuses and the number of instances in this managed instance group that have the status. For more information about how to interpret each status check the instance lifecycle documentation. Currently only shown for TPU MIGs.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupManagerStatusInstanceStatusSummary

Returns a new instance of InstanceGroupManagerStatusInstanceStatusSummary.



28764
28765
28766
# File 'lib/google/apis/compute_alpha/classes.rb', line 28764

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#deprovisioningFixnum

Output only. The number of instances in the managed instance group that have DEPROVISIONING status. Corresponds to the JSON property deprovisioning

Returns:

  • (Fixnum)


28684
28685
28686
# File 'lib/google/apis/compute_alpha/classes.rb', line 28684

def deprovisioning
  @deprovisioning
end

#non_existentFixnum

Output only. The number of instances that have not been created yet or have been deleted. Includes only instances that would be shown in the listManagedInstances method and not all instances that have been deleted in the lifetime of the MIG. Does not include FlexStart instances that are waiting for the resources availability, they are considered as 'pending'. Corresponds to the JSON property nonExistent

Returns:

  • (Fixnum)


28694
28695
28696
# File 'lib/google/apis/compute_alpha/classes.rb', line 28694

def non_existent
  @non_existent
end

#pendingFixnum

Output only. The number of instances in the managed instance group that have PENDING status, that is FlexStart instances that are waiting for resources. Instances that do not exist because of the other reasons are counted as 'non_existent'. Corresponds to the JSON property pending

Returns:

  • (Fixnum)


28702
28703
28704
# File 'lib/google/apis/compute_alpha/classes.rb', line 28702

def pending
  @pending
end

#pending_stopFixnum

Output only. The number of instances in the managed instance group that have PENDING_STOP status. Corresponds to the JSON property pendingStop

Returns:

  • (Fixnum)


28708
28709
28710
# File 'lib/google/apis/compute_alpha/classes.rb', line 28708

def pending_stop
  @pending_stop
end

#provisioningFixnum

Output only. The number of instances in the managed instance group that have PROVISIONING status. Corresponds to the JSON property provisioning

Returns:

  • (Fixnum)


28714
28715
28716
# File 'lib/google/apis/compute_alpha/classes.rb', line 28714

def provisioning
  @provisioning
end

#repairingFixnum

Output only. The number of instances in the managed instance group that have REPAIRING status. Corresponds to the JSON property repairing

Returns:

  • (Fixnum)


28720
28721
28722
# File 'lib/google/apis/compute_alpha/classes.rb', line 28720

def repairing
  @repairing
end

#runningFixnum

Output only. The number of instances in the managed instance group that have RUNNING status. Corresponds to the JSON property running

Returns:

  • (Fixnum)


28726
28727
28728
# File 'lib/google/apis/compute_alpha/classes.rb', line 28726

def running
  @running
end

#stagingFixnum

Output only. The number of instances in the managed instance group that have STAGING status. Corresponds to the JSON property staging

Returns:

  • (Fixnum)


28732
28733
28734
# File 'lib/google/apis/compute_alpha/classes.rb', line 28732

def staging
  @staging
end

#stoppedFixnum

Output only. The number of instances in the managed instance group that have STOPPED status. Corresponds to the JSON property stopped

Returns:

  • (Fixnum)


28738
28739
28740
# File 'lib/google/apis/compute_alpha/classes.rb', line 28738

def stopped
  @stopped
end

#stoppingFixnum

Output only. The number of instances in the managed instance group that have STOPPING status. Corresponds to the JSON property stopping

Returns:

  • (Fixnum)


28744
28745
28746
# File 'lib/google/apis/compute_alpha/classes.rb', line 28744

def stopping
  @stopping
end

#suspendedFixnum

Output only. The number of instances in the managed instance group that have SUSPENDED status. Corresponds to the JSON property suspended

Returns:

  • (Fixnum)


28750
28751
28752
# File 'lib/google/apis/compute_alpha/classes.rb', line 28750

def suspended
  @suspended
end

#suspendingFixnum

Output only. The number of instances in the managed instance group that have SUSPENDING status. Corresponds to the JSON property suspending

Returns:

  • (Fixnum)


28756
28757
28758
# File 'lib/google/apis/compute_alpha/classes.rb', line 28756

def suspending
  @suspending
end

#terminatedFixnum

Output only. The number of instances in the managed instance group that have TERMINATED status. Corresponds to the JSON property terminated

Returns:

  • (Fixnum)


28762
28763
28764
# File 'lib/google/apis/compute_alpha/classes.rb', line 28762

def terminated
  @terminated
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



28769
28770
28771
28772
28773
28774
28775
28776
28777
28778
28779
28780
28781
28782
28783
# File 'lib/google/apis/compute_alpha/classes.rb', line 28769

def update!(**args)
  @deprovisioning = args[:deprovisioning] if args.key?(:deprovisioning)
  @non_existent = args[:non_existent] if args.key?(:non_existent)
  @pending = args[:pending] if args.key?(:pending)
  @pending_stop = args[:pending_stop] if args.key?(:pending_stop)
  @provisioning = args[:provisioning] if args.key?(:provisioning)
  @repairing = args[:repairing] if args.key?(:repairing)
  @running = args[:running] if args.key?(:running)
  @staging = args[:staging] if args.key?(:staging)
  @stopped = args[:stopped] if args.key?(:stopped)
  @stopping = args[:stopping] if args.key?(:stopping)
  @suspended = args[:suspended] if args.key?(:suspended)
  @suspending = args[:suspending] if args.key?(:suspending)
  @terminated = args[:terminated] if args.key?(:terminated)
end