Class: Google::Apis::ComputeAlpha::InstanceGroupManagerStatusInstanceStatusSummary
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::InstanceGroupManagerStatusInstanceStatusSummary
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
The list of instance statuses and the number of instances in this managed instance group that have the status. For more information about how to interpret each status check the instance lifecycle documentation. Currently only shown for TPU MIGs.
Instance Attribute Summary collapse
-
#deprovisioning ⇒ Fixnum
Output only.
-
#non_existent ⇒ Fixnum
Output only.
-
#pending ⇒ Fixnum
Output only.
-
#pending_stop ⇒ Fixnum
Output only.
-
#provisioning ⇒ Fixnum
Output only.
-
#repairing ⇒ Fixnum
Output only.
-
#running ⇒ Fixnum
Output only.
-
#staging ⇒ Fixnum
Output only.
-
#stopped ⇒ Fixnum
Output only.
-
#stopping ⇒ Fixnum
Output only.
-
#suspended ⇒ Fixnum
Output only.
-
#suspending ⇒ Fixnum
Output only.
-
#terminated ⇒ Fixnum
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceGroupManagerStatusInstanceStatusSummary
constructor
A new instance of InstanceGroupManagerStatusInstanceStatusSummary.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceGroupManagerStatusInstanceStatusSummary
Returns a new instance of InstanceGroupManagerStatusInstanceStatusSummary.
28101 28102 28103 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 28101 def initialize(**args) update!(**args) end |
Instance Attribute Details
#deprovisioning ⇒ Fixnum
Output only. [Output Only] The number of instances in the managed instance
group
that have DEPROVISIONING status.
Corresponds to the JSON property deprovisioning
28009 28010 28011 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 28009 def deprovisioning @deprovisioning end |
#non_existent ⇒ Fixnum
Output only. [Output Only] The number of instances that have not been created
yet or
have been deleted. Includes only instances that would be shown in the
listManagedInstances method and not all instances that have been
deleted in the lifetime of the MIG.
Does not include FlexStart instances that are waiting for the resources
availability, they are considered as 'pending'.
Corresponds to the JSON property nonExistent
28020 28021 28022 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 28020 def non_existent @non_existent end |
#pending ⇒ Fixnum
Output only. [Output Only] The number of instances in the managed instance
group
that have PENDING status, that is FlexStart instances that are waiting
for resources. Instances that do not exist because of the other reasons
are counted as 'non_existent'.
Corresponds to the JSON property pending
28029 28030 28031 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 28029 def pending @pending end |
#pending_stop ⇒ Fixnum
Output only. [Output Only] The number of instances in the managed instance
group
that have PENDING_STOP status.
Corresponds to the JSON property pendingStop
28036 28037 28038 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 28036 def pending_stop @pending_stop end |
#provisioning ⇒ Fixnum
Output only. [Output Only] The number of instances in the managed instance
group
that have PROVISIONING status.
Corresponds to the JSON property provisioning
28043 28044 28045 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 28043 def provisioning @provisioning end |
#repairing ⇒ Fixnum
Output only. [Output Only] The number of instances in the managed instance
group
that have REPAIRING status.
Corresponds to the JSON property repairing
28050 28051 28052 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 28050 def repairing @repairing end |
#running ⇒ Fixnum
Output only. [Output Only] The number of instances in the managed instance
group
that have RUNNING status.
Corresponds to the JSON property running
28057 28058 28059 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 28057 def running @running end |
#staging ⇒ Fixnum
Output only. [Output Only] The number of instances in the managed instance
group
that have STAGING status.
Corresponds to the JSON property staging
28064 28065 28066 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 28064 def staging @staging end |
#stopped ⇒ Fixnum
Output only. [Output Only] The number of instances in the managed instance
group
that have STOPPED status.
Corresponds to the JSON property stopped
28071 28072 28073 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 28071 def stopped @stopped end |
#stopping ⇒ Fixnum
Output only. [Output Only] The number of instances in the managed instance
group
that have STOPPING status.
Corresponds to the JSON property stopping
28078 28079 28080 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 28078 def stopping @stopping end |
#suspended ⇒ Fixnum
Output only. [Output Only] The number of instances in the managed instance
group
that have SUSPENDED status.
Corresponds to the JSON property suspended
28085 28086 28087 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 28085 def suspended @suspended end |
#suspending ⇒ Fixnum
Output only. [Output Only] The number of instances in the managed instance
group
that have SUSPENDING status.
Corresponds to the JSON property suspending
28092 28093 28094 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 28092 def suspending @suspending end |
#terminated ⇒ Fixnum
Output only. [Output Only] The number of instances in the managed instance
group
that have TERMINATED status.
Corresponds to the JSON property terminated
28099 28100 28101 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 28099 def terminated @terminated end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
28106 28107 28108 28109 28110 28111 28112 28113 28114 28115 28116 28117 28118 28119 28120 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 28106 def update!(**args) @deprovisioning = args[:deprovisioning] if args.key?(:deprovisioning) @non_existent = args[:non_existent] if args.key?(:non_existent) @pending = args[:pending] if args.key?(:pending) @pending_stop = args[:pending_stop] if args.key?(:pending_stop) @provisioning = args[:provisioning] if args.key?(:provisioning) @repairing = args[:repairing] if args.key?(:repairing) @running = args[:running] if args.key?(:running) @staging = args[:staging] if args.key?(:staging) @stopped = args[:stopped] if args.key?(:stopped) @stopping = args[:stopping] if args.key?(:stopping) @suspended = args[:suspended] if args.key?(:suspended) @suspending = args[:suspending] if args.key?(:suspending) @terminated = args[:terminated] if args.key?(:terminated) end |