Class: Google::Apis::ComputeAlpha::InstanceGroupManagerStatusVersionTarget

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupManagerStatusVersionTarget

Returns a new instance of InstanceGroupManagerStatusVersionTarget.



28994
28995
28996
# File 'lib/google/apis/compute_alpha/classes.rb', line 28994

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#is_reachedBoolean Also known as: is_reached?

Output only. A bit indicating whether version target has been reached in this managed instance group, i.e. all instances are in their target version. Instances' target version are specified byversion field on Instance Group Manager. Corresponds to the JSON property isReached

Returns:

  • (Boolean)


28991
28992
28993
# File 'lib/google/apis/compute_alpha/classes.rb', line 28991

def is_reached
  @is_reached
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



28999
29000
29001
# File 'lib/google/apis/compute_alpha/classes.rb', line 28999

def update!(**args)
  @is_reached = args[:is_reached] if args.key?(:is_reached)
end