Class: Google::Apis::ComputeAlpha::InstanceGroupManagerVersion

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupManagerVersion

Returns a new instance of InstanceGroupManagerVersion.



30119
30120
30121
# File 'lib/google/apis/compute_alpha/classes.rb', line 30119

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#instance_templateString

The URL of the instance template that is specified for this managed instance group. The group uses this template to create new instances in the managed instance group until the targetSize for this version is reached. The templates for existing instances in the group do not change unless you run recreateInstances, runapplyUpdatesToInstances, or set the group' supdatePolicy.type to PROACTIVE; in those cases, existing instances are updated until the targetSize for this version is reached. Corresponds to the JSON property instanceTemplate

Returns:

  • (String)


30099
30100
30101
# File 'lib/google/apis/compute_alpha/classes.rb', line 30099

def instance_template
  @instance_template
end

#nameString

Name of the version. Unique among all versions in the scope of this managed instance group. Corresponds to the JSON property name

Returns:

  • (String)


30105
30106
30107
# File 'lib/google/apis/compute_alpha/classes.rb', line 30105

def name
  @name
end

#tagString

Tag describing the version. Used to trigger rollout of a target version even if instance_template remains unchanged. Deprecated in favor of 'name'. Corresponds to the JSON property tag

Returns:

  • (String)


30112
30113
30114
# File 'lib/google/apis/compute_alpha/classes.rb', line 30112

def tag
  @tag
end

#target_sizeGoogle::Apis::ComputeAlpha::FixedOrPercent

Encapsulates numeric value that can be either absolute or relative. Corresponds to the JSON property targetSize



30117
30118
30119
# File 'lib/google/apis/compute_alpha/classes.rb', line 30117

def target_size
  @target_size
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



30124
30125
30126
30127
30128
30129
# File 'lib/google/apis/compute_alpha/classes.rb', line 30124

def update!(**args)
  @instance_template = args[:instance_template] if args.key?(:instance_template)
  @name = args[:name] if args.key?(:name)
  @tag = args[:tag] if args.key?(:tag)
  @target_size = args[:target_size] if args.key?(:target_size)
end