Class: Google::Apis::ComputeAlpha::InstanceGroupManagerVersion
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::InstanceGroupManagerVersion
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#instance_template ⇒ String
The URL of the instance template that is specified for this managed instance group.
-
#name ⇒ String
Name of the version.
-
#tag ⇒ String
Tag describing the version.
-
#target_size ⇒ Google::Apis::ComputeAlpha::FixedOrPercent
Encapsulates numeric value that can be either absolute or relative.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceGroupManagerVersion
constructor
A new instance of InstanceGroupManagerVersion.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceGroupManagerVersion
Returns a new instance of InstanceGroupManagerVersion.
28368 28369 28370 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 28368 def initialize(**args) update!(**args) end |
Instance Attribute Details
#instance_template ⇒ String
The URL of the instance template that is specified for this managed
instance group. The group uses this template to create new instances in
the managed instance group until the targetSize for this version is
reached. The templates for existing instances in the group do not change
unless you run recreateInstances, runapplyUpdatesToInstances, or set the group'
supdatePolicy.type to PROACTIVE; in those cases,
existing instances are updated until the targetSize for this version is
reached.
Corresponds to the JSON property instanceTemplate
28348 28349 28350 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 28348 def instance_template @instance_template end |
#name ⇒ String
Name of the version. Unique among all versions in the scope of this
managed instance group.
Corresponds to the JSON property name
28354 28355 28356 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 28354 def name @name end |
#tag ⇒ String
Tag describing the version. Used to trigger rollout of a target version
even if instance_template remains unchanged.
Deprecated in favor of 'name'.
Corresponds to the JSON property tag
28361 28362 28363 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 28361 def tag @tag end |
#target_size ⇒ Google::Apis::ComputeAlpha::FixedOrPercent
Encapsulates numeric value that can be either absolute or relative.
Corresponds to the JSON property targetSize
28366 28367 28368 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 28366 def target_size @target_size end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
28373 28374 28375 28376 28377 28378 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 28373 def update!(**args) @instance_template = args[:instance_template] if args.key?(:instance_template) @name = args[:name] if args.key?(:name) @tag = args[:tag] if args.key?(:tag) @target_size = args[:target_size] if args.key?(:target_size) end |