Class: Google::Apis::ComputeAlpha::InstanceGroupManagersApplyUpdatesRequest
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::InstanceGroupManagersApplyUpdatesRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
InstanceGroupManagers.applyUpdatesToInstances
Instance Attribute Summary collapse
-
#all_instances ⇒ Boolean
(also: #all_instances?)
Flag to update all instances instead of specified list of "instances".
-
#allowed_actions ⇒ Array<String>
Actions that are allowed to update instances within MIG.
-
#disruption_mode ⇒ String
Whether the boot disk is allowed to be updated with restart.
-
#instances ⇒ Array<String>
The list of URLs of one or more instances for which you want to apply updates.
-
#maximal_action ⇒ String
The maximal action that should be performed on the instances.
-
#minimal_action ⇒ String
The minimal action that you want to perform on each instance during the update:.
-
#most_disruptive_allowed_action ⇒ String
The most disruptive action that you want to perform on each instance during the update:.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceGroupManagersApplyUpdatesRequest
constructor
A new instance of InstanceGroupManagersApplyUpdatesRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceGroupManagersApplyUpdatesRequest
Returns a new instance of InstanceGroupManagersApplyUpdatesRequest.
30224 30225 30226 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 30224 def initialize(**args) update!(**args) end |
Instance Attribute Details
#all_instances ⇒ Boolean Also known as: all_instances?
Flag to update all instances instead of specified list of "instances".
If the flag is set to true then the instances may not be specified
in the request.
Corresponds to the JSON property allInstances
30161 30162 30163 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 30161 def all_instances @all_instances end |
#allowed_actions ⇒ Array<String>
Actions that are allowed to update instances within MIG.
Corresponds to the JSON property allowedActions
30167 30168 30169 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 30167 def allowed_actions @allowed_actions end |
#disruption_mode ⇒ String
Whether the boot disk is allowed to be updated with restart.
Corresponds to the JSON property disruptionMode
30172 30173 30174 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 30172 def disruption_mode @disruption_mode end |
#instances ⇒ Array<String>
The list of URLs of one or more instances for which you want to apply
updates. Each URL can be a full URL or a partial URL, such aszones/[ZONE]/
instances/[INSTANCE_NAME].
Corresponds to the JSON property instances
30179 30180 30181 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 30179 def instances @instances end |
#maximal_action ⇒ String
The maximal action that should be performed on the instances.
By default REPLACE.
This field is deprecated, please use most_disruptive_allowed_action.
Corresponds to the JSON property maximalAction
30186 30187 30188 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 30186 def maximal_action @maximal_action end |
#minimal_action ⇒ String
The minimal action that you want to perform on each instance during the update:
- REPLACE: At minimum, delete the instance and create it again.
- RESTART: Stop the instance and start it again.
- REFRESH: Do not stop the instance and limit disruption as much as possible.
- NONE: Do not
disrupt the instance at all.
By default, the minimum action is NONE. If your update
requires a more disruptive action than you set with this flag, the
necessary action is performed to execute the update.
Corresponds to the JSON property
minimalAction
30205 30206 30207 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 30205 def minimal_action @minimal_action end |
#most_disruptive_allowed_action ⇒ String
The most disruptive action that you want to perform on each instance during the update:
- REPLACE: Delete the instance and create it again.
- RESTART: Stop the instance and start it again.
- REFRESH: Do not stop the instance and limit disruption as much as possible.
- NONE: Do not disrupt the
instance at all.
By default, the most disruptive allowed action is REPLACE. If
your update requires a more disruptive action than you set with this flag,
the update request will fail.
Corresponds to the JSON property
mostDisruptiveAllowedAction
30222 30223 30224 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 30222 def most_disruptive_allowed_action @most_disruptive_allowed_action end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
30229 30230 30231 30232 30233 30234 30235 30236 30237 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 30229 def update!(**args) @all_instances = args[:all_instances] if args.key?(:all_instances) @allowed_actions = args[:allowed_actions] if args.key?(:allowed_actions) @disruption_mode = args[:disruption_mode] if args.key?(:disruption_mode) @instances = args[:instances] if args.key?(:instances) @maximal_action = args[:maximal_action] if args.key?(:maximal_action) @minimal_action = args[:minimal_action] if args.key?(:minimal_action) @most_disruptive_allowed_action = args[:most_disruptive_allowed_action] if args.key?(:most_disruptive_allowed_action) end |