Class: Google::Apis::ComputeAlpha::InstanceGroupManagersApplyUpdatesRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

InstanceGroupManagers.applyUpdatesToInstances

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupManagersApplyUpdatesRequest

Returns a new instance of InstanceGroupManagersApplyUpdatesRequest.



29257
29258
29259
# File 'lib/google/apis/compute_alpha/classes.rb', line 29257

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#all_instancesBoolean Also known as: all_instances?

Flag to update all instances instead of specified list of “instances”. If the flag is set to true then the instances may not be specified in the request. Corresponds to the JSON property allInstances

Returns:

  • (Boolean)


29199
29200
29201
# File 'lib/google/apis/compute_alpha/classes.rb', line 29199

def all_instances
  @all_instances
end

#disruption_modeString

Whether the boot disk is allowed to be updated with restart. Corresponds to the JSON property disruptionMode

Returns:

  • (String)


29205
29206
29207
# File 'lib/google/apis/compute_alpha/classes.rb', line 29205

def disruption_mode
  @disruption_mode
end

#instancesArray<String>

The list of URLs of one or more instances for which you want to apply updates. Each URL can be a full URL or a partial URL, such aszones/[ZONE]/ instances/[INSTANCE_NAME]. Corresponds to the JSON property instances

Returns:

  • (Array<String>)


29212
29213
29214
# File 'lib/google/apis/compute_alpha/classes.rb', line 29212

def instances
  @instances
end

#maximal_actionString

The maximal action that should be performed on the instances. By default REPLACE. This field is deprecated, please use most_disruptive_allowed_action. Corresponds to the JSON property maximalAction

Returns:

  • (String)


29219
29220
29221
# File 'lib/google/apis/compute_alpha/classes.rb', line 29219

def maximal_action
  @maximal_action
end

#minimal_actionString

The minimal action that you want to perform on each instance during the update:

  • REPLACE: At minimum, delete the instance and create it again.
  • RESTART: Stop the instance and start it again.
  • REFRESH: Do not stop the instance and limit disruption as much as possible.
  • NONE: Do not disrupt the instance at all. By default, the minimum action is NONE. If your update requires a more disruptive action than you set with this flag, the necessary action is performed to execute the update. Corresponds to the JSON property minimalAction

Returns:

  • (String)


29238
29239
29240
# File 'lib/google/apis/compute_alpha/classes.rb', line 29238

def minimal_action
  @minimal_action
end

#most_disruptive_allowed_actionString

The most disruptive action that you want to perform on each instance during the update:

  • REPLACE: Delete the instance and create it again.
  • RESTART: Stop the instance and start it again.
  • REFRESH: Do not stop the instance and limit disruption as much as possible.
  • NONE: Do not disrupt the instance at all. By default, the most disruptive allowed action is REPLACE. If your update requires a more disruptive action than you set with this flag, the update request will fail. Corresponds to the JSON property mostDisruptiveAllowedAction

Returns:

  • (String)


29255
29256
29257
# File 'lib/google/apis/compute_alpha/classes.rb', line 29255

def most_disruptive_allowed_action
  @most_disruptive_allowed_action
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



29262
29263
29264
29265
29266
29267
29268
29269
# File 'lib/google/apis/compute_alpha/classes.rb', line 29262

def update!(**args)
  @all_instances = args[:all_instances] if args.key?(:all_instances)
  @disruption_mode = args[:disruption_mode] if args.key?(:disruption_mode)
  @instances = args[:instances] if args.key?(:instances)
  @maximal_action = args[:maximal_action] if args.key?(:maximal_action)
  @minimal_action = args[:minimal_action] if args.key?(:minimal_action)
  @most_disruptive_allowed_action = args[:most_disruptive_allowed_action] if args.key?(:most_disruptive_allowed_action)
end