Class: Google::Apis::ComputeAlpha::InstanceGroupManagersConfigureAcceleratorTopologiesRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

InstanceGroupManagers.ConfigureAcceleratorTopologies

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupManagersConfigureAcceleratorTopologiesRequest

Returns a new instance of InstanceGroupManagersConfigureAcceleratorTopologiesRequest.



29515
29516
29517
# File 'lib/google/apis/compute_alpha/classes.rb', line 29515

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#accelerator_topology_actionsHash<String,String>

Map of accelerator topologies that should have their state changed to the specified value. The key is the hashed topology locus id. It can be obtained from the GetAvailableAcceleratorTopologies rpc. Corresponds to the JSON property acceleratorTopologyActions

Returns:

  • (Hash<String,String>)


29506
29507
29508
# File 'lib/google/apis/compute_alpha/classes.rb', line 29506

def accelerator_topology_actions
  @accelerator_topology_actions
end

#accelerator_topology_configurationsHash<String,Google::Apis::ComputeAlpha::InstanceGroupManagersConfigureAcceleratorTopologiesRequestAcceleratorTopologyConfiguration>

Map of accelerator topologies that should have their state changed to the specified configuration. The map key is the hashed topology locus id. It can be obtained from the GetAvailableAcceleratorTopologies rpc. Corresponds to the JSON property acceleratorTopologyConfigurations



29513
29514
29515
# File 'lib/google/apis/compute_alpha/classes.rb', line 29513

def accelerator_topology_configurations
  @accelerator_topology_configurations
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



29520
29521
29522
29523
# File 'lib/google/apis/compute_alpha/classes.rb', line 29520

def update!(**args)
  @accelerator_topology_actions = args[:accelerator_topology_actions] if args.key?(:accelerator_topology_actions)
  @accelerator_topology_configurations = args[:accelerator_topology_configurations] if args.key?(:accelerator_topology_configurations)
end