Class: Google::Apis::ComputeAlpha::InstanceGroupManagersConfigureAcceleratorTopologiesRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

InstanceGroupManagers.ConfigureAcceleratorTopologies

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupManagersConfigureAcceleratorTopologiesRequest

Returns a new instance of InstanceGroupManagersConfigureAcceleratorTopologiesRequest.



29290
29291
29292
# File 'lib/google/apis/compute_alpha/classes.rb', line 29290

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#accelerator_topology_actionsHash<String,String>

Map of accelerator topologies that should have their state changed to the specified value. The key is the hashed topology locus id. It can be obtained from the GetAvailableAcceleratorTopologies rpc. Corresponds to the JSON property acceleratorTopologyActions

Returns:

  • (Hash<String,String>)


29281
29282
29283
# File 'lib/google/apis/compute_alpha/classes.rb', line 29281

def accelerator_topology_actions
  @accelerator_topology_actions
end

#accelerator_topology_configurationsHash<String,Google::Apis::ComputeAlpha::InstanceGroupManagersConfigureAcceleratorTopologiesRequestAcceleratorTopologyConfiguration>

Map of accelerator topologies that should have their state changed to the specified configuration. The map key is the hashed topology locus id. It can be obtained from the GetAvailableAcceleratorTopologies rpc. Corresponds to the JSON property acceleratorTopologyConfigurations



29288
29289
29290
# File 'lib/google/apis/compute_alpha/classes.rb', line 29288

def accelerator_topology_configurations
  @accelerator_topology_configurations
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



29295
29296
29297
29298
# File 'lib/google/apis/compute_alpha/classes.rb', line 29295

def update!(**args)
  @accelerator_topology_actions = args[:accelerator_topology_actions] if args.key?(:accelerator_topology_actions)
  @accelerator_topology_configurations = args[:accelerator_topology_configurations] if args.key?(:accelerator_topology_configurations)
end