Class: Google::Apis::ComputeAlpha::InstanceGroupManagersConfigureAcceleratorTopologiesRequest
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::InstanceGroupManagersConfigureAcceleratorTopologiesRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
InstanceGroupManagers.ConfigureAcceleratorTopologies
Instance Attribute Summary collapse
-
#accelerator_topology_actions ⇒ Hash<String,String>
Map of accelerator topologies that should have their state changed to the specified value.
-
#accelerator_topology_configurations ⇒ Hash<String,Google::Apis::ComputeAlpha::InstanceGroupManagersConfigureAcceleratorTopologiesRequestAcceleratorTopologyConfiguration>
Map of accelerator topologies that should have their state changed to the specified configuration.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceGroupManagersConfigureAcceleratorTopologiesRequest
constructor
A new instance of InstanceGroupManagersConfigureAcceleratorTopologiesRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceGroupManagersConfigureAcceleratorTopologiesRequest
Returns a new instance of InstanceGroupManagersConfigureAcceleratorTopologiesRequest.
29162 29163 29164 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 29162 def initialize(**args) update!(**args) end |
Instance Attribute Details
#accelerator_topology_actions ⇒ Hash<String,String>
Map of accelerator topologies that should have their state changed to
the specified value. The key is the hashed topology locus id. It can be
obtained from the GetAvailableAcceleratorTopologies rpc.
Corresponds to the JSON property acceleratorTopologyActions
29153 29154 29155 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 29153 def accelerator_topology_actions @accelerator_topology_actions end |
#accelerator_topology_configurations ⇒ Hash<String,Google::Apis::ComputeAlpha::InstanceGroupManagersConfigureAcceleratorTopologiesRequestAcceleratorTopologyConfiguration>
Map of accelerator topologies that should have their state changed to
the specified configuration. The map key is the hashed topology locus id.
It can be obtained from the GetAvailableAcceleratorTopologies rpc.
Corresponds to the JSON property acceleratorTopologyConfigurations
29160 29161 29162 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 29160 def accelerator_topology_configurations @accelerator_topology_configurations end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
29167 29168 29169 29170 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 29167 def update!(**args) @accelerator_topology_actions = args[:accelerator_topology_actions] if args.key?(:accelerator_topology_actions) @accelerator_topology_configurations = args[:accelerator_topology_configurations] if args.key?(:accelerator_topology_configurations) end |