Class: Google::Apis::ComputeAlpha::InstanceGroupManagersConfigureAcceleratorTopologiesRequestAcceleratorTopologyConfiguration

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Configuration for a single accelerator topology.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupManagersConfigureAcceleratorTopologiesRequestAcceleratorTopologyConfiguration

Returns a new instance of InstanceGroupManagersConfigureAcceleratorTopologiesRequestAcceleratorTopologyConfiguration.



29545
29546
29547
# File 'lib/google/apis/compute_alpha/classes.rb', line 29545

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#actionString

Corresponds to the JSON property action

Returns:

  • (String)


29533
29534
29535
# File 'lib/google/apis/compute_alpha/classes.rb', line 29533

def action
  @action
end

#external_idString

Identifier of the accelerator topology assigned externally to differentiate who is the owner of the topology. The format needs to conform to RFC1035 and be unique. The uniqueness is guaranteed by the requestor. If it is provided on activating the sub-slice it will have to be provided on deactivating as well. This identifier is cleared on successful deform of a sub-slice. Corresponds to the JSON property externalId

Returns:

  • (String)


29543
29544
29545
# File 'lib/google/apis/compute_alpha/classes.rb', line 29543

def external_id
  @external_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



29550
29551
29552
29553
# File 'lib/google/apis/compute_alpha/classes.rb', line 29550

def update!(**args)
  @action = args[:action] if args.key?(:action)
  @external_id = args[:external_id] if args.key?(:external_id)
end