Class: Google::Apis::ComputeAlpha::InstanceGroupManagersDeleteInstancesRequest
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::InstanceGroupManagersDeleteInstancesRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#instance_names ⇒ Array<String>
The list of instance names to delete.
-
#instances ⇒ Array<String>
The URLs of one or more instances to delete.
-
#skip_instances_on_validation_error ⇒ Boolean
(also: #skip_instances_on_validation_error?)
Specifies whether the request should proceed despite the inclusion of instances that are not members of the group or that are already in the process of being deleted or abandoned.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceGroupManagersDeleteInstancesRequest
constructor
A new instance of InstanceGroupManagersDeleteInstancesRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceGroupManagersDeleteInstancesRequest
Returns a new instance of InstanceGroupManagersDeleteInstancesRequest.
30621 30622 30623 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 30621 def initialize(**args) update!(**args) end |
Instance Attribute Details
#instance_names ⇒ Array<String>
The list of instance names to delete. Queued instances do not have URL and
can be deleted only by name. You cannot specify both URLs and names in a
single request.
Corresponds to the JSON property instanceNames
30599 30600 30601 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 30599 def instance_names @instance_names end |
#instances ⇒ Array<String>
The URLs of one or more instances to delete. This can be a full URL or
a partial URL, such as zones/[ZONE]/instances/[INSTANCE_NAME].
Queued instances do not have URL and can be deleted only by name.
One cannot specify both URLs and names in a single request.
Corresponds to the JSON property instances
30607 30608 30609 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 30607 def instances @instances end |
#skip_instances_on_validation_error ⇒ Boolean Also known as: skip_instances_on_validation_error?
Specifies whether the request should proceed despite the inclusion of
instances that are not members of the group or that are already in the
process of being deleted or abandoned. If this field is set to false and
such an instance is specified in the request, the operation fails. The
operation always fails if the request contains a malformed instance URL or
a reference to an instance that exists in a zone or region other than the
group's zone or region.
Corresponds to the JSON property skipInstancesOnValidationError
30618 30619 30620 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 30618 def skip_instances_on_validation_error @skip_instances_on_validation_error end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
30626 30627 30628 30629 30630 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 30626 def update!(**args) @instance_names = args[:instance_names] if args.key?(:instance_names) @instances = args[:instances] if args.key?(:instances) @skip_instances_on_validation_error = args[:skip_instances_on_validation_error] if args.key?(:skip_instances_on_validation_error) end |