Class: Google::Apis::ComputeAlpha::InstanceGroupManagersDeleteInstancesRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupManagersDeleteInstancesRequest

Returns a new instance of InstanceGroupManagersDeleteInstancesRequest.



29606
29607
29608
# File 'lib/google/apis/compute_alpha/classes.rb', line 29606

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#instance_namesArray<String>

The list of instance names to delete. Queued instances do not have URL and can be deleted only by name. You cannot specify both URLs and names in a single request. Corresponds to the JSON property instanceNames

Returns:

  • (Array<String>)


29584
29585
29586
# File 'lib/google/apis/compute_alpha/classes.rb', line 29584

def instance_names
  @instance_names
end

#instancesArray<String>

The URLs of one or more instances to delete. This can be a full URL or a partial URL, such as zones/[ZONE]/instances/[INSTANCE_NAME]. Queued instances do not have URL and can be deleted only by name. One cannot specify both URLs and names in a single request. Corresponds to the JSON property instances

Returns:

  • (Array<String>)


29592
29593
29594
# File 'lib/google/apis/compute_alpha/classes.rb', line 29592

def instances
  @instances
end

#skip_instances_on_validation_errorBoolean Also known as: skip_instances_on_validation_error?

Specifies whether the request should proceed despite the inclusion of instances that are not members of the group or that are already in the process of being deleted or abandoned. If this field is set to false and such an instance is specified in the request, the operation fails. The operation always fails if the request contains a malformed instance URL or a reference to an instance that exists in a zone or region other than the group's zone or region. Corresponds to the JSON property skipInstancesOnValidationError

Returns:

  • (Boolean)


29603
29604
29605
# File 'lib/google/apis/compute_alpha/classes.rb', line 29603

def skip_instances_on_validation_error
  @skip_instances_on_validation_error
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



29611
29612
29613
29614
29615
# File 'lib/google/apis/compute_alpha/classes.rb', line 29611

def update!(**args)
  @instance_names = args[:instance_names] if args.key?(:instance_names)
  @instances = args[:instances] if args.key?(:instances)
  @skip_instances_on_validation_error = args[:skip_instances_on_validation_error] if args.key?(:skip_instances_on_validation_error)
end