Class: Google::Apis::ComputeAlpha::InstanceGroupManagersGetAvailableAcceleratorTopologiesResponse
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::InstanceGroupManagersGetAvailableAcceleratorTopologiesResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#accelerator_topologies_info ⇒ Hash<String,Google::Apis::ComputeAlpha::InstanceGroupManagersGetAvailableAcceleratorTopologiesResponseAcceleratorTopologyInfo>
The accelerator topology information returned per id of the topology location.
-
#multi_mig ⇒ String
URL to MMIG this MIG belongs to.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceGroupManagersGetAvailableAcceleratorTopologiesResponse
constructor
A new instance of InstanceGroupManagersGetAvailableAcceleratorTopologiesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceGroupManagersGetAvailableAcceleratorTopologiesResponse
Returns a new instance of InstanceGroupManagersGetAvailableAcceleratorTopologiesResponse.
28601 28602 28603 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 28601 def initialize(**args) update!(**args) end |
Instance Attribute Details
#accelerator_topologies_info ⇒ Hash<String,Google::Apis::ComputeAlpha::InstanceGroupManagersGetAvailableAcceleratorTopologiesResponseAcceleratorTopologyInfo>
The accelerator topology information returned per id of the topology
location.
Corresponds to the JSON property acceleratorTopologiesInfo
28594 28595 28596 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 28594 def accelerator_topologies_info @accelerator_topologies_info end |
#multi_mig ⇒ String
URL to MMIG this MIG belongs to.
Corresponds to the JSON property multiMig
28599 28600 28601 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 28599 def multi_mig @multi_mig end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
28606 28607 28608 28609 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 28606 def update!(**args) @accelerator_topologies_info = args[:accelerator_topologies_info] if args.key?(:accelerator_topologies_info) @multi_mig = args[:multi_mig] if args.key?(:multi_mig) end |