Class: Google::Apis::ComputeAlpha::InstanceGroupManagersGetAvailableAcceleratorTopologiesResponseAcceleratorTopologyState

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Specifies the topology state

Defined Under Namespace

Classes: Error

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupManagersGetAvailableAcceleratorTopologiesResponseAcceleratorTopologyState

Returns a new instance of InstanceGroupManagersGetAvailableAcceleratorTopologiesResponseAcceleratorTopologyState.



28675
28676
28677
# File 'lib/google/apis/compute_alpha/classes.rb', line 28675

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#current_stateString

Corresponds to the JSON property currentState

Returns:

  • (String)


28663
28664
28665
# File 'lib/google/apis/compute_alpha/classes.rb', line 28663

def current_state
  @current_state
end

#errorGoogle::Apis::ComputeAlpha::InstanceGroupManagersGetAvailableAcceleratorTopologiesResponseAcceleratorTopologyState::Error

Reason why the topology state change failed Corresponds to the JSON property error



28668
28669
28670
# File 'lib/google/apis/compute_alpha/classes.rb', line 28668

def error
  @error
end

#error_timestampString

Timestamp when the last error happened Corresponds to the JSON property errorTimestamp

Returns:

  • (String)


28673
28674
28675
# File 'lib/google/apis/compute_alpha/classes.rb', line 28673

def error_timestamp
  @error_timestamp
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



28680
28681
28682
28683
28684
# File 'lib/google/apis/compute_alpha/classes.rb', line 28680

def update!(**args)
  @current_state = args[:current_state] if args.key?(:current_state)
  @error = args[:error] if args.key?(:error)
  @error_timestamp = args[:error_timestamp] if args.key?(:error_timestamp)
end