Class: Google::Apis::ComputeAlpha::InstanceGroupManagersListManagedInstancesResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupManagersListManagedInstancesResponse

Returns a new instance of InstanceGroupManagersListManagedInstancesResponse.



30938
30939
30940
# File 'lib/google/apis/compute_alpha/classes.rb', line 30938

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#managed_instancesArray<Google::Apis::ComputeAlpha::ManagedInstance>

Output only. [Output Only] The list of instances in the managed instance group. Corresponds to the JSON property managedInstances



30925
30926
30927
# File 'lib/google/apis/compute_alpha/classes.rb', line 30925

def managed_instances
  @managed_instances
end

#next_page_tokenString

Output only. [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


30936
30937
30938
# File 'lib/google/apis/compute_alpha/classes.rb', line 30936

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



30943
30944
30945
30946
# File 'lib/google/apis/compute_alpha/classes.rb', line 30943

def update!(**args)
  @managed_instances = args[:managed_instances] if args.key?(:managed_instances)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end