Class: Google::Apis::ComputeAlpha::InstanceGroupManagersListManagedInstancesResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupManagersListManagedInstancesResponse

Returns a new instance of InstanceGroupManagersListManagedInstancesResponse.



29568
29569
29570
# File 'lib/google/apis/compute_alpha/classes.rb', line 29568

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#managed_instancesArray<Google::Apis::ComputeAlpha::ManagedInstance>

Output only. [Output Only] The list of instances in the managed instance group. Corresponds to the JSON property managedInstances



29555
29556
29557
# File 'lib/google/apis/compute_alpha/classes.rb', line 29555

def managed_instances
  @managed_instances
end

#next_page_tokenString

Output only. [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


29566
29567
29568
# File 'lib/google/apis/compute_alpha/classes.rb', line 29566

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



29573
29574
29575
29576
# File 'lib/google/apis/compute_alpha/classes.rb', line 29573

def update!(**args)
  @managed_instances = args[:managed_instances] if args.key?(:managed_instances)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end