Class: Google::Apis::ComputeAlpha::InstanceGroupManagersListPerInstanceConfigsResp

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupManagersListPerInstanceConfigsResp

Returns a new instance of InstanceGroupManagersListPerInstanceConfigsResp.



30702
30703
30704
# File 'lib/google/apis/compute_alpha/classes.rb', line 30702

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#itemsArray<Google::Apis::ComputeAlpha::PerInstanceConfig>

Output only. [Output Only] The list of PerInstanceConfig. Corresponds to the JSON property items



30684
30685
30686
# File 'lib/google/apis/compute_alpha/classes.rb', line 30684

def items
  @items
end

#next_page_tokenString

Output only. [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


30695
30696
30697
# File 'lib/google/apis/compute_alpha/classes.rb', line 30695

def next_page_token
  @next_page_token
end

#warningGoogle::Apis::ComputeAlpha::InstanceGroupManagersListPerInstanceConfigsResp::Warning

Output only. [Output Only] Informational warning message. Corresponds to the JSON property warning



30700
30701
30702
# File 'lib/google/apis/compute_alpha/classes.rb', line 30700

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



30707
30708
30709
30710
30711
# File 'lib/google/apis/compute_alpha/classes.rb', line 30707

def update!(**args)
  @items = args[:items] if args.key?(:items)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @warning = args[:warning] if args.key?(:warning)
end