Class: Google::Apis::ComputeAlpha::InstanceGroupManagersScopedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::InstanceGroupManagersScopedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#instance_group_managers ⇒ Array<Google::Apis::ComputeAlpha::InstanceGroupManager>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::InstanceGroupManagersScopedList::Warning
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceGroupManagersScopedList
constructor
A new instance of InstanceGroupManagersScopedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceGroupManagersScopedList
Returns a new instance of InstanceGroupManagersScopedList.
30160 30161 30162 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 30160 def initialize(**args) update!(**args) end |
Instance Attribute Details
#instance_group_managers ⇒ Array<Google::Apis::ComputeAlpha::InstanceGroupManager>
Output only. The list of managed instance groups that are contained in the
specified
project and zone.
Corresponds to the JSON property instanceGroupManagers
30151 30152 30153 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 30151 def instance_group_managers @instance_group_managers end |
#warning ⇒ Google::Apis::ComputeAlpha::InstanceGroupManagersScopedList::Warning
Output only. The warning that replaces the list of managed instance groups
when the list
is empty.
Corresponds to the JSON property warning
30158 30159 30160 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 30158 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
30165 30166 30167 30168 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 30165 def update!(**args) @instance_group_managers = args[:instance_group_managers] if args.key?(:instance_group_managers) @warning = args[:warning] if args.key?(:warning) end |