Class: Google::Apis::ComputeAlpha::InstanceGroupManagersScopedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::InstanceGroupManagersScopedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#instance_group_managers ⇒ Array<Google::Apis::ComputeAlpha::InstanceGroupManager>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::InstanceGroupManagersScopedList::Warning
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceGroupManagersScopedList
constructor
A new instance of InstanceGroupManagersScopedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceGroupManagersScopedList
Returns a new instance of InstanceGroupManagersScopedList.
29943 29944 29945 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 29943 def initialize(**args) update!(**args) end |
Instance Attribute Details
#instance_group_managers ⇒ Array<Google::Apis::ComputeAlpha::InstanceGroupManager>
Output only. The list of managed instance groups that are contained in the
specified
project and zone.
Corresponds to the JSON property instanceGroupManagers
29934 29935 29936 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 29934 def instance_group_managers @instance_group_managers end |
#warning ⇒ Google::Apis::ComputeAlpha::InstanceGroupManagersScopedList::Warning
Output only. The warning that replaces the list of managed instance groups
when the list
is empty.
Corresponds to the JSON property warning
29941 29942 29943 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 29941 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
29948 29949 29950 29951 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 29948 def update!(**args) @instance_group_managers = args[:instance_group_managers] if args.key?(:instance_group_managers) @warning = args[:warning] if args.key?(:warning) end |