Class: Google::Apis::ComputeAlpha::InstanceGroupManagersScopedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupManagersScopedList

Returns a new instance of InstanceGroupManagersScopedList.



29953
29954
29955
# File 'lib/google/apis/compute_alpha/classes.rb', line 29953

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#instance_group_managersArray<Google::Apis::ComputeAlpha::InstanceGroupManager>

Output only. The list of managed instance groups that are contained in the specified project and zone. Corresponds to the JSON property instanceGroupManagers



29944
29945
29946
# File 'lib/google/apis/compute_alpha/classes.rb', line 29944

def instance_group_managers
  @instance_group_managers
end

#warningGoogle::Apis::ComputeAlpha::InstanceGroupManagersScopedList::Warning

Output only. The warning that replaces the list of managed instance groups when the list is empty. Corresponds to the JSON property warning



29951
29952
29953
# File 'lib/google/apis/compute_alpha/classes.rb', line 29951

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



29958
29959
29960
29961
# File 'lib/google/apis/compute_alpha/classes.rb', line 29958

def update!(**args)
  @instance_group_managers = args[:instance_group_managers] if args.key?(:instance_group_managers)
  @warning = args[:warning] if args.key?(:warning)
end