Class: Google::Apis::ComputeAlpha::InstanceGroupManagersSetInstanceTemplateRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupManagersSetInstanceTemplateRequest

Returns a new instance of InstanceGroupManagersSetInstanceTemplateRequest.



29213
29214
29215
# File 'lib/google/apis/compute_alpha/classes.rb', line 29213

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#instance_templateString

The URL of the instance template that is specified for this managed instance group. The group uses this template to create all new instances in the managed instance group. The templates for existing instances in the group do not change unless you run recreateInstances, runapplyUpdatesToInstances, or set the group'supdatePolicy.type to PROACTIVE. Corresponds to the JSON property instanceTemplate

Returns:

  • (String)


29211
29212
29213
# File 'lib/google/apis/compute_alpha/classes.rb', line 29211

def instance_template
  @instance_template
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



29218
29219
29220
# File 'lib/google/apis/compute_alpha/classes.rb', line 29218

def update!(**args)
  @instance_template = args[:instance_template] if args.key?(:instance_template)
end