Class: Google::Apis::ComputeAlpha::InstanceGroupsListInstances

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupsListInstances

Returns a new instance of InstanceGroupsListInstances.



31231
31232
31233
# File 'lib/google/apis/compute_alpha/classes.rb', line 31231

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Output only. [Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


31196
31197
31198
# File 'lib/google/apis/compute_alpha/classes.rb', line 31196

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::InstanceWithNamedPorts>

A list of InstanceWithNamedPorts resources. Corresponds to the JSON property items



31201
31202
31203
# File 'lib/google/apis/compute_alpha/classes.rb', line 31201

def items
  @items
end

#kindString

Output only. [Output Only] The resource type, which is alwayscompute# instanceGroupsListInstances for the list of instances in the specified instance group. Corresponds to the JSON property kind

Returns:

  • (String)


31208
31209
31210
# File 'lib/google/apis/compute_alpha/classes.rb', line 31208

def kind
  @kind
end

#next_page_tokenString

Output only. [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


31219
31220
31221
# File 'lib/google/apis/compute_alpha/classes.rb', line 31219

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


31224
31225
31226
# File 'lib/google/apis/compute_alpha/classes.rb', line 31224

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::InstanceGroupsListInstances::Warning

Output only. [Output Only] Informational warning message. Corresponds to the JSON property warning



31229
31230
31231
# File 'lib/google/apis/compute_alpha/classes.rb', line 31229

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



31236
31237
31238
31239
31240
31241
31242
31243
# File 'lib/google/apis/compute_alpha/classes.rb', line 31236

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end