Class: Google::Apis::ComputeAlpha::InstanceGroupsListInstancesRequest
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::InstanceGroupsListInstancesRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#instance_state ⇒ String
A filter for the state of the instances in the instance group.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceGroupsListInstancesRequest
constructor
A new instance of InstanceGroupsListInstancesRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceGroupsListInstancesRequest
Returns a new instance of InstanceGroupsListInstancesRequest.
29512 29513 29514 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 29512 def initialize(**args) update!(**args) end |
Instance Attribute Details
#instance_state ⇒ String
A filter for the state of the instances in the instance group. Valid
options are ALL or RUNNING. If you do not specify
this parameter the list includes all instances regardless of their state.
Corresponds to the JSON property instanceState
29510 29511 29512 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 29510 def instance_state @instance_state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
29517 29518 29519 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 29517 def update!(**args) @instance_state = args[:instance_state] if args.key?(:instance_state) end |