Class: Google::Apis::ComputeAlpha::InstanceGroupsSetNamedPortsRequest
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::InstanceGroupsSetNamedPortsRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#fingerprint ⇒ String
The fingerprint of the named ports information for this instance group.
-
#named_ports ⇒ Array<Google::Apis::ComputeAlpha::NamedPort>
The list of named ports to set for this instance group.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceGroupsSetNamedPortsRequest
constructor
A new instance of InstanceGroupsSetNamedPortsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceGroupsSetNamedPortsRequest
Returns a new instance of InstanceGroupsSetNamedPortsRequest.
31748 31749 31750 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 31748 def initialize(**args) update!(**args) end |
Instance Attribute Details
#fingerprint ⇒ String
The fingerprint of the named ports information for this instance group.
Use this optional property to prevent conflicts when multiple users change
the named ports settings concurrently. Obtain the fingerprint with
theinstanceGroups.get
method. Then, include the fingerprint in your request to ensure that you
do not overwrite changes that were applied from another concurrent request.
A request with an incorrect fingerprint will fail with error412
conditionNotMet.
Corresponds to the JSON property fingerprint
NOTE: Values are automatically base64 encoded/decoded in the client library.
31741 31742 31743 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 31741 def fingerprint @fingerprint end |
#named_ports ⇒ Array<Google::Apis::ComputeAlpha::NamedPort>
The list of named ports to set for this instance group.
Corresponds to the JSON property namedPorts
31746 31747 31748 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 31746 def named_ports @named_ports end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
31753 31754 31755 31756 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 31753 def update!(**args) @fingerprint = args[:fingerprint] if args.key?(:fingerprint) @named_ports = args[:named_ports] if args.key?(:named_ports) end |