Class: Google::Apis::ComputeAlpha::InstanceGroupsSetNamedPortsRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupsSetNamedPortsRequest

Returns a new instance of InstanceGroupsSetNamedPortsRequest.



29661
29662
29663
# File 'lib/google/apis/compute_alpha/classes.rb', line 29661

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#fingerprintString

The fingerprint of the named ports information for this instance group. Use this optional property to prevent conflicts when multiple users change the named ports settings concurrently. Obtain the fingerprint with theinstanceGroups.get method. Then, include the fingerprint in your request to ensure that you do not overwrite changes that were applied from another concurrent request. A request with an incorrect fingerprint will fail with error412 conditionNotMet. Corresponds to the JSON property fingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


29654
29655
29656
# File 'lib/google/apis/compute_alpha/classes.rb', line 29654

def fingerprint
  @fingerprint
end

#named_portsArray<Google::Apis::ComputeAlpha::NamedPort>

The list of named ports to set for this instance group. Corresponds to the JSON property namedPorts



29659
29660
29661
# File 'lib/google/apis/compute_alpha/classes.rb', line 29659

def named_ports
  @named_ports
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



29666
29667
29668
29669
# File 'lib/google/apis/compute_alpha/classes.rb', line 29666

def update!(**args)
  @fingerprint = args[:fingerprint] if args.key?(:fingerprint)
  @named_ports = args[:named_ports] if args.key?(:named_ports)
end