Class: Google::Apis::ComputeAlpha::InstanceList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of instances.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceList

Returns a new instance of InstanceList.



31799
31800
31801
# File 'lib/google/apis/compute_alpha/classes.rb', line 31799

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


31766
31767
31768
# File 'lib/google/apis/compute_alpha/classes.rb', line 31766

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::Instance>

A list of Instance resources. Corresponds to the JSON property items



31771
31772
31773
# File 'lib/google/apis/compute_alpha/classes.rb', line 31771

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#instanceList for lists of Instance resources. Corresponds to the JSON property kind

Returns:

  • (String)


31777
31778
31779
# File 'lib/google/apis/compute_alpha/classes.rb', line 31777

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


31787
31788
31789
# File 'lib/google/apis/compute_alpha/classes.rb', line 31787

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


31792
31793
31794
# File 'lib/google/apis/compute_alpha/classes.rb', line 31792

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::InstanceList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



31797
31798
31799
# File 'lib/google/apis/compute_alpha/classes.rb', line 31797

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



31804
31805
31806
31807
31808
31809
31810
31811
# File 'lib/google/apis/compute_alpha/classes.rb', line 31804

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end