Class: Google::Apis::ComputeAlpha::InstanceList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::InstanceList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Contains a list of instances.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::Instance>
A list of Instance resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::InstanceList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceList
constructor
A new instance of InstanceList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceList
Returns a new instance of InstanceList.
30774 30775 30776 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 30774 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
30741 30742 30743 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 30741 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::Instance>
A list of Instance resources.
Corresponds to the JSON property items
30746 30747 30748 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 30746 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#instanceList
for lists of Instance resources.
Corresponds to the JSON property kind
30752 30753 30754 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 30752 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
30762 30763 30764 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 30762 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
30767 30768 30769 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 30767 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::InstanceList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
30772 30773 30774 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 30772 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
30779 30780 30781 30782 30783 30784 30785 30786 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 30779 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |