Class: Google::Apis::ComputeAlpha::InstanceList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of instances.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceList

Returns a new instance of InstanceList.



30557
30558
30559
# File 'lib/google/apis/compute_alpha/classes.rb', line 30557

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


30524
30525
30526
# File 'lib/google/apis/compute_alpha/classes.rb', line 30524

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::Instance>

A list of Instance resources. Corresponds to the JSON property items



30529
30530
30531
# File 'lib/google/apis/compute_alpha/classes.rb', line 30529

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#instanceList for lists of Instance resources. Corresponds to the JSON property kind

Returns:

  • (String)


30535
30536
30537
# File 'lib/google/apis/compute_alpha/classes.rb', line 30535

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


30545
30546
30547
# File 'lib/google/apis/compute_alpha/classes.rb', line 30545

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


30550
30551
30552
# File 'lib/google/apis/compute_alpha/classes.rb', line 30550

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::InstanceList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



30555
30556
30557
# File 'lib/google/apis/compute_alpha/classes.rb', line 30555

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



30562
30563
30564
30565
30566
30567
30568
30569
# File 'lib/google/apis/compute_alpha/classes.rb', line 30562

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end