Class: Google::Apis::ComputeAlpha::InstanceList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::InstanceList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Contains a list of instances.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::Instance>
A list of Instance resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::InstanceList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceList
constructor
A new instance of InstanceList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceList
Returns a new instance of InstanceList.
30429 30430 30431 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 30429 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
30396 30397 30398 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 30396 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::Instance>
A list of Instance resources.
Corresponds to the JSON property items
30401 30402 30403 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 30401 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#instanceList
for lists of Instance resources.
Corresponds to the JSON property kind
30407 30408 30409 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 30407 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
30417 30418 30419 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 30417 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
30422 30423 30424 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 30422 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::InstanceList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
30427 30428 30429 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 30427 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
30434 30435 30436 30437 30438 30439 30440 30441 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 30434 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |