Class: Google::Apis::ComputeAlpha::InstanceList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::InstanceList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Contains a list of instances.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::Instance>
A list of Instance resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::InstanceList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceList
constructor
A new instance of InstanceList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceList
Returns a new instance of InstanceList.
29712 29713 29714 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 29712 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
29679 29680 29681 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 29679 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::Instance>
A list of Instance resources.
Corresponds to the JSON property items
29684 29685 29686 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 29684 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#instanceList
for lists of Instance resources.
Corresponds to the JSON property kind
29690 29691 29692 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 29690 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
29700 29701 29702 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 29700 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
29705 29706 29707 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 29705 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::InstanceList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
29710 29711 29712 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 29710 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
29717 29718 29719 29720 29721 29722 29723 29724 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 29717 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |