Class: Google::Apis::ComputeAlpha::InstanceListReferrers
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::InstanceListReferrers
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Contains a list of instance referrers.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::Reference>
A list of Reference resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::InstanceListReferrers::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceListReferrers
constructor
A new instance of InstanceListReferrers.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceListReferrers
Returns a new instance of InstanceListReferrers.
31924 31925 31926 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 31924 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
31891 31892 31893 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 31891 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::Reference>
A list of Reference resources.
Corresponds to the JSON property items
31896 31897 31898 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 31896 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
instanceListReferrers for lists of Instance referrers.
Corresponds to the JSON property kind
31902 31903 31904 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 31902 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
31912 31913 31914 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 31912 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
31917 31918 31919 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 31917 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::InstanceListReferrers::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
31922 31923 31924 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 31922 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
31929 31930 31931 31932 31933 31934 31935 31936 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 31929 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |