Class: Google::Apis::ComputeAlpha::InstanceListReferrers

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of instance referrers.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceListReferrers

Returns a new instance of InstanceListReferrers.



31652
31653
31654
# File 'lib/google/apis/compute_alpha/classes.rb', line 31652

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


31619
31620
31621
# File 'lib/google/apis/compute_alpha/classes.rb', line 31619

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::Reference>

A list of Reference resources. Corresponds to the JSON property items



31624
31625
31626
# File 'lib/google/apis/compute_alpha/classes.rb', line 31624

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# instanceListReferrers for lists of Instance referrers. Corresponds to the JSON property kind

Returns:

  • (String)


31630
31631
31632
# File 'lib/google/apis/compute_alpha/classes.rb', line 31630

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


31640
31641
31642
# File 'lib/google/apis/compute_alpha/classes.rb', line 31640

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


31645
31646
31647
# File 'lib/google/apis/compute_alpha/classes.rb', line 31645

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::InstanceListReferrers::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



31650
31651
31652
# File 'lib/google/apis/compute_alpha/classes.rb', line 31650

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



31657
31658
31659
31660
31661
31662
31663
31664
# File 'lib/google/apis/compute_alpha/classes.rb', line 31657

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end