Class: Google::Apis::ComputeAlpha::InstanceListReferrers
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::InstanceListReferrers
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Contains a list of instance referrers.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::Reference>
A list of Reference resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::InstanceListReferrers::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceListReferrers
constructor
A new instance of InstanceListReferrers.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceListReferrers
Returns a new instance of InstanceListReferrers.
30899 30900 30901 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 30899 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
30866 30867 30868 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 30866 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::Reference>
A list of Reference resources.
Corresponds to the JSON property items
30871 30872 30873 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 30871 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
instanceListReferrers for lists of Instance referrers.
Corresponds to the JSON property kind
30877 30878 30879 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 30877 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
30887 30888 30889 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 30887 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
30892 30893 30894 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 30892 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::InstanceListReferrers::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
30897 30898 30899 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 30897 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
30904 30905 30906 30907 30908 30909 30910 30911 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 30904 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |