Class: Google::Apis::ComputeAlpha::InstanceListReferrers

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of instance referrers.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceListReferrers

Returns a new instance of InstanceListReferrers.



30554
30555
30556
# File 'lib/google/apis/compute_alpha/classes.rb', line 30554

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


30521
30522
30523
# File 'lib/google/apis/compute_alpha/classes.rb', line 30521

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::Reference>

A list of Reference resources. Corresponds to the JSON property items



30526
30527
30528
# File 'lib/google/apis/compute_alpha/classes.rb', line 30526

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# instanceListReferrers for lists of Instance referrers. Corresponds to the JSON property kind

Returns:

  • (String)


30532
30533
30534
# File 'lib/google/apis/compute_alpha/classes.rb', line 30532

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


30542
30543
30544
# File 'lib/google/apis/compute_alpha/classes.rb', line 30542

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


30547
30548
30549
# File 'lib/google/apis/compute_alpha/classes.rb', line 30547

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::InstanceListReferrers::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



30552
30553
30554
# File 'lib/google/apis/compute_alpha/classes.rb', line 30552

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



30559
30560
30561
30562
30563
30564
30565
30566
# File 'lib/google/apis/compute_alpha/classes.rb', line 30559

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end