Class: Google::Apis::ComputeAlpha::InstanceManagedByIgmError
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::InstanceManagedByIgmError
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#error ⇒ Google::Apis::ComputeAlpha::InstanceManagedByIgmErrorManagedInstanceError
Output only.
-
#instance_action_details ⇒ Google::Apis::ComputeAlpha::InstanceManagedByIgmErrorInstanceActionDetails
Output only.
-
#timestamp ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceManagedByIgmError
constructor
A new instance of InstanceManagedByIgmError.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceManagedByIgmError
Returns a new instance of InstanceManagedByIgmError.
32166 32167 32168 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 32166 def initialize(**args) update!(**args) end |
Instance Attribute Details
#error ⇒ Google::Apis::ComputeAlpha::InstanceManagedByIgmErrorManagedInstanceError
Output only. Contents of the error.
Corresponds to the JSON property error
32151 32152 32153 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 32151 def error @error end |
#instance_action_details ⇒ Google::Apis::ComputeAlpha::InstanceManagedByIgmErrorInstanceActionDetails
Output only. Details of the instance action that triggered this error.
May be null, if the error was not caused by an action on an instance.
This field is optional.
Corresponds to the JSON property instanceActionDetails
32158 32159 32160 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 32158 def instance_action_details @instance_action_details end |
#timestamp ⇒ String
Output only. The time that this error occurred. This value is in RFC3339 text
format.
Corresponds to the JSON property timestamp
32164 32165 32166 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 32164 def @timestamp end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
32171 32172 32173 32174 32175 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 32171 def update!(**args) @error = args[:error] if args.key?(:error) @instance_action_details = args[:instance_action_details] if args.key?(:instance_action_details) @timestamp = args[:timestamp] if args.key?(:timestamp) end |