Class: Google::Apis::ComputeAlpha::InstanceManagedByIgmError
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::InstanceManagedByIgmError
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#error ⇒ Google::Apis::ComputeAlpha::InstanceManagedByIgmErrorManagedInstanceError
Output only.
-
#instance_action_details ⇒ Google::Apis::ComputeAlpha::InstanceManagedByIgmErrorInstanceActionDetails
Output only.
-
#timestamp ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceManagedByIgmError
constructor
A new instance of InstanceManagedByIgmError.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceManagedByIgmError
Returns a new instance of InstanceManagedByIgmError.
31014 31015 31016 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 31014 def initialize(**args) update!(**args) end |
Instance Attribute Details
#error ⇒ Google::Apis::ComputeAlpha::InstanceManagedByIgmErrorManagedInstanceError
Output only. Contents of the error.
Corresponds to the JSON property error
30999 31000 31001 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 30999 def error @error end |
#instance_action_details ⇒ Google::Apis::ComputeAlpha::InstanceManagedByIgmErrorInstanceActionDetails
Output only. Details of the instance action that triggered this error.
May be null, if the error was not caused by an action on an instance.
This field is optional.
Corresponds to the JSON property instanceActionDetails
31006 31007 31008 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 31006 def instance_action_details @instance_action_details end |
#timestamp ⇒ String
Output only. The time that this error occurred. This value is in RFC3339 text
format.
Corresponds to the JSON property timestamp
31012 31013 31014 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 31012 def @timestamp end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
31019 31020 31021 31022 31023 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 31019 def update!(**args) @error = args[:error] if args.key?(:error) @instance_action_details = args[:instance_action_details] if args.key?(:instance_action_details) @timestamp = args[:timestamp] if args.key?(:timestamp) end |