Class: Google::Apis::ComputeAlpha::InstanceManagedByIgmError

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceManagedByIgmError

Returns a new instance of InstanceManagedByIgmError.



30790
30791
30792
# File 'lib/google/apis/compute_alpha/classes.rb', line 30790

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#errorGoogle::Apis::ComputeAlpha::InstanceManagedByIgmErrorManagedInstanceError

Output only. [Output Only] Contents of the error. Corresponds to the JSON property error



30774
30775
30776
# File 'lib/google/apis/compute_alpha/classes.rb', line 30774

def error
  @error
end

#instance_action_detailsGoogle::Apis::ComputeAlpha::InstanceManagedByIgmErrorInstanceActionDetails

Output only. [Output Only] Details of the instance action that triggered this error. May be null, if the error was not caused by an action on an instance. This field is optional. Corresponds to the JSON property instanceActionDetails



30782
30783
30784
# File 'lib/google/apis/compute_alpha/classes.rb', line 30782

def instance_action_details
  @instance_action_details
end

#timestampString

Output only. [Output Only] The time that this error occurred. This value is in RFC3339 text format. Corresponds to the JSON property timestamp

Returns:

  • (String)


30788
30789
30790
# File 'lib/google/apis/compute_alpha/classes.rb', line 30788

def timestamp
  @timestamp
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



30795
30796
30797
30798
30799
# File 'lib/google/apis/compute_alpha/classes.rb', line 30795

def update!(**args)
  @error = args[:error] if args.key?(:error)
  @instance_action_details = args[:instance_action_details] if args.key?(:instance_action_details)
  @timestamp = args[:timestamp] if args.key?(:timestamp)
end