Class: Google::Apis::ComputeAlpha::InstanceManagedByIgmErrorInstanceActionDetails
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::InstanceManagedByIgmErrorInstanceActionDetails
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#action ⇒ String
Output only.
-
#instance ⇒ String
Output only.
-
#version ⇒ Google::Apis::ComputeAlpha::ManagedInstanceVersion
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceManagedByIgmErrorInstanceActionDetails
constructor
A new instance of InstanceManagedByIgmErrorInstanceActionDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceManagedByIgmErrorInstanceActionDetails
Returns a new instance of InstanceManagedByIgmErrorInstanceActionDetails.
31797 31798 31799 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 31797 def initialize(**args) update!(**args) end |
Instance Attribute Details
#action ⇒ String
Output only. Action that managed instance group was executing on the instance
when the
error occurred. Possible values:
Corresponds to the JSON property action
31780 31781 31782 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 31780 def action @action end |
#instance ⇒ String
Output only. The URL of the instance. The URL can be set even if the instance
has not
yet been created.
Corresponds to the JSON property instance
31787 31788 31789 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 31787 def instance @instance end |
#version ⇒ Google::Apis::ComputeAlpha::ManagedInstanceVersion
Output only. Version this instance was created from, or was being
created from, but the creation failed. Corresponds to one of the versions
that were set on the Instance Group Manager resource at the time this
instance was being created.
Corresponds to the JSON property version
31795 31796 31797 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 31795 def version @version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
31802 31803 31804 31805 31806 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 31802 def update!(**args) @action = args[:action] if args.key?(:action) @instance = args[:instance] if args.key?(:instance) @version = args[:version] if args.key?(:version) end |