Class: Google::Apis::ComputeAlpha::InstanceManagedByIgmErrorInstanceActionDetails
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::InstanceManagedByIgmErrorInstanceActionDetails
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#action ⇒ String
Output only.
-
#instance ⇒ String
Output only.
-
#version ⇒ Google::Apis::ComputeAlpha::ManagedInstanceVersion
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceManagedByIgmErrorInstanceActionDetails
constructor
A new instance of InstanceManagedByIgmErrorInstanceActionDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceManagedByIgmErrorInstanceActionDetails
Returns a new instance of InstanceManagedByIgmErrorInstanceActionDetails.
31052 31053 31054 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 31052 def initialize(**args) update!(**args) end |
Instance Attribute Details
#action ⇒ String
Output only. Action that managed instance group was executing on the instance
when the
error occurred. Possible values:
Corresponds to the JSON property action
31035 31036 31037 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 31035 def action @action end |
#instance ⇒ String
Output only. The URL of the instance. The URL can be set even if the instance
has not
yet been created.
Corresponds to the JSON property instance
31042 31043 31044 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 31042 def instance @instance end |
#version ⇒ Google::Apis::ComputeAlpha::ManagedInstanceVersion
Output only. Version this instance was created from, or was being
created from, but the creation failed. Corresponds to one of the versions
that were set on the Instance Group Manager resource at the time this
instance was being created.
Corresponds to the JSON property version
31050 31051 31052 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 31050 def version @version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
31057 31058 31059 31060 31061 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 31057 def update!(**args) @action = args[:action] if args.key?(:action) @instance = args[:instance] if args.key?(:instance) @version = args[:version] if args.key?(:version) end |