Class: Google::Apis::ComputeAlpha::InstanceManagedByIgmErrorInstanceActionDetails

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceManagedByIgmErrorInstanceActionDetails

Returns a new instance of InstanceManagedByIgmErrorInstanceActionDetails.



31044
31045
31046
# File 'lib/google/apis/compute_alpha/classes.rb', line 31044

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#actionString

Output only. Action that managed instance group was executing on the instance when the error occurred. Possible values: Corresponds to the JSON property action

Returns:

  • (String)


31027
31028
31029
# File 'lib/google/apis/compute_alpha/classes.rb', line 31027

def action
  @action
end

#instanceString

Output only. The URL of the instance. The URL can be set even if the instance has not yet been created. Corresponds to the JSON property instance

Returns:

  • (String)


31034
31035
31036
# File 'lib/google/apis/compute_alpha/classes.rb', line 31034

def instance
  @instance
end

#versionGoogle::Apis::ComputeAlpha::ManagedInstanceVersion

Output only. Version this instance was created from, or was being created from, but the creation failed. Corresponds to one of the versions that were set on the Instance Group Manager resource at the time this instance was being created. Corresponds to the JSON property version



31042
31043
31044
# File 'lib/google/apis/compute_alpha/classes.rb', line 31042

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



31049
31050
31051
31052
31053
# File 'lib/google/apis/compute_alpha/classes.rb', line 31049

def update!(**args)
  @action = args[:action] if args.key?(:action)
  @instance = args[:instance] if args.key?(:instance)
  @version = args[:version] if args.key?(:version)
end