Class: Google::Apis::ComputeAlpha::InstanceManagedByIgmErrorInstanceActionDetails
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::InstanceManagedByIgmErrorInstanceActionDetails
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#action ⇒ String
Output only.
-
#instance ⇒ String
Output only.
-
#version ⇒ Google::Apis::ComputeAlpha::ManagedInstanceVersion
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceManagedByIgmErrorInstanceActionDetails
constructor
A new instance of InstanceManagedByIgmErrorInstanceActionDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceManagedByIgmErrorInstanceActionDetails
Returns a new instance of InstanceManagedByIgmErrorInstanceActionDetails.
30699 30700 30701 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 30699 def initialize(**args) update!(**args) end |
Instance Attribute Details
#action ⇒ String
Output only. [Output Only] Action that managed instance group was executing on
the instance when the error occurred. Possible values:
Corresponds to the JSON property action
30682 30683 30684 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 30682 def action @action end |
#instance ⇒ String
Output only. [Output Only] The URL of the instance.
The URL can be set even if the instance has not yet been created.
Corresponds to the JSON property instance
30688 30689 30690 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 30688 def instance @instance end |
#version ⇒ Google::Apis::ComputeAlpha::ManagedInstanceVersion
Output only. [Output Only] Version this instance was created from, or was
being
created from, but the creation failed. Corresponds to one of the versions
that were set on the Instance Group Manager resource at the time this
instance was being created.
Corresponds to the JSON property version
30697 30698 30699 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 30697 def version @version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
30704 30705 30706 30707 30708 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 30704 def update!(**args) @action = args[:action] if args.key?(:action) @instance = args[:instance] if args.key?(:instance) @version = args[:version] if args.key?(:version) end |