Class: Google::Apis::ComputeAlpha::InstanceManagedByIgmErrorInstanceActionDetails

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceManagedByIgmErrorInstanceActionDetails

Returns a new instance of InstanceManagedByIgmErrorInstanceActionDetails.



29982
29983
29984
# File 'lib/google/apis/compute_alpha/classes.rb', line 29982

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#actionString

Output only. [Output Only] Action that managed instance group was executing on the instance when the error occurred. Possible values: Corresponds to the JSON property action

Returns:

  • (String)


29965
29966
29967
# File 'lib/google/apis/compute_alpha/classes.rb', line 29965

def action
  @action
end

#instanceString

Output only. [Output Only] The URL of the instance. The URL can be set even if the instance has not yet been created. Corresponds to the JSON property instance

Returns:

  • (String)


29971
29972
29973
# File 'lib/google/apis/compute_alpha/classes.rb', line 29971

def instance
  @instance
end

#versionGoogle::Apis::ComputeAlpha::ManagedInstanceVersion

Output only. [Output Only] Version this instance was created from, or was being created from, but the creation failed. Corresponds to one of the versions that were set on the Instance Group Manager resource at the time this instance was being created. Corresponds to the JSON property version



29980
29981
29982
# File 'lib/google/apis/compute_alpha/classes.rb', line 29980

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



29987
29988
29989
29990
29991
# File 'lib/google/apis/compute_alpha/classes.rb', line 29987

def update!(**args)
  @action = args[:action] if args.key?(:action)
  @instance = args[:instance] if args.key?(:instance)
  @version = args[:version] if args.key?(:version)
end