Class: Google::Apis::ComputeAlpha::InstanceParams

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Additional instance params.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceParams

Returns a new instance of InstanceParams.



30924
30925
30926
# File 'lib/google/apis/compute_alpha/classes.rb', line 30924

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#request_valid_for_durationGoogle::Apis::ComputeAlpha::Duration

A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution. It is independent of any calendar and concepts like "day" or "month". Range is approximately 10,000 years. Corresponds to the JSON property requestValidForDuration



30910
30911
30912
# File 'lib/google/apis/compute_alpha/classes.rb', line 30910

def request_valid_for_duration
  @request_valid_for_duration
end

#resource_manager_tagsHash<String,String>

Input only. Resource manager tags to be bound to the instance. Tag keys and values have the same definition as resource manager tags. Keys and values can be either in numeric format, such as tagKeys/tag_key_idand `tagValues/`tag_value_id or in namespaced format such as org_id|project_id`/`tag_key_short_name and tag_value_short_name. The field is ignored (both PUT & PATCH) when empty. Corresponds to the JSON property resourceManagerTags

Returns:

  • (Hash<String,String>)


30922
30923
30924
# File 'lib/google/apis/compute_alpha/classes.rb', line 30922

def resource_manager_tags
  @resource_manager_tags
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



30929
30930
30931
30932
# File 'lib/google/apis/compute_alpha/classes.rb', line 30929

def update!(**args)
  @request_valid_for_duration = args[:request_valid_for_duration] if args.key?(:request_valid_for_duration)
  @resource_manager_tags = args[:resource_manager_tags] if args.key?(:resource_manager_tags)
end