Class: Google::Apis::ComputeAlpha::InstanceProperties

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceProperties

Returns a new instance of InstanceProperties.



32381
32382
32383
# File 'lib/google/apis/compute_alpha/classes.rb', line 32381

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#advanced_machine_featuresGoogle::Apis::ComputeAlpha::AdvancedMachineFeatures

Specifies options for controlling advanced machine features. Options that would traditionally be configured in a BIOS belong here. Features that require operating system support may have corresponding entries in the GuestOsFeatures of anImage (e.g., whether or not the OS in theImage supports nested virtualization being enabled or disabled). Corresponds to the JSON property advancedMachineFeatures



32189
32190
32191
# File 'lib/google/apis/compute_alpha/classes.rb', line 32189

def advanced_machine_features
  @advanced_machine_features
end

#can_ip_forwardBoolean Also known as: can_ip_forward?

Enables instances created based on these properties to send packets with source IP addresses other than their own and receive packets with destination IP addresses other than their own. If these instances will be used as an IP gateway or it will be set as the next-hop in a Route resource, specify true. If unsure, leave this set tofalse. See theEnable IP forwarding documentation for more information. Corresponds to the JSON property canIpForward

Returns:

  • (Boolean)


32200
32201
32202
# File 'lib/google/apis/compute_alpha/classes.rb', line 32200

def can_ip_forward
  @can_ip_forward
end

#confidential_instance_configGoogle::Apis::ComputeAlpha::ConfidentialInstanceConfig

A set of Confidential Instance options. Corresponds to the JSON property confidentialInstanceConfig



32206
32207
32208
# File 'lib/google/apis/compute_alpha/classes.rb', line 32206

def confidential_instance_config
  @confidential_instance_config
end

#descriptionString

An optional text description for the instances that are created from these properties. Corresponds to the JSON property description

Returns:

  • (String)


32212
32213
32214
# File 'lib/google/apis/compute_alpha/classes.rb', line 32212

def description
  @description
end

#disksArray<Google::Apis::ComputeAlpha::AttachedDisk>

An array of disks that are associated with the instances that are created from these properties. Corresponds to the JSON property disks



32218
32219
32220
# File 'lib/google/apis/compute_alpha/classes.rb', line 32218

def disks
  @disks
end

#display_deviceGoogle::Apis::ComputeAlpha::DisplayDevice

A set of Display Device options Corresponds to the JSON property displayDevice



32223
32224
32225
# File 'lib/google/apis/compute_alpha/classes.rb', line 32223

def display_device
  @display_device
end

#guest_acceleratorsArray<Google::Apis::ComputeAlpha::AcceleratorConfig>

A list of guest accelerator cards' type and count to use for instances created from these properties. Corresponds to the JSON property guestAccelerators



32229
32230
32231
# File 'lib/google/apis/compute_alpha/classes.rb', line 32229

def guest_accelerators
  @guest_accelerators
end

#identityString

Corresponds to the JSON property identity

Returns:

  • (String)


32234
32235
32236
# File 'lib/google/apis/compute_alpha/classes.rb', line 32234

def identity
  @identity
end

#identity_certificateBoolean Also known as: identity_certificate?

Corresponds to the JSON property identityCertificate

Returns:

  • (Boolean)


32239
32240
32241
# File 'lib/google/apis/compute_alpha/classes.rb', line 32239

def identity_certificate
  @identity_certificate
end

#key_revocation_action_typeString

KeyRevocationActionType of the instance. Supported options are "STOP" and "NONE". The default value is "NONE" if it is not specified. Corresponds to the JSON property keyRevocationActionType

Returns:

  • (String)


32246
32247
32248
# File 'lib/google/apis/compute_alpha/classes.rb', line 32246

def key_revocation_action_type
  @key_revocation_action_type
end

#labelsHash<String,String>

Labels to apply to instances that are created from these properties. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


32251
32252
32253
# File 'lib/google/apis/compute_alpha/classes.rb', line 32251

def labels
  @labels
end

#local_ssd_encryption_modeString

Specifies which method should be used for encrypting the Local SSDs attached to the VM. Corresponds to the JSON property localSsdEncryptionMode

Returns:

  • (String)


32257
32258
32259
# File 'lib/google/apis/compute_alpha/classes.rb', line 32257

def local_ssd_encryption_mode
  @local_ssd_encryption_mode
end

#machine_typeString

The machine type to use for instances that are created from these properties. This field only accepts a machine type name, for example n2-standard-4. If you use the machine type full or partial URL, for example projects/my-l7ilb-project/zones/us-central1-a/machineTypes/n2-standard-4, the request will result in an INTERNAL_ERROR. Corresponds to the JSON property machineType

Returns:

  • (String)


32267
32268
32269
# File 'lib/google/apis/compute_alpha/classes.rb', line 32267

def machine_type
  @machine_type
end

#metadataGoogle::Apis::ComputeAlpha::Metadata

A metadata key/value entry. Corresponds to the JSON property metadata



32272
32273
32274
# File 'lib/google/apis/compute_alpha/classes.rb', line 32272

def 
  @metadata
end

#min_cpu_platformString

Minimum cpu/platform to be used by instances. The instance may be scheduled on the specified or newer cpu/platform. Applicable values are the friendly names of CPU platforms, such asminCpuPlatform: "Intel Haswell" orminCpuPlatform: "Intel Sandy Bridge". For more information, read Specifying a Minimum CPU Platform. Corresponds to the JSON property minCpuPlatform

Returns:

  • (String)


32282
32283
32284
# File 'lib/google/apis/compute_alpha/classes.rb', line 32282

def min_cpu_platform
  @min_cpu_platform
end

#network_interfacesArray<Google::Apis::ComputeAlpha::NetworkInterface>

An array of network access configurations for this interface. Corresponds to the JSON property networkInterfaces



32287
32288
32289
# File 'lib/google/apis/compute_alpha/classes.rb', line 32287

def network_interfaces
  @network_interfaces
end

#network_performance_configGoogle::Apis::ComputeAlpha::NetworkPerformanceConfig

Note that for MachineImage, this is not supported yet. Corresponds to the JSON property networkPerformanceConfig



32292
32293
32294
# File 'lib/google/apis/compute_alpha/classes.rb', line 32292

def network_performance_config
  @network_performance_config
end

#partner_metadataHash<String,Google::Apis::ComputeAlpha::StructuredEntries>

Partner Metadata assigned to the instance properties. A map from a subdomain (namespace) to entries map. Corresponds to the JSON property partnerMetadata



32298
32299
32300
# File 'lib/google/apis/compute_alpha/classes.rb', line 32298

def 
  @partner_metadata
end

#post_key_revocation_action_typeString

PostKeyRevocationActionType of the instance. Corresponds to the JSON property postKeyRevocationActionType

Returns:

  • (String)


32303
32304
32305
# File 'lib/google/apis/compute_alpha/classes.rb', line 32303

def post_key_revocation_action_type
  @post_key_revocation_action_type
end

#private_ipv6_google_accessString

The private IPv6 google access type for VMs. If not specified, use INHERIT_FROM_SUBNETWORK as default. Note that for MachineImage, this is not supported yet. Corresponds to the JSON property privateIpv6GoogleAccess

Returns:

  • (String)


32310
32311
32312
# File 'lib/google/apis/compute_alpha/classes.rb', line 32310

def private_ipv6_google_access
  @private_ipv6_google_access
end

#reservation_affinityGoogle::Apis::ComputeAlpha::ReservationAffinity

Specifies the reservations that this instance can consume from. Corresponds to the JSON property reservationAffinity



32315
32316
32317
# File 'lib/google/apis/compute_alpha/classes.rb', line 32315

def reservation_affinity
  @reservation_affinity
end

#resource_manager_tagsHash<String,String>

Input only. Resource manager tags to be bound to the instance. Tag keys and values have the same definition as resource manager tags. Keys and values can be either in numeric format, such as tagKeys/tag_key_idand `tagValues/`tag_value_id or in namespaced format such as org_id|project_id`/`tag_key_short_name and tag_value_short_name. The field is ignored (both PUT & PATCH) when empty. Corresponds to the JSON property resourceManagerTags

Returns:

  • (Hash<String,String>)


32327
32328
32329
# File 'lib/google/apis/compute_alpha/classes.rb', line 32327

def resource_manager_tags
  @resource_manager_tags
end

#resource_policiesArray<String>

Resource policies (names, not URLs) applied to instances created from these properties. Note that for MachineImage, this is not supported yet. Corresponds to the JSON property resourcePolicies

Returns:

  • (Array<String>)


32334
32335
32336
# File 'lib/google/apis/compute_alpha/classes.rb', line 32334

def resource_policies
  @resource_policies
end

#schedulingGoogle::Apis::ComputeAlpha::Scheduling

Sets the scheduling options for an Instance. Corresponds to the JSON property scheduling



32339
32340
32341
# File 'lib/google/apis/compute_alpha/classes.rb', line 32339

def scheduling
  @scheduling
end

#secure_tagsArray<String>

[Input Only] Secure tags to apply to this instance. Maximum number of secure tags allowed is 50. Note that for MachineImage, this is not supported yet. Corresponds to the JSON property secureTags

Returns:

  • (Array<String>)


32346
32347
32348
# File 'lib/google/apis/compute_alpha/classes.rb', line 32346

def secure_tags
  @secure_tags
end

#service_accountsArray<Google::Apis::ComputeAlpha::ServiceAccount>

A list of service accounts with specified scopes. Access tokens for these service accounts are available to the instances that are created from these properties. Use metadata queries to obtain the access tokens for these instances. Corresponds to the JSON property serviceAccounts



32354
32355
32356
# File 'lib/google/apis/compute_alpha/classes.rb', line 32354

def service_accounts
  @service_accounts
end

#service_integration_specsHash<String,Google::Apis::ComputeAlpha::ServiceIntegrationSpec>

Mapping of user defined keys to ServiceIntegrationSpec. Corresponds to the JSON property serviceIntegrationSpecs



32359
32360
32361
# File 'lib/google/apis/compute_alpha/classes.rb', line 32359

def service_integration_specs
  @service_integration_specs
end

#shielded_instance_configGoogle::Apis::ComputeAlpha::ShieldedInstanceConfig

A set of Shielded Instance options. Corresponds to the JSON property shieldedInstanceConfig



32364
32365
32366
# File 'lib/google/apis/compute_alpha/classes.rb', line 32364

def shielded_instance_config
  @shielded_instance_config
end

#shielded_vm_configGoogle::Apis::ComputeAlpha::ShieldedVmConfig

A set of Shielded VM options. Corresponds to the JSON property shieldedVmConfig



32369
32370
32371
# File 'lib/google/apis/compute_alpha/classes.rb', line 32369

def shielded_vm_config
  @shielded_vm_config
end

#tagsGoogle::Apis::ComputeAlpha::Tags

A set of instance tags. Corresponds to the JSON property tags



32374
32375
32376
# File 'lib/google/apis/compute_alpha/classes.rb', line 32374

def tags
  @tags
end

#workload_identity_configGoogle::Apis::ComputeAlpha::WorkloadIdentityConfig

Corresponds to the JSON property workloadIdentityConfig



32379
32380
32381
# File 'lib/google/apis/compute_alpha/classes.rb', line 32379

def workload_identity_config
  @workload_identity_config
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



32386
32387
32388
32389
32390
32391
32392
32393
32394
32395
32396
32397
32398
32399
32400
32401
32402
32403
32404
32405
32406
32407
32408
32409
32410
32411
32412
32413
32414
32415
32416
32417
32418
# File 'lib/google/apis/compute_alpha/classes.rb', line 32386

def update!(**args)
  @advanced_machine_features = args[:advanced_machine_features] if args.key?(:advanced_machine_features)
  @can_ip_forward = args[:can_ip_forward] if args.key?(:can_ip_forward)
  @confidential_instance_config = args[:confidential_instance_config] if args.key?(:confidential_instance_config)
  @description = args[:description] if args.key?(:description)
  @disks = args[:disks] if args.key?(:disks)
  @display_device = args[:display_device] if args.key?(:display_device)
  @guest_accelerators = args[:guest_accelerators] if args.key?(:guest_accelerators)
  @identity = args[:identity] if args.key?(:identity)
  @identity_certificate = args[:identity_certificate] if args.key?(:identity_certificate)
  @key_revocation_action_type = args[:key_revocation_action_type] if args.key?(:key_revocation_action_type)
  @labels = args[:labels] if args.key?(:labels)
  @local_ssd_encryption_mode = args[:local_ssd_encryption_mode] if args.key?(:local_ssd_encryption_mode)
  @machine_type = args[:machine_type] if args.key?(:machine_type)
  @metadata = args[:metadata] if args.key?(:metadata)
  @min_cpu_platform = args[:min_cpu_platform] if args.key?(:min_cpu_platform)
  @network_interfaces = args[:network_interfaces] if args.key?(:network_interfaces)
  @network_performance_config = args[:network_performance_config] if args.key?(:network_performance_config)
  @partner_metadata = args[:partner_metadata] if args.key?(:partner_metadata)
  @post_key_revocation_action_type = args[:post_key_revocation_action_type] if args.key?(:post_key_revocation_action_type)
  @private_ipv6_google_access = args[:private_ipv6_google_access] if args.key?(:private_ipv6_google_access)
  @reservation_affinity = args[:reservation_affinity] if args.key?(:reservation_affinity)
  @resource_manager_tags = args[:resource_manager_tags] if args.key?(:resource_manager_tags)
  @resource_policies = args[:resource_policies] if args.key?(:resource_policies)
  @scheduling = args[:scheduling] if args.key?(:scheduling)
  @secure_tags = args[:secure_tags] if args.key?(:secure_tags)
  @service_accounts = args[:service_accounts] if args.key?(:service_accounts)
  @service_integration_specs = args[:service_integration_specs] if args.key?(:service_integration_specs)
  @shielded_instance_config = args[:shielded_instance_config] if args.key?(:shielded_instance_config)
  @shielded_vm_config = args[:shielded_vm_config] if args.key?(:shielded_vm_config)
  @tags = args[:tags] if args.key?(:tags)
  @workload_identity_config = args[:workload_identity_config] if args.key?(:workload_identity_config)
end