Class: Google::Apis::ComputeAlpha::InstanceProperties
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::InstanceProperties
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#advanced_machine_features ⇒ Google::Apis::ComputeAlpha::AdvancedMachineFeatures
Specifies options for controlling advanced machine features.
-
#can_ip_forward ⇒ Boolean
(also: #can_ip_forward?)
Enables instances created based on these properties to send packets with source IP addresses other than their own and receive packets with destination IP addresses other than their own.
-
#confidential_instance_config ⇒ Google::Apis::ComputeAlpha::ConfidentialInstanceConfig
A set of Confidential Instance options.
-
#description ⇒ String
An optional text description for the instances that are created from these properties.
-
#disks ⇒ Array<Google::Apis::ComputeAlpha::AttachedDisk>
An array of disks that are associated with the instances that are created from these properties.
-
#display_device ⇒ Google::Apis::ComputeAlpha::DisplayDevice
A set of Display Device options Corresponds to the JSON property
displayDevice. -
#guest_accelerators ⇒ Array<Google::Apis::ComputeAlpha::AcceleratorConfig>
A list of guest accelerator cards' type and count to use for instances created from these properties.
-
#identity ⇒ String
Corresponds to the JSON property
identity. -
#identity_certificate ⇒ Boolean
(also: #identity_certificate?)
Corresponds to the JSON property
identityCertificate. -
#key_revocation_action_type ⇒ String
KeyRevocationActionType of the instance.
-
#labels ⇒ Hash<String,String>
Labels to apply to instances that are created from these properties.
-
#machine_type ⇒ String
The machine type to use for instances that are created from these properties.
-
#metadata ⇒ Google::Apis::ComputeAlpha::Metadata
A metadata key/value entry.
-
#min_cpu_platform ⇒ String
Minimum cpu/platform to be used by instances.
-
#network_interfaces ⇒ Array<Google::Apis::ComputeAlpha::NetworkInterface>
An array of network access configurations for this interface.
-
#network_performance_config ⇒ Google::Apis::ComputeAlpha::NetworkPerformanceConfig
Note that for MachineImage, this is not supported yet.
-
#partner_metadata ⇒ Hash<String,Google::Apis::ComputeAlpha::StructuredEntries>
Partner Metadata assigned to the instance properties.
-
#post_key_revocation_action_type ⇒ String
PostKeyRevocationActionType of the instance.
-
#private_ipv6_google_access ⇒ String
The private IPv6 google access type for VMs.
-
#reservation_affinity ⇒ Google::Apis::ComputeAlpha::ReservationAffinity
Specifies the reservations that this instance can consume from.
-
#resource_manager_tags ⇒ Hash<String,String>
Input only.
-
#resource_policies ⇒ Array<String>
Resource policies (names, not URLs) applied to instances created from these properties.
-
#scheduling ⇒ Google::Apis::ComputeAlpha::Scheduling
Sets the scheduling options for an Instance.
-
#secure_tags ⇒ Array<String>
[Input Only] Secure tags to apply to this instance.
-
#service_accounts ⇒ Array<Google::Apis::ComputeAlpha::ServiceAccount>
A list of service accounts with specified scopes.
-
#service_integration_specs ⇒ Hash<String,Google::Apis::ComputeAlpha::ServiceIntegrationSpec>
Mapping of user defined keys to ServiceIntegrationSpec.
-
#shielded_instance_config ⇒ Google::Apis::ComputeAlpha::ShieldedInstanceConfig
A set of Shielded Instance options.
-
#shielded_vm_config ⇒ Google::Apis::ComputeAlpha::ShieldedVmConfig
A set of Shielded VM options.
-
#tags ⇒ Google::Apis::ComputeAlpha::Tags
A set of instance tags.
-
#workload_identity_config ⇒ Google::Apis::ComputeAlpha::WorkloadIdentityConfig
Corresponds to the JSON property
workloadIdentityConfig.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceProperties
constructor
A new instance of InstanceProperties.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceProperties
Returns a new instance of InstanceProperties.
31358 31359 31360 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 31358 def initialize(**args) update!(**args) end |
Instance Attribute Details
#advanced_machine_features ⇒ Google::Apis::ComputeAlpha::AdvancedMachineFeatures
Specifies options for controlling advanced machine features.
Options that would traditionally be configured in a BIOS belong
here. Features that require operating system support may have
corresponding entries in the GuestOsFeatures of anImage (e.g., whether or not
the OS in theImage supports nested virtualization being enabled or
disabled).
Corresponds to the JSON property advancedMachineFeatures
31172 31173 31174 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 31172 def advanced_machine_features @advanced_machine_features end |
#can_ip_forward ⇒ Boolean Also known as: can_ip_forward?
Enables instances created based on these properties to send packets with
source IP addresses other than their own and receive packets with
destination IP addresses other than their own. If these instances will be
used as an IP gateway or it will be set as the next-hop in a Route
resource, specify true. If unsure, leave this set tofalse. See theEnable IP
forwarding
documentation for more information.
Corresponds to the JSON property canIpForward
31183 31184 31185 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 31183 def can_ip_forward @can_ip_forward end |
#confidential_instance_config ⇒ Google::Apis::ComputeAlpha::ConfidentialInstanceConfig
A set of Confidential Instance options.
Corresponds to the JSON property confidentialInstanceConfig
31189 31190 31191 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 31189 def confidential_instance_config @confidential_instance_config end |
#description ⇒ String
An optional text description for the instances that are created from these
properties.
Corresponds to the JSON property description
31195 31196 31197 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 31195 def description @description end |
#disks ⇒ Array<Google::Apis::ComputeAlpha::AttachedDisk>
An array of disks that are associated with the instances that are created
from these properties.
Corresponds to the JSON property disks
31201 31202 31203 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 31201 def disks @disks end |
#display_device ⇒ Google::Apis::ComputeAlpha::DisplayDevice
A set of Display Device options
Corresponds to the JSON property displayDevice
31206 31207 31208 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 31206 def display_device @display_device end |
#guest_accelerators ⇒ Array<Google::Apis::ComputeAlpha::AcceleratorConfig>
A list of guest accelerator cards' type and count to use for instances
created from these properties.
Corresponds to the JSON property guestAccelerators
31212 31213 31214 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 31212 def guest_accelerators @guest_accelerators end |
#identity ⇒ String
Corresponds to the JSON property identity
31217 31218 31219 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 31217 def identity @identity end |
#identity_certificate ⇒ Boolean Also known as: identity_certificate?
Corresponds to the JSON property identityCertificate
31222 31223 31224 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 31222 def identity_certificate @identity_certificate end |
#key_revocation_action_type ⇒ String
KeyRevocationActionType of the instance. Supported options are "STOP" and
"NONE". The default value is "NONE" if it is not specified.
Corresponds to the JSON property keyRevocationActionType
31229 31230 31231 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 31229 def key_revocation_action_type @key_revocation_action_type end |
#labels ⇒ Hash<String,String>
Labels to apply to instances that are created from these properties.
Corresponds to the JSON property labels
31234 31235 31236 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 31234 def labels @labels end |
#machine_type ⇒ String
The machine type to use for instances that are created from these
properties.
This field only accepts a machine type name, for example n2-standard-4.
If you use the machine type full or partial URL, for example
projects/my-l7ilb-project/zones/us-central1-a/machineTypes/n2-standard-4,
the request will result in an INTERNAL_ERROR.
Corresponds to the JSON property machineType
31244 31245 31246 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 31244 def machine_type @machine_type end |
#metadata ⇒ Google::Apis::ComputeAlpha::Metadata
A metadata key/value entry.
Corresponds to the JSON property metadata
31249 31250 31251 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 31249 def @metadata end |
#min_cpu_platform ⇒ String
Minimum cpu/platform to be used by instances. The instance may be
scheduled on the specified or newer cpu/platform. Applicable values are the
friendly names of CPU platforms, such asminCpuPlatform: "Intel Haswell"
orminCpuPlatform: "Intel Sandy Bridge". For more
information, read Specifying a
Minimum CPU Platform.
Corresponds to the JSON property minCpuPlatform
31259 31260 31261 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 31259 def min_cpu_platform @min_cpu_platform end |
#network_interfaces ⇒ Array<Google::Apis::ComputeAlpha::NetworkInterface>
An array of network access configurations for this interface.
Corresponds to the JSON property networkInterfaces
31264 31265 31266 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 31264 def network_interfaces @network_interfaces end |
#network_performance_config ⇒ Google::Apis::ComputeAlpha::NetworkPerformanceConfig
Note that for MachineImage, this is not supported yet.
Corresponds to the JSON property networkPerformanceConfig
31269 31270 31271 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 31269 def network_performance_config @network_performance_config end |
#partner_metadata ⇒ Hash<String,Google::Apis::ComputeAlpha::StructuredEntries>
Partner Metadata assigned to the instance properties. A map from a
subdomain (namespace) to entries map.
Corresponds to the JSON property partnerMetadata
31275 31276 31277 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 31275 def @partner_metadata end |
#post_key_revocation_action_type ⇒ String
PostKeyRevocationActionType of the instance.
Corresponds to the JSON property postKeyRevocationActionType
31280 31281 31282 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 31280 def post_key_revocation_action_type @post_key_revocation_action_type end |
#private_ipv6_google_access ⇒ String
The private IPv6 google access type for VMs.
If not specified, use INHERIT_FROM_SUBNETWORK as default.
Note that for MachineImage, this is not supported yet.
Corresponds to the JSON property privateIpv6GoogleAccess
31287 31288 31289 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 31287 def private_ipv6_google_access @private_ipv6_google_access end |
#reservation_affinity ⇒ Google::Apis::ComputeAlpha::ReservationAffinity
Specifies the reservations that this instance can consume from.
Corresponds to the JSON property reservationAffinity
31292 31293 31294 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 31292 def reservation_affinity @reservation_affinity end |
#resource_manager_tags ⇒ Hash<String,String>
Input only. Resource manager tags to be bound to the instance. Tag keys and
values
have the same definition as resource
manager tags. Keys and values can be either in numeric format,
such as tagKeys/tag_key_idand `tagValues/`tag_value_id or in
namespaced format such as org_id|project_id`/`tag_key_short_name and
tag_value_short_name. The field is ignored (both PUT &
PATCH) when empty.
Corresponds to the JSON property resourceManagerTags
31304 31305 31306 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 31304 def @resource_manager_tags end |
#resource_policies ⇒ Array<String>
Resource policies (names, not URLs) applied to instances created from
these properties.
Note that for MachineImage, this is not supported yet.
Corresponds to the JSON property resourcePolicies
31311 31312 31313 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 31311 def resource_policies @resource_policies end |
#scheduling ⇒ Google::Apis::ComputeAlpha::Scheduling
Sets the scheduling options for an Instance.
Corresponds to the JSON property scheduling
31316 31317 31318 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 31316 def scheduling @scheduling end |
#secure_tags ⇒ Array<String>
[Input Only] Secure tags to apply to this instance.
Maximum number of secure tags allowed is 50.
Note that for MachineImage, this is not supported yet.
Corresponds to the JSON property secureTags
31323 31324 31325 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 31323 def @secure_tags end |
#service_accounts ⇒ Array<Google::Apis::ComputeAlpha::ServiceAccount>
A list of service accounts with specified scopes. Access tokens for these
service accounts are available to the instances that are created from
these properties. Use metadata queries to obtain the access tokens for
these instances.
Corresponds to the JSON property serviceAccounts
31331 31332 31333 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 31331 def service_accounts @service_accounts end |
#service_integration_specs ⇒ Hash<String,Google::Apis::ComputeAlpha::ServiceIntegrationSpec>
Mapping of user defined keys to ServiceIntegrationSpec.
Corresponds to the JSON property serviceIntegrationSpecs
31336 31337 31338 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 31336 def service_integration_specs @service_integration_specs end |
#shielded_instance_config ⇒ Google::Apis::ComputeAlpha::ShieldedInstanceConfig
A set of Shielded Instance options.
Corresponds to the JSON property shieldedInstanceConfig
31341 31342 31343 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 31341 def shielded_instance_config @shielded_instance_config end |
#shielded_vm_config ⇒ Google::Apis::ComputeAlpha::ShieldedVmConfig
A set of Shielded VM options.
Corresponds to the JSON property shieldedVmConfig
31346 31347 31348 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 31346 def shielded_vm_config @shielded_vm_config end |
#tags ⇒ Google::Apis::ComputeAlpha::Tags
A set of instance tags.
Corresponds to the JSON property tags
31351 31352 31353 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 31351 def @tags end |
#workload_identity_config ⇒ Google::Apis::ComputeAlpha::WorkloadIdentityConfig
Corresponds to the JSON property workloadIdentityConfig
31356 31357 31358 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 31356 def workload_identity_config @workload_identity_config end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
31363 31364 31365 31366 31367 31368 31369 31370 31371 31372 31373 31374 31375 31376 31377 31378 31379 31380 31381 31382 31383 31384 31385 31386 31387 31388 31389 31390 31391 31392 31393 31394 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 31363 def update!(**args) @advanced_machine_features = args[:advanced_machine_features] if args.key?(:advanced_machine_features) @can_ip_forward = args[:can_ip_forward] if args.key?(:can_ip_forward) @confidential_instance_config = args[:confidential_instance_config] if args.key?(:confidential_instance_config) @description = args[:description] if args.key?(:description) @disks = args[:disks] if args.key?(:disks) @display_device = args[:display_device] if args.key?(:display_device) @guest_accelerators = args[:guest_accelerators] if args.key?(:guest_accelerators) @identity = args[:identity] if args.key?(:identity) @identity_certificate = args[:identity_certificate] if args.key?(:identity_certificate) @key_revocation_action_type = args[:key_revocation_action_type] if args.key?(:key_revocation_action_type) @labels = args[:labels] if args.key?(:labels) @machine_type = args[:machine_type] if args.key?(:machine_type) @metadata = args[:metadata] if args.key?(:metadata) @min_cpu_platform = args[:min_cpu_platform] if args.key?(:min_cpu_platform) @network_interfaces = args[:network_interfaces] if args.key?(:network_interfaces) @network_performance_config = args[:network_performance_config] if args.key?(:network_performance_config) @partner_metadata = args[:partner_metadata] if args.key?(:partner_metadata) @post_key_revocation_action_type = args[:post_key_revocation_action_type] if args.key?(:post_key_revocation_action_type) @private_ipv6_google_access = args[:private_ipv6_google_access] if args.key?(:private_ipv6_google_access) @reservation_affinity = args[:reservation_affinity] if args.key?(:reservation_affinity) @resource_manager_tags = args[:resource_manager_tags] if args.key?(:resource_manager_tags) @resource_policies = args[:resource_policies] if args.key?(:resource_policies) @scheduling = args[:scheduling] if args.key?(:scheduling) @secure_tags = args[:secure_tags] if args.key?(:secure_tags) @service_accounts = args[:service_accounts] if args.key?(:service_accounts) @service_integration_specs = args[:service_integration_specs] if args.key?(:service_integration_specs) @shielded_instance_config = args[:shielded_instance_config] if args.key?(:shielded_instance_config) @shielded_vm_config = args[:shielded_vm_config] if args.key?(:shielded_vm_config) @tags = args[:tags] if args.key?(:tags) @workload_identity_config = args[:workload_identity_config] if args.key?(:workload_identity_config) end |