Class: Google::Apis::ComputeAlpha::InstanceProperties

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceProperties

Returns a new instance of InstanceProperties.



31133
31134
31135
# File 'lib/google/apis/compute_alpha/classes.rb', line 31133

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#advanced_machine_featuresGoogle::Apis::ComputeAlpha::AdvancedMachineFeatures

Specifies options for controlling advanced machine features. Options that would traditionally be configured in a BIOS belong here. Features that require operating system support may have corresponding entries in the GuestOsFeatures of anImage (e.g., whether or not the OS in theImage supports nested virtualization being enabled or disabled). Corresponds to the JSON property advancedMachineFeatures



30947
30948
30949
# File 'lib/google/apis/compute_alpha/classes.rb', line 30947

def advanced_machine_features
  @advanced_machine_features
end

#can_ip_forwardBoolean Also known as: can_ip_forward?

Enables instances created based on these properties to send packets with source IP addresses other than their own and receive packets with destination IP addresses other than their own. If these instances will be used as an IP gateway or it will be set as the next-hop in a Route resource, specify true. If unsure, leave this set tofalse. See theEnable IP forwarding documentation for more information. Corresponds to the JSON property canIpForward

Returns:

  • (Boolean)


30958
30959
30960
# File 'lib/google/apis/compute_alpha/classes.rb', line 30958

def can_ip_forward
  @can_ip_forward
end

#confidential_instance_configGoogle::Apis::ComputeAlpha::ConfidentialInstanceConfig

A set of Confidential Instance options. Corresponds to the JSON property confidentialInstanceConfig



30964
30965
30966
# File 'lib/google/apis/compute_alpha/classes.rb', line 30964

def confidential_instance_config
  @confidential_instance_config
end

#descriptionString

An optional text description for the instances that are created from these properties. Corresponds to the JSON property description

Returns:

  • (String)


30970
30971
30972
# File 'lib/google/apis/compute_alpha/classes.rb', line 30970

def description
  @description
end

#disksArray<Google::Apis::ComputeAlpha::AttachedDisk>

An array of disks that are associated with the instances that are created from these properties. Corresponds to the JSON property disks



30976
30977
30978
# File 'lib/google/apis/compute_alpha/classes.rb', line 30976

def disks
  @disks
end

#display_deviceGoogle::Apis::ComputeAlpha::DisplayDevice

A set of Display Device options Corresponds to the JSON property displayDevice



30981
30982
30983
# File 'lib/google/apis/compute_alpha/classes.rb', line 30981

def display_device
  @display_device
end

#guest_acceleratorsArray<Google::Apis::ComputeAlpha::AcceleratorConfig>

A list of guest accelerator cards' type and count to use for instances created from these properties. Corresponds to the JSON property guestAccelerators



30987
30988
30989
# File 'lib/google/apis/compute_alpha/classes.rb', line 30987

def guest_accelerators
  @guest_accelerators
end

#identityString

Corresponds to the JSON property identity

Returns:

  • (String)


30992
30993
30994
# File 'lib/google/apis/compute_alpha/classes.rb', line 30992

def identity
  @identity
end

#identity_certificateBoolean Also known as: identity_certificate?

Corresponds to the JSON property identityCertificate

Returns:

  • (Boolean)


30997
30998
30999
# File 'lib/google/apis/compute_alpha/classes.rb', line 30997

def identity_certificate
  @identity_certificate
end

#key_revocation_action_typeString

KeyRevocationActionType of the instance. Supported options are "STOP" and "NONE". The default value is "NONE" if it is not specified. Corresponds to the JSON property keyRevocationActionType

Returns:

  • (String)


31004
31005
31006
# File 'lib/google/apis/compute_alpha/classes.rb', line 31004

def key_revocation_action_type
  @key_revocation_action_type
end

#labelsHash<String,String>

Labels to apply to instances that are created from these properties. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


31009
31010
31011
# File 'lib/google/apis/compute_alpha/classes.rb', line 31009

def labels
  @labels
end

#machine_typeString

The machine type to use for instances that are created from these properties. This field only accepts a machine type name, for example n2-standard-4. If you use the machine type full or partial URL, for example projects/my-l7ilb-project/zones/us-central1-a/machineTypes/n2-standard-4, the request will result in an INTERNAL_ERROR. Corresponds to the JSON property machineType

Returns:

  • (String)


31019
31020
31021
# File 'lib/google/apis/compute_alpha/classes.rb', line 31019

def machine_type
  @machine_type
end

#metadataGoogle::Apis::ComputeAlpha::Metadata

A metadata key/value entry. Corresponds to the JSON property metadata



31024
31025
31026
# File 'lib/google/apis/compute_alpha/classes.rb', line 31024

def 
  @metadata
end

#min_cpu_platformString

Minimum cpu/platform to be used by instances. The instance may be scheduled on the specified or newer cpu/platform. Applicable values are the friendly names of CPU platforms, such asminCpuPlatform: "Intel Haswell" orminCpuPlatform: "Intel Sandy Bridge". For more information, read Specifying a Minimum CPU Platform. Corresponds to the JSON property minCpuPlatform

Returns:

  • (String)


31034
31035
31036
# File 'lib/google/apis/compute_alpha/classes.rb', line 31034

def min_cpu_platform
  @min_cpu_platform
end

#network_interfacesArray<Google::Apis::ComputeAlpha::NetworkInterface>

An array of network access configurations for this interface. Corresponds to the JSON property networkInterfaces



31039
31040
31041
# File 'lib/google/apis/compute_alpha/classes.rb', line 31039

def network_interfaces
  @network_interfaces
end

#network_performance_configGoogle::Apis::ComputeAlpha::NetworkPerformanceConfig

Note that for MachineImage, this is not supported yet. Corresponds to the JSON property networkPerformanceConfig



31044
31045
31046
# File 'lib/google/apis/compute_alpha/classes.rb', line 31044

def network_performance_config
  @network_performance_config
end

#partner_metadataHash<String,Google::Apis::ComputeAlpha::StructuredEntries>

Partner Metadata assigned to the instance properties. A map from a subdomain (namespace) to entries map. Corresponds to the JSON property partnerMetadata



31050
31051
31052
# File 'lib/google/apis/compute_alpha/classes.rb', line 31050

def 
  @partner_metadata
end

#post_key_revocation_action_typeString

PostKeyRevocationActionType of the instance. Corresponds to the JSON property postKeyRevocationActionType

Returns:

  • (String)


31055
31056
31057
# File 'lib/google/apis/compute_alpha/classes.rb', line 31055

def post_key_revocation_action_type
  @post_key_revocation_action_type
end

#private_ipv6_google_accessString

The private IPv6 google access type for VMs. If not specified, use INHERIT_FROM_SUBNETWORK as default. Note that for MachineImage, this is not supported yet. Corresponds to the JSON property privateIpv6GoogleAccess

Returns:

  • (String)


31062
31063
31064
# File 'lib/google/apis/compute_alpha/classes.rb', line 31062

def private_ipv6_google_access
  @private_ipv6_google_access
end

#reservation_affinityGoogle::Apis::ComputeAlpha::ReservationAffinity

Specifies the reservations that this instance can consume from. Corresponds to the JSON property reservationAffinity



31067
31068
31069
# File 'lib/google/apis/compute_alpha/classes.rb', line 31067

def reservation_affinity
  @reservation_affinity
end

#resource_manager_tagsHash<String,String>

Input only. Resource manager tags to be bound to the instance. Tag keys and values have the same definition as resource manager tags. Keys and values can be either in numeric format, such as tagKeys/tag_key_idand `tagValues/`tag_value_id or in namespaced format such as org_id|project_id`/`tag_key_short_name and tag_value_short_name. The field is ignored (both PUT & PATCH) when empty. Corresponds to the JSON property resourceManagerTags

Returns:

  • (Hash<String,String>)


31079
31080
31081
# File 'lib/google/apis/compute_alpha/classes.rb', line 31079

def resource_manager_tags
  @resource_manager_tags
end

#resource_policiesArray<String>

Resource policies (names, not URLs) applied to instances created from these properties. Note that for MachineImage, this is not supported yet. Corresponds to the JSON property resourcePolicies

Returns:

  • (Array<String>)


31086
31087
31088
# File 'lib/google/apis/compute_alpha/classes.rb', line 31086

def resource_policies
  @resource_policies
end

#schedulingGoogle::Apis::ComputeAlpha::Scheduling

Sets the scheduling options for an Instance. Corresponds to the JSON property scheduling



31091
31092
31093
# File 'lib/google/apis/compute_alpha/classes.rb', line 31091

def scheduling
  @scheduling
end

#secure_tagsArray<String>

[Input Only] Secure tags to apply to this instance. Maximum number of secure tags allowed is 50. Note that for MachineImage, this is not supported yet. Corresponds to the JSON property secureTags

Returns:

  • (Array<String>)


31098
31099
31100
# File 'lib/google/apis/compute_alpha/classes.rb', line 31098

def secure_tags
  @secure_tags
end

#service_accountsArray<Google::Apis::ComputeAlpha::ServiceAccount>

A list of service accounts with specified scopes. Access tokens for these service accounts are available to the instances that are created from these properties. Use metadata queries to obtain the access tokens for these instances. Corresponds to the JSON property serviceAccounts



31106
31107
31108
# File 'lib/google/apis/compute_alpha/classes.rb', line 31106

def service_accounts
  @service_accounts
end

#service_integration_specsHash<String,Google::Apis::ComputeAlpha::ServiceIntegrationSpec>

Mapping of user defined keys to ServiceIntegrationSpec. Corresponds to the JSON property serviceIntegrationSpecs



31111
31112
31113
# File 'lib/google/apis/compute_alpha/classes.rb', line 31111

def service_integration_specs
  @service_integration_specs
end

#shielded_instance_configGoogle::Apis::ComputeAlpha::ShieldedInstanceConfig

A set of Shielded Instance options. Corresponds to the JSON property shieldedInstanceConfig



31116
31117
31118
# File 'lib/google/apis/compute_alpha/classes.rb', line 31116

def shielded_instance_config
  @shielded_instance_config
end

#shielded_vm_configGoogle::Apis::ComputeAlpha::ShieldedVmConfig

A set of Shielded VM options. Corresponds to the JSON property shieldedVmConfig



31121
31122
31123
# File 'lib/google/apis/compute_alpha/classes.rb', line 31121

def shielded_vm_config
  @shielded_vm_config
end

#tagsGoogle::Apis::ComputeAlpha::Tags

A set of instance tags. Corresponds to the JSON property tags



31126
31127
31128
# File 'lib/google/apis/compute_alpha/classes.rb', line 31126

def tags
  @tags
end

#workload_identity_configGoogle::Apis::ComputeAlpha::WorkloadIdentityConfig

Corresponds to the JSON property workloadIdentityConfig



31131
31132
31133
# File 'lib/google/apis/compute_alpha/classes.rb', line 31131

def workload_identity_config
  @workload_identity_config
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



31138
31139
31140
31141
31142
31143
31144
31145
31146
31147
31148
31149
31150
31151
31152
31153
31154
31155
31156
31157
31158
31159
31160
31161
31162
31163
31164
31165
31166
31167
31168
31169
# File 'lib/google/apis/compute_alpha/classes.rb', line 31138

def update!(**args)
  @advanced_machine_features = args[:advanced_machine_features] if args.key?(:advanced_machine_features)
  @can_ip_forward = args[:can_ip_forward] if args.key?(:can_ip_forward)
  @confidential_instance_config = args[:confidential_instance_config] if args.key?(:confidential_instance_config)
  @description = args[:description] if args.key?(:description)
  @disks = args[:disks] if args.key?(:disks)
  @display_device = args[:display_device] if args.key?(:display_device)
  @guest_accelerators = args[:guest_accelerators] if args.key?(:guest_accelerators)
  @identity = args[:identity] if args.key?(:identity)
  @identity_certificate = args[:identity_certificate] if args.key?(:identity_certificate)
  @key_revocation_action_type = args[:key_revocation_action_type] if args.key?(:key_revocation_action_type)
  @labels = args[:labels] if args.key?(:labels)
  @machine_type = args[:machine_type] if args.key?(:machine_type)
  @metadata = args[:metadata] if args.key?(:metadata)
  @min_cpu_platform = args[:min_cpu_platform] if args.key?(:min_cpu_platform)
  @network_interfaces = args[:network_interfaces] if args.key?(:network_interfaces)
  @network_performance_config = args[:network_performance_config] if args.key?(:network_performance_config)
  @partner_metadata = args[:partner_metadata] if args.key?(:partner_metadata)
  @post_key_revocation_action_type = args[:post_key_revocation_action_type] if args.key?(:post_key_revocation_action_type)
  @private_ipv6_google_access = args[:private_ipv6_google_access] if args.key?(:private_ipv6_google_access)
  @reservation_affinity = args[:reservation_affinity] if args.key?(:reservation_affinity)
  @resource_manager_tags = args[:resource_manager_tags] if args.key?(:resource_manager_tags)
  @resource_policies = args[:resource_policies] if args.key?(:resource_policies)
  @scheduling = args[:scheduling] if args.key?(:scheduling)
  @secure_tags = args[:secure_tags] if args.key?(:secure_tags)
  @service_accounts = args[:service_accounts] if args.key?(:service_accounts)
  @service_integration_specs = args[:service_integration_specs] if args.key?(:service_integration_specs)
  @shielded_instance_config = args[:shielded_instance_config] if args.key?(:shielded_instance_config)
  @shielded_vm_config = args[:shielded_vm_config] if args.key?(:shielded_vm_config)
  @tags = args[:tags] if args.key?(:tags)
  @workload_identity_config = args[:workload_identity_config] if args.key?(:workload_identity_config)
end