Class: Google::Apis::ComputeAlpha::InstancePropertiesPatch
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::InstancePropertiesPatch
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Represents the change that you want to make to the instance properties.
Instance Attribute Summary collapse
-
#expose_host_topology ⇒ Boolean
(also: #expose_host_topology?)
This optional flag exposes the hashed physical host ID.
-
#labels ⇒ Hash<String,String>
The label key-value pairs that you want to patch onto the instance.
-
#metadata ⇒ Hash<String,String>
The metadata key-value pairs that you want to patch onto the instance.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstancePropertiesPatch
constructor
A new instance of InstancePropertiesPatch.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstancePropertiesPatch
Returns a new instance of InstancePropertiesPatch.
32443 32444 32445 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 32443 def initialize(**args) update!(**args) end |
Instance Attribute Details
#expose_host_topology ⇒ Boolean Also known as: expose_host_topology?
This optional flag exposes the hashed physical host ID.
Corresponds to the JSON property exposeHostTopology
32428 32429 32430 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 32428 def expose_host_topology @expose_host_topology end |
#labels ⇒ Hash<String,String>
The label key-value pairs that you want to patch onto the instance.
Corresponds to the JSON property labels
32434 32435 32436 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 32434 def labels @labels end |
#metadata ⇒ Hash<String,String>
The metadata key-value pairs that you want to patch onto the instance. For
more information, see Project and
instance metadata.
Corresponds to the JSON property metadata
32441 32442 32443 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 32441 def @metadata end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
32448 32449 32450 32451 32452 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 32448 def update!(**args) @expose_host_topology = args[:expose_host_topology] if args.key?(:expose_host_topology) @labels = args[:labels] if args.key?(:labels) @metadata = args[:metadata] if args.key?(:metadata) end |