Class: Google::Apis::ComputeAlpha::InstancePropertiesPatch
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::InstancePropertiesPatch
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Represents the change that you want to make to the instance properties.
Instance Attribute Summary collapse
-
#labels ⇒ Hash<String,String>
The label key-value pairs that you want to patch onto the instance.
-
#metadata ⇒ Hash<String,String>
The metadata key-value pairs that you want to patch onto the instance.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstancePropertiesPatch
constructor
A new instance of InstancePropertiesPatch.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstancePropertiesPatch
Returns a new instance of InstancePropertiesPatch.
32165 32166 32167 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 32165 def initialize(**args) update!(**args) end |
Instance Attribute Details
#labels ⇒ Hash<String,String>
The label key-value pairs that you want to patch onto the instance.
Corresponds to the JSON property labels
32156 32157 32158 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 32156 def labels @labels end |
#metadata ⇒ Hash<String,String>
The metadata key-value pairs that you want to patch onto the instance. For
more information, see Project and
instance metadata.
Corresponds to the JSON property metadata
32163 32164 32165 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 32163 def @metadata end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
32170 32171 32172 32173 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 32170 def update!(**args) @labels = args[:labels] if args.key?(:labels) @metadata = args[:metadata] if args.key?(:metadata) end |