Class: Google::Apis::ComputeAlpha::InstanceSettings

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Represents a Instance Settings resource. You can use instance settings to configure default settings for Compute Engine VM instances. For example, you can use it to configure default machine type of Compute Engine VM instances.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceSettings

Returns a new instance of InstanceSettings.



31133
31134
31135
# File 'lib/google/apis/compute_alpha/classes.rb', line 31133

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#emailString

Email address of the service account. Corresponds to the JSON property email

Returns:

  • (String)


31098
31099
31100
# File 'lib/google/apis/compute_alpha/classes.rb', line 31098

def email
  @email
end

#fingerprintString

Specifies a fingerprint for instance settings, which is essentially a hash of the instance settings resource's contents and used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update the instance settings resource. You must always provide an up-to-date fingerprint hash in order to update or change the resource, otherwise the request will fail with error 412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve the resource. Corresponds to the JSON property fingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


31112
31113
31114
# File 'lib/google/apis/compute_alpha/classes.rb', line 31112

def fingerprint
  @fingerprint
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# instance_settings for instance settings. Corresponds to the JSON property kind

Returns:

  • (String)


31118
31119
31120
# File 'lib/google/apis/compute_alpha/classes.rb', line 31118

def kind
  @kind
end

#metadataGoogle::Apis::ComputeAlpha::InstanceSettingsMetadata

The metadata key/value pairs assigned to all the instances in the corresponding scope. Corresponds to the JSON property metadata



31124
31125
31126
# File 'lib/google/apis/compute_alpha/classes.rb', line 31124

def 
  @metadata
end

#zoneString

Output only. [Output Only] URL of the zone where the resource resides You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body. Corresponds to the JSON property zone

Returns:

  • (String)


31131
31132
31133
# File 'lib/google/apis/compute_alpha/classes.rb', line 31131

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



31138
31139
31140
31141
31142
31143
31144
# File 'lib/google/apis/compute_alpha/classes.rb', line 31138

def update!(**args)
  @email = args[:email] if args.key?(:email)
  @fingerprint = args[:fingerprint] if args.key?(:fingerprint)
  @kind = args[:kind] if args.key?(:kind)
  @metadata = args[:metadata] if args.key?(:metadata)
  @zone = args[:zone] if args.key?(:zone)
end