Class: Google::Apis::ComputeAlpha::InstanceSettings
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::InstanceSettings
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Represents a Instance Settings resource. You can use instance settings to configure default settings for Compute Engine VM instances. For example, you can use it to configure default machine type of Compute Engine VM instances.
Instance Attribute Summary collapse
-
#email ⇒ String
Email address of the service account.
-
#fingerprint ⇒ String
Specifies a fingerprint for instance settings, which is essentially a hash of the instance settings resource's contents and used for optimistic locking.
-
#kind ⇒ String
Output only.
-
#metadata ⇒ Google::Apis::ComputeAlpha::InstanceSettingsMetadata
The metadata key/value pairs assigned to all the instances in the corresponding scope.
-
#zone ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceSettings
constructor
A new instance of InstanceSettings.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceSettings
Returns a new instance of InstanceSettings.
30416 30417 30418 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 30416 def initialize(**args) update!(**args) end |
Instance Attribute Details
#email ⇒ String
Email address of the service account.
Corresponds to the JSON property email
30381 30382 30383 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 30381 def email @email end |
#fingerprint ⇒ String
Specifies a fingerprint for instance settings, which is essentially a hash
of the instance settings resource's contents and used for optimistic
locking. The fingerprint is initially generated by Compute Engine and
changes after every request to modify or update the instance settings
resource. You must always provide an up-to-date fingerprint hash in order
to update or change the resource, otherwise the request will fail with
error 412 conditionNotMet.
To see the latest fingerprint, make a get() request to
retrieve the resource.
Corresponds to the JSON property fingerprint
NOTE: Values are automatically base64 encoded/decoded in the client library.
30395 30396 30397 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 30395 def fingerprint @fingerprint end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#
instance_settings for instance settings.
Corresponds to the JSON property kind
30401 30402 30403 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 30401 def kind @kind end |
#metadata ⇒ Google::Apis::ComputeAlpha::InstanceSettingsMetadata
The metadata key/value pairs assigned to all the instances in the
corresponding scope.
Corresponds to the JSON property metadata
30407 30408 30409 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 30407 def @metadata end |
#zone ⇒ String
Output only. [Output Only] URL of the zone where the resource resides
You must specify this field as part of the HTTP request URL. It is not
settable as a field in the request body.
Corresponds to the JSON property zone
30414 30415 30416 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 30414 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
30421 30422 30423 30424 30425 30426 30427 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 30421 def update!(**args) @email = args[:email] if args.key?(:email) @fingerprint = args[:fingerprint] if args.key?(:fingerprint) @kind = args[:kind] if args.key?(:kind) @metadata = args[:metadata] if args.key?(:metadata) @zone = args[:zone] if args.key?(:zone) end |