Class: Google::Apis::ComputeAlpha::InstanceTemplate

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Represents an Instance Template resource. Google Compute Engine has two Instance Template resources:

  • Global
  • Regional You can reuse a global instance template in different regions whereas you can use a regional instance template in a specified region only. If you want to reduce cross-region dependency or achieve data residency, use a regional instance template. To create VMs, managed instance groups, and reservations, you can use either global or regional instance templates. For more information, readInstance Templates.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceTemplate

Returns a new instance of InstanceTemplate.



32654
32655
32656
# File 'lib/google/apis/compute_alpha/classes.rb', line 32654

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#creation_timestampString

Output only. [Output Only] The creation timestamp for this instance template inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


32579
32580
32581
# File 'lib/google/apis/compute_alpha/classes.rb', line 32579

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


32585
32586
32587
# File 'lib/google/apis/compute_alpha/classes.rb', line 32585

def description
  @description
end

#idFixnum

Output only. [Output Only] A unique identifier for this instance template. The server defines this identifier. Corresponds to the JSON property id

Returns:

  • (Fixnum)


32592
32593
32594
# File 'lib/google/apis/compute_alpha/classes.rb', line 32592

def id
  @id
end

#kindString

Output only. [Output Only] The resource type, which is alwayscompute# instanceTemplate for instance templates. Corresponds to the JSON property kind

Returns:

  • (String)


32598
32599
32600
# File 'lib/google/apis/compute_alpha/classes.rb', line 32598

def kind
  @kind
end

#nameString

Name of the resource; provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


32609
32610
32611
# File 'lib/google/apis/compute_alpha/classes.rb', line 32609

def name
  @name
end

#propertiesGoogle::Apis::ComputeAlpha::InstanceProperties

The instance properties for this instance template. Corresponds to the JSON property properties



32614
32615
32616
# File 'lib/google/apis/compute_alpha/classes.rb', line 32614

def properties
  @properties
end

#regionString

Output only. [Output Only] URL of the region where the instance template resides. Only applicable for regional resources. Corresponds to the JSON property region

Returns:

  • (String)


32621
32622
32623
# File 'lib/google/apis/compute_alpha/classes.rb', line 32621

def region
  @region
end

Output only. [Output Only] The URL for this instance template. The server defines this URL. Corresponds to the JSON property selfLink

Returns:

  • (String)


32628
32629
32630
# File 'lib/google/apis/compute_alpha/classes.rb', line 32628

def self_link
  @self_link
end

Output only. [Output Only] Server-defined URL for this resource with the resource id. Corresponds to the JSON property selfLinkWithId

Returns:

  • (String)


32634
32635
32636
# File 'lib/google/apis/compute_alpha/classes.rb', line 32634

def self_link_with_id
  @self_link_with_id
end

#source_instanceString

The source instance used to create the template. You can provide this as a partial or full URL to the resource. For example, the following are valid values:

Returns:

  • (String)


32646
32647
32648
# File 'lib/google/apis/compute_alpha/classes.rb', line 32646

def source_instance
  @source_instance
end

#source_instance_paramsGoogle::Apis::ComputeAlpha::SourceInstanceParams

A specification of the parameters to use when creating the instance template from a source instance. Corresponds to the JSON property sourceInstanceParams



32652
32653
32654
# File 'lib/google/apis/compute_alpha/classes.rb', line 32652

def source_instance_params
  @source_instance_params
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



32659
32660
32661
32662
32663
32664
32665
32666
32667
32668
32669
32670
32671
# File 'lib/google/apis/compute_alpha/classes.rb', line 32659

def update!(**args)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @properties = args[:properties] if args.key?(:properties)
  @region = args[:region] if args.key?(:region)
  @self_link = args[:self_link] if args.key?(:self_link)
  @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id)
  @source_instance = args[:source_instance] if args.key?(:source_instance)
  @source_instance_params = args[:source_instance_params] if args.key?(:source_instance_params)
end