Class: Google::Apis::ComputeAlpha::InstanceTemplateAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of InstanceTemplatesScopedList.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceTemplateAggregatedList

Returns a new instance of InstanceTemplateAggregatedList.



31682
31683
31684
# File 'lib/google/apis/compute_alpha/classes.rb', line 31682

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


31650
31651
31652
# File 'lib/google/apis/compute_alpha/classes.rb', line 31650

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::InstanceTemplatesScopedList>

A list of InstanceTemplatesScopedList resources. Corresponds to the JSON property items



31655
31656
31657
# File 'lib/google/apis/compute_alpha/classes.rb', line 31655

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


31660
31661
31662
# File 'lib/google/apis/compute_alpha/classes.rb', line 31660

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


31670
31671
31672
# File 'lib/google/apis/compute_alpha/classes.rb', line 31670

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


31675
31676
31677
# File 'lib/google/apis/compute_alpha/classes.rb', line 31675

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::InstanceTemplateAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



31680
31681
31682
# File 'lib/google/apis/compute_alpha/classes.rb', line 31680

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



31687
31688
31689
31690
31691
31692
31693
31694
# File 'lib/google/apis/compute_alpha/classes.rb', line 31687

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end