Class: Google::Apis::ComputeAlpha::InstanceTemplateAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::InstanceTemplateAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Contains a list of InstanceTemplatesScopedList.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::InstanceTemplatesScopedList>
A list of InstanceTemplatesScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::InstanceTemplateAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceTemplateAggregatedList
constructor
A new instance of InstanceTemplateAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceTemplateAggregatedList
Returns a new instance of InstanceTemplateAggregatedList.
31467 31468 31469 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 31467 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
31435 31436 31437 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 31435 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::InstanceTemplatesScopedList>
A list of InstanceTemplatesScopedList resources.
Corresponds to the JSON property items
31440 31441 31442 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 31440 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
31445 31446 31447 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 31445 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
31455 31456 31457 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 31455 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
31460 31461 31462 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 31460 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::InstanceTemplateAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
31465 31466 31467 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 31465 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
31472 31473 31474 31475 31476 31477 31478 31479 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 31472 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |