Class: Google::Apis::ComputeAlpha::InstanceTemplateAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of InstanceTemplatesScopedList.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceTemplateAggregatedList

Returns a new instance of InstanceTemplateAggregatedList.



30610
30611
30612
# File 'lib/google/apis/compute_alpha/classes.rb', line 30610

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


30578
30579
30580
# File 'lib/google/apis/compute_alpha/classes.rb', line 30578

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::InstanceTemplatesScopedList>

A list of InstanceTemplatesScopedList resources. Corresponds to the JSON property items



30583
30584
30585
# File 'lib/google/apis/compute_alpha/classes.rb', line 30583

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


30588
30589
30590
# File 'lib/google/apis/compute_alpha/classes.rb', line 30588

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


30598
30599
30600
# File 'lib/google/apis/compute_alpha/classes.rb', line 30598

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


30603
30604
30605
# File 'lib/google/apis/compute_alpha/classes.rb', line 30603

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::InstanceTemplateAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



30608
30609
30610
# File 'lib/google/apis/compute_alpha/classes.rb', line 30608

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



30615
30616
30617
30618
30619
30620
30621
30622
# File 'lib/google/apis/compute_alpha/classes.rb', line 30615

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end