Class: Google::Apis::ComputeAlpha::InstanceTemplateList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::InstanceTemplateList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
A list of instance templates.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::InstanceTemplate>
A list of InstanceTemplate resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::InstanceTemplateList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceTemplateList
constructor
A new instance of InstanceTemplateList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceTemplateList
Returns a new instance of InstanceTemplateList.
32839 32840 32841 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 32839 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
32805 32806 32807 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 32805 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::InstanceTemplate>
A list of InstanceTemplate resources.
Corresponds to the JSON property items
32810 32811 32812 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 32810 def items @items end |
#kind ⇒ String
Output only. [Output Only] The resource type, which is alwayscompute#
instanceTemplatesListResponse for instance template
lists.
Corresponds to the JSON property kind
32817 32818 32819 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 32817 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
32827 32828 32829 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 32827 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
32832 32833 32834 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 32832 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::InstanceTemplateList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
32837 32838 32839 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 32837 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
32844 32845 32846 32847 32848 32849 32850 32851 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 32844 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |