Class: Google::Apis::ComputeAlpha::InstanceTemplateList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

A list of instance templates.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceTemplateList

Returns a new instance of InstanceTemplateList.



30736
30737
30738
# File 'lib/google/apis/compute_alpha/classes.rb', line 30736

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


30702
30703
30704
# File 'lib/google/apis/compute_alpha/classes.rb', line 30702

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::InstanceTemplate>

A list of InstanceTemplate resources. Corresponds to the JSON property items



30707
30708
30709
# File 'lib/google/apis/compute_alpha/classes.rb', line 30707

def items
  @items
end

#kindString

Output only. [Output Only] The resource type, which is alwayscompute# instanceTemplatesListResponse for instance template lists. Corresponds to the JSON property kind

Returns:

  • (String)


30714
30715
30716
# File 'lib/google/apis/compute_alpha/classes.rb', line 30714

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


30724
30725
30726
# File 'lib/google/apis/compute_alpha/classes.rb', line 30724

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


30729
30730
30731
# File 'lib/google/apis/compute_alpha/classes.rb', line 30729

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::InstanceTemplateList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



30734
30735
30736
# File 'lib/google/apis/compute_alpha/classes.rb', line 30734

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



30741
30742
30743
30744
30745
30746
30747
30748
# File 'lib/google/apis/compute_alpha/classes.rb', line 30741

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end