Class: Google::Apis::ComputeAlpha::InstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy

Returns a new instance of InstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy.



32892
32893
32894
# File 'lib/google/apis/compute_alpha/classes.rb', line 32892

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

Output only. [Output Only] Deprecated, please use short name instead. The display name of the firewall policy. Corresponds to the JSON property displayName

Returns:

  • (String)


32853
32854
32855
# File 'lib/google/apis/compute_alpha/classes.rb', line 32853

def display_name
  @display_name
end

#nameString

Output only. [Output Only] The name of the firewall policy. Corresponds to the JSON property name

Returns:

  • (String)


32858
32859
32860
# File 'lib/google/apis/compute_alpha/classes.rb', line 32858

def name
  @name
end

#packet_mirroring_rulesArray<Google::Apis::ComputeAlpha::FirewallPolicyRule>

Output only. [Output Only] The packet mirroring rules that apply to the instance. Corresponds to the JSON property packetMirroringRules



32864
32865
32866
# File 'lib/google/apis/compute_alpha/classes.rb', line 32864

def packet_mirroring_rules
  @packet_mirroring_rules
end

#priorityFixnum

Output only. [Output only] Priority of firewall policy association. Not applicable for type=HIERARCHY. Corresponds to the JSON property priority

Returns:

  • (Fixnum)


32871
32872
32873
# File 'lib/google/apis/compute_alpha/classes.rb', line 32871

def priority
  @priority
end

#rulesArray<Google::Apis::ComputeAlpha::FirewallPolicyRule>

[Output Only] The rules that apply to the instance. Only rules that target the specific VM instance are returned if target service accounts or target secure tags are specified in the rules. Corresponds to the JSON property rules



32878
32879
32880
# File 'lib/google/apis/compute_alpha/classes.rb', line 32878

def rules
  @rules
end

#short_nameString

Output only. [Output Only] The short name of the firewall policy. Corresponds to the JSON property shortName

Returns:

  • (String)


32883
32884
32885
# File 'lib/google/apis/compute_alpha/classes.rb', line 32883

def short_name
  @short_name
end

#typeString

Output only. [Output Only] The type of the firewall policy. Can be one of HIERARCHY, NETWORK, NETWORK_REGIONAL, SYSTEM_GLOBAL, SYSTEM_REGIONAL. Corresponds to the JSON property type

Returns:

  • (String)


32890
32891
32892
# File 'lib/google/apis/compute_alpha/classes.rb', line 32890

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



32897
32898
32899
32900
32901
32902
32903
32904
32905
# File 'lib/google/apis/compute_alpha/classes.rb', line 32897

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @name = args[:name] if args.key?(:name)
  @packet_mirroring_rules = args[:packet_mirroring_rules] if args.key?(:packet_mirroring_rules)
  @priority = args[:priority] if args.key?(:priority)
  @rules = args[:rules] if args.key?(:rules)
  @short_name = args[:short_name] if args.key?(:short_name)
  @type = args[:type] if args.key?(:type)
end