Class: Google::Apis::ComputeAlpha::InstancesSetLabelsRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstancesSetLabelsRequest

Returns a new instance of InstancesSetLabelsRequest.



32399
32400
32401
# File 'lib/google/apis/compute_alpha/classes.rb', line 32399

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#label_fingerprintString

Fingerprint of the previous set of labels for this resource, used to prevent conflicts. Provide the latest fingerprint value when making a request to add or change labels. Corresponds to the JSON property labelFingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


32392
32393
32394
# File 'lib/google/apis/compute_alpha/classes.rb', line 32392

def label_fingerprint
  @label_fingerprint
end

#labelsHash<String,String>

Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


32397
32398
32399
# File 'lib/google/apis/compute_alpha/classes.rb', line 32397

def labels
  @labels
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



32404
32405
32406
32407
# File 'lib/google/apis/compute_alpha/classes.rb', line 32404

def update!(**args)
  @label_fingerprint = args[:label_fingerprint] if args.key?(:label_fingerprint)
  @labels = args[:labels] if args.key?(:labels)
end