Class: Google::Apis::ComputeAlpha::InstantSnapshotGroup
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::InstantSnapshotGroup
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Represents an InstantSnapshotGroup resource. An instant snapshot group is a set of instant snapshots that represents a point in time state of a consistency group.
Instance Attribute Summary collapse
-
#creation_timestamp ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#id ⇒ Fixnum
Output only.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
Identifier.
-
#region ⇒ String
Output only.
-
#resource_status ⇒ Google::Apis::ComputeAlpha::InstantSnapshotGroupResourceStatus
Corresponds to the JSON property
resourceStatus. -
#self_link ⇒ String
Output only.
-
#self_link_with_id ⇒ String
Output only.
-
#source_consistency_group ⇒ String
Corresponds to the JSON property
sourceConsistencyGroup. -
#status ⇒ String
Output only.
-
#zone ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstantSnapshotGroup
constructor
A new instance of InstantSnapshotGroup.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstantSnapshotGroup
Returns a new instance of InstantSnapshotGroup.
32816 32817 32818 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 32816 def initialize(**args) update!(**args) end |
Instance Attribute Details
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
32740 32741 32742 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 32740 def @creation_timestamp end |
#description ⇒ String
Optional. An optional description of this resource. Provide this property when
you
create the resource.
Corresponds to the JSON property description
32747 32748 32749 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 32747 def description @description end |
#id ⇒ Fixnum
Output only. [Output Only] The unique identifier for the resource. This
identifier is
defined by the server.
Corresponds to the JSON property id
32754 32755 32756 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 32754 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#
instantSnapshotGroup for InstantSnapshotGroup
resources.
Corresponds to the JSON property kind
32761 32762 32763 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 32761 def kind @kind end |
#name ⇒ String
Identifier. Name of the resource; provided by the client when the resource is
created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must be
a dash, lowercase letter, or digit, except the last character, which cannot
be a dash.
Corresponds to the JSON property name
32773 32774 32775 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 32773 def name @name end |
#region ⇒ String
Output only. [Output Only] URL of the region where the instant snapshot group
resides.
You must specify this field as part of the HTTP request URL. It is
not settable as a field in the request body.
Corresponds to the JSON property region
32781 32782 32783 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 32781 def region @region end |
#resource_status ⇒ Google::Apis::ComputeAlpha::InstantSnapshotGroupResourceStatus
Corresponds to the JSON property resourceStatus
32786 32787 32788 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 32786 def resource_status @resource_status end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
32791 32792 32793 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 32791 def self_link @self_link end |
#self_link_with_id ⇒ String
Output only. [Output Only] Server-defined URL for this resource's resource id.
Corresponds to the JSON property selfLinkWithId
32796 32797 32798 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 32796 def self_link_with_id @self_link_with_id end |
#source_consistency_group ⇒ String
Corresponds to the JSON property sourceConsistencyGroup
32801 32802 32803 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 32801 def source_consistency_group @source_consistency_group end |
#status ⇒ String
Output only. [Output Only]
Corresponds to the JSON property status
32806 32807 32808 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 32806 def status @status end |
#zone ⇒ String
Output only. [Output Only] URL of the zone where the instant snapshot group
resides.
You must specify this field as part of the HTTP request URL. It is
not settable as a field in the request body.
Corresponds to the JSON property zone
32814 32815 32816 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 32814 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
32821 32822 32823 32824 32825 32826 32827 32828 32829 32830 32831 32832 32833 32834 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 32821 def update!(**args) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @region = args[:region] if args.key?(:region) @resource_status = args[:resource_status] if args.key?(:resource_status) @self_link = args[:self_link] if args.key?(:self_link) @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id) @source_consistency_group = args[:source_consistency_group] if args.key?(:source_consistency_group) @status = args[:status] if args.key?(:status) @zone = args[:zone] if args.key?(:zone) end |