Class: Google::Apis::ComputeAlpha::InstantSnapshotGroup

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Represents an InstantSnapshotGroup resource. An instant snapshot group is a set of instant snapshots that represents a point in time state of a consistency group.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstantSnapshotGroup

Returns a new instance of InstantSnapshotGroup.



31959
31960
31961
# File 'lib/google/apis/compute_alpha/classes.rb', line 31959

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


31883
31884
31885
# File 'lib/google/apis/compute_alpha/classes.rb', line 31883

def creation_timestamp
  @creation_timestamp
end

#descriptionString

Optional. An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


31890
31891
31892
# File 'lib/google/apis/compute_alpha/classes.rb', line 31890

def description
  @description
end

#idFixnum

Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


31897
31898
31899
# File 'lib/google/apis/compute_alpha/classes.rb', line 31897

def id
  @id
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# instantSnapshotGroup for InstantSnapshotGroup resources. Corresponds to the JSON property kind

Returns:

  • (String)


31904
31905
31906
# File 'lib/google/apis/compute_alpha/classes.rb', line 31904

def kind
  @kind
end

#nameString

Identifier. Name of the resource; provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


31916
31917
31918
# File 'lib/google/apis/compute_alpha/classes.rb', line 31916

def name
  @name
end

#regionString

Output only. [Output Only] URL of the region where the instant snapshot group resides. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body. Corresponds to the JSON property region

Returns:

  • (String)


31924
31925
31926
# File 'lib/google/apis/compute_alpha/classes.rb', line 31924

def region
  @region
end

#resource_statusGoogle::Apis::ComputeAlpha::InstantSnapshotGroupResourceStatus

Corresponds to the JSON property resourceStatus



31929
31930
31931
# File 'lib/google/apis/compute_alpha/classes.rb', line 31929

def resource_status
  @resource_status
end

Output only. [Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


31934
31935
31936
# File 'lib/google/apis/compute_alpha/classes.rb', line 31934

def self_link
  @self_link
end

Output only. [Output Only] Server-defined URL for this resource's resource id. Corresponds to the JSON property selfLinkWithId

Returns:

  • (String)


31939
31940
31941
# File 'lib/google/apis/compute_alpha/classes.rb', line 31939

def self_link_with_id
  @self_link_with_id
end

#source_consistency_groupString

Corresponds to the JSON property sourceConsistencyGroup

Returns:

  • (String)


31944
31945
31946
# File 'lib/google/apis/compute_alpha/classes.rb', line 31944

def source_consistency_group
  @source_consistency_group
end

#statusString

Output only. [Output Only] Corresponds to the JSON property status

Returns:

  • (String)


31949
31950
31951
# File 'lib/google/apis/compute_alpha/classes.rb', line 31949

def status
  @status
end

#zoneString

Output only. [Output Only] URL of the zone where the instant snapshot group resides. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body. Corresponds to the JSON property zone

Returns:

  • (String)


31957
31958
31959
# File 'lib/google/apis/compute_alpha/classes.rb', line 31957

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



31964
31965
31966
31967
31968
31969
31970
31971
31972
31973
31974
31975
31976
31977
# File 'lib/google/apis/compute_alpha/classes.rb', line 31964

def update!(**args)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @region = args[:region] if args.key?(:region)
  @resource_status = args[:resource_status] if args.key?(:resource_status)
  @self_link = args[:self_link] if args.key?(:self_link)
  @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id)
  @source_consistency_group = args[:source_consistency_group] if args.key?(:source_consistency_group)
  @status = args[:status] if args.key?(:status)
  @zone = args[:zone] if args.key?(:zone)
end