Class: Google::Apis::ComputeAlpha::InstantSnapshotList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of InstantSnapshot resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstantSnapshotList

Returns a new instance of InstantSnapshotList.



34199
34200
34201
# File 'lib/google/apis/compute_alpha/classes.rb', line 34199

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


34167
34168
34169
# File 'lib/google/apis/compute_alpha/classes.rb', line 34167

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::InstantSnapshot>

A list of InstantSnapshot resources. Corresponds to the JSON property items



34172
34173
34174
# File 'lib/google/apis/compute_alpha/classes.rb', line 34172

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


34177
34178
34179
# File 'lib/google/apis/compute_alpha/classes.rb', line 34177

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


34187
34188
34189
# File 'lib/google/apis/compute_alpha/classes.rb', line 34187

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


34192
34193
34194
# File 'lib/google/apis/compute_alpha/classes.rb', line 34192

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::InstantSnapshotList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



34197
34198
34199
# File 'lib/google/apis/compute_alpha/classes.rb', line 34197

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



34204
34205
34206
34207
34208
34209
34210
34211
# File 'lib/google/apis/compute_alpha/classes.rb', line 34204

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end