Class: Google::Apis::ComputeAlpha::InstantSnapshotList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of InstantSnapshot resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstantSnapshotList

Returns a new instance of InstantSnapshotList.



33920
33921
33922
# File 'lib/google/apis/compute_alpha/classes.rb', line 33920

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


33888
33889
33890
# File 'lib/google/apis/compute_alpha/classes.rb', line 33888

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::InstantSnapshot>

A list of InstantSnapshot resources. Corresponds to the JSON property items



33893
33894
33895
# File 'lib/google/apis/compute_alpha/classes.rb', line 33893

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


33898
33899
33900
# File 'lib/google/apis/compute_alpha/classes.rb', line 33898

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


33908
33909
33910
# File 'lib/google/apis/compute_alpha/classes.rb', line 33908

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


33913
33914
33915
# File 'lib/google/apis/compute_alpha/classes.rb', line 33913

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::InstantSnapshotList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



33918
33919
33920
# File 'lib/google/apis/compute_alpha/classes.rb', line 33918

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



33925
33926
33927
33928
33929
33930
33931
33932
# File 'lib/google/apis/compute_alpha/classes.rb', line 33925

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end