Class: Google::Apis::ComputeAlpha::InstantSnapshotList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::InstantSnapshotList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Contains a list of InstantSnapshot resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::InstantSnapshot>
A list of InstantSnapshot resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::InstantSnapshotList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstantSnapshotList
constructor
A new instance of InstantSnapshotList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstantSnapshotList
Returns a new instance of InstantSnapshotList.
33168 33169 33170 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 33168 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
33136 33137 33138 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 33136 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::InstantSnapshot>
A list of InstantSnapshot resources.
Corresponds to the JSON property items
33141 33142 33143 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 33141 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
33146 33147 33148 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 33146 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
33156 33157 33158 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 33156 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
33161 33162 33163 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 33161 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::InstantSnapshotList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
33166 33167 33168 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 33166 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
33173 33174 33175 33176 33177 33178 33179 33180 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 33173 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |