Class: Google::Apis::ComputeAlpha::InstantSnapshotList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of InstantSnapshot resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstantSnapshotList

Returns a new instance of InstantSnapshotList.



32096
32097
32098
# File 'lib/google/apis/compute_alpha/classes.rb', line 32096

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


32064
32065
32066
# File 'lib/google/apis/compute_alpha/classes.rb', line 32064

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::InstantSnapshot>

A list of InstantSnapshot resources. Corresponds to the JSON property items



32069
32070
32071
# File 'lib/google/apis/compute_alpha/classes.rb', line 32069

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


32074
32075
32076
# File 'lib/google/apis/compute_alpha/classes.rb', line 32074

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


32084
32085
32086
# File 'lib/google/apis/compute_alpha/classes.rb', line 32084

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


32089
32090
32091
# File 'lib/google/apis/compute_alpha/classes.rb', line 32089

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::InstantSnapshotList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



32094
32095
32096
# File 'lib/google/apis/compute_alpha/classes.rb', line 32094

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



32101
32102
32103
32104
32105
32106
32107
32108
# File 'lib/google/apis/compute_alpha/classes.rb', line 32101

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end