Class: Google::Apis::ComputeAlpha::InstantSnapshotParams
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::InstantSnapshotParams
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Additional instant snapshot params.
Instance Attribute Summary collapse
-
#resource_manager_tags ⇒ Hash<String,String>
Input only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstantSnapshotParams
constructor
A new instance of InstantSnapshotParams.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstantSnapshotParams
Returns a new instance of InstantSnapshotParams.
33261 33262 33263 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 33261 def initialize(**args) update!(**args) end |
Instance Attribute Details
#resource_manager_tags ⇒ Hash<String,String>
Input only. Resource manager tags to be bound to the instant snapshot. Tag
keys and
values have the same definition as resource
manager tags. Keys and values can be either in numeric format,
such as tagKeys/tag_key_idand `tagValues/`tag_value_id or in
namespaced format such as org_id|project_id`/`tag_key_short_name and
tag_value_short_name. The field is ignored (both PUT &
PATCH) when empty.
Corresponds to the JSON property resourceManagerTags
33259 33260 33261 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 33259 def @resource_manager_tags end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
33266 33267 33268 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 33266 def update!(**args) @resource_manager_tags = args[:resource_manager_tags] if args.key?(:resource_manager_tags) end |