Class: Google::Apis::ComputeAlpha::InstantSnapshotParams
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::InstantSnapshotParams
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Additional instant snapshot params.
Instance Attribute Summary collapse
-
#resource_manager_tags ⇒ Hash<String,String>
Input only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstantSnapshotParams
constructor
A new instance of InstantSnapshotParams.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstantSnapshotParams
Returns a new instance of InstantSnapshotParams.
32914 32915 32916 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 32914 def initialize(**args) update!(**args) end |
Instance Attribute Details
#resource_manager_tags ⇒ Hash<String,String>
Input only. Resource manager tags to be bound to the instant snapshot. Tag
keys and
values have the same definition as resource
manager tags. Keys and values can be either in numeric format,
such as tagKeys/tag_key_idand `tagValues/`tag_value_id or in
namespaced format such as org_id|project_id`/`tag_key_short_name and
tag_value_short_name. The field is ignored (both PUT &
PATCH) when empty.
Corresponds to the JSON property resourceManagerTags
32912 32913 32914 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 32912 def @resource_manager_tags end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
32919 32920 32921 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 32919 def update!(**args) @resource_manager_tags = args[:resource_manager_tags] if args.key?(:resource_manager_tags) end |