Class: Google::Apis::ComputeAlpha::Interconnect
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::Interconnect
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Represents an Interconnect resource. An Interconnect resource is a dedicated connection between the Google Cloud network and your on-premises network. For more information, read the Dedicated Interconnect Overview.
Instance Attribute Summary collapse
-
#aai_enabled ⇒ Boolean
(also: #aai_enabled?)
Enable or disable the application awareness feature on this Cloud Interconnect.
-
#admin_enabled ⇒ Boolean
(also: #admin_enabled?)
Administrative status of the interconnect.
-
#application_aware_interconnect ⇒ Google::Apis::ComputeAlpha::InterconnectApplicationAwareInterconnect
Configuration information for application awareness on this Cloud Interconnect.
-
#available_features ⇒ Array<String>
[Output only] List of features available for this Interconnect connection, which can take one of the following values:.
-
#circuit_infos ⇒ Array<Google::Apis::ComputeAlpha::InterconnectCircuitInfo>
Output only.
-
#creation_timestamp ⇒ String
Output only.
-
#customer_name ⇒ String
Customer name, to put in the Letter of Authorization as the party authorized to request a crossconnect.
-
#description ⇒ String
An optional description of this resource.
-
#effective_location ⇒ String
Output only.
-
#expected_outages ⇒ Array<Google::Apis::ComputeAlpha::InterconnectOutageNotification>
Output only.
-
#google_ip_address ⇒ String
Output only.
-
#google_reference_id ⇒ String
Output only.
-
#id ⇒ Fixnum
Output only.
-
#interconnect_attachments ⇒ Array<String>
Output only.
-
#interconnect_groups ⇒ Array<String>
Output only.
-
#interconnect_type ⇒ String
Type of interconnect, which can take one of the following values:.
-
#kind ⇒ String
Output only.
-
#label_fingerprint ⇒ String
A fingerprint for the labels being applied to this Interconnect, which is essentially a hash of the labels set used for optimistic locking.
-
#labels ⇒ Hash<String,String>
Labels for this resource.
-
#link_type ⇒ String
Type of link requested, which can take one of the following values:.
-
#location ⇒ String
URL of the InterconnectLocation object that represents where this connection is to be provisioned.
-
#macsec ⇒ Google::Apis::ComputeAlpha::InterconnectMacsec
Configuration information for enabling Media Access Control security (MACsec) on this Cloud Interconnect connection between Google and your on-premises router.
-
#macsec_enabled ⇒ Boolean
(also: #macsec_enabled?)
Enable or disable MACsec on this Interconnect connection.
-
#name ⇒ String
Name of the resource.
-
#noc_contact_email ⇒ String
Email address to contact the customer NOC for operations and maintenance notifications regarding this Interconnect.
-
#operational_status ⇒ String
Output only.
-
#params ⇒ Google::Apis::ComputeAlpha::InterconnectParams
Additional interconnect parameters.
-
#peer_ip_address ⇒ String
Output only.
-
#provisioned_link_count ⇒ Fixnum
Output only.
-
#remote_location ⇒ String
Indicates that this is a Cross-Cloud Interconnect.
-
#requested_features ⇒ Array<String>
Optional.
-
#requested_link_count ⇒ Fixnum
Target number of physical links in the link bundle, as requested by the customer.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
Output only.
-
#self_link ⇒ String
Output only.
-
#self_link_with_id ⇒ String
Output only.
-
#state ⇒ String
Output only.
-
#subzone ⇒ String
To be deprecated.
-
#wire_groups ⇒ Array<String>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Interconnect
constructor
A new instance of Interconnect.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Interconnect
Returns a new instance of Interconnect.
34483 34484 34485 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 34483 def initialize(**args) update!(**args) end |
Instance Attribute Details
#aai_enabled ⇒ Boolean Also known as: aai_enabled?
Enable or disable the application awareness feature on this Cloud
Interconnect.
Corresponds to the JSON property aaiEnabled
34184 34185 34186 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 34184 def aai_enabled @aai_enabled end |
#admin_enabled ⇒ Boolean Also known as: admin_enabled?
Administrative status of the interconnect. When this is set to true, the
Interconnect is functional and can carry traffic.
When set to false, no packets can be carried over the interconnect and
no BGP routes are exchanged over it. By default, the status is set to true.
Corresponds to the JSON property adminEnabled
34193 34194 34195 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 34193 def admin_enabled @admin_enabled end |
#application_aware_interconnect ⇒ Google::Apis::ComputeAlpha::InterconnectApplicationAwareInterconnect
Configuration information for application awareness on this Cloud
Interconnect.
Corresponds to the JSON property applicationAwareInterconnect
34200 34201 34202 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 34200 def application_aware_interconnect @application_aware_interconnect end |
#available_features ⇒ Array<String>
[Output only] List of features available for this Interconnect connection, which can take one of the following values:
- IF_MACSEC: If present, then the Interconnect connection is provisioned on MACsec capable hardware ports. If not present, then the Interconnect connection is provisioned on non-MACsec capable ports. Any attempt to enable MACsec will fail.
- IF_CROSS_SITE_NETWORK: If present, then the Interconnect connection is
provisioned exclusively for Cross-Site Networking. Any attempt to configure
VLAN attachments will fail. If not present, then the Interconnect
connection is not provisioned for Cross-Site Networking. Any attempt to use
it for Cross-Site Networking will fail.
Corresponds to the JSON property
availableFeatures
34216 34217 34218 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 34216 def available_features @available_features end |
#circuit_infos ⇒ Array<Google::Apis::ComputeAlpha::InterconnectCircuitInfo>
Output only. [Output Only] A list of CircuitInfo objects, that describe the
individual
circuits in this LAG.
Corresponds to the JSON property circuitInfos
34223 34224 34225 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 34223 def circuit_infos @circuit_infos end |
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
34229 34230 34231 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 34229 def @creation_timestamp end |
#customer_name ⇒ String
Customer name, to put in the Letter of Authorization as the party
authorized to request a crossconnect.
Corresponds to the JSON property customerName
34235 34236 34237 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 34235 def customer_name @customer_name end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
34241 34242 34243 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 34241 def description @description end |
#effective_location ⇒ String
Output only. URL of the InterconnectLocation object that represents where
this connection is to be provisioned. By default it will be the same as the
location field.
Corresponds to the JSON property effectiveLocation
34248 34249 34250 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 34248 def effective_location @effective_location end |
#expected_outages ⇒ Array<Google::Apis::ComputeAlpha::InterconnectOutageNotification>
Output only. [Output Only] A list of outages expected for this Interconnect.
Corresponds to the JSON property expectedOutages
34253 34254 34255 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 34253 def expected_outages @expected_outages end |
#google_ip_address ⇒ String
Output only. [Output Only] IP address configured on the Google side of the
Interconnect
link. This can be used only for ping tests.
Corresponds to the JSON property googleIpAddress
34260 34261 34262 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 34260 def google_ip_address @google_ip_address end |
#google_reference_id ⇒ String
Output only. [Output Only] Google reference ID to be used when raising support
tickets
with Google or otherwise to debug backend connectivity issues.
Corresponds to the JSON property googleReferenceId
34267 34268 34269 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 34267 def google_reference_id @google_reference_id end |
#id ⇒ Fixnum
Output only. [Output Only] The unique identifier for the resource. This
identifier is
defined by the server.
Corresponds to the JSON property id
34274 34275 34276 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 34274 def id @id end |
#interconnect_attachments ⇒ Array<String>
Output only. [Output Only] A list of the URLs of all InterconnectAttachments
configured
to use this Interconnect.
Corresponds to the JSON property interconnectAttachments
34281 34282 34283 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 34281 def @interconnect_attachments end |
#interconnect_groups ⇒ Array<String>
Output only. [Output Only] URLs of InterconnectGroups that include this
Interconnect.
Order is arbitrary and items are unique.
Corresponds to the JSON property interconnectGroups
34288 34289 34290 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 34288 def interconnect_groups @interconnect_groups end |
#interconnect_type ⇒ String
Type of interconnect, which can take one of the following values:
- PARTNER: A partner-managed interconnection shared between customers though a partner.
- DEDICATED: A dedicated physical interconnection with the
customer.
Note that a value IT_PRIVATE has been deprecated in favor of DEDICATED.
Corresponds to the JSON property
interconnectType
34299 34300 34301 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 34299 def interconnect_type @interconnect_type end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#interconnect
for interconnects.
Corresponds to the JSON property kind
34305 34306 34307 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 34305 def kind @kind end |
#label_fingerprint ⇒ String
A fingerprint for the labels being applied to this Interconnect, which
is essentially a hash of the labels set used for optimistic locking. The
fingerprint is initially generated by Compute Engine and changes after
every request to modify or update labels. You must always provide an
up-to-date fingerprint hash in order to update or change labels,
otherwise the request will fail with error412 conditionNotMet.
To see the latest fingerprint, make a get() request to
retrieve an Interconnect.
Corresponds to the JSON property labelFingerprint
NOTE: Values are automatically base64 encoded/decoded in the client library.
34318 34319 34320 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 34318 def label_fingerprint @label_fingerprint end |
#labels ⇒ Hash<String,String>
Labels for this resource. These can only be added or modified by thesetLabels
method. Each label key/value pair must comply withRFC1035.
Label values may be empty.
Corresponds to the JSON property labels
34325 34326 34327 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 34325 def labels @labels end |
#link_type ⇒ String
Type of link requested, which can take one of the following values:
- LINK_TYPE_ETHERNET_10G_LR: A 10G Ethernet with LR optics
- LINK_TYPE_ETHERNET_100G_LR: A 100G Ethernet with LR optics.
- LINK_TYPE_ETHERNET_400G_LR4: A 400G Ethernet with LR4 optics.
Note that this field indicates the speed of each of
the links in the bundle, not the speed of the entire bundle.
Corresponds to the JSON property
linkType
34336 34337 34338 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 34336 def link_type @link_type end |
#location ⇒ String
URL of the InterconnectLocation object that represents where this
connection is to be provisioned.
Corresponds to the JSON property location
34342 34343 34344 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 34342 def location @location end |
#macsec ⇒ Google::Apis::ComputeAlpha::InterconnectMacsec
Configuration information for enabling Media Access Control security
(MACsec) on this Cloud Interconnect connection between Google and your
on-premises router.
Corresponds to the JSON property macsec
34349 34350 34351 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 34349 def macsec @macsec end |
#macsec_enabled ⇒ Boolean Also known as: macsec_enabled?
Enable or disable MACsec on this Interconnect connection. MACsec enablement
fails if the MACsec object is not specified.
Corresponds to the JSON property macsecEnabled
34355 34356 34357 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 34355 def macsec_enabled @macsec_enabled end |
#name ⇒ String
Name of the resource. Provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must be
a dash, lowercase letter, or digit, except the last character, which cannot
be a dash.
Corresponds to the JSON property name
34367 34368 34369 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 34367 def name @name end |
#noc_contact_email ⇒ String
Email address to contact the customer NOC for operations and maintenance
notifications regarding this Interconnect. If specified, this will be used
for notifications in addition to all other forms described, such as
Cloud Monitoring logs alerting and Cloud Notifications. This field is
required for users who sign up for Cloud Interconnect using
workforce identity federation.
Corresponds to the JSON property nocContactEmail
34377 34378 34379 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 34377 def noc_contact_email @noc_contact_email end |
#operational_status ⇒ String
Output only. [Output Only] The current status of this Interconnect's functionality, which can take one of the following values:
- OS_ACTIVE: A valid Interconnect, which is turned up and is ready to use. Attachments may be provisioned on this Interconnect.
- OS_UNPROVISIONED: An Interconnect that has not completed turnup. No attachments may be provisioned on this Interconnect.
- OS_UNDER_MAINTENANCE: An Interconnect that is undergoing internal
maintenance. No attachments may be provisioned or updated on this
Interconnect.
Corresponds to the JSON property
operationalStatus
34392 34393 34394 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 34392 def operational_status @operational_status end |
#params ⇒ Google::Apis::ComputeAlpha::InterconnectParams
Additional interconnect parameters.
Corresponds to the JSON property params
34397 34398 34399 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 34397 def params @params end |
#peer_ip_address ⇒ String
Output only. [Output Only] IP address configured on the customer side of the
Interconnect link. The customer should configure this IP address during
turnup when prompted by Google NOC. This can be used only for ping tests.
Corresponds to the JSON property peerIpAddress
34404 34405 34406 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 34404 def peer_ip_address @peer_ip_address end |
#provisioned_link_count ⇒ Fixnum
Output only. [Output Only] Number of links actually provisioned in this
interconnect.
Corresponds to the JSON property provisionedLinkCount
34410 34411 34412 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 34410 def provisioned_link_count @provisioned_link_count end |
#remote_location ⇒ String
Indicates that this is a Cross-Cloud Interconnect. This field specifies the
location outside of Google's network that the interconnect is connected to.
Corresponds to the JSON property remoteLocation
34416 34417 34418 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 34416 def remote_location @remote_location end |
#requested_features ⇒ Array<String>
Optional. This parameter can be provided only with Interconnect INSERT. It isn't valid for Interconnect PATCH. List of features requested for this Interconnect connection, which can take one of the following values:
- IF_MACSEC: If specified, then the connection is created on MACsec capable hardware ports. If not specified, non-MACsec capable ports will also be considered.
- IF_CROSS_SITE_NETWORK: If specified, then the connection is created
exclusively for Cross-Site Networking. The connection can not be used for
Cross-Site Networking unless this feature is specified.
Corresponds to the JSON property
requestedFeatures
34430 34431 34432 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 34430 def requested_features @requested_features end |
#requested_link_count ⇒ Fixnum
Target number of physical links in the link bundle, as requested by the
customer.
Corresponds to the JSON property requestedLinkCount
34436 34437 34438 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 34436 def requested_link_count @requested_link_count end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
Output only. [Output Only] Reserved for future use.
Corresponds to the JSON property satisfiesPzs
34441 34442 34443 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 34441 def satisfies_pzs @satisfies_pzs end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
34447 34448 34449 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 34447 def self_link @self_link end |
#self_link_with_id ⇒ String
Output only. [Output Only] Server-defined URL for this resource with the
resource id.
Corresponds to the JSON property selfLinkWithId
34453 34454 34455 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 34453 def self_link_with_id @self_link_with_id end |
#state ⇒ String
Output only. [Output Only] The current state of Interconnect functionality, which can take one of the following values:
- ACTIVE: The Interconnect is valid, turned up and ready to use. Attachments may be provisioned on this Interconnect.
- UNPROVISIONED: The Interconnect has not completed turnup. No attachments may be provisioned on this Interconnect.
- UNDER_MAINTENANCE: The Interconnect is undergoing internal maintenance.
No attachments may be provisioned or updated on this
Interconnect.
Corresponds to the JSON property
state
34468 34469 34470 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 34468 def state @state end |
#subzone ⇒ String
To be deprecated.
Corresponds to the JSON property subzone
34473 34474 34475 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 34473 def subzone @subzone end |
#wire_groups ⇒ Array<String>
Output only. [Output Only] A list of the URLs of all CrossSiteNetwork
WireGroups
configured to use this Interconnect. The Interconnect cannot be deleted if
this list is non-empty.
Corresponds to the JSON property wireGroups
34481 34482 34483 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 34481 def wire_groups @wire_groups end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
34488 34489 34490 34491 34492 34493 34494 34495 34496 34497 34498 34499 34500 34501 34502 34503 34504 34505 34506 34507 34508 34509 34510 34511 34512 34513 34514 34515 34516 34517 34518 34519 34520 34521 34522 34523 34524 34525 34526 34527 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 34488 def update!(**args) @aai_enabled = args[:aai_enabled] if args.key?(:aai_enabled) @admin_enabled = args[:admin_enabled] if args.key?(:admin_enabled) @application_aware_interconnect = args[:application_aware_interconnect] if args.key?(:application_aware_interconnect) @available_features = args[:available_features] if args.key?(:available_features) @circuit_infos = args[:circuit_infos] if args.key?(:circuit_infos) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @customer_name = args[:customer_name] if args.key?(:customer_name) @description = args[:description] if args.key?(:description) @effective_location = args[:effective_location] if args.key?(:effective_location) @expected_outages = args[:expected_outages] if args.key?(:expected_outages) @google_ip_address = args[:google_ip_address] if args.key?(:google_ip_address) @google_reference_id = args[:google_reference_id] if args.key?(:google_reference_id) @id = args[:id] if args.key?(:id) @interconnect_attachments = args[:interconnect_attachments] if args.key?(:interconnect_attachments) @interconnect_groups = args[:interconnect_groups] if args.key?(:interconnect_groups) @interconnect_type = args[:interconnect_type] if args.key?(:interconnect_type) @kind = args[:kind] if args.key?(:kind) @label_fingerprint = args[:label_fingerprint] if args.key?(:label_fingerprint) @labels = args[:labels] if args.key?(:labels) @link_type = args[:link_type] if args.key?(:link_type) @location = args[:location] if args.key?(:location) @macsec = args[:macsec] if args.key?(:macsec) @macsec_enabled = args[:macsec_enabled] if args.key?(:macsec_enabled) @name = args[:name] if args.key?(:name) @noc_contact_email = args[:noc_contact_email] if args.key?(:noc_contact_email) @operational_status = args[:operational_status] if args.key?(:operational_status) @params = args[:params] if args.key?(:params) @peer_ip_address = args[:peer_ip_address] if args.key?(:peer_ip_address) @provisioned_link_count = args[:provisioned_link_count] if args.key?(:provisioned_link_count) @remote_location = args[:remote_location] if args.key?(:remote_location) @requested_features = args[:requested_features] if args.key?(:requested_features) @requested_link_count = args[:requested_link_count] if args.key?(:requested_link_count) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @self_link = args[:self_link] if args.key?(:self_link) @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id) @state = args[:state] if args.key?(:state) @subzone = args[:subzone] if args.key?(:subzone) @wire_groups = args[:wire_groups] if args.key?(:wire_groups) end |