Class: Google::Apis::ComputeAlpha::InterconnectApplicationAwareInterconnect

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Configuration information for application awareness on this Cloud Interconnect.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectApplicationAwareInterconnect

Returns a new instance of InterconnectApplicationAwareInterconnect.



34558
34559
34560
# File 'lib/google/apis/compute_alpha/classes.rb', line 34558

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bandwidth_percentage_policyGoogle::Apis::ComputeAlpha::InterconnectApplicationAwareInterconnectBandwidthPercentagePolicy

Corresponds to the JSON property bandwidthPercentagePolicy



34538
34539
34540
# File 'lib/google/apis/compute_alpha/classes.rb', line 34538

def bandwidth_percentage_policy
  @bandwidth_percentage_policy
end

#profile_descriptionString

Description for the application awareness profile on this Cloud Interconnect. Corresponds to the JSON property profileDescription

Returns:

  • (String)


34544
34545
34546
# File 'lib/google/apis/compute_alpha/classes.rb', line 34544

def profile_description
  @profile_description
end

#shape_average_percentagesArray<Google::Apis::ComputeAlpha::InterconnectApplicationAwareInterconnectBandwidthPercentage>

Optional field to specify a list of shape average percentages to be applied in conjunction with StrictPriorityPolicy or BandwidthPercentagePolicy. Corresponds to the JSON property shapeAveragePercentages



34551
34552
34553
# File 'lib/google/apis/compute_alpha/classes.rb', line 34551

def shape_average_percentages
  @shape_average_percentages
end

#strict_priority_policyGoogle::Apis::ComputeAlpha::InterconnectApplicationAwareInterconnectStrictPriorityPolicy

Specify configuration for StrictPriorityPolicy. Corresponds to the JSON property strictPriorityPolicy



34556
34557
34558
# File 'lib/google/apis/compute_alpha/classes.rb', line 34556

def strict_priority_policy
  @strict_priority_policy
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



34563
34564
34565
34566
34567
34568
# File 'lib/google/apis/compute_alpha/classes.rb', line 34563

def update!(**args)
  @bandwidth_percentage_policy = args[:bandwidth_percentage_policy] if args.key?(:bandwidth_percentage_policy)
  @profile_description = args[:profile_description] if args.key?(:profile_description)
  @shape_average_percentages = args[:shape_average_percentages] if args.key?(:shape_average_percentages)
  @strict_priority_policy = args[:strict_priority_policy] if args.key?(:strict_priority_policy)
end