Class: Google::Apis::ComputeAlpha::InterconnectApplicationAwareInterconnect
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::InterconnectApplicationAwareInterconnect
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Configuration information for application awareness on this Cloud Interconnect.
Instance Attribute Summary collapse
-
#bandwidth_percentage_policy ⇒ Google::Apis::ComputeAlpha::InterconnectApplicationAwareInterconnectBandwidthPercentagePolicy
Corresponds to the JSON property
bandwidthPercentagePolicy. -
#profile_description ⇒ String
Description for the application awareness profile on this Cloud Interconnect.
-
#shape_average_percentages ⇒ Array<Google::Apis::ComputeAlpha::InterconnectApplicationAwareInterconnectBandwidthPercentage>
Optional field to specify a list of shape average percentages to be applied in conjunction with StrictPriorityPolicy or BandwidthPercentagePolicy.
-
#strict_priority_policy ⇒ Google::Apis::ComputeAlpha::InterconnectApplicationAwareInterconnectStrictPriorityPolicy
Specify configuration for StrictPriorityPolicy.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InterconnectApplicationAwareInterconnect
constructor
A new instance of InterconnectApplicationAwareInterconnect.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InterconnectApplicationAwareInterconnect
Returns a new instance of InterconnectApplicationAwareInterconnect.
33798 33799 33800 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 33798 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bandwidth_percentage_policy ⇒ Google::Apis::ComputeAlpha::InterconnectApplicationAwareInterconnectBandwidthPercentagePolicy
Corresponds to the JSON property bandwidthPercentagePolicy
33778 33779 33780 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 33778 def bandwidth_percentage_policy @bandwidth_percentage_policy end |
#profile_description ⇒ String
Description for the application awareness profile on this Cloud
Interconnect.
Corresponds to the JSON property profileDescription
33784 33785 33786 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 33784 def profile_description @profile_description end |
#shape_average_percentages ⇒ Array<Google::Apis::ComputeAlpha::InterconnectApplicationAwareInterconnectBandwidthPercentage>
Optional field to specify a list of shape average percentages to be
applied in conjunction with StrictPriorityPolicy or
BandwidthPercentagePolicy.
Corresponds to the JSON property shapeAveragePercentages
33791 33792 33793 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 33791 def shape_average_percentages @shape_average_percentages end |
#strict_priority_policy ⇒ Google::Apis::ComputeAlpha::InterconnectApplicationAwareInterconnectStrictPriorityPolicy
Specify configuration for StrictPriorityPolicy.
Corresponds to the JSON property strictPriorityPolicy
33796 33797 33798 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 33796 def strict_priority_policy @strict_priority_policy end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
33803 33804 33805 33806 33807 33808 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 33803 def update!(**args) @bandwidth_percentage_policy = args[:bandwidth_percentage_policy] if args.key?(:bandwidth_percentage_policy) @profile_description = args[:profile_description] if args.key?(:profile_description) @shape_average_percentages = args[:shape_average_percentages] if args.key?(:shape_average_percentages) @strict_priority_policy = args[:strict_priority_policy] if args.key?(:strict_priority_policy) end |