Class: Google::Apis::ComputeAlpha::InterconnectApplicationAwareInterconnect

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Configuration information for application awareness on this Cloud Interconnect.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectApplicationAwareInterconnect

Returns a new instance of InterconnectApplicationAwareInterconnect.



32735
32736
32737
# File 'lib/google/apis/compute_alpha/classes.rb', line 32735

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bandwidth_percentage_policyGoogle::Apis::ComputeAlpha::InterconnectApplicationAwareInterconnectBandwidthPercentagePolicy

Corresponds to the JSON property bandwidthPercentagePolicy



32715
32716
32717
# File 'lib/google/apis/compute_alpha/classes.rb', line 32715

def bandwidth_percentage_policy
  @bandwidth_percentage_policy
end

#profile_descriptionString

Description for the application awareness profile on this Cloud Interconnect. Corresponds to the JSON property profileDescription

Returns:

  • (String)


32721
32722
32723
# File 'lib/google/apis/compute_alpha/classes.rb', line 32721

def profile_description
  @profile_description
end

#shape_average_percentagesArray<Google::Apis::ComputeAlpha::InterconnectApplicationAwareInterconnectBandwidthPercentage>

Optional field to specify a list of shape average percentages to be applied in conjunction with StrictPriorityPolicy or BandwidthPercentagePolicy. Corresponds to the JSON property shapeAveragePercentages



32728
32729
32730
# File 'lib/google/apis/compute_alpha/classes.rb', line 32728

def shape_average_percentages
  @shape_average_percentages
end

#strict_priority_policyGoogle::Apis::ComputeAlpha::InterconnectApplicationAwareInterconnectStrictPriorityPolicy

Specify configuration for StrictPriorityPolicy. Corresponds to the JSON property strictPriorityPolicy



32733
32734
32735
# File 'lib/google/apis/compute_alpha/classes.rb', line 32733

def strict_priority_policy
  @strict_priority_policy
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



32740
32741
32742
32743
32744
32745
# File 'lib/google/apis/compute_alpha/classes.rb', line 32740

def update!(**args)
  @bandwidth_percentage_policy = args[:bandwidth_percentage_policy] if args.key?(:bandwidth_percentage_policy)
  @profile_description = args[:profile_description] if args.key?(:profile_description)
  @shape_average_percentages = args[:shape_average_percentages] if args.key?(:shape_average_percentages)
  @strict_priority_policy = args[:strict_priority_policy] if args.key?(:strict_priority_policy)
end