Class: Google::Apis::ComputeAlpha::InterconnectAttachment

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Represents an Interconnect Attachment (VLAN) resource. You can use Interconnect attachments (VLANS) to connect your Virtual Private Cloud networks to your on-premises networks through an Interconnect. For more information, read Creating VLAN Attachments.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectAttachment

Returns a new instance of InterconnectAttachment.



34338
34339
34340
# File 'lib/google/apis/compute_alpha/classes.rb', line 34338

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#admin_enabledBoolean Also known as: admin_enabled?

Determines whether this Attachment will carry packets. Not present for PARTNER_PROVIDER. Corresponds to the JSON property adminEnabled

Returns:

  • (Boolean)


33891
33892
33893
# File 'lib/google/apis/compute_alpha/classes.rb', line 33891

def admin_enabled
  @admin_enabled
end

#attachment_groupString

Output only. [Output Only] URL of the AttachmentGroup that includes this Attachment. Corresponds to the JSON property attachmentGroup

Returns:

  • (String)


33898
33899
33900
# File 'lib/google/apis/compute_alpha/classes.rb', line 33898

def attachment_group
  @attachment_group
end

#bandwidthString

Provisioned bandwidth capacity for the interconnect attachment. For attachments of type DEDICATED, the user can set the bandwidth. For attachments of type PARTNER, the Google Partner that is operating the interconnect must set the bandwidth. Output only for PARTNER type, mutable for PARTNER_PROVIDER and DEDICATED, and can take one of the following values:

  • BPS_50M: 50 Mbit/s
  • BPS_100M: 100 Mbit/s
  • BPS_200M: 200 Mbit/s
  • BPS_300M: 300 Mbit/s
  • BPS_400M: 400 Mbit/s
  • BPS_500M: 500 Mbit/s
  • BPS_1G: 1 Gbit/s
  • BPS_2G: 2 Gbit/s
  • BPS_5G: 5 Gbit/s
  • BPS_10G: 10 Gbit/s
  • BPS_20G: 20 Gbit/s
  • BPS_50G: 50 Gbit/s
  • BPS_100G: 100 Gbit/s
  • BPS_400G: 400 Gbit/s Corresponds to the JSON property bandwidth

Returns:

  • (String)


33923
33924
33925
# File 'lib/google/apis/compute_alpha/classes.rb', line 33923

def bandwidth
  @bandwidth
end

#candidate_cloud_router_ip_addressString

Single IPv4 address + prefix length to be configured on the cloud router interface for this interconnect attachment.

  • Both candidate_cloud_router_ip_address and candidate_customer_router_ip_address fields must be set or both must be unset.
  • Prefix length of both candidate_cloud_router_ip_address and candidate_customer_router_ip_address must be the same.
  • Max prefix length is 31. Corresponds to the JSON property candidateCloudRouterIpAddress

Returns:

  • (String)


33936
33937
33938
# File 'lib/google/apis/compute_alpha/classes.rb', line 33936

def candidate_cloud_router_ip_address
  @candidate_cloud_router_ip_address
end

#candidate_cloud_router_ipv6_addressString

Single IPv6 address + prefix length to be configured on the cloud router interface for this interconnect attachment.

  • Both candidate_cloud_router_ipv6_address and candidate_customer_router_ipv6_address fields must be set or both must be unset.
  • Prefix length of both candidate_cloud_router_ipv6_address and candidate_customer_router_ipv6_address must be the same.
  • Max prefix length is 126. Corresponds to the JSON property candidateCloudRouterIpv6Address

Returns:

  • (String)


33949
33950
33951
# File 'lib/google/apis/compute_alpha/classes.rb', line 33949

def candidate_cloud_router_ipv6_address
  @candidate_cloud_router_ipv6_address
end

#candidate_customer_router_ip_addressString

Single IPv4 address + prefix length to be configured on the customer router interface for this interconnect attachment. Corresponds to the JSON property candidateCustomerRouterIpAddress

Returns:

  • (String)


33955
33956
33957
# File 'lib/google/apis/compute_alpha/classes.rb', line 33955

def candidate_customer_router_ip_address
  @candidate_customer_router_ip_address
end

#candidate_customer_router_ipv6_addressString

Single IPv6 address + prefix length to be configured on the customer router interface for this interconnect attachment. Corresponds to the JSON property candidateCustomerRouterIpv6Address

Returns:

  • (String)


33961
33962
33963
# File 'lib/google/apis/compute_alpha/classes.rb', line 33961

def candidate_customer_router_ipv6_address
  @candidate_customer_router_ipv6_address
end

#candidate_ipv6_subnetsArray<String>

This field is not available. Corresponds to the JSON property candidateIpv6Subnets

Returns:

  • (Array<String>)


33966
33967
33968
# File 'lib/google/apis/compute_alpha/classes.rb', line 33966

def candidate_ipv6_subnets
  @candidate_ipv6_subnets
end

#candidate_subnetsArray<String>

Input only. Up to 16 candidate prefixes that can be used to restrict the allocation of cloudRouterIpAddress and customerRouterIpAddress for this attachment. All prefixes must be within link-local address space (169.254.0.0/16) and must be /29 or shorter (/28, /27, etc). Google will attempt to select an unused /29 from the supplied candidate prefix(es). The request will fail if all possible /29s are in use on Google's edge. If not supplied, Google will randomly select an unused /29 from all of link-local space. Corresponds to the JSON property candidateSubnets

Returns:

  • (Array<String>)


33978
33979
33980
# File 'lib/google/apis/compute_alpha/classes.rb', line 33978

def candidate_subnets
  @candidate_subnets
end

#cloud_router_ip_addressString

Output only. [Output Only] IPv4 address + prefix length to be configured on Cloud Router Interface for this interconnect attachment. Corresponds to the JSON property cloudRouterIpAddress

Returns:

  • (String)


33985
33986
33987
# File 'lib/google/apis/compute_alpha/classes.rb', line 33985

def cloud_router_ip_address
  @cloud_router_ip_address
end

#cloud_router_ipv6_addressString

Output only. [Output Only] IPv6 address + prefix length to be configured on Cloud Router Interface for this interconnect attachment. Corresponds to the JSON property cloudRouterIpv6Address

Returns:

  • (String)


33992
33993
33994
# File 'lib/google/apis/compute_alpha/classes.rb', line 33992

def cloud_router_ipv6_address
  @cloud_router_ipv6_address
end

#cloud_router_ipv6_interface_idString

This field is not available. Corresponds to the JSON property cloudRouterIpv6InterfaceId

Returns:

  • (String)


33997
33998
33999
# File 'lib/google/apis/compute_alpha/classes.rb', line 33997

def cloud_router_ipv6_interface_id
  @cloud_router_ipv6_interface_id
end

#configuration_constraintsGoogle::Apis::ComputeAlpha::InterconnectAttachmentConfigurationConstraints

Output only. [Output Only] Constraints for this attachment, if any. The attachment does not work if these constraints are not met. Corresponds to the JSON property configurationConstraints



34004
34005
34006
# File 'lib/google/apis/compute_alpha/classes.rb', line 34004

def configuration_constraints
  @configuration_constraints
end

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


34010
34011
34012
# File 'lib/google/apis/compute_alpha/classes.rb', line 34010

def creation_timestamp
  @creation_timestamp
end

#customer_router_ip_addressString

Output only. [Output Only] IPv4 address + prefix length to be configured on the customer router subinterface for this interconnect attachment. Corresponds to the JSON property customerRouterIpAddress

Returns:

  • (String)


34017
34018
34019
# File 'lib/google/apis/compute_alpha/classes.rb', line 34017

def customer_router_ip_address
  @customer_router_ip_address
end

#customer_router_ipv6_addressString

Output only. [Output Only] IPv6 address + prefix length to be configured on the customer router subinterface for this interconnect attachment. Corresponds to the JSON property customerRouterIpv6Address

Returns:

  • (String)


34024
34025
34026
# File 'lib/google/apis/compute_alpha/classes.rb', line 34024

def customer_router_ipv6_address
  @customer_router_ipv6_address
end

#customer_router_ipv6_interface_idString

This field is not available. Corresponds to the JSON property customerRouterIpv6InterfaceId

Returns:

  • (String)


34029
34030
34031
# File 'lib/google/apis/compute_alpha/classes.rb', line 34029

def customer_router_ipv6_interface_id
  @customer_router_ipv6_interface_id
end

#dataplane_versionFixnum

Output only. [Output Only] Dataplane version for this InterconnectAttachment. This field is only present for Dataplane version 2 and higher. Absence of this field in the API output indicates that the Dataplane is version 1. Corresponds to the JSON property dataplaneVersion

Returns:

  • (Fixnum)


34037
34038
34039
# File 'lib/google/apis/compute_alpha/classes.rb', line 34037

def dataplane_version
  @dataplane_version
end

#descriptionString

An optional description of this resource. Corresponds to the JSON property description

Returns:

  • (String)


34042
34043
34044
# File 'lib/google/apis/compute_alpha/classes.rb', line 34042

def description
  @description
end

#edge_availability_domainString

Input only. Desired availability domain for the attachment. Only available for type PARTNER, at creation time, and can take one of the following values:

  • AVAILABILITY_DOMAIN_ANY
  • AVAILABILITY_DOMAIN_1
  • AVAILABILITY_DOMAIN_2 For improved reliability, customers should configure a pair of attachments, one per availability domain. The selected availability domain will be provided to the Partner via the pairing key, so that the provisioned circuit will lie in the specified domain. If not specified, the value will default to AVAILABILITY_DOMAIN_ANY. Corresponds to the JSON property edgeAvailabilityDomain

Returns:

  • (String)


34058
34059
34060
# File 'lib/google/apis/compute_alpha/classes.rb', line 34058

def edge_availability_domain
  @edge_availability_domain
end

#encryptionString

Indicates the user-supplied encryption option of this VLAN attachment (interconnectAttachment). Can only be specified at attachment creation for PARTNER or DEDICATED attachments. Possible values are:

  • NONE - This is the default value, which means that the VLAN attachment carries unencrypted traffic. VMs are able to send traffic to, or receive traffic from, such a VLAN attachment.
  • IPSEC - The VLAN attachment carries only encrypted traffic that is encrypted by an IPsec device, such as an HA VPN gateway or third-party IPsec VPN. VMs cannot directly send traffic to, or receive traffic from, such a VLAN attachment. To use HA VPN over Cloud Interconnect, the VLAN attachment must be created with this option. Corresponds to the JSON property encryption

Returns:

  • (String)


34076
34077
34078
# File 'lib/google/apis/compute_alpha/classes.rb', line 34076

def encryption
  @encryption
end

#google_reference_idString

Output only. [Output Only] Google reference ID, to be used when raising support tickets with Google or otherwise to debug backend connectivity issues. [Deprecated] This field is not used. Corresponds to the JSON property googleReferenceId

Returns:

  • (String)


34084
34085
34086
# File 'lib/google/apis/compute_alpha/classes.rb', line 34084

def google_reference_id
  @google_reference_id
end

#idFixnum

Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


34091
34092
34093
# File 'lib/google/apis/compute_alpha/classes.rb', line 34091

def id
  @id
end

#interconnectString

URL of the underlying Interconnect object that this attachment's traffic will traverse through. Corresponds to the JSON property interconnect

Returns:

  • (String)


34097
34098
34099
# File 'lib/google/apis/compute_alpha/classes.rb', line 34097

def interconnect
  @interconnect
end

#ipsec_internal_addressesArray<String>

A list of URLs of addresses that have been reserved for the VLAN attachment. Used only for the VLAN attachment that has the encryption option as IPSEC. The addresses must be regional internal IP address ranges. When creating an HA VPN gateway over the VLAN attachment, if the attachment is configured to use a regional internal IP address, then the VPN gateway's IP address is allocated from the IP address range specified here. For example, if the HA VPN gateway's interface 0 is paired to this VLAN attachment, then a regional internal IP address for the VPN gateway interface 0 will be allocated from the IP address specified for this VLAN attachment. If this field is not specified when creating the VLAN attachment, then later on when creating an HA VPN gateway on this VLAN attachment, the HA VPN gateway's IP address is allocated from the regional external IP address pool. Corresponds to the JSON property ipsecInternalAddresses

Returns:

  • (Array<String>)


34115
34116
34117
# File 'lib/google/apis/compute_alpha/classes.rb', line 34115

def ipsec_internal_addresses
  @ipsec_internal_addresses
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# interconnectAttachment for interconnect attachments. Corresponds to the JSON property kind

Returns:

  • (String)


34121
34122
34123
# File 'lib/google/apis/compute_alpha/classes.rb', line 34121

def kind
  @kind
end

#l2_forwardingGoogle::Apis::ComputeAlpha::InterconnectAttachmentL2Forwarding

L2 Interconnect Attachment related configuration. Corresponds to the JSON property l2Forwarding



34126
34127
34128
# File 'lib/google/apis/compute_alpha/classes.rb', line 34126

def l2_forwarding
  @l2_forwarding
end

#label_fingerprintString

A fingerprint for the labels being applied to this InterconnectAttachment, which is essentially a hash of the labels set used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update labels. You must always provide an up-to-date fingerprint hash in order to update or change labels, otherwise the request will fail with error412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve an InterconnectAttachment. Corresponds to the JSON property labelFingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


34139
34140
34141
# File 'lib/google/apis/compute_alpha/classes.rb', line 34139

def label_fingerprint
  @label_fingerprint
end

#labelsHash<String,String>

Labels for this resource. These can only be added or modified by thesetLabels method. Each label key/value pair must comply withRFC1035. Label values may be empty. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


34146
34147
34148
# File 'lib/google/apis/compute_alpha/classes.rb', line 34146

def labels
  @labels
end

#mtuFixnum

Maximum Transmission Unit (MTU), in bytes, of packets passing through this interconnect attachment. Valid values are 1440, 1460, 1500, and 8896. If not specified, the value will default to 1440. Corresponds to the JSON property mtu

Returns:

  • (Fixnum)


34154
34155
34156
# File 'lib/google/apis/compute_alpha/classes.rb', line 34154

def mtu
  @mtu
end

#multicast_enabledBoolean Also known as: multicast_enabled?

Whether or not to permit multicast traffic for this attachment. Multicast packets will be dropped if this is not enabled. Corresponds to the JSON property multicastEnabled

Returns:

  • (Boolean)


34160
34161
34162
# File 'lib/google/apis/compute_alpha/classes.rb', line 34160

def multicast_enabled
  @multicast_enabled
end

#nameString

Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


34172
34173
34174
# File 'lib/google/apis/compute_alpha/classes.rb', line 34172

def name
  @name
end

#operational_statusString

Output only. [Output Only] The current status of whether or not this interconnect attachment is functional, which can take one of the following values:

  • OS_ACTIVE: The attachment has been turned up and is ready to use.
  • OS_UNPROVISIONED: The attachment is not ready to use yet, because turnup is not complete. Corresponds to the JSON property operationalStatus

Returns:

  • (String)


34184
34185
34186
# File 'lib/google/apis/compute_alpha/classes.rb', line 34184

def operational_status
  @operational_status
end

#pairing_keyString

[Output only for type PARTNER. Input only for PARTNER_PROVIDER. Not present for DEDICATED]. The opaque identifier of a PARTNER attachment used to initiate provisioning with a selected partner. Of the form "XXXXX/region/domain" Corresponds to the JSON property pairingKey

Returns:

  • (String)


34193
34194
34195
# File 'lib/google/apis/compute_alpha/classes.rb', line 34193

def pairing_key
  @pairing_key
end

#paramsGoogle::Apis::ComputeAlpha::InterconnectAttachmentParams

Additional interconnect attachment parameters. Corresponds to the JSON property params



34198
34199
34200
# File 'lib/google/apis/compute_alpha/classes.rb', line 34198

def params
  @params
end

#partner_asnFixnum

Optional BGP ASN for the router supplied by a Layer 3 Partner if they configured BGP on behalf of the customer. Output only for PARTNER type, input only for PARTNER_PROVIDER, not available for DEDICATED. Corresponds to the JSON property partnerAsn

Returns:

  • (Fixnum)


34206
34207
34208
# File 'lib/google/apis/compute_alpha/classes.rb', line 34206

def partner_asn
  @partner_asn
end

#partner_metadataGoogle::Apis::ComputeAlpha::InterconnectAttachmentPartnerMetadata

Informational metadata about Partner attachments from Partners to display to customers. These fields are propagated from PARTNER_PROVIDER attachments to their corresponding PARTNER attachments. Corresponds to the JSON property partnerMetadata



34213
34214
34215
# File 'lib/google/apis/compute_alpha/classes.rb', line 34213

def 
  @partner_metadata
end

#private_interconnect_infoGoogle::Apis::ComputeAlpha::InterconnectAttachmentPrivateInfo

Information for an interconnect attachment when this belongs to an interconnect of type DEDICATED. Corresponds to the JSON property privateInterconnectInfo



34219
34220
34221
# File 'lib/google/apis/compute_alpha/classes.rb', line 34219

def private_interconnect_info
  @private_interconnect_info
end

#regionString

Output only. [Output Only] URL of the region where the regional interconnect attachment resides. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body. Corresponds to the JSON property region

Returns:

  • (String)


34228
34229
34230
# File 'lib/google/apis/compute_alpha/classes.rb', line 34228

def region
  @region
end

#remote_serviceString

Output only. [Output Only] If the attachment is on a Cross-Cloud Interconnect connection, this field contains the interconnect's remote location service provider. Example values: "Amazon Web Services" "Microsoft Azure". The field is set only for attachments on Cross-Cloud Interconnect connections. Its value is copied from the InterconnectRemoteLocation remoteService field. Corresponds to the JSON property remoteService

Returns:

  • (String)


34239
34240
34241
# File 'lib/google/apis/compute_alpha/classes.rb', line 34239

def remote_service
  @remote_service
end

#routerString

URL of the Cloud Router to be used for dynamic routing. This router must be in the same region as this InterconnectAttachment. The InterconnectAttachment will automatically connect the Interconnect to the network & region within which the Cloud Router is configured. Corresponds to the JSON property router

Returns:

  • (String)


34247
34248
34249
# File 'lib/google/apis/compute_alpha/classes.rb', line 34247

def router
  @router
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

Output only. [Output Only] Reserved for future use. Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


34252
34253
34254
# File 'lib/google/apis/compute_alpha/classes.rb', line 34252

def satisfies_pzs
  @satisfies_pzs
end

Output only. [Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


34258
34259
34260
# File 'lib/google/apis/compute_alpha/classes.rb', line 34258

def self_link
  @self_link
end

Output only. [Output Only] Server-defined URL for this resource with the resource id. Corresponds to the JSON property selfLinkWithId

Returns:

  • (String)


34264
34265
34266
# File 'lib/google/apis/compute_alpha/classes.rb', line 34264

def self_link_with_id
  @self_link_with_id
end

#stack_typeString

The stack type for this interconnect attachment to identify whether the IPv6 feature is enabled or not. If not specified, IPV4_ONLY will be used. This field can be both set at interconnect attachments creation and update interconnect attachment operations. Corresponds to the JSON property stackType

Returns:

  • (String)


34273
34274
34275
# File 'lib/google/apis/compute_alpha/classes.rb', line 34273

def stack_type
  @stack_type
end

#stateString

Output only. [Output Only] The current state of this attachment's functionality. Enum values ACTIVE and UNPROVISIONED are shared by DEDICATED/PRIVATE, PARTNER, and PARTNER_PROVIDER interconnect attachments, while enum values PENDING_PARTNER, PARTNER_REQUEST_RECEIVED, and PENDING_CUSTOMER are used for only PARTNER and PARTNER_PROVIDER interconnect attachments. This state can take one of the following values:

  • ACTIVE: The attachment has been turned up and is ready to use.
  • UNPROVISIONED: The attachment is not ready to use yet, because turnup is not complete.
  • PENDING_PARTNER: A newly-created PARTNER attachment that has not yet been configured on the Partner side.
  • PARTNER_REQUEST_RECEIVED: A PARTNER attachment is in the process of provisioning after a PARTNER_PROVIDER attachment was created that references it.
  • PENDING_CUSTOMER: A PARTNER or PARTNER_PROVIDER attachment that is waiting for a customer to activate it.
  • DEFUNCT: The attachment was deleted externally and is no longer functional. This could be because the associated Interconnect was removed, or because the other side of a Partner attachment was deleted. Corresponds to the JSON property state

Returns:

  • (String)


34299
34300
34301
# File 'lib/google/apis/compute_alpha/classes.rb', line 34299

def state
  @state
end

#subnet_lengthFixnum

Input only. Length of the IPv4 subnet mask. Allowed values:

  • 29 (default)
  • 30 The default value is 29, except for Cross-Cloud Interconnect connections that use an InterconnectRemoteLocation with a constraints.subnetLengthRange.min equal to 30. For example, connections that use an Azure remote location fall into this category. In these cases, the default value is 30, and requesting 29 returns an error. Where both 29 and 30 are allowed, 29 is preferred, because it gives Google Cloud Support more debugging visibility. Corresponds to the JSON property subnetLength

Returns:

  • (Fixnum)


34317
34318
34319
# File 'lib/google/apis/compute_alpha/classes.rb', line 34317

def subnet_length
  @subnet_length
end

#typeString

The type of interconnect attachment this is, which can take one of the following values:

  • DEDICATED: an attachment to a Dedicated Interconnect.
  • PARTNER: an attachment to a Partner Interconnect, created by the customer.
  • PARTNER_PROVIDER: an attachment to a Partner Interconnect, created by the partner.
  • L2_DEDICATED: a L2 attachment to a Dedicated Interconnect. Corresponds to the JSON property type

Returns:

  • (String)


34330
34331
34332
# File 'lib/google/apis/compute_alpha/classes.rb', line 34330

def type
  @type
end

#vlan_tag8021qFixnum

The IEEE 802.1Q VLAN tag for this attachment, in the range 2-4093. Only specified at creation time. Corresponds to the JSON property vlanTag8021q

Returns:

  • (Fixnum)


34336
34337
34338
# File 'lib/google/apis/compute_alpha/classes.rb', line 34336

def vlan_tag8021q
  @vlan_tag8021q
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



34343
34344
34345
34346
34347
34348
34349
34350
34351
34352
34353
34354
34355
34356
34357
34358
34359
34360
34361
34362
34363
34364
34365
34366
34367
34368
34369
34370
34371
34372
34373
34374
34375
34376
34377
34378
34379
34380
34381
34382
34383
34384
34385
34386
34387
34388
34389
34390
34391
34392
34393
# File 'lib/google/apis/compute_alpha/classes.rb', line 34343

def update!(**args)
  @admin_enabled = args[:admin_enabled] if args.key?(:admin_enabled)
  @attachment_group = args[:attachment_group] if args.key?(:attachment_group)
  @bandwidth = args[:bandwidth] if args.key?(:bandwidth)
  @candidate_cloud_router_ip_address = args[:candidate_cloud_router_ip_address] if args.key?(:candidate_cloud_router_ip_address)
  @candidate_cloud_router_ipv6_address = args[:candidate_cloud_router_ipv6_address] if args.key?(:candidate_cloud_router_ipv6_address)
  @candidate_customer_router_ip_address = args[:candidate_customer_router_ip_address] if args.key?(:candidate_customer_router_ip_address)
  @candidate_customer_router_ipv6_address = args[:candidate_customer_router_ipv6_address] if args.key?(:candidate_customer_router_ipv6_address)
  @candidate_ipv6_subnets = args[:candidate_ipv6_subnets] if args.key?(:candidate_ipv6_subnets)
  @candidate_subnets = args[:candidate_subnets] if args.key?(:candidate_subnets)
  @cloud_router_ip_address = args[:cloud_router_ip_address] if args.key?(:cloud_router_ip_address)
  @cloud_router_ipv6_address = args[:cloud_router_ipv6_address] if args.key?(:cloud_router_ipv6_address)
  @cloud_router_ipv6_interface_id = args[:cloud_router_ipv6_interface_id] if args.key?(:cloud_router_ipv6_interface_id)
  @configuration_constraints = args[:configuration_constraints] if args.key?(:configuration_constraints)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @customer_router_ip_address = args[:customer_router_ip_address] if args.key?(:customer_router_ip_address)
  @customer_router_ipv6_address = args[:customer_router_ipv6_address] if args.key?(:customer_router_ipv6_address)
  @customer_router_ipv6_interface_id = args[:customer_router_ipv6_interface_id] if args.key?(:customer_router_ipv6_interface_id)
  @dataplane_version = args[:dataplane_version] if args.key?(:dataplane_version)
  @description = args[:description] if args.key?(:description)
  @edge_availability_domain = args[:edge_availability_domain] if args.key?(:edge_availability_domain)
  @encryption = args[:encryption] if args.key?(:encryption)
  @google_reference_id = args[:google_reference_id] if args.key?(:google_reference_id)
  @id = args[:id] if args.key?(:id)
  @interconnect = args[:interconnect] if args.key?(:interconnect)
  @ipsec_internal_addresses = args[:ipsec_internal_addresses] if args.key?(:ipsec_internal_addresses)
  @kind = args[:kind] if args.key?(:kind)
  @l2_forwarding = args[:l2_forwarding] if args.key?(:l2_forwarding)
  @label_fingerprint = args[:label_fingerprint] if args.key?(:label_fingerprint)
  @labels = args[:labels] if args.key?(:labels)
  @mtu = args[:mtu] if args.key?(:mtu)
  @multicast_enabled = args[:multicast_enabled] if args.key?(:multicast_enabled)
  @name = args[:name] if args.key?(:name)
  @operational_status = args[:operational_status] if args.key?(:operational_status)
  @pairing_key = args[:pairing_key] if args.key?(:pairing_key)
  @params = args[:params] if args.key?(:params)
  @partner_asn = args[:partner_asn] if args.key?(:partner_asn)
  @partner_metadata = args[:partner_metadata] if args.key?(:partner_metadata)
  @private_interconnect_info = args[:private_interconnect_info] if args.key?(:private_interconnect_info)
  @region = args[:region] if args.key?(:region)
  @remote_service = args[:remote_service] if args.key?(:remote_service)
  @router = args[:router] if args.key?(:router)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @self_link = args[:self_link] if args.key?(:self_link)
  @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id)
  @stack_type = args[:stack_type] if args.key?(:stack_type)
  @state = args[:state] if args.key?(:state)
  @subnet_length = args[:subnet_length] if args.key?(:subnet_length)
  @type = args[:type] if args.key?(:type)
  @vlan_tag8021q = args[:vlan_tag8021q] if args.key?(:vlan_tag8021q)
end