Class: Google::Apis::ComputeAlpha::InterconnectAttachmentGroup

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

An interconnect attachment group resource allows customers to create, analyze, and expand highly available deployments.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectAttachmentGroup

Returns a new instance of InterconnectAttachmentGroup.



34458
34459
34460
# File 'lib/google/apis/compute_alpha/classes.rb', line 34458

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#attachmentsHash<String,Google::Apis::ComputeAlpha::InterconnectAttachmentGroupAttachment>

Attachments in the AttachmentGroup. Keys are arbitrary user-specified strings. Users are encouraged, but not required, to use their preferred format for resource links as keys. Note that there are add-members and remove-members methods in gcloud. The size of this map is limited by an "Attachments per group" quota. Corresponds to the JSON property attachments



34380
34381
34382
# File 'lib/google/apis/compute_alpha/classes.rb', line 34380

def attachments
  @attachments
end

#configuredGoogle::Apis::ComputeAlpha::InterconnectAttachmentGroupConfigured

[Output Only] The redundancy this group is configured to support. The way a user queries what SLA their Attachment gets is by looking at this field of the Attachment's AttachmentGroup. Corresponds to the JSON property configured



34387
34388
34389
# File 'lib/google/apis/compute_alpha/classes.rb', line 34387

def configured
  @configured
end

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


34393
34394
34395
# File 'lib/google/apis/compute_alpha/classes.rb', line 34393

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


34399
34400
34401
# File 'lib/google/apis/compute_alpha/classes.rb', line 34399

def description
  @description
end

#etagString

Opaque system-generated token that uniquely identifies the configuration. If provided when patching a configuration in update mode, the provided token must match the current token or the update is rejected. This provides a reliable means of doing read-modify-write (optimistic locking) as described byAIP 154. Corresponds to the JSON property etag

Returns:

  • (String)


34408
34409
34410
# File 'lib/google/apis/compute_alpha/classes.rb', line 34408

def etag
  @etag
end

#idFixnum

Output only. [Output Only] The unique identifier for the resource type. The server generates this identifier. Corresponds to the JSON property id

Returns:

  • (Fixnum)


34415
34416
34417
# File 'lib/google/apis/compute_alpha/classes.rb', line 34415

def id
  @id
end

#intentGoogle::Apis::ComputeAlpha::InterconnectAttachmentGroupIntent

The user's intent for this AttachmentGroup. This is the only required field besides the name that must be specified on group creation. Corresponds to the JSON property intent



34421
34422
34423
# File 'lib/google/apis/compute_alpha/classes.rb', line 34421

def intent
  @intent
end

#interconnect_groupString

The URL of an InterconnectGroup that groups these Attachments' Interconnects. Customers do not need to set this unless directed by Google Support. Corresponds to the JSON property interconnectGroup

Returns:

  • (String)


34428
34429
34430
# File 'lib/google/apis/compute_alpha/classes.rb', line 34428

def interconnect_group
  @interconnect_group
end

#kindString

Output only. [Output Only] Type of the resource. Always compute#interconnectAttachmentGroup. Corresponds to the JSON property kind

Returns:

  • (String)


34434
34435
34436
# File 'lib/google/apis/compute_alpha/classes.rb', line 34434

def kind
  @kind
end

#logical_structureGoogle::Apis::ComputeAlpha::InterconnectAttachmentGroupLogicalStructure

[Output Only] An analysis of the logical layout of Attachments in this group. Every Attachment in the group is shown once in this structure. Corresponds to the JSON property logicalStructure



34440
34441
34442
# File 'lib/google/apis/compute_alpha/classes.rb', line 34440

def logical_structure
  @logical_structure
end

#nameString

Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


34451
34452
34453
# File 'lib/google/apis/compute_alpha/classes.rb', line 34451

def name
  @name
end

Output only. [Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


34456
34457
34458
# File 'lib/google/apis/compute_alpha/classes.rb', line 34456

def self_link
  @self_link
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



34463
34464
34465
34466
34467
34468
34469
34470
34471
34472
34473
34474
34475
34476
# File 'lib/google/apis/compute_alpha/classes.rb', line 34463

def update!(**args)
  @attachments = args[:attachments] if args.key?(:attachments)
  @configured = args[:configured] if args.key?(:configured)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @intent = args[:intent] if args.key?(:intent)
  @interconnect_group = args[:interconnect_group] if args.key?(:interconnect_group)
  @kind = args[:kind] if args.key?(:kind)
  @logical_structure = args[:logical_structure] if args.key?(:logical_structure)
  @name = args[:name] if args.key?(:name)
  @self_link = args[:self_link] if args.key?(:self_link)
end