Class: Google::Apis::ComputeAlpha::InterconnectAttachmentGroup
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::InterconnectAttachmentGroup
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
An interconnect attachment group resource allows customers to create, analyze, and expand highly available deployments.
Instance Attribute Summary collapse
-
#attachments ⇒ Hash<String,Google::Apis::ComputeAlpha::InterconnectAttachmentGroupAttachment>
Attachments in the AttachmentGroup.
-
#configured ⇒ Google::Apis::ComputeAlpha::InterconnectAttachmentGroupConfigured
[Output Only] The redundancy this group is configured to support.
-
#creation_timestamp ⇒ String
Output only.
-
#description ⇒ String
An optional description of this resource.
-
#etag ⇒ String
Opaque system-generated token that uniquely identifies the configuration.
-
#id ⇒ Fixnum
Output only.
-
#intent ⇒ Google::Apis::ComputeAlpha::InterconnectAttachmentGroupIntent
The user's intent for this AttachmentGroup.
-
#interconnect_group ⇒ String
The URL of an InterconnectGroup that groups these Attachments' Interconnects.
-
#kind ⇒ String
Output only.
-
#logical_structure ⇒ Google::Apis::ComputeAlpha::InterconnectAttachmentGroupLogicalStructure
[Output Only] An analysis of the logical layout of Attachments in this group.
-
#name ⇒ String
Name of the resource.
-
#self_link ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InterconnectAttachmentGroup
constructor
A new instance of InterconnectAttachmentGroup.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InterconnectAttachmentGroup
Returns a new instance of InterconnectAttachmentGroup.
33611 33612 33613 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 33611 def initialize(**args) update!(**args) end |
Instance Attribute Details
#attachments ⇒ Hash<String,Google::Apis::ComputeAlpha::InterconnectAttachmentGroupAttachment>
Attachments in the AttachmentGroup. Keys are arbitrary user-specified
strings. Users are encouraged, but not required, to use their preferred
format for resource links as keys.
Note that there are add-members and remove-members methods in gcloud.
The size of this map is limited by an "Attachments per group" quota.
Corresponds to the JSON property attachments
33533 33534 33535 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 33533 def @attachments end |
#configured ⇒ Google::Apis::ComputeAlpha::InterconnectAttachmentGroupConfigured
[Output Only] The redundancy this group is configured to support. The way a
user queries what SLA their Attachment gets is by looking at this field of
the Attachment's AttachmentGroup.
Corresponds to the JSON property configured
33540 33541 33542 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 33540 def configured @configured end |
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
33546 33547 33548 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 33546 def @creation_timestamp end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
33552 33553 33554 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 33552 def description @description end |
#etag ⇒ String
Opaque system-generated token that uniquely identifies the configuration.
If provided when patching a configuration in update mode, the provided
token must match the current token or the update is rejected. This provides
a reliable means of doing read-modify-write (optimistic locking) as
described byAIP 154.
Corresponds to the JSON property etag
33561 33562 33563 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 33561 def etag @etag end |
#id ⇒ Fixnum
Output only. [Output Only] The unique identifier for the resource type. The
server
generates this identifier.
Corresponds to the JSON property id
33568 33569 33570 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 33568 def id @id end |
#intent ⇒ Google::Apis::ComputeAlpha::InterconnectAttachmentGroupIntent
The user's intent for this AttachmentGroup. This is the only required field
besides the name that must be specified on group creation.
Corresponds to the JSON property intent
33574 33575 33576 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 33574 def intent @intent end |
#interconnect_group ⇒ String
The URL of an InterconnectGroup that groups these Attachments'
Interconnects. Customers do not need to set this unless directed by
Google Support.
Corresponds to the JSON property interconnectGroup
33581 33582 33583 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 33581 def interconnect_group @interconnect_group end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Always
compute#interconnectAttachmentGroup.
Corresponds to the JSON property kind
33587 33588 33589 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 33587 def kind @kind end |
#logical_structure ⇒ Google::Apis::ComputeAlpha::InterconnectAttachmentGroupLogicalStructure
[Output Only] An analysis of the logical layout of Attachments in this
group. Every Attachment in the group is shown once in this structure.
Corresponds to the JSON property logicalStructure
33593 33594 33595 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 33593 def logical_structure @logical_structure end |
#name ⇒ String
Name of the resource. Provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must
be a dash, lowercase letter, or digit, except the last character, which
cannot be a dash.
Corresponds to the JSON property name
33604 33605 33606 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 33604 def name @name end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
33609 33610 33611 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 33609 def self_link @self_link end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
33616 33617 33618 33619 33620 33621 33622 33623 33624 33625 33626 33627 33628 33629 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 33616 def update!(**args) @attachments = args[:attachments] if args.key?(:attachments) @configured = args[:configured] if args.key?(:configured) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @intent = args[:intent] if args.key?(:intent) @interconnect_group = args[:interconnect_group] if args.key?(:interconnect_group) @kind = args[:kind] if args.key?(:kind) @logical_structure = args[:logical_structure] if args.key?(:logical_structure) @name = args[:name] if args.key?(:name) @self_link = args[:self_link] if args.key?(:self_link) end |