Class: Google::Apis::ComputeAlpha::InterconnectAttachmentGroupConfiguredAvailabilitySlaIntendedSlaBlockers
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::InterconnectAttachmentGroupConfiguredAvailabilitySlaIntendedSlaBlockers
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
[Output Only] Reasons why configuration.availabilitySLA.sla differs from intent.availabilitySLA. This list is empty if and only if those are the same.
Instance Attribute Summary collapse
-
#attachments ⇒ Array<String>
Output only.
-
#blocker_type ⇒ String
Corresponds to the JSON property
blockerType. -
#documentation_link ⇒ String
Output only.
-
#explanation ⇒ String
Output only.
-
#metros ⇒ Array<String>
Output only.
-
#regions ⇒ Array<String>
Output only.
-
#zones ⇒ Array<String>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InterconnectAttachmentGroupConfiguredAvailabilitySlaIntendedSlaBlockers
constructor
A new instance of InterconnectAttachmentGroupConfiguredAvailabilitySlaIntendedSlaBlockers.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InterconnectAttachmentGroupConfiguredAvailabilitySlaIntendedSlaBlockers
Returns a new instance of InterconnectAttachmentGroupConfiguredAvailabilitySlaIntendedSlaBlockers.
34600 34601 34602 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 34600 def initialize(**args) update!(**args) end |
Instance Attribute Details
#attachments ⇒ Array<String>
Output only. [Output Only] URLs of any particular Attachments to explain this
blocker in more detail.
Corresponds to the JSON property attachments
34556 34557 34558 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 34556 def @attachments end |
#blocker_type ⇒ String
Corresponds to the JSON property blockerType
34561 34562 34563 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 34561 def blocker_type @blocker_type end |
#documentation_link ⇒ String
Output only. [Output Only] The url of Google Cloud public documentation
explaining
this requirement. This is set for every type of requirement.
Corresponds to the JSON property documentationLink
34568 34569 34570 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 34568 def documentation_link @documentation_link end |
#explanation ⇒ String
Output only. [Output Only] A human-readable explanation of this requirement
and
why it's not met. This is set for every type of requirement.
Corresponds to the JSON property explanation
34575 34576 34577 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 34575 def explanation @explanation end |
#metros ⇒ Array<String>
Output only. [Output Only] Metros used to explain this blocker in more detail.
These are three-letter lowercase strings like "iad". This will be set
for some blockers (like NO_ATTACHMENTS_IN_METRO_AND_ZONE) but does
not apply to others.
Corresponds to the JSON property metros
34583 34584 34585 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 34583 def metros @metros end |
#regions ⇒ Array<String>
Output only. [Output Only] Regions used to explain this blocker in more
detail. These are region names formatted like "us-central1". This
will be set for some blockers (like INCOMPATIBLE_REGIONS) but does
not apply to others.
Corresponds to the JSON property regions
34591 34592 34593 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 34591 def regions @regions end |
#zones ⇒ Array<String>
Output only. [Output Only] Zones used to explain this blocker in more detail.
Format is "zone1" and/or "zone2". This will be set for some blockers
(like MISSING_ZONE) but does not apply to others.
Corresponds to the JSON property zones
34598 34599 34600 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 34598 def zones @zones end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
34605 34606 34607 34608 34609 34610 34611 34612 34613 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 34605 def update!(**args) @attachments = args[:attachments] if args.key?(:attachments) @blocker_type = args[:blocker_type] if args.key?(:blocker_type) @documentation_link = args[:documentation_link] if args.key?(:documentation_link) @explanation = args[:explanation] if args.key?(:explanation) @metros = args[:metros] if args.key?(:metros) @regions = args[:regions] if args.key?(:regions) @zones = args[:zones] if args.key?(:zones) end |