Class: Google::Apis::ComputeAlpha::InterconnectAttachmentGroupConfiguredAvailabilitySlaIntendedSlaBlockers
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::InterconnectAttachmentGroupConfiguredAvailabilitySlaIntendedSlaBlockers
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
[Output Only] Reasons why configuration.availabilitySLA.sla differs from intent.availabilitySLA. This list is empty if and only if those are the same.
Instance Attribute Summary collapse
-
#attachments ⇒ Array<String>
Output only.
-
#blocker_type ⇒ String
Corresponds to the JSON property
blockerType. -
#documentation_link ⇒ String
Output only.
-
#explanation ⇒ String
Output only.
-
#metros ⇒ Array<String>
Output only.
-
#regions ⇒ Array<String>
Output only.
-
#zones ⇒ Array<String>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InterconnectAttachmentGroupConfiguredAvailabilitySlaIntendedSlaBlockers
constructor
A new instance of InterconnectAttachmentGroupConfiguredAvailabilitySlaIntendedSlaBlockers.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InterconnectAttachmentGroupConfiguredAvailabilitySlaIntendedSlaBlockers
Returns a new instance of InterconnectAttachmentGroupConfiguredAvailabilitySlaIntendedSlaBlockers.
34470 34471 34472 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 34470 def initialize(**args) update!(**args) end |
Instance Attribute Details
#attachments ⇒ Array<String>
Output only. [Output Only] URLs of any particular Attachments to explain this
blocker in more detail.
Corresponds to the JSON property attachments
34426 34427 34428 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 34426 def @attachments end |
#blocker_type ⇒ String
Corresponds to the JSON property blockerType
34431 34432 34433 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 34431 def blocker_type @blocker_type end |
#documentation_link ⇒ String
Output only. [Output Only] The url of Google Cloud public documentation
explaining
this requirement. This is set for every type of requirement.
Corresponds to the JSON property documentationLink
34438 34439 34440 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 34438 def documentation_link @documentation_link end |
#explanation ⇒ String
Output only. [Output Only] A human-readable explanation of this requirement
and
why it's not met. This is set for every type of requirement.
Corresponds to the JSON property explanation
34445 34446 34447 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 34445 def explanation @explanation end |
#metros ⇒ Array<String>
Output only. [Output Only] Metros used to explain this blocker in more detail.
These are three-letter lowercase strings like "iad". This will be set
for some blockers (like NO_ATTACHMENTS_IN_METRO_AND_ZONE) but does
not apply to others.
Corresponds to the JSON property metros
34453 34454 34455 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 34453 def metros @metros end |
#regions ⇒ Array<String>
Output only. [Output Only] Regions used to explain this blocker in more
detail. These are region names formatted like "us-central1". This
will be set for some blockers (like INCOMPATIBLE_REGIONS) but does
not apply to others.
Corresponds to the JSON property regions
34461 34462 34463 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 34461 def regions @regions end |
#zones ⇒ Array<String>
Output only. [Output Only] Zones used to explain this blocker in more detail.
Format is "zone1" and/or "zone2". This will be set for some blockers
(like MISSING_ZONE) but does not apply to others.
Corresponds to the JSON property zones
34468 34469 34470 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 34468 def zones @zones end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
34475 34476 34477 34478 34479 34480 34481 34482 34483 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 34475 def update!(**args) @attachments = args[:attachments] if args.key?(:attachments) @blocker_type = args[:blocker_type] if args.key?(:blocker_type) @documentation_link = args[:documentation_link] if args.key?(:documentation_link) @explanation = args[:explanation] if args.key?(:explanation) @metros = args[:metros] if args.key?(:metros) @regions = args[:regions] if args.key?(:regions) @zones = args[:zones] if args.key?(:zones) end |