Class: Google::Apis::ComputeAlpha::InterconnectAttachmentGroupConfiguredAvailabilitySlaIntendedSlaBlockers

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

[Output Only] Reasons why configuration.availabilitySLA.sla differs from intent.availabilitySLA. This list is empty if and only if those are the same.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectAttachmentGroupConfiguredAvailabilitySlaIntendedSlaBlockers

Returns a new instance of InterconnectAttachmentGroupConfiguredAvailabilitySlaIntendedSlaBlockers.



33753
33754
33755
# File 'lib/google/apis/compute_alpha/classes.rb', line 33753

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#attachmentsArray<String>

Output only. [Output Only] URLs of any particular Attachments to explain this blocker in more detail. Corresponds to the JSON property attachments

Returns:

  • (Array<String>)


33709
33710
33711
# File 'lib/google/apis/compute_alpha/classes.rb', line 33709

def attachments
  @attachments
end

#blocker_typeString

Corresponds to the JSON property blockerType

Returns:

  • (String)


33714
33715
33716
# File 'lib/google/apis/compute_alpha/classes.rb', line 33714

def blocker_type
  @blocker_type
end

Output only. [Output Only] The url of Google Cloud public documentation explaining this requirement. This is set for every type of requirement. Corresponds to the JSON property documentationLink

Returns:

  • (String)


33721
33722
33723
# File 'lib/google/apis/compute_alpha/classes.rb', line 33721

def documentation_link
  @documentation_link
end

#explanationString

Output only. [Output Only] A human-readable explanation of this requirement and why it's not met. This is set for every type of requirement. Corresponds to the JSON property explanation

Returns:

  • (String)


33728
33729
33730
# File 'lib/google/apis/compute_alpha/classes.rb', line 33728

def explanation
  @explanation
end

#metrosArray<String>

Output only. [Output Only] Metros used to explain this blocker in more detail. These are three-letter lowercase strings like "iad". This will be set for some blockers (like NO_ATTACHMENTS_IN_METRO_AND_ZONE) but does not apply to others. Corresponds to the JSON property metros

Returns:

  • (Array<String>)


33736
33737
33738
# File 'lib/google/apis/compute_alpha/classes.rb', line 33736

def metros
  @metros
end

#regionsArray<String>

Output only. [Output Only] Regions used to explain this blocker in more detail. These are region names formatted like "us-central1". This will be set for some blockers (like INCOMPATIBLE_REGIONS) but does not apply to others. Corresponds to the JSON property regions

Returns:

  • (Array<String>)


33744
33745
33746
# File 'lib/google/apis/compute_alpha/classes.rb', line 33744

def regions
  @regions
end

#zonesArray<String>

Output only. [Output Only] Zones used to explain this blocker in more detail. Format is "zone1" and/or "zone2". This will be set for some blockers (like MISSING_ZONE) but does not apply to others. Corresponds to the JSON property zones

Returns:

  • (Array<String>)


33751
33752
33753
# File 'lib/google/apis/compute_alpha/classes.rb', line 33751

def zones
  @zones
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



33758
33759
33760
33761
33762
33763
33764
33765
33766
# File 'lib/google/apis/compute_alpha/classes.rb', line 33758

def update!(**args)
  @attachments = args[:attachments] if args.key?(:attachments)
  @blocker_type = args[:blocker_type] if args.key?(:blocker_type)
  @documentation_link = args[:documentation_link] if args.key?(:documentation_link)
  @explanation = args[:explanation] if args.key?(:explanation)
  @metros = args[:metros] if args.key?(:metros)
  @regions = args[:regions] if args.key?(:regions)
  @zones = args[:zones] if args.key?(:zones)
end