Class: Google::Apis::ComputeAlpha::InterconnectAttachmentGroupLogicalStructure

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

[Output Only] An analysis of the logical layout of Attachments in this group. Every Attachment in the group is shown once in this structure.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectAttachmentGroupLogicalStructure

Returns a new instance of InterconnectAttachmentGroupLogicalStructure.



35622
35623
35624
# File 'lib/google/apis/compute_alpha/classes.rb', line 35622

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#regionsArray<Google::Apis::ComputeAlpha::InterconnectAttachmentGroupLogicalStructureRegion>

Corresponds to the JSON property regions



35620
35621
35622
# File 'lib/google/apis/compute_alpha/classes.rb', line 35620

def regions
  @regions
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



35627
35628
35629
# File 'lib/google/apis/compute_alpha/classes.rb', line 35627

def update!(**args)
  @regions = args[:regions] if args.key?(:regions)
end