Class: Google::Apis::ComputeAlpha::InterconnectAttachmentGroupLogicalStructure

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

[Output Only] An analysis of the logical layout of Attachments in this group. Every Attachment in the group is shown once in this structure.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectAttachmentGroupLogicalStructure

Returns a new instance of InterconnectAttachmentGroupLogicalStructure.



33799
33800
33801
# File 'lib/google/apis/compute_alpha/classes.rb', line 33799

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#regionsArray<Google::Apis::ComputeAlpha::InterconnectAttachmentGroupLogicalStructureRegion>

Corresponds to the JSON property regions



33797
33798
33799
# File 'lib/google/apis/compute_alpha/classes.rb', line 33797

def regions
  @regions
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



33804
33805
33806
# File 'lib/google/apis/compute_alpha/classes.rb', line 33804

def update!(**args)
  @regions = args[:regions] if args.key?(:regions)
end