Class: Google::Apis::ComputeAlpha::InterconnectAttachmentGroupLogicalStructureRegionMetro

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

[Output Only] The metros of Attachments in this group in this region.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectAttachmentGroupLogicalStructureRegionMetro

Returns a new instance of InterconnectAttachmentGroupLogicalStructureRegionMetro.



35673
35674
35675
# File 'lib/google/apis/compute_alpha/classes.rb', line 35673

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#facilitiesArray<Google::Apis::ComputeAlpha::InterconnectAttachmentGroupLogicalStructureRegionMetroFacility>

Corresponds to the JSON property facilities



35664
35665
35666
# File 'lib/google/apis/compute_alpha/classes.rb', line 35664

def facilities
  @facilities
end

#metroString

Output only. [Output Only] The name of the metro, as a three-letter lowercase string like "iad". This is the first component of the location of an Interconnect. Corresponds to the JSON property metro

Returns:

  • (String)


35671
35672
35673
# File 'lib/google/apis/compute_alpha/classes.rb', line 35671

def metro
  @metro
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



35678
35679
35680
35681
# File 'lib/google/apis/compute_alpha/classes.rb', line 35678

def update!(**args)
  @facilities = args[:facilities] if args.key?(:facilities)
  @metro = args[:metro] if args.key?(:metro)
end