Class: Google::Apis::ComputeAlpha::InterconnectAttachmentGroupLogicalStructureRegionMetro
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::InterconnectAttachmentGroupLogicalStructureRegionMetro
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
[Output Only] The metros of Attachments in this group in this region.
Instance Attribute Summary collapse
-
#facilities ⇒ Array<Google::Apis::ComputeAlpha::InterconnectAttachmentGroupLogicalStructureRegionMetroFacility>
Corresponds to the JSON property
facilities. -
#metro ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InterconnectAttachmentGroupLogicalStructureRegionMetro
constructor
A new instance of InterconnectAttachmentGroupLogicalStructureRegionMetro.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InterconnectAttachmentGroupLogicalStructureRegionMetro
Returns a new instance of InterconnectAttachmentGroupLogicalStructureRegionMetro.
34697 34698 34699 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 34697 def initialize(**args) update!(**args) end |
Instance Attribute Details
#facilities ⇒ Array<Google::Apis::ComputeAlpha::InterconnectAttachmentGroupLogicalStructureRegionMetroFacility>
Corresponds to the JSON property facilities
34688 34689 34690 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 34688 def facilities @facilities end |
#metro ⇒ String
Output only. [Output Only] The name of the metro, as a three-letter lowercase
string like "iad". This is the first component of the location of an
Interconnect.
Corresponds to the JSON property metro
34695 34696 34697 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 34695 def metro @metro end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
34702 34703 34704 34705 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 34702 def update!(**args) @facilities = args[:facilities] if args.key?(:facilities) @metro = args[:metro] if args.key?(:metro) end |