Class: Google::Apis::ComputeAlpha::InterconnectAttachmentGroupLogicalStructureRegionMetro

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

[Output Only] The metros of Attachments in this group in this region.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectAttachmentGroupLogicalStructureRegionMetro

Returns a new instance of InterconnectAttachmentGroupLogicalStructureRegionMetro.



34567
34568
34569
# File 'lib/google/apis/compute_alpha/classes.rb', line 34567

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#facilitiesArray<Google::Apis::ComputeAlpha::InterconnectAttachmentGroupLogicalStructureRegionMetroFacility>

Corresponds to the JSON property facilities



34558
34559
34560
# File 'lib/google/apis/compute_alpha/classes.rb', line 34558

def facilities
  @facilities
end

#metroString

Output only. [Output Only] The name of the metro, as a three-letter lowercase string like "iad". This is the first component of the location of an Interconnect. Corresponds to the JSON property metro

Returns:

  • (String)


34565
34566
34567
# File 'lib/google/apis/compute_alpha/classes.rb', line 34565

def metro
  @metro
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



34572
34573
34574
34575
# File 'lib/google/apis/compute_alpha/classes.rb', line 34572

def update!(**args)
  @facilities = args[:facilities] if args.key?(:facilities)
  @metro = args[:metro] if args.key?(:metro)
end