Class: Google::Apis::ComputeAlpha::InterconnectAttachmentGroupLogicalStructureRegionMetro

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

[Output Only] The metros of Attachments in this group in this region.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectAttachmentGroupLogicalStructureRegionMetro

Returns a new instance of InterconnectAttachmentGroupLogicalStructureRegionMetro.



33850
33851
33852
# File 'lib/google/apis/compute_alpha/classes.rb', line 33850

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#facilitiesArray<Google::Apis::ComputeAlpha::InterconnectAttachmentGroupLogicalStructureRegionMetroFacility>

Corresponds to the JSON property facilities



33841
33842
33843
# File 'lib/google/apis/compute_alpha/classes.rb', line 33841

def facilities
  @facilities
end

#metroString

Output only. [Output Only] The name of the metro, as a three-letter lowercase string like "iad". This is the first component of the location of an Interconnect. Corresponds to the JSON property metro

Returns:

  • (String)


33848
33849
33850
# File 'lib/google/apis/compute_alpha/classes.rb', line 33848

def metro
  @metro
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



33855
33856
33857
33858
# File 'lib/google/apis/compute_alpha/classes.rb', line 33855

def update!(**args)
  @facilities = args[:facilities] if args.key?(:facilities)
  @metro = args[:metro] if args.key?(:metro)
end