Class: Google::Apis::ComputeAlpha::InterconnectAttachmentGroupLogicalStructureRegionMetroFacilityZone
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::InterconnectAttachmentGroupLogicalStructureRegionMetroFacilityZone
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
[Output Only] The zones that Attachments in this group are present in, in the given facilities. This is inherited from their Interconnects.
Instance Attribute Summary collapse
-
#attachments ⇒ Array<String>
Output only.
-
#zone ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InterconnectAttachmentGroupLogicalStructureRegionMetroFacilityZone
constructor
A new instance of InterconnectAttachmentGroupLogicalStructureRegionMetroFacilityZone.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InterconnectAttachmentGroupLogicalStructureRegionMetroFacilityZone
Returns a new instance of InterconnectAttachmentGroupLogicalStructureRegionMetroFacilityZone.
34762 34763 34764 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 34762 def initialize(**args) update!(**args) end |
Instance Attribute Details
#attachments ⇒ Array<String>
Output only. [Output Only] URLs of Attachments in the given zone, to the given
region, on Interconnects in the given facility and metro. Every
Attachment in the AG has such an entry.
Corresponds to the JSON property attachments
34755 34756 34757 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 34755 def @attachments end |
#zone ⇒ String
Output only. [Output Only] The name of a zone, either "zone1" or "zone2".
Corresponds to the JSON property zone
34760 34761 34762 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 34760 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
34767 34768 34769 34770 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 34767 def update!(**args) @attachments = args[:attachments] if args.key?(:attachments) @zone = args[:zone] if args.key?(:zone) end |