Class: Google::Apis::ComputeAlpha::InterconnectAttachmentGroupLogicalStructureRegionMetroFacilityZone

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

[Output Only] The zones that Attachments in this group are present in, in the given facilities. This is inherited from their Interconnects.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectAttachmentGroupLogicalStructureRegionMetroFacilityZone

Returns a new instance of InterconnectAttachmentGroupLogicalStructureRegionMetroFacilityZone.



34622
34623
34624
# File 'lib/google/apis/compute_alpha/classes.rb', line 34622

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#attachmentsArray<String>

Output only. [Output Only] URLs of Attachments in the given zone, to the given region, on Interconnects in the given facility and metro. Every Attachment in the AG has such an entry. Corresponds to the JSON property attachments

Returns:

  • (Array<String>)


34615
34616
34617
# File 'lib/google/apis/compute_alpha/classes.rb', line 34615

def attachments
  @attachments
end

#zoneString

Output only. [Output Only] The name of a zone, either "zone1" or "zone2". Corresponds to the JSON property zone

Returns:

  • (String)


34620
34621
34622
# File 'lib/google/apis/compute_alpha/classes.rb', line 34620

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



34627
34628
34629
34630
# File 'lib/google/apis/compute_alpha/classes.rb', line 34627

def update!(**args)
  @attachments = args[:attachments] if args.key?(:attachments)
  @zone = args[:zone] if args.key?(:zone)
end