Class: Google::Apis::ComputeAlpha::InterconnectAttachmentGroupsCreateMembers

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectAttachmentGroupsCreateMembers

Returns a new instance of InterconnectAttachmentGroupsCreateMembers.



34785
34786
34787
# File 'lib/google/apis/compute_alpha/classes.rb', line 34785

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#attachmentsArray<Google::Apis::ComputeAlpha::InterconnectAttachmentGroupsCreateMembersInterconnectAttachmentInput>

Parameters for the specific Attachments to create. Corresponds to the JSON property attachments



34770
34771
34772
# File 'lib/google/apis/compute_alpha/classes.rb', line 34770

def attachments
  @attachments
end

#intent_mismatch_behaviorString

How to behave when configured.availabilitySLA.effectiveSLA would not equal intent.availabilitySLA after this call. Corresponds to the JSON property intentMismatchBehavior

Returns:

  • (String)


34776
34777
34778
# File 'lib/google/apis/compute_alpha/classes.rb', line 34776

def intent_mismatch_behavior
  @intent_mismatch_behavior
end

#template_attachmentGoogle::Apis::ComputeAlpha::InterconnectAttachmentGroupsCreateMembersInterconnectAttachmentInput

Parameters used to create an InterconnectAttachment. This is similar to InterconnectAttachment, but the region field used here is not output only and all other output only fields are excluded. Corresponds to the JSON property templateAttachment



34783
34784
34785
# File 'lib/google/apis/compute_alpha/classes.rb', line 34783

def template_attachment
  @template_attachment
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



34790
34791
34792
34793
34794
# File 'lib/google/apis/compute_alpha/classes.rb', line 34790

def update!(**args)
  @attachments = args[:attachments] if args.key?(:attachments)
  @intent_mismatch_behavior = args[:intent_mismatch_behavior] if args.key?(:intent_mismatch_behavior)
  @template_attachment = args[:template_attachment] if args.key?(:template_attachment)
end