Class: Google::Apis::ComputeAlpha::InterconnectAttachmentGroupsCreateMembersInterconnectAttachmentInput

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Parameters used to create an InterconnectAttachment. This is similar to InterconnectAttachment, but the region field used here is not output only and all other output only fields are excluded.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectAttachmentGroupsCreateMembersInterconnectAttachmentInput

Returns a new instance of InterconnectAttachmentGroupsCreateMembersInterconnectAttachmentInput.



36052
36053
36054
# File 'lib/google/apis/compute_alpha/classes.rb', line 36052

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#admin_enabledBoolean Also known as: admin_enabled?

Determines whether this Attachment will carry packets. Not present for PARTNER_PROVIDER. Corresponds to the JSON property adminEnabled

Returns:

  • (Boolean)


35783
35784
35785
# File 'lib/google/apis/compute_alpha/classes.rb', line 35783

def admin_enabled
  @admin_enabled
end

#bandwidthString

Provisioned bandwidth capacity for the interconnect attachment. For attachments of type DEDICATED, the user can set the bandwidth. For attachments of type PARTNER, the Google Partner that is operating the interconnect must set the bandwidth. Output only for PARTNER type, mutable for PARTNER_PROVIDER and DEDICATED, and can take one of the following values:

  • BPS_50M: 50 Mbit/s
  • BPS_100M: 100 Mbit/s
  • BPS_200M: 200 Mbit/s
  • BPS_300M: 300 Mbit/s
  • BPS_400M: 400 Mbit/s
  • BPS_500M: 500 Mbit/s
  • BPS_1G: 1 Gbit/s
  • BPS_2G: 2 Gbit/s
  • BPS_5G: 5 Gbit/s
  • BPS_10G: 10 Gbit/s
  • BPS_20G: 20 Gbit/s
  • BPS_50G: 50 Gbit/s
  • BPS_100G: 100 Gbit/s
  • BPS_400G: 400 Gbit/s Corresponds to the JSON property bandwidth

Returns:

  • (String)


35809
35810
35811
# File 'lib/google/apis/compute_alpha/classes.rb', line 35809

def bandwidth
  @bandwidth
end

#candidate_cloud_router_ip_addressString

Single IPv4 address + prefix length to be configured on the cloud router interface for this interconnect attachment.

  • Both candidate_cloud_router_ip_address and candidate_customer_router_ip_address fields must be set or both must be unset.
  • Prefix length of both candidate_cloud_router_ip_address and candidate_customer_router_ip_address must be the same.
  • Max prefix length is 31. Corresponds to the JSON property candidateCloudRouterIpAddress

Returns:

  • (String)


35822
35823
35824
# File 'lib/google/apis/compute_alpha/classes.rb', line 35822

def candidate_cloud_router_ip_address
  @candidate_cloud_router_ip_address
end

#candidate_cloud_router_ipv6_addressString

Single IPv6 address + prefix length to be configured on the cloud router interface for this interconnect attachment.

  • Both candidate_cloud_router_ipv6_address and candidate_customer_router_ipv6_address fields must be set or both must be unset.
  • Prefix length of both candidate_cloud_router_ipv6_address and candidate_customer_router_ipv6_address must be the same.
  • Max prefix length is 126. Corresponds to the JSON property candidateCloudRouterIpv6Address

Returns:

  • (String)


35835
35836
35837
# File 'lib/google/apis/compute_alpha/classes.rb', line 35835

def candidate_cloud_router_ipv6_address
  @candidate_cloud_router_ipv6_address
end

#candidate_customer_router_ip_addressString

Single IPv4 address + prefix length to be configured on the customer router interface for this interconnect attachment. Corresponds to the JSON property candidateCustomerRouterIpAddress

Returns:

  • (String)


35841
35842
35843
# File 'lib/google/apis/compute_alpha/classes.rb', line 35841

def candidate_customer_router_ip_address
  @candidate_customer_router_ip_address
end

#candidate_customer_router_ipv6_addressString

Single IPv6 address + prefix length to be configured on the customer router interface for this interconnect attachment. Corresponds to the JSON property candidateCustomerRouterIpv6Address

Returns:

  • (String)


35847
35848
35849
# File 'lib/google/apis/compute_alpha/classes.rb', line 35847

def candidate_customer_router_ipv6_address
  @candidate_customer_router_ipv6_address
end

#candidate_ipv6_subnetsArray<String>

This field is not available. Corresponds to the JSON property candidateIpv6Subnets

Returns:

  • (Array<String>)


35852
35853
35854
# File 'lib/google/apis/compute_alpha/classes.rb', line 35852

def candidate_ipv6_subnets
  @candidate_ipv6_subnets
end

#candidate_subnetsArray<String>

Input only. Up to 16 candidate prefixes that can be used to restrict the allocation of cloudRouterIpAddress and customerRouterIpAddress for this attachment. All prefixes must be within link-local address space (169.254.0.0/16) and must be /29 or shorter (/28, /27, etc). Google will attempt to select an unused /29 from the supplied candidate prefix(es). The request will fail if all possible /29s are in use on Google's edge. If not supplied, Google will randomly select an unused /29 from all of link-local space. Corresponds to the JSON property candidateSubnets

Returns:

  • (Array<String>)


35864
35865
35866
# File 'lib/google/apis/compute_alpha/classes.rb', line 35864

def candidate_subnets
  @candidate_subnets
end

#cloud_router_ipv6_interface_idString

This field is not available. Corresponds to the JSON property cloudRouterIpv6InterfaceId

Returns:

  • (String)


35869
35870
35871
# File 'lib/google/apis/compute_alpha/classes.rb', line 35869

def cloud_router_ipv6_interface_id
  @cloud_router_ipv6_interface_id
end

#customer_router_ipv6_interface_idString

This field is not available. Corresponds to the JSON property customerRouterIpv6InterfaceId

Returns:

  • (String)


35874
35875
35876
# File 'lib/google/apis/compute_alpha/classes.rb', line 35874

def customer_router_ipv6_interface_id
  @customer_router_ipv6_interface_id
end

#descriptionString

An optional description of this resource. Corresponds to the JSON property description

Returns:

  • (String)


35879
35880
35881
# File 'lib/google/apis/compute_alpha/classes.rb', line 35879

def description
  @description
end

#edge_availability_domainString

Input only. Desired availability domain for the attachment. Only available for type PARTNER, at creation time, and can take one of the following values:

  • AVAILABILITY_DOMAIN_ANY
  • AVAILABILITY_DOMAIN_1
  • AVAILABILITY_DOMAIN_2 For improved reliability, customers should configure a pair of attachments, one per availability domain. The selected availability domain will be provided to the Partner via the pairing key, so that the provisioned circuit will lie in the specified domain. If not specified, the value will default to AVAILABILITY_DOMAIN_ANY. Corresponds to the JSON property edgeAvailabilityDomain

Returns:

  • (String)


35895
35896
35897
# File 'lib/google/apis/compute_alpha/classes.rb', line 35895

def edge_availability_domain
  @edge_availability_domain
end

#encryptionString

Indicates the user-supplied encryption option of this VLAN attachment (interconnectAttachment). Can only be specified at attachment creation for PARTNER or DEDICATED attachments. Possible values are:

  • alpha - This is the default value, which means that the VLAN attachment carries unencrypted traffic. VMs are able to send traffic to, or receive traffic from, such a VLAN attachment.
  • IPSEC - The VLAN attachment carries only encrypted traffic that is encrypted by an IPsec device, such as an HA VPN gateway or third-party IPsec VPN. VMs cannot directly send traffic to, or receive traffic from, such a VLAN attachment. To use HA VPN over Cloud Interconnect, the VLAN attachment must be created with this option. Corresponds to the JSON property encryption

Returns:

  • (String)


35913
35914
35915
# File 'lib/google/apis/compute_alpha/classes.rb', line 35913

def encryption
  @encryption
end

#interconnectString

URL of the underlying Interconnect object that this attachment's traffic will traverse through. Corresponds to the JSON property interconnect

Returns:

  • (String)


35919
35920
35921
# File 'lib/google/apis/compute_alpha/classes.rb', line 35919

def interconnect
  @interconnect
end

#ipsec_internal_addressesArray<String>

A list of URLs of addresses that have been reserved for the VLAN attachment. Used only for the VLAN attachment that has the encryption option as IPSEC. The addresses must be regional internal IP address ranges. When creating an HA VPN gateway over the VLAN attachment, if the attachment is configured to use a regional internal IP address, then the VPN gateway's IP address is allocated from the IP address range specified here. For example, if the HA VPN gateway's interface 0 is paired to this VLAN attachment, then a regional internal IP address for the VPN gateway interface 0 will be allocated from the IP address specified for this VLAN attachment. If this field is not specified when creating the VLAN attachment, then later on when creating an HA VPN gateway on this VLAN attachment, the HA VPN gateway's IP address is allocated from the regional external IP address pool. Corresponds to the JSON property ipsecInternalAddresses

Returns:

  • (Array<String>)


35937
35938
35939
# File 'lib/google/apis/compute_alpha/classes.rb', line 35937

def ipsec_internal_addresses
  @ipsec_internal_addresses
end

#l2_forwardingGoogle::Apis::ComputeAlpha::InterconnectAttachmentL2Forwarding

L2 Interconnect Attachment related configuration. Corresponds to the JSON property l2Forwarding



35942
35943
35944
# File 'lib/google/apis/compute_alpha/classes.rb', line 35942

def l2_forwarding
  @l2_forwarding
end

#mtuFixnum

Maximum Transmission Unit (MTU), in bytes, of packets passing through this interconnect attachment. Valid values are 1440, 1460, 1500, or 8896. If not specified, the value will default to 1440. Corresponds to the JSON property mtu

Returns:

  • (Fixnum)


35949
35950
35951
# File 'lib/google/apis/compute_alpha/classes.rb', line 35949

def mtu
  @mtu
end

#multicast_enabledBoolean Also known as: multicast_enabled?

Whether or not to permit multicast traffic for this attachment. Multicast packets will be dropped if this is not enabled. Corresponds to the JSON property multicastEnabled

Returns:

  • (Boolean)


35955
35956
35957
# File 'lib/google/apis/compute_alpha/classes.rb', line 35955

def multicast_enabled
  @multicast_enabled
end

#nameString

Name of the resource. Provided by the client when the resource is created. Must be set on either the template_attachment or on each specific attachment. If set, the name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


35968
35969
35970
# File 'lib/google/apis/compute_alpha/classes.rb', line 35968

def name
  @name
end

#pairing_keyString

[Output only for type PARTNER. Input only for PARTNER_PROVIDER. Not present for DEDICATED]. The opaque identifier of a PARTNER attachment used to initiate provisioning with a selected partner. Of the form "XXXXX/region/domain" Corresponds to the JSON property pairingKey

Returns:

  • (String)


35977
35978
35979
# File 'lib/google/apis/compute_alpha/classes.rb', line 35977

def pairing_key
  @pairing_key
end

#partner_asnFixnum

Optional BGP ASN for the router supplied by a Layer 3 Partner if they configured BGP on behalf of the customer. Output only for PARTNER type, input only for PARTNER_PROVIDER, not available for DEDICATED. Corresponds to the JSON property partnerAsn

Returns:

  • (Fixnum)


35985
35986
35987
# File 'lib/google/apis/compute_alpha/classes.rb', line 35985

def partner_asn
  @partner_asn
end

#partner_metadataGoogle::Apis::ComputeAlpha::InterconnectAttachmentPartnerMetadata

Informational metadata about Partner attachments from Partners to display to customers. These fields are propagated from PARTNER_PROVIDER attachments to their corresponding PARTNER attachments. Corresponds to the JSON property partnerMetadata



35992
35993
35994
# File 'lib/google/apis/compute_alpha/classes.rb', line 35992

def 
  @partner_metadata
end

#regionString

The region that the Attachment is in. Corresponds to the JSON property region

Returns:

  • (String)


35997
35998
35999
# File 'lib/google/apis/compute_alpha/classes.rb', line 35997

def region
  @region
end

#routerString

URL of the Cloud Router to be used for dynamic routing. This router must be in the same region as this InterconnectAttachment. The InterconnectAttachment will automatically connect the Interconnect to the network & region within which the Cloud Router is configured. Corresponds to the JSON property router

Returns:

  • (String)


36005
36006
36007
# File 'lib/google/apis/compute_alpha/classes.rb', line 36005

def router
  @router
end

#stack_typeString

The stack type for this interconnect attachment to identify whether the IPv6 feature is enabled or not. If not specified, IPV4_ONLY will be used. This field can be both set at interconnect attachments creation and update interconnect attachment operations. Corresponds to the JSON property stackType

Returns:

  • (String)


36014
36015
36016
# File 'lib/google/apis/compute_alpha/classes.rb', line 36014

def stack_type
  @stack_type
end

#subnet_lengthFixnum

Input only. Length of the IPv4 subnet mask. Allowed values:

  • 29 (default)
  • 30 The default value is 29, except for Cross-Cloud Interconnect connections that use an InterconnectRemoteLocation with a constraints.subnetLengthRange.min equal to 30. For example, connections that use an Azure remote location fall into this category. In these cases, the default value is 30, and requesting 29 returns an error. Where both 29 and 30 are allowed, 29 is preferred, because it gives Google Cloud Support more debugging visibility. Corresponds to the JSON property subnetLength

Returns:

  • (Fixnum)


36032
36033
36034
# File 'lib/google/apis/compute_alpha/classes.rb', line 36032

def subnet_length
  @subnet_length
end

#typeString

The type of interconnect attachment this is, which can take one of the following values:

  • DEDICATED: an attachment to a Dedicated Interconnect.
  • PARTNER: an attachment to a Partner Interconnect, created by the customer.
  • PARTNER_PROVIDER: an attachment to a Partner Interconnect, created by the partner. Corresponds to the JSON property type

Returns:

  • (String)


36044
36045
36046
# File 'lib/google/apis/compute_alpha/classes.rb', line 36044

def type
  @type
end

#vlan_tag8021qFixnum

The IEEE 802.1Q VLAN tag for this attachment, in the range 2-4093. Only specified at creation time. Corresponds to the JSON property vlanTag8021q

Returns:

  • (Fixnum)


36050
36051
36052
# File 'lib/google/apis/compute_alpha/classes.rb', line 36050

def vlan_tag8021q
  @vlan_tag8021q
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



36057
36058
36059
36060
36061
36062
36063
36064
36065
36066
36067
36068
36069
36070
36071
36072
36073
36074
36075
36076
36077
36078
36079
36080
36081
36082
36083
36084
36085
36086
# File 'lib/google/apis/compute_alpha/classes.rb', line 36057

def update!(**args)
  @admin_enabled = args[:admin_enabled] if args.key?(:admin_enabled)
  @bandwidth = args[:bandwidth] if args.key?(:bandwidth)
  @candidate_cloud_router_ip_address = args[:candidate_cloud_router_ip_address] if args.key?(:candidate_cloud_router_ip_address)
  @candidate_cloud_router_ipv6_address = args[:candidate_cloud_router_ipv6_address] if args.key?(:candidate_cloud_router_ipv6_address)
  @candidate_customer_router_ip_address = args[:candidate_customer_router_ip_address] if args.key?(:candidate_customer_router_ip_address)
  @candidate_customer_router_ipv6_address = args[:candidate_customer_router_ipv6_address] if args.key?(:candidate_customer_router_ipv6_address)
  @candidate_ipv6_subnets = args[:candidate_ipv6_subnets] if args.key?(:candidate_ipv6_subnets)
  @candidate_subnets = args[:candidate_subnets] if args.key?(:candidate_subnets)
  @cloud_router_ipv6_interface_id = args[:cloud_router_ipv6_interface_id] if args.key?(:cloud_router_ipv6_interface_id)
  @customer_router_ipv6_interface_id = args[:customer_router_ipv6_interface_id] if args.key?(:customer_router_ipv6_interface_id)
  @description = args[:description] if args.key?(:description)
  @edge_availability_domain = args[:edge_availability_domain] if args.key?(:edge_availability_domain)
  @encryption = args[:encryption] if args.key?(:encryption)
  @interconnect = args[:interconnect] if args.key?(:interconnect)
  @ipsec_internal_addresses = args[:ipsec_internal_addresses] if args.key?(:ipsec_internal_addresses)
  @l2_forwarding = args[:l2_forwarding] if args.key?(:l2_forwarding)
  @mtu = args[:mtu] if args.key?(:mtu)
  @multicast_enabled = args[:multicast_enabled] if args.key?(:multicast_enabled)
  @name = args[:name] if args.key?(:name)
  @pairing_key = args[:pairing_key] if args.key?(:pairing_key)
  @partner_asn = args[:partner_asn] if args.key?(:partner_asn)
  @partner_metadata = args[:partner_metadata] if args.key?(:partner_metadata)
  @region = args[:region] if args.key?(:region)
  @router = args[:router] if args.key?(:router)
  @stack_type = args[:stack_type] if args.key?(:stack_type)
  @subnet_length = args[:subnet_length] if args.key?(:subnet_length)
  @type = args[:type] if args.key?(:type)
  @vlan_tag8021q = args[:vlan_tag8021q] if args.key?(:vlan_tag8021q)
end