Class: Google::Apis::ComputeAlpha::InterconnectAttachmentGroupsListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectAttachmentGroupsListResponse

Returns a new instance of InterconnectAttachmentGroupsListResponse.



36463
36464
36465
# File 'lib/google/apis/compute_alpha/classes.rb', line 36463

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


36419
36420
36421
# File 'lib/google/apis/compute_alpha/classes.rb', line 36419

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


36424
36425
36426
# File 'lib/google/apis/compute_alpha/classes.rb', line 36424

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::InterconnectAttachmentGroup>

A list of InterconnectAttachmentGroup resources. Corresponds to the JSON property items



36429
36430
36431
# File 'lib/google/apis/compute_alpha/classes.rb', line 36429

def items
  @items
end

#kindString

Corresponds to the JSON property kind

Returns:

  • (String)


36434
36435
36436
# File 'lib/google/apis/compute_alpha/classes.rb', line 36434

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


36444
36445
36446
# File 'lib/google/apis/compute_alpha/classes.rb', line 36444

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


36449
36450
36451
# File 'lib/google/apis/compute_alpha/classes.rb', line 36449

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


36456
36457
36458
# File 'lib/google/apis/compute_alpha/classes.rb', line 36456

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::InterconnectAttachmentGroupsListResponse::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



36461
36462
36463
# File 'lib/google/apis/compute_alpha/classes.rb', line 36461

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



36468
36469
36470
36471
36472
36473
36474
36475
36476
36477
# File 'lib/google/apis/compute_alpha/classes.rb', line 36468

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end