Class: Google::Apis::ComputeAlpha::InterconnectAttachmentGroupsListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectAttachmentGroupsListResponse

Returns a new instance of InterconnectAttachmentGroupsListResponse.



36184
36185
36186
# File 'lib/google/apis/compute_alpha/classes.rb', line 36184

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


36140
36141
36142
# File 'lib/google/apis/compute_alpha/classes.rb', line 36140

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


36145
36146
36147
# File 'lib/google/apis/compute_alpha/classes.rb', line 36145

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::InterconnectAttachmentGroup>

A list of InterconnectAttachmentGroup resources. Corresponds to the JSON property items



36150
36151
36152
# File 'lib/google/apis/compute_alpha/classes.rb', line 36150

def items
  @items
end

#kindString

Corresponds to the JSON property kind

Returns:

  • (String)


36155
36156
36157
# File 'lib/google/apis/compute_alpha/classes.rb', line 36155

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


36165
36166
36167
# File 'lib/google/apis/compute_alpha/classes.rb', line 36165

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


36170
36171
36172
# File 'lib/google/apis/compute_alpha/classes.rb', line 36170

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


36177
36178
36179
# File 'lib/google/apis/compute_alpha/classes.rb', line 36177

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::InterconnectAttachmentGroupsListResponse::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



36182
36183
36184
# File 'lib/google/apis/compute_alpha/classes.rb', line 36182

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



36189
36190
36191
36192
36193
36194
36195
36196
36197
36198
# File 'lib/google/apis/compute_alpha/classes.rb', line 36189

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end