Class: Google::Apis::ComputeAlpha::InterconnectAttachmentGroupsListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectAttachmentGroupsListResponse

Returns a new instance of InterconnectAttachmentGroupsListResponse.



35432
35433
35434
# File 'lib/google/apis/compute_alpha/classes.rb', line 35432

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


35388
35389
35390
# File 'lib/google/apis/compute_alpha/classes.rb', line 35388

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


35393
35394
35395
# File 'lib/google/apis/compute_alpha/classes.rb', line 35393

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::InterconnectAttachmentGroup>

A list of InterconnectAttachmentGroup resources. Corresponds to the JSON property items



35398
35399
35400
# File 'lib/google/apis/compute_alpha/classes.rb', line 35398

def items
  @items
end

#kindString

Corresponds to the JSON property kind

Returns:

  • (String)


35403
35404
35405
# File 'lib/google/apis/compute_alpha/classes.rb', line 35403

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


35413
35414
35415
# File 'lib/google/apis/compute_alpha/classes.rb', line 35413

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


35418
35419
35420
# File 'lib/google/apis/compute_alpha/classes.rb', line 35418

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


35425
35426
35427
# File 'lib/google/apis/compute_alpha/classes.rb', line 35425

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::InterconnectAttachmentGroupsListResponse::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



35430
35431
35432
# File 'lib/google/apis/compute_alpha/classes.rb', line 35430

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



35437
35438
35439
35440
35441
35442
35443
35444
35445
35446
# File 'lib/google/apis/compute_alpha/classes.rb', line 35437

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end