Class: Google::Apis::ComputeAlpha::InterconnectAttachmentGroupsListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectAttachmentGroupsListResponse

Returns a new instance of InterconnectAttachmentGroupsListResponse.



35424
35425
35426
# File 'lib/google/apis/compute_alpha/classes.rb', line 35424

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


35380
35381
35382
# File 'lib/google/apis/compute_alpha/classes.rb', line 35380

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


35385
35386
35387
# File 'lib/google/apis/compute_alpha/classes.rb', line 35385

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::InterconnectAttachmentGroup>

A list of InterconnectAttachmentGroup resources. Corresponds to the JSON property items



35390
35391
35392
# File 'lib/google/apis/compute_alpha/classes.rb', line 35390

def items
  @items
end

#kindString

Corresponds to the JSON property kind

Returns:

  • (String)


35395
35396
35397
# File 'lib/google/apis/compute_alpha/classes.rb', line 35395

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


35405
35406
35407
# File 'lib/google/apis/compute_alpha/classes.rb', line 35405

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


35410
35411
35412
# File 'lib/google/apis/compute_alpha/classes.rb', line 35410

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


35417
35418
35419
# File 'lib/google/apis/compute_alpha/classes.rb', line 35417

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::InterconnectAttachmentGroupsListResponse::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



35422
35423
35424
# File 'lib/google/apis/compute_alpha/classes.rb', line 35422

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



35429
35430
35431
35432
35433
35434
35435
35436
35437
35438
# File 'lib/google/apis/compute_alpha/classes.rb', line 35429

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end