Class: Google::Apis::ComputeAlpha::InterconnectAttachmentGroupsListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectAttachmentGroupsListResponse

Returns a new instance of InterconnectAttachmentGroupsListResponse.



35208
35209
35210
# File 'lib/google/apis/compute_alpha/classes.rb', line 35208

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


35164
35165
35166
# File 'lib/google/apis/compute_alpha/classes.rb', line 35164

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


35169
35170
35171
# File 'lib/google/apis/compute_alpha/classes.rb', line 35169

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::InterconnectAttachmentGroup>

A list of InterconnectAttachmentGroup resources. Corresponds to the JSON property items



35174
35175
35176
# File 'lib/google/apis/compute_alpha/classes.rb', line 35174

def items
  @items
end

#kindString

Corresponds to the JSON property kind

Returns:

  • (String)


35179
35180
35181
# File 'lib/google/apis/compute_alpha/classes.rb', line 35179

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


35189
35190
35191
# File 'lib/google/apis/compute_alpha/classes.rb', line 35189

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


35194
35195
35196
# File 'lib/google/apis/compute_alpha/classes.rb', line 35194

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


35201
35202
35203
# File 'lib/google/apis/compute_alpha/classes.rb', line 35201

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::InterconnectAttachmentGroupsListResponse::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



35206
35207
35208
# File 'lib/google/apis/compute_alpha/classes.rb', line 35206

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



35213
35214
35215
35216
35217
35218
35219
35220
35221
35222
# File 'lib/google/apis/compute_alpha/classes.rb', line 35213

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end