Class: Google::Apis::ComputeAlpha::InterconnectAttachmentGroupsListResponse
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::InterconnectAttachmentGroupsListResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::InterconnectAttachmentGroup>
A list of InterconnectAttachmentGroup resources.
-
#kind ⇒ String
Corresponds to the JSON property
kind. -
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::InterconnectAttachmentGroupsListResponse::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InterconnectAttachmentGroupsListResponse
constructor
A new instance of InterconnectAttachmentGroupsListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InterconnectAttachmentGroupsListResponse
Returns a new instance of InterconnectAttachmentGroupsListResponse.
35208 35209 35210 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 35208 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
35164 35165 35166 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 35164 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
35169 35170 35171 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 35169 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::InterconnectAttachmentGroup>
A list of InterconnectAttachmentGroup resources.
Corresponds to the JSON property items
35174 35175 35176 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 35174 def items @items end |
#kind ⇒ String
Corresponds to the JSON property kind
35179 35180 35181 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 35179 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
35189 35190 35191 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 35189 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
35194 35195 35196 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 35194 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
end_interface:
MixerListResponseWithEtagBuilder
Corresponds to the JSON property unreachables
35201 35202 35203 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 35201 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::InterconnectAttachmentGroupsListResponse::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
35206 35207 35208 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 35206 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
35213 35214 35215 35216 35217 35218 35219 35220 35221 35222 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 35213 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |