Class: Google::Apis::ComputeAlpha::InterconnectAttachmentGroupsListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectAttachmentGroupsListResponse

Returns a new instance of InterconnectAttachmentGroupsListResponse.



35218
35219
35220
# File 'lib/google/apis/compute_alpha/classes.rb', line 35218

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


35174
35175
35176
# File 'lib/google/apis/compute_alpha/classes.rb', line 35174

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


35179
35180
35181
# File 'lib/google/apis/compute_alpha/classes.rb', line 35179

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::InterconnectAttachmentGroup>

A list of InterconnectAttachmentGroup resources. Corresponds to the JSON property items



35184
35185
35186
# File 'lib/google/apis/compute_alpha/classes.rb', line 35184

def items
  @items
end

#kindString

Corresponds to the JSON property kind

Returns:

  • (String)


35189
35190
35191
# File 'lib/google/apis/compute_alpha/classes.rb', line 35189

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


35199
35200
35201
# File 'lib/google/apis/compute_alpha/classes.rb', line 35199

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


35204
35205
35206
# File 'lib/google/apis/compute_alpha/classes.rb', line 35204

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


35211
35212
35213
# File 'lib/google/apis/compute_alpha/classes.rb', line 35211

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::InterconnectAttachmentGroupsListResponse::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



35216
35217
35218
# File 'lib/google/apis/compute_alpha/classes.rb', line 35216

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



35223
35224
35225
35226
35227
35228
35229
35230
35231
35232
# File 'lib/google/apis/compute_alpha/classes.rb', line 35223

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end