Class: Google::Apis::ComputeAlpha::InterconnectAttachmentGroupsListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectAttachmentGroupsListResponse

Returns a new instance of InterconnectAttachmentGroupsListResponse.



34363
34364
34365
# File 'lib/google/apis/compute_alpha/classes.rb', line 34363

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


34319
34320
34321
# File 'lib/google/apis/compute_alpha/classes.rb', line 34319

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


34324
34325
34326
# File 'lib/google/apis/compute_alpha/classes.rb', line 34324

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::InterconnectAttachmentGroup>

A list of InterconnectAttachmentGroup resources. Corresponds to the JSON property items



34329
34330
34331
# File 'lib/google/apis/compute_alpha/classes.rb', line 34329

def items
  @items
end

#kindString

Corresponds to the JSON property kind

Returns:

  • (String)


34334
34335
34336
# File 'lib/google/apis/compute_alpha/classes.rb', line 34334

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


34344
34345
34346
# File 'lib/google/apis/compute_alpha/classes.rb', line 34344

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


34349
34350
34351
# File 'lib/google/apis/compute_alpha/classes.rb', line 34349

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


34356
34357
34358
# File 'lib/google/apis/compute_alpha/classes.rb', line 34356

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::InterconnectAttachmentGroupsListResponse::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



34361
34362
34363
# File 'lib/google/apis/compute_alpha/classes.rb', line 34361

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



34368
34369
34370
34371
34372
34373
34374
34375
34376
34377
# File 'lib/google/apis/compute_alpha/classes.rb', line 34368

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end