Class: Google::Apis::ComputeAlpha::InterconnectAttachmentGroupsOperationalStatus
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::InterconnectAttachmentGroupsOperationalStatus
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#attachment_statuses ⇒ Array<Google::Apis::ComputeAlpha::InterconnectAttachmentGroupsOperationalStatusAttachmentStatus>
Corresponds to the JSON property
attachmentStatuses. -
#configured ⇒ Google::Apis::ComputeAlpha::InterconnectAttachmentGroupConfigured
[Output Only] The redundancy this group is configured to support.
-
#group_status ⇒ String
Output only.
-
#intent ⇒ Google::Apis::ComputeAlpha::InterconnectAttachmentGroupIntent
The user's intent for this AttachmentGroup.
-
#operational ⇒ Google::Apis::ComputeAlpha::InterconnectAttachmentGroupConfigured
[Output Only] The redundancy this group is configured to support.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InterconnectAttachmentGroupsOperationalStatus
constructor
A new instance of InterconnectAttachmentGroupsOperationalStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InterconnectAttachmentGroupsOperationalStatus
Returns a new instance of InterconnectAttachmentGroupsOperationalStatus.
35545 35546 35547 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 35545 def initialize(**args) update!(**args) end |
Instance Attribute Details
#attachment_statuses ⇒ Array<Google::Apis::ComputeAlpha::InterconnectAttachmentGroupsOperationalStatusAttachmentStatus>
Corresponds to the JSON property attachmentStatuses
35518 35519 35520 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 35518 def @attachment_statuses end |
#configured ⇒ Google::Apis::ComputeAlpha::InterconnectAttachmentGroupConfigured
[Output Only] The redundancy this group is configured to support. The way a
user queries what SLA their Attachment gets is by looking at this field of
the Attachment's AttachmentGroup.
Corresponds to the JSON property configured
35525 35526 35527 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 35525 def configured @configured end |
#group_status ⇒ String
Output only. Summarizes the status of the group.
Corresponds to the JSON property groupStatus
35530 35531 35532 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 35530 def group_status @group_status end |
#intent ⇒ Google::Apis::ComputeAlpha::InterconnectAttachmentGroupIntent
The user's intent for this AttachmentGroup. This is the only required field
besides the name that must be specified on group creation.
Corresponds to the JSON property intent
35536 35537 35538 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 35536 def intent @intent end |
#operational ⇒ Google::Apis::ComputeAlpha::InterconnectAttachmentGroupConfigured
[Output Only] The redundancy this group is configured to support. The way a
user queries what SLA their Attachment gets is by looking at this field of
the Attachment's AttachmentGroup.
Corresponds to the JSON property operational
35543 35544 35545 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 35543 def operational @operational end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
35550 35551 35552 35553 35554 35555 35556 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 35550 def update!(**args) @attachment_statuses = args[:attachment_statuses] if args.key?(:attachment_statuses) @configured = args[:configured] if args.key?(:configured) @group_status = args[:group_status] if args.key?(:group_status) @intent = args[:intent] if args.key?(:intent) @operational = args[:operational] if args.key?(:operational) end |