Class: Google::Apis::ComputeAlpha::InterconnectAttachmentGroupsOperationalStatus
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::InterconnectAttachmentGroupsOperationalStatus
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#attachment_statuses ⇒ Array<Google::Apis::ComputeAlpha::InterconnectAttachmentGroupsOperationalStatusAttachmentStatus>
Corresponds to the JSON property
attachmentStatuses. -
#configured ⇒ Google::Apis::ComputeAlpha::InterconnectAttachmentGroupConfigured
[Output Only] The redundancy this group is configured to support.
-
#group_status ⇒ String
Output only.
-
#intent ⇒ Google::Apis::ComputeAlpha::InterconnectAttachmentGroupIntent
The user's intent for this AttachmentGroup.
-
#operational ⇒ Google::Apis::ComputeAlpha::InterconnectAttachmentGroupConfigured
[Output Only] The redundancy this group is configured to support.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InterconnectAttachmentGroupsOperationalStatus
constructor
A new instance of InterconnectAttachmentGroupsOperationalStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InterconnectAttachmentGroupsOperationalStatus
Returns a new instance of InterconnectAttachmentGroupsOperationalStatus.
35329 35330 35331 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 35329 def initialize(**args) update!(**args) end |
Instance Attribute Details
#attachment_statuses ⇒ Array<Google::Apis::ComputeAlpha::InterconnectAttachmentGroupsOperationalStatusAttachmentStatus>
Corresponds to the JSON property attachmentStatuses
35302 35303 35304 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 35302 def @attachment_statuses end |
#configured ⇒ Google::Apis::ComputeAlpha::InterconnectAttachmentGroupConfigured
[Output Only] The redundancy this group is configured to support. The way a
user queries what SLA their Attachment gets is by looking at this field of
the Attachment's AttachmentGroup.
Corresponds to the JSON property configured
35309 35310 35311 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 35309 def configured @configured end |
#group_status ⇒ String
Output only. Summarizes the status of the group.
Corresponds to the JSON property groupStatus
35314 35315 35316 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 35314 def group_status @group_status end |
#intent ⇒ Google::Apis::ComputeAlpha::InterconnectAttachmentGroupIntent
The user's intent for this AttachmentGroup. This is the only required field
besides the name that must be specified on group creation.
Corresponds to the JSON property intent
35320 35321 35322 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 35320 def intent @intent end |
#operational ⇒ Google::Apis::ComputeAlpha::InterconnectAttachmentGroupConfigured
[Output Only] The redundancy this group is configured to support. The way a
user queries what SLA their Attachment gets is by looking at this field of
the Attachment's AttachmentGroup.
Corresponds to the JSON property operational
35327 35328 35329 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 35327 def operational @operational end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
35334 35335 35336 35337 35338 35339 35340 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 35334 def update!(**args) @attachment_statuses = args[:attachment_statuses] if args.key?(:attachment_statuses) @configured = args[:configured] if args.key?(:configured) @group_status = args[:group_status] if args.key?(:group_status) @intent = args[:intent] if args.key?(:intent) @operational = args[:operational] if args.key?(:operational) end |