Class: Google::Apis::ComputeAlpha::InterconnectAttachmentGroupsOperationalStatus

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectAttachmentGroupsOperationalStatus

Returns a new instance of InterconnectAttachmentGroupsOperationalStatus.



35339
35340
35341
# File 'lib/google/apis/compute_alpha/classes.rb', line 35339

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#attachment_statusesArray<Google::Apis::ComputeAlpha::InterconnectAttachmentGroupsOperationalStatusAttachmentStatus>

Corresponds to the JSON property attachmentStatuses



35312
35313
35314
# File 'lib/google/apis/compute_alpha/classes.rb', line 35312

def attachment_statuses
  @attachment_statuses
end

#configuredGoogle::Apis::ComputeAlpha::InterconnectAttachmentGroupConfigured

[Output Only] The redundancy this group is configured to support. The way a user queries what SLA their Attachment gets is by looking at this field of the Attachment's AttachmentGroup. Corresponds to the JSON property configured



35319
35320
35321
# File 'lib/google/apis/compute_alpha/classes.rb', line 35319

def configured
  @configured
end

#group_statusString

Output only. Summarizes the status of the group. Corresponds to the JSON property groupStatus

Returns:

  • (String)


35324
35325
35326
# File 'lib/google/apis/compute_alpha/classes.rb', line 35324

def group_status
  @group_status
end

#intentGoogle::Apis::ComputeAlpha::InterconnectAttachmentGroupIntent

The user's intent for this AttachmentGroup. This is the only required field besides the name that must be specified on group creation. Corresponds to the JSON property intent



35330
35331
35332
# File 'lib/google/apis/compute_alpha/classes.rb', line 35330

def intent
  @intent
end

#operationalGoogle::Apis::ComputeAlpha::InterconnectAttachmentGroupConfigured

[Output Only] The redundancy this group is configured to support. The way a user queries what SLA their Attachment gets is by looking at this field of the Attachment's AttachmentGroup. Corresponds to the JSON property operational



35337
35338
35339
# File 'lib/google/apis/compute_alpha/classes.rb', line 35337

def operational
  @operational
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



35344
35345
35346
35347
35348
35349
35350
# File 'lib/google/apis/compute_alpha/classes.rb', line 35344

def update!(**args)
  @attachment_statuses = args[:attachment_statuses] if args.key?(:attachment_statuses)
  @configured = args[:configured] if args.key?(:configured)
  @group_status = args[:group_status] if args.key?(:group_status)
  @intent = args[:intent] if args.key?(:intent)
  @operational = args[:operational] if args.key?(:operational)
end