Class: Google::Apis::ComputeAlpha::InterconnectAttachmentGroupsOperationalStatus

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectAttachmentGroupsOperationalStatus

Returns a new instance of InterconnectAttachmentGroupsOperationalStatus.



35201
35202
35203
# File 'lib/google/apis/compute_alpha/classes.rb', line 35201

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#attachment_statusesArray<Google::Apis::ComputeAlpha::InterconnectAttachmentGroupsOperationalStatusAttachmentStatus>

Corresponds to the JSON property attachmentStatuses



35174
35175
35176
# File 'lib/google/apis/compute_alpha/classes.rb', line 35174

def attachment_statuses
  @attachment_statuses
end

#configuredGoogle::Apis::ComputeAlpha::InterconnectAttachmentGroupConfigured

[Output Only] The redundancy this group is configured to support. The way a user queries what SLA their Attachment gets is by looking at this field of the Attachment's AttachmentGroup. Corresponds to the JSON property configured



35181
35182
35183
# File 'lib/google/apis/compute_alpha/classes.rb', line 35181

def configured
  @configured
end

#group_statusString

Output only. Summarizes the status of the group. Corresponds to the JSON property groupStatus

Returns:

  • (String)


35186
35187
35188
# File 'lib/google/apis/compute_alpha/classes.rb', line 35186

def group_status
  @group_status
end

#intentGoogle::Apis::ComputeAlpha::InterconnectAttachmentGroupIntent

The user's intent for this AttachmentGroup. This is the only required field besides the name that must be specified on group creation. Corresponds to the JSON property intent



35192
35193
35194
# File 'lib/google/apis/compute_alpha/classes.rb', line 35192

def intent
  @intent
end

#operationalGoogle::Apis::ComputeAlpha::InterconnectAttachmentGroupConfigured

[Output Only] The redundancy this group is configured to support. The way a user queries what SLA their Attachment gets is by looking at this field of the Attachment's AttachmentGroup. Corresponds to the JSON property operational



35199
35200
35201
# File 'lib/google/apis/compute_alpha/classes.rb', line 35199

def operational
  @operational
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



35206
35207
35208
35209
35210
35211
35212
# File 'lib/google/apis/compute_alpha/classes.rb', line 35206

def update!(**args)
  @attachment_statuses = args[:attachment_statuses] if args.key?(:attachment_statuses)
  @configured = args[:configured] if args.key?(:configured)
  @group_status = args[:group_status] if args.key?(:group_status)
  @intent = args[:intent] if args.key?(:intent)
  @operational = args[:operational] if args.key?(:operational)
end