Class: Google::Apis::ComputeAlpha::InterconnectAttachmentGroupsOperationalStatus

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectAttachmentGroupsOperationalStatus

Returns a new instance of InterconnectAttachmentGroupsOperationalStatus.



34484
34485
34486
# File 'lib/google/apis/compute_alpha/classes.rb', line 34484

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#attachment_statusesArray<Google::Apis::ComputeAlpha::InterconnectAttachmentGroupsOperationalStatusAttachmentStatus>

Corresponds to the JSON property attachmentStatuses



34457
34458
34459
# File 'lib/google/apis/compute_alpha/classes.rb', line 34457

def attachment_statuses
  @attachment_statuses
end

#configuredGoogle::Apis::ComputeAlpha::InterconnectAttachmentGroupConfigured

[Output Only] The redundancy this group is configured to support. The way a user queries what SLA their Attachment gets is by looking at this field of the Attachment's AttachmentGroup. Corresponds to the JSON property configured



34464
34465
34466
# File 'lib/google/apis/compute_alpha/classes.rb', line 34464

def configured
  @configured
end

#group_statusString

Output only. Summarizes the status of the group. Corresponds to the JSON property groupStatus

Returns:

  • (String)


34469
34470
34471
# File 'lib/google/apis/compute_alpha/classes.rb', line 34469

def group_status
  @group_status
end

#intentGoogle::Apis::ComputeAlpha::InterconnectAttachmentGroupIntent

The user's intent for this AttachmentGroup. This is the only required field besides the name that must be specified on group creation. Corresponds to the JSON property intent



34475
34476
34477
# File 'lib/google/apis/compute_alpha/classes.rb', line 34475

def intent
  @intent
end

#operationalGoogle::Apis::ComputeAlpha::InterconnectAttachmentGroupConfigured

[Output Only] The redundancy this group is configured to support. The way a user queries what SLA their Attachment gets is by looking at this field of the Attachment's AttachmentGroup. Corresponds to the JSON property operational



34482
34483
34484
# File 'lib/google/apis/compute_alpha/classes.rb', line 34482

def operational
  @operational
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



34489
34490
34491
34492
34493
34494
34495
# File 'lib/google/apis/compute_alpha/classes.rb', line 34489

def update!(**args)
  @attachment_statuses = args[:attachment_statuses] if args.key?(:attachment_statuses)
  @configured = args[:configured] if args.key?(:configured)
  @group_status = args[:group_status] if args.key?(:group_status)
  @intent = args[:intent] if args.key?(:intent)
  @operational = args[:operational] if args.key?(:operational)
end