Class: Google::Apis::ComputeAlpha::InterconnectAttachmentGroupsOperationalStatusAttachmentStatus
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::InterconnectAttachmentGroupsOperationalStatusAttachmentStatus
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
The status of one Attachment in the group. List order is arbitrary.
Instance Attribute Summary collapse
-
#admin_enabled ⇒ Boolean
(also: #admin_enabled?)
Output only.
-
#attachment ⇒ String
Output only.
-
#is_active ⇒ String
Output only.
-
#status ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InterconnectAttachmentGroupsOperationalStatusAttachmentStatus
constructor
A new instance of InterconnectAttachmentGroupsOperationalStatusAttachmentStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InterconnectAttachmentGroupsOperationalStatusAttachmentStatus
Returns a new instance of InterconnectAttachmentGroupsOperationalStatusAttachmentStatus.
34529 34530 34531 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 34529 def initialize(**args) update!(**args) end |
Instance Attribute Details
#admin_enabled ⇒ Boolean Also known as: admin_enabled?
Output only. Whether this Attachment is enabled. This becomes false when the
customer
drains their Attachment.
Corresponds to the JSON property adminEnabled
34507 34508 34509 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 34507 def admin_enabled @admin_enabled end |
#attachment ⇒ String
Output only. The URL of the Attachment being described.
Corresponds to the JSON property attachment
34513 34514 34515 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 34513 def @attachment end |
#is_active ⇒ String
Output only. Whether this Attachment is participating in the redundant
configuration.
This will be ACTIVE if and only if the status below is CONNECTION_UP.
Any INACTIVE Attachments are excluded from the analysis that generates
operational.availabilitySLA.
Corresponds to the JSON property isActive
34522 34523 34524 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 34522 def is_active @is_active end |
#status ⇒ String
Output only. Whether this Attachment is active, and if so, whether BGP is up.
Corresponds to the JSON property status
34527 34528 34529 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 34527 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
34534 34535 34536 34537 34538 34539 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 34534 def update!(**args) @admin_enabled = args[:admin_enabled] if args.key?(:admin_enabled) @attachment = args[:attachment] if args.key?(:attachment) @is_active = args[:is_active] if args.key?(:is_active) @status = args[:status] if args.key?(:status) end |