Class: Google::Apis::ComputeAlpha::InterconnectAttachmentL2ForwardingApplianceMapping

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Two-level VLAN-to-Appliance mapping rule.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectAttachmentL2ForwardingApplianceMapping

Returns a new instance of InterconnectAttachmentL2ForwardingApplianceMapping.



35480
35481
35482
# File 'lib/google/apis/compute_alpha/classes.rb', line 35480

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#appliance_ip_addressString

Optional. A single IPv4 or IPv6 address used as the destination IP address for ingress packets that match on a VLAN tag, but do not match a more specific inner VLAN tag. Unset field (null-value) indicates both VLAN tags are required to be mapped. Otherwise, defaultApplianceIpAddress is used. Corresponds to the JSON property applianceIpAddress

Returns:

  • (String)


35464
35465
35466
# File 'lib/google/apis/compute_alpha/classes.rb', line 35464

def appliance_ip_address
  @appliance_ip_address
end

#inner_vlan_to_appliance_mappingsArray<Google::Apis::ComputeAlpha::InterconnectAttachmentL2ForwardingApplianceMappingInnerVlanToApplianceMapping>

Optional. Used to match against the inner VLAN when the packet contains two VLAN tags. A list of mapping rules from inner VLAN tags to IP addresses. If the inner VLAN is not explicitly mapped to an IP address range, the applianceIpAddress is used. Corresponds to the JSON property innerVlanToApplianceMappings



35473
35474
35475
# File 'lib/google/apis/compute_alpha/classes.rb', line 35473

def inner_vlan_to_appliance_mappings
  @inner_vlan_to_appliance_mappings
end

#nameString

Optional. The name of this appliance mapping rule. Corresponds to the JSON property name

Returns:

  • (String)


35478
35479
35480
# File 'lib/google/apis/compute_alpha/classes.rb', line 35478

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



35485
35486
35487
35488
35489
# File 'lib/google/apis/compute_alpha/classes.rb', line 35485

def update!(**args)
  @appliance_ip_address = args[:appliance_ip_address] if args.key?(:appliance_ip_address)
  @inner_vlan_to_appliance_mappings = args[:inner_vlan_to_appliance_mappings] if args.key?(:inner_vlan_to_appliance_mappings)
  @name = args[:name] if args.key?(:name)
end