Class: Google::Apis::ComputeAlpha::InterconnectAttachmentL2ForwardingApplianceMappingInnerVlanToApplianceMapping

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

The inner VLAN-to-Appliance mapping.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectAttachmentL2ForwardingApplianceMappingInnerVlanToApplianceMapping

Returns a new instance of InterconnectAttachmentL2ForwardingApplianceMappingInnerVlanToApplianceMapping.



34658
34659
34660
# File 'lib/google/apis/compute_alpha/classes.rb', line 34658

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#inner_appliance_ip_addressString

Required in this object. A single IPv4 or IPv6 address used as the destination IP address for ingress packets that match on both VLAN tags. Corresponds to the JSON property innerApplianceIpAddress

Returns:

  • (String)


34646
34647
34648
# File 'lib/google/apis/compute_alpha/classes.rb', line 34646

def inner_appliance_ip_address
  @inner_appliance_ip_address
end

#inner_vlan_tagsArray<String>

Required in this object. Used to match the inner VLAN tag on the packet. Each entry can be a single number or a range of numbers in the range of 1 to 4094, e.g., ["1", "4001-4094"] is valid. Non-empty and Non-overlapping VLAN tag ranges are enforced, and violating operations will be rejected. The inner VLAN tags must have an ethertype value of 0x8100. Corresponds to the JSON property innerVlanTags

Returns:

  • (Array<String>)


34656
34657
34658
# File 'lib/google/apis/compute_alpha/classes.rb', line 34656

def inner_vlan_tags
  @inner_vlan_tags
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



34663
34664
34665
34666
# File 'lib/google/apis/compute_alpha/classes.rb', line 34663

def update!(**args)
  @inner_appliance_ip_address = args[:inner_appliance_ip_address] if args.key?(:inner_appliance_ip_address)
  @inner_vlan_tags = args[:inner_vlan_tags] if args.key?(:inner_vlan_tags)
end