Class: Google::Apis::ComputeAlpha::InterconnectAttachmentList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::InterconnectAttachmentList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Response to the list request, and contains a list of interconnect attachments.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::InterconnectAttachment>
A list of InterconnectAttachment resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::InterconnectAttachmentList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InterconnectAttachmentList
constructor
A new instance of InterconnectAttachmentList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InterconnectAttachmentList
Returns a new instance of InterconnectAttachmentList.
36552 36553 36554 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 36552 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
36518 36519 36520 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 36518 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::InterconnectAttachment>
A list of InterconnectAttachment resources.
Corresponds to the JSON property items
36523 36524 36525 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 36523 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
interconnectAttachmentList for lists of interconnect
attachments.
Corresponds to the JSON property kind
36530 36531 36532 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 36530 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
36540 36541 36542 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 36540 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
36545 36546 36547 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 36545 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::InterconnectAttachmentList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
36550 36551 36552 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 36550 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
36557 36558 36559 36560 36561 36562 36563 36564 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 36557 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |