Class: Google::Apis::ComputeAlpha::InterconnectAttachmentList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Response to the list request, and contains a list of interconnect attachments.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectAttachmentList

Returns a new instance of InterconnectAttachmentList.



35792
35793
35794
# File 'lib/google/apis/compute_alpha/classes.rb', line 35792

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


35758
35759
35760
# File 'lib/google/apis/compute_alpha/classes.rb', line 35758

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::InterconnectAttachment>

A list of InterconnectAttachment resources. Corresponds to the JSON property items



35763
35764
35765
# File 'lib/google/apis/compute_alpha/classes.rb', line 35763

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# interconnectAttachmentList for lists of interconnect attachments. Corresponds to the JSON property kind

Returns:

  • (String)


35770
35771
35772
# File 'lib/google/apis/compute_alpha/classes.rb', line 35770

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


35780
35781
35782
# File 'lib/google/apis/compute_alpha/classes.rb', line 35780

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


35785
35786
35787
# File 'lib/google/apis/compute_alpha/classes.rb', line 35785

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::InterconnectAttachmentList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



35790
35791
35792
# File 'lib/google/apis/compute_alpha/classes.rb', line 35790

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



35797
35798
35799
35800
35801
35802
35803
35804
# File 'lib/google/apis/compute_alpha/classes.rb', line 35797

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end