Class: Google::Apis::ComputeAlpha::InterconnectAttachmentList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::InterconnectAttachmentList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Response to the list request, and contains a list of interconnect attachments.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::InterconnectAttachment>
A list of InterconnectAttachment resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::InterconnectAttachmentList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InterconnectAttachmentList
constructor
A new instance of InterconnectAttachmentList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InterconnectAttachmentList
Returns a new instance of InterconnectAttachmentList.
35576 35577 35578 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 35576 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
35542 35543 35544 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 35542 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::InterconnectAttachment>
A list of InterconnectAttachment resources.
Corresponds to the JSON property items
35547 35548 35549 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 35547 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
interconnectAttachmentList for lists of interconnect
attachments.
Corresponds to the JSON property kind
35554 35555 35556 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 35554 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
35564 35565 35566 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 35564 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
35569 35570 35571 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 35569 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::InterconnectAttachmentList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
35574 35575 35576 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 35574 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
35581 35582 35583 35584 35585 35586 35587 35588 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 35581 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |