Class: Google::Apis::ComputeAlpha::InterconnectAttachmentList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Response to the list request, and contains a list of interconnect attachments.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectAttachmentList

Returns a new instance of InterconnectAttachmentList.



35448
35449
35450
# File 'lib/google/apis/compute_alpha/classes.rb', line 35448

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


35414
35415
35416
# File 'lib/google/apis/compute_alpha/classes.rb', line 35414

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::InterconnectAttachment>

A list of InterconnectAttachment resources. Corresponds to the JSON property items



35419
35420
35421
# File 'lib/google/apis/compute_alpha/classes.rb', line 35419

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# interconnectAttachmentList for lists of interconnect attachments. Corresponds to the JSON property kind

Returns:

  • (String)


35426
35427
35428
# File 'lib/google/apis/compute_alpha/classes.rb', line 35426

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


35436
35437
35438
# File 'lib/google/apis/compute_alpha/classes.rb', line 35436

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


35441
35442
35443
# File 'lib/google/apis/compute_alpha/classes.rb', line 35441

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::InterconnectAttachmentList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



35446
35447
35448
# File 'lib/google/apis/compute_alpha/classes.rb', line 35446

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



35453
35454
35455
35456
35457
35458
35459
35460
# File 'lib/google/apis/compute_alpha/classes.rb', line 35453

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end