Class: Google::Apis::ComputeAlpha::InterconnectAttachmentPartnerMetadata
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::InterconnectAttachmentPartnerMetadata
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Informational metadata about Partner attachments from Partners to display to customers. These fields are propagated from PARTNER_PROVIDER attachments to their corresponding PARTNER attachments.
Instance Attribute Summary collapse
-
#interconnect_name ⇒ String
Plain text name of the Interconnect this attachment is connected to, as displayed in the Partner's portal.
-
#partner_name ⇒ String
Plain text name of the Partner providing this attachment.
-
#portal_url ⇒ String
URL of the Partner's portal for this Attachment.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InterconnectAttachmentPartnerMetadata
constructor
A new instance of InterconnectAttachmentPartnerMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InterconnectAttachmentPartnerMetadata
Returns a new instance of InterconnectAttachmentPartnerMetadata.
34874 34875 34876 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 34874 def initialize(**args) update!(**args) end |
Instance Attribute Details
#interconnect_name ⇒ String
Plain text name of the Interconnect this attachment is connected to, as
displayed in the Partner's portal. For instance "Chicago 1".
This value may be validated to match approved Partner values.
Corresponds to the JSON property interconnectName
34859 34860 34861 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 34859 def interconnect_name @interconnect_name end |
#partner_name ⇒ String
Plain text name of the Partner providing this attachment.
This value may be validated to match approved Partner values.
Corresponds to the JSON property partnerName
34865 34866 34867 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 34865 def partner_name @partner_name end |
#portal_url ⇒ String
URL of the Partner's portal for this Attachment. Partners may customise
this to be a deep link to the specific resource on the Partner portal.
This value may be validated to match approved Partner values.
Corresponds to the JSON property portalUrl
34872 34873 34874 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 34872 def portal_url @portal_url end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
34879 34880 34881 34882 34883 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 34879 def update!(**args) @interconnect_name = args[:interconnect_name] if args.key?(:interconnect_name) @partner_name = args[:partner_name] if args.key?(:partner_name) @portal_url = args[:portal_url] if args.key?(:portal_url) end |