Class: Google::Apis::ComputeAlpha::InterconnectCircuitInfo

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Describes a single physical circuit between the Customer and Google. CircuitInfo objects are created by Google, so all fields are output only.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectCircuitInfo

Returns a new instance of InterconnectCircuitInfo.



35742
35743
35744
# File 'lib/google/apis/compute_alpha/classes.rb', line 35742

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#customer_demarc_idString

Customer-side demarc ID for this circuit. Corresponds to the JSON property customerDemarcId

Returns:

  • (String)


35729
35730
35731
# File 'lib/google/apis/compute_alpha/classes.rb', line 35729

def customer_demarc_id
  @customer_demarc_id
end

#google_circuit_idString

Google-assigned unique ID for this circuit. Assigned at circuit turn-up. Corresponds to the JSON property googleCircuitId

Returns:

  • (String)


35734
35735
35736
# File 'lib/google/apis/compute_alpha/classes.rb', line 35734

def google_circuit_id
  @google_circuit_id
end

#google_demarc_idString

Google-side demarc ID for this circuit. Assigned at circuit turn-up and provided by Google to the customer in the LOA. Corresponds to the JSON property googleDemarcId

Returns:

  • (String)


35740
35741
35742
# File 'lib/google/apis/compute_alpha/classes.rb', line 35740

def google_demarc_id
  @google_demarc_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



35747
35748
35749
35750
35751
# File 'lib/google/apis/compute_alpha/classes.rb', line 35747

def update!(**args)
  @customer_demarc_id = args[:customer_demarc_id] if args.key?(:customer_demarc_id)
  @google_circuit_id = args[:google_circuit_id] if args.key?(:google_circuit_id)
  @google_demarc_id = args[:google_demarc_id] if args.key?(:google_demarc_id)
end