Class: Google::Apis::ComputeAlpha::InterconnectDiagnostics

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Diagnostics information about the Interconnect connection, which contains detailed and current technical information about Google's side of the connection.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectDiagnostics

Returns a new instance of InterconnectDiagnostics.



36893
36894
36895
# File 'lib/google/apis/compute_alpha/classes.rb', line 36893

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#arp_cachesArray<Google::Apis::ComputeAlpha::InterconnectDiagnosticsArpEntry>

A list of InterconnectDiagnostics.ARPEntry objects, describing individual neighbors currently seen by the Google router in the ARP cache for the Interconnect. This will be empty when the Interconnect is not bundled. Corresponds to the JSON property arpCaches



36870
36871
36872
# File 'lib/google/apis/compute_alpha/classes.rb', line 36870

def arp_caches
  @arp_caches
end

#bundle_aggregation_typeString

The aggregation type of the bundle interface. Corresponds to the JSON property bundleAggregationType

Returns:

  • (String)


36875
36876
36877
# File 'lib/google/apis/compute_alpha/classes.rb', line 36875

def bundle_aggregation_type
  @bundle_aggregation_type
end

#bundle_operational_statusString

The operational status of the bundle interface. Corresponds to the JSON property bundleOperationalStatus

Returns:

  • (String)


36880
36881
36882
# File 'lib/google/apis/compute_alpha/classes.rb', line 36880

def bundle_operational_status
  @bundle_operational_status
end

A list of InterconnectDiagnostics.LinkStatus objects, describing the status for each link on the Interconnect. Corresponds to the JSON property links



36886
36887
36888
# File 'lib/google/apis/compute_alpha/classes.rb', line 36886

def links
  @links
end

#mac_addressString

The MAC address of the Interconnect's bundle interface. Corresponds to the JSON property macAddress

Returns:

  • (String)


36891
36892
36893
# File 'lib/google/apis/compute_alpha/classes.rb', line 36891

def mac_address
  @mac_address
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



36898
36899
36900
36901
36902
36903
36904
# File 'lib/google/apis/compute_alpha/classes.rb', line 36898

def update!(**args)
  @arp_caches = args[:arp_caches] if args.key?(:arp_caches)
  @bundle_aggregation_type = args[:bundle_aggregation_type] if args.key?(:bundle_aggregation_type)
  @bundle_operational_status = args[:bundle_operational_status] if args.key?(:bundle_operational_status)
  @links = args[:links] if args.key?(:links)
  @mac_address = args[:mac_address] if args.key?(:mac_address)
end