Class: Google::Apis::ComputeAlpha::InterconnectDiagnosticsLinkStatus

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectDiagnosticsLinkStatus

Returns a new instance of InterconnectDiagnosticsLinkStatus.



37056
37057
37058
# File 'lib/google/apis/compute_alpha/classes.rb', line 37056

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#arp_cachesArray<Google::Apis::ComputeAlpha::InterconnectDiagnosticsArpEntry>

A list of InterconnectDiagnostics.ARPEntry objects, describing the ARP neighbor entries seen on this link. This will be empty if the link is bundled Corresponds to the JSON property arpCaches



37017
37018
37019
# File 'lib/google/apis/compute_alpha/classes.rb', line 37017

def arp_caches
  @arp_caches
end

#circuit_idString

The unique ID for this link assigned during turn up by Google. Corresponds to the JSON property circuitId

Returns:

  • (String)


37022
37023
37024
# File 'lib/google/apis/compute_alpha/classes.rb', line 37022

def circuit_id
  @circuit_id
end

#google_demarcString

The Demarc address assigned by Google and provided in the LoA. Corresponds to the JSON property googleDemarc

Returns:

  • (String)


37027
37028
37029
# File 'lib/google/apis/compute_alpha/classes.rb', line 37027

def google_demarc
  @google_demarc
end

#lacp_statusGoogle::Apis::ComputeAlpha::InterconnectDiagnosticsLinkLacpStatus

Corresponds to the JSON property lacpStatus



37032
37033
37034
# File 'lib/google/apis/compute_alpha/classes.rb', line 37032

def lacp_status
  @lacp_status
end

#macsecGoogle::Apis::ComputeAlpha::InterconnectDiagnosticsMacsecStatus

Describes the status of MACsec encryption on the link. Corresponds to the JSON property macsec



37037
37038
37039
# File 'lib/google/apis/compute_alpha/classes.rb', line 37037

def macsec
  @macsec
end

#operational_statusString

The operational status of the link. Corresponds to the JSON property operationalStatus

Returns:

  • (String)


37042
37043
37044
# File 'lib/google/apis/compute_alpha/classes.rb', line 37042

def operational_status
  @operational_status
end

#receiving_optical_powerGoogle::Apis::ComputeAlpha::InterconnectDiagnosticsLinkOpticalPower

An InterconnectDiagnostics.LinkOpticalPower object, describing the current value and status of the received light level. Corresponds to the JSON property receivingOpticalPower



37048
37049
37050
# File 'lib/google/apis/compute_alpha/classes.rb', line 37048

def receiving_optical_power
  @receiving_optical_power
end

#transmitting_optical_powerGoogle::Apis::ComputeAlpha::InterconnectDiagnosticsLinkOpticalPower

An InterconnectDiagnostics.LinkOpticalPower object, describing the current value and status of the transmitted light level. Corresponds to the JSON property transmittingOpticalPower



37054
37055
37056
# File 'lib/google/apis/compute_alpha/classes.rb', line 37054

def transmitting_optical_power
  @transmitting_optical_power
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



37061
37062
37063
37064
37065
37066
37067
37068
37069
37070
# File 'lib/google/apis/compute_alpha/classes.rb', line 37061

def update!(**args)
  @arp_caches = args[:arp_caches] if args.key?(:arp_caches)
  @circuit_id = args[:circuit_id] if args.key?(:circuit_id)
  @google_demarc = args[:google_demarc] if args.key?(:google_demarc)
  @lacp_status = args[:lacp_status] if args.key?(:lacp_status)
  @macsec = args[:macsec] if args.key?(:macsec)
  @operational_status = args[:operational_status] if args.key?(:operational_status)
  @receiving_optical_power = args[:receiving_optical_power] if args.key?(:receiving_optical_power)
  @transmitting_optical_power = args[:transmitting_optical_power] if args.key?(:transmitting_optical_power)
end