Class: Google::Apis::ComputeAlpha::InterconnectDiagnosticsLinkStatus

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectDiagnosticsLinkStatus

Returns a new instance of InterconnectDiagnosticsLinkStatus.



36304
36305
36306
# File 'lib/google/apis/compute_alpha/classes.rb', line 36304

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#arp_cachesArray<Google::Apis::ComputeAlpha::InterconnectDiagnosticsArpEntry>

A list of InterconnectDiagnostics.ARPEntry objects, describing the ARP neighbor entries seen on this link. This will be empty if the link is bundled Corresponds to the JSON property arpCaches



36265
36266
36267
# File 'lib/google/apis/compute_alpha/classes.rb', line 36265

def arp_caches
  @arp_caches
end

#circuit_idString

The unique ID for this link assigned during turn up by Google. Corresponds to the JSON property circuitId

Returns:

  • (String)


36270
36271
36272
# File 'lib/google/apis/compute_alpha/classes.rb', line 36270

def circuit_id
  @circuit_id
end

#google_demarcString

The Demarc address assigned by Google and provided in the LoA. Corresponds to the JSON property googleDemarc

Returns:

  • (String)


36275
36276
36277
# File 'lib/google/apis/compute_alpha/classes.rb', line 36275

def google_demarc
  @google_demarc
end

#lacp_statusGoogle::Apis::ComputeAlpha::InterconnectDiagnosticsLinkLacpStatus

Corresponds to the JSON property lacpStatus



36280
36281
36282
# File 'lib/google/apis/compute_alpha/classes.rb', line 36280

def lacp_status
  @lacp_status
end

#macsecGoogle::Apis::ComputeAlpha::InterconnectDiagnosticsMacsecStatus

Describes the status of MACsec encryption on the link. Corresponds to the JSON property macsec



36285
36286
36287
# File 'lib/google/apis/compute_alpha/classes.rb', line 36285

def macsec
  @macsec
end

#operational_statusString

The operational status of the link. Corresponds to the JSON property operationalStatus

Returns:

  • (String)


36290
36291
36292
# File 'lib/google/apis/compute_alpha/classes.rb', line 36290

def operational_status
  @operational_status
end

#receiving_optical_powerGoogle::Apis::ComputeAlpha::InterconnectDiagnosticsLinkOpticalPower

An InterconnectDiagnostics.LinkOpticalPower object, describing the current value and status of the received light level. Corresponds to the JSON property receivingOpticalPower



36296
36297
36298
# File 'lib/google/apis/compute_alpha/classes.rb', line 36296

def receiving_optical_power
  @receiving_optical_power
end

#transmitting_optical_powerGoogle::Apis::ComputeAlpha::InterconnectDiagnosticsLinkOpticalPower

An InterconnectDiagnostics.LinkOpticalPower object, describing the current value and status of the transmitted light level. Corresponds to the JSON property transmittingOpticalPower



36302
36303
36304
# File 'lib/google/apis/compute_alpha/classes.rb', line 36302

def transmitting_optical_power
  @transmitting_optical_power
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



36309
36310
36311
36312
36313
36314
36315
36316
36317
36318
# File 'lib/google/apis/compute_alpha/classes.rb', line 36309

def update!(**args)
  @arp_caches = args[:arp_caches] if args.key?(:arp_caches)
  @circuit_id = args[:circuit_id] if args.key?(:circuit_id)
  @google_demarc = args[:google_demarc] if args.key?(:google_demarc)
  @lacp_status = args[:lacp_status] if args.key?(:lacp_status)
  @macsec = args[:macsec] if args.key?(:macsec)
  @operational_status = args[:operational_status] if args.key?(:operational_status)
  @receiving_optical_power = args[:receiving_optical_power] if args.key?(:receiving_optical_power)
  @transmitting_optical_power = args[:transmitting_optical_power] if args.key?(:transmitting_optical_power)
end