Class: Google::Apis::ComputeAlpha::InterconnectDiagnosticsLinkStatus

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectDiagnosticsLinkStatus

Returns a new instance of InterconnectDiagnosticsLinkStatus.



36296
36297
36298
# File 'lib/google/apis/compute_alpha/classes.rb', line 36296

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#arp_cachesArray<Google::Apis::ComputeAlpha::InterconnectDiagnosticsArpEntry>

A list of InterconnectDiagnostics.ARPEntry objects, describing the ARP neighbor entries seen on this link. This will be empty if the link is bundled Corresponds to the JSON property arpCaches



36257
36258
36259
# File 'lib/google/apis/compute_alpha/classes.rb', line 36257

def arp_caches
  @arp_caches
end

#circuit_idString

The unique ID for this link assigned during turn up by Google. Corresponds to the JSON property circuitId

Returns:

  • (String)


36262
36263
36264
# File 'lib/google/apis/compute_alpha/classes.rb', line 36262

def circuit_id
  @circuit_id
end

#google_demarcString

The Demarc address assigned by Google and provided in the LoA. Corresponds to the JSON property googleDemarc

Returns:

  • (String)


36267
36268
36269
# File 'lib/google/apis/compute_alpha/classes.rb', line 36267

def google_demarc
  @google_demarc
end

#lacp_statusGoogle::Apis::ComputeAlpha::InterconnectDiagnosticsLinkLacpStatus

Corresponds to the JSON property lacpStatus



36272
36273
36274
# File 'lib/google/apis/compute_alpha/classes.rb', line 36272

def lacp_status
  @lacp_status
end

#macsecGoogle::Apis::ComputeAlpha::InterconnectDiagnosticsMacsecStatus

Describes the status of MACsec encryption on the link. Corresponds to the JSON property macsec



36277
36278
36279
# File 'lib/google/apis/compute_alpha/classes.rb', line 36277

def macsec
  @macsec
end

#operational_statusString

The operational status of the link. Corresponds to the JSON property operationalStatus

Returns:

  • (String)


36282
36283
36284
# File 'lib/google/apis/compute_alpha/classes.rb', line 36282

def operational_status
  @operational_status
end

#receiving_optical_powerGoogle::Apis::ComputeAlpha::InterconnectDiagnosticsLinkOpticalPower

An InterconnectDiagnostics.LinkOpticalPower object, describing the current value and status of the received light level. Corresponds to the JSON property receivingOpticalPower



36288
36289
36290
# File 'lib/google/apis/compute_alpha/classes.rb', line 36288

def receiving_optical_power
  @receiving_optical_power
end

#transmitting_optical_powerGoogle::Apis::ComputeAlpha::InterconnectDiagnosticsLinkOpticalPower

An InterconnectDiagnostics.LinkOpticalPower object, describing the current value and status of the transmitted light level. Corresponds to the JSON property transmittingOpticalPower



36294
36295
36296
# File 'lib/google/apis/compute_alpha/classes.rb', line 36294

def transmitting_optical_power
  @transmitting_optical_power
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



36301
36302
36303
36304
36305
36306
36307
36308
36309
36310
# File 'lib/google/apis/compute_alpha/classes.rb', line 36301

def update!(**args)
  @arp_caches = args[:arp_caches] if args.key?(:arp_caches)
  @circuit_id = args[:circuit_id] if args.key?(:circuit_id)
  @google_demarc = args[:google_demarc] if args.key?(:google_demarc)
  @lacp_status = args[:lacp_status] if args.key?(:lacp_status)
  @macsec = args[:macsec] if args.key?(:macsec)
  @operational_status = args[:operational_status] if args.key?(:operational_status)
  @receiving_optical_power = args[:receiving_optical_power] if args.key?(:receiving_optical_power)
  @transmitting_optical_power = args[:transmitting_optical_power] if args.key?(:transmitting_optical_power)
end