Class: Google::Apis::ComputeAlpha::InterconnectDiagnosticsLinkStatus

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectDiagnosticsLinkStatus

Returns a new instance of InterconnectDiagnosticsLinkStatus.



35952
35953
35954
# File 'lib/google/apis/compute_alpha/classes.rb', line 35952

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#arp_cachesArray<Google::Apis::ComputeAlpha::InterconnectDiagnosticsArpEntry>

A list of InterconnectDiagnostics.ARPEntry objects, describing the ARP neighbor entries seen on this link. This will be empty if the link is bundled Corresponds to the JSON property arpCaches



35913
35914
35915
# File 'lib/google/apis/compute_alpha/classes.rb', line 35913

def arp_caches
  @arp_caches
end

#circuit_idString

The unique ID for this link assigned during turn up by Google. Corresponds to the JSON property circuitId

Returns:

  • (String)


35918
35919
35920
# File 'lib/google/apis/compute_alpha/classes.rb', line 35918

def circuit_id
  @circuit_id
end

#google_demarcString

The Demarc address assigned by Google and provided in the LoA. Corresponds to the JSON property googleDemarc

Returns:

  • (String)


35923
35924
35925
# File 'lib/google/apis/compute_alpha/classes.rb', line 35923

def google_demarc
  @google_demarc
end

#lacp_statusGoogle::Apis::ComputeAlpha::InterconnectDiagnosticsLinkLacpStatus

Corresponds to the JSON property lacpStatus



35928
35929
35930
# File 'lib/google/apis/compute_alpha/classes.rb', line 35928

def lacp_status
  @lacp_status
end

#macsecGoogle::Apis::ComputeAlpha::InterconnectDiagnosticsMacsecStatus

Describes the status of MACsec encryption on the link. Corresponds to the JSON property macsec



35933
35934
35935
# File 'lib/google/apis/compute_alpha/classes.rb', line 35933

def macsec
  @macsec
end

#operational_statusString

The operational status of the link. Corresponds to the JSON property operationalStatus

Returns:

  • (String)


35938
35939
35940
# File 'lib/google/apis/compute_alpha/classes.rb', line 35938

def operational_status
  @operational_status
end

#receiving_optical_powerGoogle::Apis::ComputeAlpha::InterconnectDiagnosticsLinkOpticalPower

An InterconnectDiagnostics.LinkOpticalPower object, describing the current value and status of the received light level. Corresponds to the JSON property receivingOpticalPower



35944
35945
35946
# File 'lib/google/apis/compute_alpha/classes.rb', line 35944

def receiving_optical_power
  @receiving_optical_power
end

#transmitting_optical_powerGoogle::Apis::ComputeAlpha::InterconnectDiagnosticsLinkOpticalPower

An InterconnectDiagnostics.LinkOpticalPower object, describing the current value and status of the transmitted light level. Corresponds to the JSON property transmittingOpticalPower



35950
35951
35952
# File 'lib/google/apis/compute_alpha/classes.rb', line 35950

def transmitting_optical_power
  @transmitting_optical_power
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



35957
35958
35959
35960
35961
35962
35963
35964
35965
35966
# File 'lib/google/apis/compute_alpha/classes.rb', line 35957

def update!(**args)
  @arp_caches = args[:arp_caches] if args.key?(:arp_caches)
  @circuit_id = args[:circuit_id] if args.key?(:circuit_id)
  @google_demarc = args[:google_demarc] if args.key?(:google_demarc)
  @lacp_status = args[:lacp_status] if args.key?(:lacp_status)
  @macsec = args[:macsec] if args.key?(:macsec)
  @operational_status = args[:operational_status] if args.key?(:operational_status)
  @receiving_optical_power = args[:receiving_optical_power] if args.key?(:receiving_optical_power)
  @transmitting_optical_power = args[:transmitting_optical_power] if args.key?(:transmitting_optical_power)
end