Class: Google::Apis::ComputeAlpha::InterconnectGroup

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

An interconnect group resource allows customers to create, analyze, and expand their redundant connections.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectGroup

Returns a new instance of InterconnectGroup.



36218
36219
36220
# File 'lib/google/apis/compute_alpha/classes.rb', line 36218

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#configuredGoogle::Apis::ComputeAlpha::InterconnectGroupConfigured

[Output Only] The status of the group as configured. This has the same structure as the operational field reported by the OperationalStatus method, but does not take into account the operational status of each resource. Corresponds to the JSON property configured



36145
36146
36147
# File 'lib/google/apis/compute_alpha/classes.rb', line 36145

def configured
  @configured
end

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


36151
36152
36153
# File 'lib/google/apis/compute_alpha/classes.rb', line 36151

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


36157
36158
36159
# File 'lib/google/apis/compute_alpha/classes.rb', line 36157

def description
  @description
end

#etagString

Opaque system-generated token that uniquely identifies the configuration. If provided when patching a configuration in update mode, the provided token must match the current token or the update is rejected. This provides a reliable means of doing read-modify-write (optimistic locking) as described by AIP 154. Corresponds to the JSON property etag

Returns:

  • (String)


36166
36167
36168
# File 'lib/google/apis/compute_alpha/classes.rb', line 36166

def etag
  @etag
end

#idFixnum

Output only. [Output Only] The unique identifier for the resource type. The server generates this identifier. Corresponds to the JSON property id

Returns:

  • (Fixnum)


36173
36174
36175
# File 'lib/google/apis/compute_alpha/classes.rb', line 36173

def id
  @id
end

#intentGoogle::Apis::ComputeAlpha::InterconnectGroupIntent

The user's intent for this group. This is the only required field besides the name that must be specified on group creation. Corresponds to the JSON property intent



36179
36180
36181
# File 'lib/google/apis/compute_alpha/classes.rb', line 36179

def intent
  @intent
end

#interconnectsHash<String,Google::Apis::ComputeAlpha::InterconnectGroupInterconnect>

Interconnects in the InterconnectGroup. Keys are arbitrary user-specified strings. Users are encouraged, but not required, to use their preferred format for resource links as keys. Note that there are add-members and remove-members methods in gcloud. The size of this map is limited by an "Interconnects per group" quota. Corresponds to the JSON property interconnects



36188
36189
36190
# File 'lib/google/apis/compute_alpha/classes.rb', line 36188

def interconnects
  @interconnects
end

#kindString

Output only. [Output Only] Type of the resource. Always compute# InterconnectGroup Corresponds to the JSON property kind

Returns:

  • (String)


36194
36195
36196
# File 'lib/google/apis/compute_alpha/classes.rb', line 36194

def kind
  @kind
end

#nameString

Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


36205
36206
36207
# File 'lib/google/apis/compute_alpha/classes.rb', line 36205

def name
  @name
end

#physical_structureGoogle::Apis::ComputeAlpha::InterconnectGroupPhysicalStructure

[Output Only] An analysis of the physical layout of Interconnects in this group. Every Interconnect in the group is shown once in this structure. Corresponds to the JSON property physicalStructure



36211
36212
36213
# File 'lib/google/apis/compute_alpha/classes.rb', line 36211

def physical_structure
  @physical_structure
end

Output only. [Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


36216
36217
36218
# File 'lib/google/apis/compute_alpha/classes.rb', line 36216

def self_link
  @self_link
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



36223
36224
36225
36226
36227
36228
36229
36230
36231
36232
36233
36234
36235
# File 'lib/google/apis/compute_alpha/classes.rb', line 36223

def update!(**args)
  @configured = args[:configured] if args.key?(:configured)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @intent = args[:intent] if args.key?(:intent)
  @interconnects = args[:interconnects] if args.key?(:interconnects)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @physical_structure = args[:physical_structure] if args.key?(:physical_structure)
  @self_link = args[:self_link] if args.key?(:self_link)
end