Class: Google::Apis::ComputeAlpha::InterconnectGroup
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::InterconnectGroup
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
An interconnect group resource allows customers to create, analyze, and expand their redundant connections.
Instance Attribute Summary collapse
-
#configured ⇒ Google::Apis::ComputeAlpha::InterconnectGroupConfigured
[Output Only] The status of the group as configured.
-
#creation_timestamp ⇒ String
Output only.
-
#description ⇒ String
An optional description of this resource.
-
#etag ⇒ String
Opaque system-generated token that uniquely identifies the configuration.
-
#id ⇒ Fixnum
Output only.
-
#intent ⇒ Google::Apis::ComputeAlpha::InterconnectGroupIntent
The user's intent for this group.
-
#interconnects ⇒ Hash<String,Google::Apis::ComputeAlpha::InterconnectGroupInterconnect>
Interconnects in the InterconnectGroup.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
Name of the resource.
-
#physical_structure ⇒ Google::Apis::ComputeAlpha::InterconnectGroupPhysicalStructure
[Output Only] An analysis of the physical layout of Interconnects in this group.
-
#self_link ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InterconnectGroup
constructor
A new instance of InterconnectGroup.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InterconnectGroup
Returns a new instance of InterconnectGroup.
36080 36081 36082 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 36080 def initialize(**args) update!(**args) end |
Instance Attribute Details
#configured ⇒ Google::Apis::ComputeAlpha::InterconnectGroupConfigured
[Output Only] The status of the group as configured. This has the same
structure as the operational field reported by the OperationalStatus
method, but does not take into account the operational status of each
resource.
Corresponds to the JSON property configured
36007 36008 36009 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 36007 def configured @configured end |
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
36013 36014 36015 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 36013 def @creation_timestamp end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
36019 36020 36021 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 36019 def description @description end |
#etag ⇒ String
Opaque system-generated token that uniquely identifies the configuration.
If provided when patching a configuration in update mode, the provided
token must match the current token or the update is rejected. This provides
a reliable means of doing read-modify-write (optimistic locking) as
described by AIP 154.
Corresponds to the JSON property etag
36028 36029 36030 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 36028 def etag @etag end |
#id ⇒ Fixnum
Output only. [Output Only] The unique identifier for the resource type. The
server
generates this identifier.
Corresponds to the JSON property id
36035 36036 36037 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 36035 def id @id end |
#intent ⇒ Google::Apis::ComputeAlpha::InterconnectGroupIntent
The user's intent for this group. This is the only required field besides
the name that must be specified on group creation.
Corresponds to the JSON property intent
36041 36042 36043 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 36041 def intent @intent end |
#interconnects ⇒ Hash<String,Google::Apis::ComputeAlpha::InterconnectGroupInterconnect>
Interconnects in the InterconnectGroup. Keys are arbitrary user-specified
strings. Users are encouraged, but not required, to use their preferred
format for resource links as keys.
Note that there are add-members and remove-members methods in gcloud.
The size of this map is limited by an "Interconnects per group" quota.
Corresponds to the JSON property interconnects
36050 36051 36052 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 36050 def interconnects @interconnects end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Always compute#
InterconnectGroup
Corresponds to the JSON property kind
36056 36057 36058 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 36056 def kind @kind end |
#name ⇒ String
Name of the resource. Provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must
be a dash, lowercase letter, or digit, except the last character, which
cannot be a dash.
Corresponds to the JSON property name
36067 36068 36069 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 36067 def name @name end |
#physical_structure ⇒ Google::Apis::ComputeAlpha::InterconnectGroupPhysicalStructure
[Output Only] An analysis of the physical layout of Interconnects in this
group. Every Interconnect in the group is shown once in this structure.
Corresponds to the JSON property physicalStructure
36073 36074 36075 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 36073 def physical_structure @physical_structure end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
36078 36079 36080 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 36078 def self_link @self_link end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
36085 36086 36087 36088 36089 36090 36091 36092 36093 36094 36095 36096 36097 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 36085 def update!(**args) @configured = args[:configured] if args.key?(:configured) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @intent = args[:intent] if args.key?(:intent) @interconnects = args[:interconnects] if args.key?(:interconnects) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @physical_structure = args[:physical_structure] if args.key?(:physical_structure) @self_link = args[:self_link] if args.key?(:self_link) end |