Class: Google::Apis::ComputeAlpha::InterconnectGroupConfigured

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

[Output Only] The status of the group as configured. This has the same structure as the operational field reported by the OperationalStatus method, but does not take into account the operational status of each resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectGroupConfigured

Returns a new instance of InterconnectGroupConfigured.



36458
36459
36460
# File 'lib/google/apis/compute_alpha/classes.rb', line 36458

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#topology_capabilityGoogle::Apis::ComputeAlpha::InterconnectGroupConfiguredTopologyCapability

[Output Only] How reliable this topology is configured to be, and why this group does or does not meet the requirements for the intended capability. Corresponds to the JSON property topologyCapability



36456
36457
36458
# File 'lib/google/apis/compute_alpha/classes.rb', line 36456

def topology_capability
  @topology_capability
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



36463
36464
36465
# File 'lib/google/apis/compute_alpha/classes.rb', line 36463

def update!(**args)
  @topology_capability = args[:topology_capability] if args.key?(:topology_capability)
end