Class: Google::Apis::ComputeAlpha::InterconnectGroupConfigured
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::InterconnectGroupConfigured
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
[Output Only] The status of the group as configured. This has the same structure as the operational field reported by the OperationalStatus method, but does not take into account the operational status of each resource.
Instance Attribute Summary collapse
-
#topology_capability ⇒ Google::Apis::ComputeAlpha::InterconnectGroupConfiguredTopologyCapability
[Output Only] How reliable this topology is configured to be, and why this group does or does not meet the requirements for the intended capability.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InterconnectGroupConfigured
constructor
A new instance of InterconnectGroupConfigured.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InterconnectGroupConfigured
Returns a new instance of InterconnectGroupConfigured.
36242 36243 36244 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 36242 def initialize(**args) update!(**args) end |
Instance Attribute Details
#topology_capability ⇒ Google::Apis::ComputeAlpha::InterconnectGroupConfiguredTopologyCapability
[Output Only] How reliable this topology is configured to be, and why
this group does or does not meet the requirements for the intended
capability.
Corresponds to the JSON property topologyCapability
36240 36241 36242 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 36240 def topology_capability @topology_capability end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
36247 36248 36249 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 36247 def update!(**args) @topology_capability = args[:topology_capability] if args.key?(:topology_capability) end |