Class: Google::Apis::ComputeAlpha::InterconnectGroupConfiguredTopologyCapability

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

[Output Only] How reliable this topology is configured to be, and why this group does or does not meet the requirements for the intended capability.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectGroupConfiguredTopologyCapability

Returns a new instance of InterconnectGroupConfiguredTopologyCapability.



36484
36485
36486
# File 'lib/google/apis/compute_alpha/classes.rb', line 36484

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#intended_capability_blockersArray<Google::Apis::ComputeAlpha::InterconnectGroupConfiguredTopologyCapabilityIntendedCapabilityBlockers>

Corresponds to the JSON property intendedCapabilityBlockers



36477
36478
36479
# File 'lib/google/apis/compute_alpha/classes.rb', line 36477

def intended_capability_blockers
  @intended_capability_blockers
end

#supported_slaString

Corresponds to the JSON property supportedSla

Returns:

  • (String)


36482
36483
36484
# File 'lib/google/apis/compute_alpha/classes.rb', line 36482

def supported_sla
  @supported_sla
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



36489
36490
36491
36492
# File 'lib/google/apis/compute_alpha/classes.rb', line 36489

def update!(**args)
  @intended_capability_blockers = args[:intended_capability_blockers] if args.key?(:intended_capability_blockers)
  @supported_sla = args[:supported_sla] if args.key?(:supported_sla)
end