Class: Google::Apis::ComputeAlpha::InterconnectGroupConfiguredTopologyCapability

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

[Output Only] How reliable this topology is configured to be, and why this group does or does not meet the requirements for the intended capability.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectGroupConfiguredTopologyCapability

Returns a new instance of InterconnectGroupConfiguredTopologyCapability.



36278
36279
36280
# File 'lib/google/apis/compute_alpha/classes.rb', line 36278

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#intended_capability_blockersArray<Google::Apis::ComputeAlpha::InterconnectGroupConfiguredTopologyCapabilityIntendedCapabilityBlockers>

Corresponds to the JSON property intendedCapabilityBlockers



36271
36272
36273
# File 'lib/google/apis/compute_alpha/classes.rb', line 36271

def intended_capability_blockers
  @intended_capability_blockers
end

#supported_slaString

Corresponds to the JSON property supportedSla

Returns:

  • (String)


36276
36277
36278
# File 'lib/google/apis/compute_alpha/classes.rb', line 36276

def supported_sla
  @supported_sla
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



36283
36284
36285
36286
# File 'lib/google/apis/compute_alpha/classes.rb', line 36283

def update!(**args)
  @intended_capability_blockers = args[:intended_capability_blockers] if args.key?(:intended_capability_blockers)
  @supported_sla = args[:supported_sla] if args.key?(:supported_sla)
end