Class: Google::Apis::ComputeAlpha::InterconnectGroupPhysicalStructure

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

[Output Only] An analysis of the physical layout of Interconnects in this group. Every Interconnect in the group is shown once in this structure.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectGroupPhysicalStructure

Returns a new instance of InterconnectGroupPhysicalStructure.



37653
37654
37655
# File 'lib/google/apis/compute_alpha/classes.rb', line 37653

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#metrosArray<Google::Apis::ComputeAlpha::InterconnectGroupPhysicalStructureMetros>

Corresponds to the JSON property metros



37651
37652
37653
# File 'lib/google/apis/compute_alpha/classes.rb', line 37651

def metros
  @metros
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



37658
37659
37660
# File 'lib/google/apis/compute_alpha/classes.rb', line 37658

def update!(**args)
  @metros = args[:metros] if args.key?(:metros)
end