Class: Google::Apis::ComputeAlpha::InterconnectGroupPhysicalStructureMetrosFacilities
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::InterconnectGroupPhysicalStructureMetrosFacilities
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
[Output Only] The facilities Interconnects in this metro are present in.
Instance Attribute Summary collapse
-
#facility ⇒ String
Output only.
-
#zones ⇒ Array<Google::Apis::ComputeAlpha::InterconnectGroupPhysicalStructureMetrosFacilitiesZones>
Corresponds to the JSON property
zones.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InterconnectGroupPhysicalStructureMetrosFacilities
constructor
A new instance of InterconnectGroupPhysicalStructureMetrosFacilities.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InterconnectGroupPhysicalStructureMetrosFacilities
Returns a new instance of InterconnectGroupPhysicalStructureMetrosFacilities.
37429 37430 37431 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 37429 def initialize(**args) update!(**args) end |
Instance Attribute Details
#facility ⇒ String
Output only. [Output Only] The ID of this facility, as a numeric string like
"5467". This is the third component of the location of Interconnects
in this facility.
Corresponds to the JSON property facility
37422 37423 37424 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 37422 def facility @facility end |
#zones ⇒ Array<Google::Apis::ComputeAlpha::InterconnectGroupPhysicalStructureMetrosFacilitiesZones>
Corresponds to the JSON property zones
37427 37428 37429 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 37427 def zones @zones end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
37434 37435 37436 37437 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 37434 def update!(**args) @facility = args[:facility] if args.key?(:facility) @zones = args[:zones] if args.key?(:zones) end |