Class: Google::Apis::ComputeAlpha::InterconnectGroupPhysicalStructureMetrosFacilities

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

[Output Only] The facilities Interconnects in this metro are present in.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectGroupPhysicalStructureMetrosFacilities

Returns a new instance of InterconnectGroupPhysicalStructureMetrosFacilities.



36463
36464
36465
# File 'lib/google/apis/compute_alpha/classes.rb', line 36463

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#facilityString

Output only. [Output Only] The ID of this facility, as a numeric string like "5467". This is the third component of the location of Interconnects in this facility. Corresponds to the JSON property facility

Returns:

  • (String)


36456
36457
36458
# File 'lib/google/apis/compute_alpha/classes.rb', line 36456

def facility
  @facility
end

#zonesArray<Google::Apis::ComputeAlpha::InterconnectGroupPhysicalStructureMetrosFacilitiesZones>

Corresponds to the JSON property zones



36461
36462
36463
# File 'lib/google/apis/compute_alpha/classes.rb', line 36461

def zones
  @zones
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



36468
36469
36470
36471
# File 'lib/google/apis/compute_alpha/classes.rb', line 36468

def update!(**args)
  @facility = args[:facility] if args.key?(:facility)
  @zones = args[:zones] if args.key?(:zones)
end