Class: Google::Apis::ComputeAlpha::InterconnectGroupPhysicalStructureMetrosFacilitiesZones

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

[Output Only] The zones that Interconnects in this facility are present in.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectGroupPhysicalStructureMetrosFacilitiesZones

Returns a new instance of InterconnectGroupPhysicalStructureMetrosFacilitiesZones.



36483
36484
36485
# File 'lib/google/apis/compute_alpha/classes.rb', line 36483

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#interconnectsArray<String>

Output only. [Output Only] URLs of Interconnects in this redundancy group in the given metro, facility, and zone. Corresponds to the JSON property interconnects

Returns:

  • (Array<String>)


36474
36475
36476
# File 'lib/google/apis/compute_alpha/classes.rb', line 36474

def interconnects
  @interconnects
end

#zoneString

Output only. [Output Only] The name of the zone, either "zone1" or "zone2". This is the second component of the location of Interconnects in this facility. Corresponds to the JSON property zone

Returns:

  • (String)


36481
36482
36483
# File 'lib/google/apis/compute_alpha/classes.rb', line 36481

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



36488
36489
36490
36491
# File 'lib/google/apis/compute_alpha/classes.rb', line 36488

def update!(**args)
  @interconnects = args[:interconnects] if args.key?(:interconnects)
  @zone = args[:zone] if args.key?(:zone)
end