Class: Google::Apis::ComputeAlpha::InterconnectGroupPhysicalStructureMetrosFacilitiesZones
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::InterconnectGroupPhysicalStructureMetrosFacilitiesZones
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
[Output Only] The zones that Interconnects in this facility are present in.
Instance Attribute Summary collapse
-
#interconnects ⇒ Array<String>
Output only.
-
#zone ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InterconnectGroupPhysicalStructureMetrosFacilitiesZones
constructor
A new instance of InterconnectGroupPhysicalStructureMetrosFacilitiesZones.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InterconnectGroupPhysicalStructureMetrosFacilitiesZones
Returns a new instance of InterconnectGroupPhysicalStructureMetrosFacilitiesZones.
36355 36356 36357 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 36355 def initialize(**args) update!(**args) end |
Instance Attribute Details
#interconnects ⇒ Array<String>
Output only. [Output Only] URLs of Interconnects in this redundancy group in
the
given metro, facility, and zone.
Corresponds to the JSON property interconnects
36346 36347 36348 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 36346 def interconnects @interconnects end |
#zone ⇒ String
Output only. [Output Only] The name of the zone, either "zone1" or "zone2".
This is the second component of the location of Interconnects in
this facility.
Corresponds to the JSON property zone
36353 36354 36355 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 36353 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
36360 36361 36362 36363 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 36360 def update!(**args) @interconnects = args[:interconnects] if args.key?(:interconnects) @zone = args[:zone] if args.key?(:zone) end |