Class: Google::Apis::ComputeAlpha::InterconnectGroupsListResponse
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::InterconnectGroupsListResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::InterconnectGroup>
A list of InterconnectGroup resources.
-
#kind ⇒ String
Corresponds to the JSON property
kind. -
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::InterconnectGroupsListResponse::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InterconnectGroupsListResponse
constructor
A new instance of InterconnectGroupsListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InterconnectGroupsListResponse
Returns a new instance of InterconnectGroupsListResponse.
37999 38000 38001 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 37999 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
37956 37957 37958 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 37956 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
37961 37962 37963 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 37961 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::InterconnectGroup>
A list of InterconnectGroup resources.
Corresponds to the JSON property items
37966 37967 37968 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 37966 def items @items end |
#kind ⇒ String
Corresponds to the JSON property kind
37971 37972 37973 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 37971 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
37981 37982 37983 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 37981 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
37986 37987 37988 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 37986 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
end_interface: MixerListResponseWithEtagBuilder
Corresponds to the JSON property unreachables
37992 37993 37994 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 37992 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::InterconnectGroupsListResponse::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
37997 37998 37999 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 37997 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
38004 38005 38006 38007 38008 38009 38010 38011 38012 38013 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 38004 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |