Class: Google::Apis::ComputeAlpha::InterconnectGroupsListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectGroupsListResponse

Returns a new instance of InterconnectGroupsListResponse.



37720
37721
37722
# File 'lib/google/apis/compute_alpha/classes.rb', line 37720

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


37677
37678
37679
# File 'lib/google/apis/compute_alpha/classes.rb', line 37677

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


37682
37683
37684
# File 'lib/google/apis/compute_alpha/classes.rb', line 37682

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::InterconnectGroup>

A list of InterconnectGroup resources. Corresponds to the JSON property items



37687
37688
37689
# File 'lib/google/apis/compute_alpha/classes.rb', line 37687

def items
  @items
end

#kindString

Corresponds to the JSON property kind

Returns:

  • (String)


37692
37693
37694
# File 'lib/google/apis/compute_alpha/classes.rb', line 37692

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


37702
37703
37704
# File 'lib/google/apis/compute_alpha/classes.rb', line 37702

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


37707
37708
37709
# File 'lib/google/apis/compute_alpha/classes.rb', line 37707

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


37713
37714
37715
# File 'lib/google/apis/compute_alpha/classes.rb', line 37713

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::InterconnectGroupsListResponse::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



37718
37719
37720
# File 'lib/google/apis/compute_alpha/classes.rb', line 37718

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



37725
37726
37727
37728
37729
37730
37731
37732
37733
37734
# File 'lib/google/apis/compute_alpha/classes.rb', line 37725

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end