Class: Google::Apis::ComputeAlpha::InterconnectGroupsListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectGroupsListResponse

Returns a new instance of InterconnectGroupsListResponse.



36968
36969
36970
# File 'lib/google/apis/compute_alpha/classes.rb', line 36968

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


36925
36926
36927
# File 'lib/google/apis/compute_alpha/classes.rb', line 36925

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


36930
36931
36932
# File 'lib/google/apis/compute_alpha/classes.rb', line 36930

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::InterconnectGroup>

A list of InterconnectGroup resources. Corresponds to the JSON property items



36935
36936
36937
# File 'lib/google/apis/compute_alpha/classes.rb', line 36935

def items
  @items
end

#kindString

Corresponds to the JSON property kind

Returns:

  • (String)


36940
36941
36942
# File 'lib/google/apis/compute_alpha/classes.rb', line 36940

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


36950
36951
36952
# File 'lib/google/apis/compute_alpha/classes.rb', line 36950

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


36955
36956
36957
# File 'lib/google/apis/compute_alpha/classes.rb', line 36955

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


36961
36962
36963
# File 'lib/google/apis/compute_alpha/classes.rb', line 36961

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::InterconnectGroupsListResponse::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



36966
36967
36968
# File 'lib/google/apis/compute_alpha/classes.rb', line 36966

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



36973
36974
36975
36976
36977
36978
36979
36980
36981
36982
# File 'lib/google/apis/compute_alpha/classes.rb', line 36973

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end