Class: Google::Apis::ComputeAlpha::InterconnectGroupsListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectGroupsListResponse

Returns a new instance of InterconnectGroupsListResponse.



36960
36961
36962
# File 'lib/google/apis/compute_alpha/classes.rb', line 36960

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


36917
36918
36919
# File 'lib/google/apis/compute_alpha/classes.rb', line 36917

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


36922
36923
36924
# File 'lib/google/apis/compute_alpha/classes.rb', line 36922

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::InterconnectGroup>

A list of InterconnectGroup resources. Corresponds to the JSON property items



36927
36928
36929
# File 'lib/google/apis/compute_alpha/classes.rb', line 36927

def items
  @items
end

#kindString

Corresponds to the JSON property kind

Returns:

  • (String)


36932
36933
36934
# File 'lib/google/apis/compute_alpha/classes.rb', line 36932

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


36942
36943
36944
# File 'lib/google/apis/compute_alpha/classes.rb', line 36942

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


36947
36948
36949
# File 'lib/google/apis/compute_alpha/classes.rb', line 36947

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


36953
36954
36955
# File 'lib/google/apis/compute_alpha/classes.rb', line 36953

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::InterconnectGroupsListResponse::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



36958
36959
36960
# File 'lib/google/apis/compute_alpha/classes.rb', line 36958

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



36965
36966
36967
36968
36969
36970
36971
36972
36973
36974
# File 'lib/google/apis/compute_alpha/classes.rb', line 36965

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end