Class: Google::Apis::ComputeAlpha::InterconnectGroupsListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectGroupsListResponse

Returns a new instance of InterconnectGroupsListResponse.



36754
36755
36756
# File 'lib/google/apis/compute_alpha/classes.rb', line 36754

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


36711
36712
36713
# File 'lib/google/apis/compute_alpha/classes.rb', line 36711

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


36716
36717
36718
# File 'lib/google/apis/compute_alpha/classes.rb', line 36716

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::InterconnectGroup>

A list of InterconnectGroup resources. Corresponds to the JSON property items



36721
36722
36723
# File 'lib/google/apis/compute_alpha/classes.rb', line 36721

def items
  @items
end

#kindString

Corresponds to the JSON property kind

Returns:

  • (String)


36726
36727
36728
# File 'lib/google/apis/compute_alpha/classes.rb', line 36726

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


36736
36737
36738
# File 'lib/google/apis/compute_alpha/classes.rb', line 36736

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


36741
36742
36743
# File 'lib/google/apis/compute_alpha/classes.rb', line 36741

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


36747
36748
36749
# File 'lib/google/apis/compute_alpha/classes.rb', line 36747

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::InterconnectGroupsListResponse::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



36752
36753
36754
# File 'lib/google/apis/compute_alpha/classes.rb', line 36752

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



36759
36760
36761
36762
36763
36764
36765
36766
36767
36768
# File 'lib/google/apis/compute_alpha/classes.rb', line 36759

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end