Class: Google::Apis::ComputeAlpha::InterconnectGroupsListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectGroupsListResponse

Returns a new instance of InterconnectGroupsListResponse.



36616
36617
36618
# File 'lib/google/apis/compute_alpha/classes.rb', line 36616

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


36573
36574
36575
# File 'lib/google/apis/compute_alpha/classes.rb', line 36573

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


36578
36579
36580
# File 'lib/google/apis/compute_alpha/classes.rb', line 36578

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::InterconnectGroup>

A list of InterconnectGroup resources. Corresponds to the JSON property items



36583
36584
36585
# File 'lib/google/apis/compute_alpha/classes.rb', line 36583

def items
  @items
end

#kindString

Corresponds to the JSON property kind

Returns:

  • (String)


36588
36589
36590
# File 'lib/google/apis/compute_alpha/classes.rb', line 36588

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


36598
36599
36600
# File 'lib/google/apis/compute_alpha/classes.rb', line 36598

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


36603
36604
36605
# File 'lib/google/apis/compute_alpha/classes.rb', line 36603

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


36609
36610
36611
# File 'lib/google/apis/compute_alpha/classes.rb', line 36609

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::InterconnectGroupsListResponse::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



36614
36615
36616
# File 'lib/google/apis/compute_alpha/classes.rb', line 36614

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



36621
36622
36623
36624
36625
36626
36627
36628
36629
36630
# File 'lib/google/apis/compute_alpha/classes.rb', line 36621

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end