Class: Google::Apis::ComputeAlpha::InterconnectGroupsListResponse
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::InterconnectGroupsListResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::InterconnectGroup>
A list of InterconnectGroup resources.
-
#kind ⇒ String
Corresponds to the JSON property
kind. -
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::InterconnectGroupsListResponse::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InterconnectGroupsListResponse
constructor
A new instance of InterconnectGroupsListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InterconnectGroupsListResponse
Returns a new instance of InterconnectGroupsListResponse.
35899 35900 35901 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 35899 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
35856 35857 35858 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 35856 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
35861 35862 35863 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 35861 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::InterconnectGroup>
A list of InterconnectGroup resources.
Corresponds to the JSON property items
35866 35867 35868 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 35866 def items @items end |
#kind ⇒ String
Corresponds to the JSON property kind
35871 35872 35873 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 35871 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
35881 35882 35883 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 35881 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
35886 35887 35888 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 35886 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
end_interface: MixerListResponseWithEtagBuilder
Corresponds to the JSON property unreachables
35892 35893 35894 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 35892 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::InterconnectGroupsListResponse::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
35897 35898 35899 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 35897 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
35904 35905 35906 35907 35908 35909 35910 35911 35912 35913 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 35904 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |