Class: Google::Apis::ComputeAlpha::InterconnectGroupsOperationalStatus
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::InterconnectGroupsOperationalStatus
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Request to get the status of the interconnect group with extra detail.
Instance Attribute Summary collapse
-
#configured ⇒ Google::Apis::ComputeAlpha::InterconnectGroupConfigured
[Output Only] The status of the group as configured.
-
#group_status ⇒ String
Output only.
-
#intent ⇒ Google::Apis::ComputeAlpha::InterconnectGroupIntent
The user's intent for this group.
-
#interconnect_statuses ⇒ Array<Google::Apis::ComputeAlpha::InterconnectGroupsOperationalStatusInterconnectStatus>
Corresponds to the JSON property
interconnectStatuses. -
#operational ⇒ Google::Apis::ComputeAlpha::InterconnectGroupConfigured
[Output Only] The status of the group as configured.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InterconnectGroupsOperationalStatus
constructor
A new instance of InterconnectGroupsOperationalStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InterconnectGroupsOperationalStatus
Returns a new instance of InterconnectGroupsOperationalStatus.
38122 38123 38124 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 38122 def initialize(**args) update!(**args) end |
Instance Attribute Details
#configured ⇒ Google::Apis::ComputeAlpha::InterconnectGroupConfigured
[Output Only] The status of the group as configured. This has the same
structure as the operational field reported by the OperationalStatus
method, but does not take into account the operational status of each
resource.
Corresponds to the JSON property configured
38096 38097 38098 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 38096 def configured @configured end |
#group_status ⇒ String
Output only. Summarizes the status of the group.
Corresponds to the JSON property groupStatus
38101 38102 38103 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 38101 def group_status @group_status end |
#intent ⇒ Google::Apis::ComputeAlpha::InterconnectGroupIntent
The user's intent for this group. This is the only required field besides
the name that must be specified on group creation.
Corresponds to the JSON property intent
38107 38108 38109 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 38107 def intent @intent end |
#interconnect_statuses ⇒ Array<Google::Apis::ComputeAlpha::InterconnectGroupsOperationalStatusInterconnectStatus>
Corresponds to the JSON property interconnectStatuses
38112 38113 38114 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 38112 def interconnect_statuses @interconnect_statuses end |
#operational ⇒ Google::Apis::ComputeAlpha::InterconnectGroupConfigured
[Output Only] The status of the group as configured. This has the same
structure as the operational field reported by the OperationalStatus
method, but does not take into account the operational status of each
resource.
Corresponds to the JSON property operational
38120 38121 38122 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 38120 def operational @operational end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
38127 38128 38129 38130 38131 38132 38133 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 38127 def update!(**args) @configured = args[:configured] if args.key?(:configured) @group_status = args[:group_status] if args.key?(:group_status) @intent = args[:intent] if args.key?(:intent) @interconnect_statuses = args[:interconnect_statuses] if args.key?(:interconnect_statuses) @operational = args[:operational] if args.key?(:operational) end |