Class: Google::Apis::ComputeAlpha::InterconnectGroupsOperationalStatus
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::InterconnectGroupsOperationalStatus
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Request to get the status of the interconnect group with extra detail.
Instance Attribute Summary collapse
-
#configured ⇒ Google::Apis::ComputeAlpha::InterconnectGroupConfigured
[Output Only] The status of the group as configured.
-
#group_status ⇒ String
Output only.
-
#intent ⇒ Google::Apis::ComputeAlpha::InterconnectGroupIntent
The user's intent for this group.
-
#interconnect_statuses ⇒ Array<Google::Apis::ComputeAlpha::InterconnectGroupsOperationalStatusInterconnectStatus>
Corresponds to the JSON property
interconnectStatuses. -
#operational ⇒ Google::Apis::ComputeAlpha::InterconnectGroupConfigured
[Output Only] The status of the group as configured.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InterconnectGroupsOperationalStatus
constructor
A new instance of InterconnectGroupsOperationalStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InterconnectGroupsOperationalStatus
Returns a new instance of InterconnectGroupsOperationalStatus.
36867 36868 36869 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 36867 def initialize(**args) update!(**args) end |
Instance Attribute Details
#configured ⇒ Google::Apis::ComputeAlpha::InterconnectGroupConfigured
[Output Only] The status of the group as configured. This has the same
structure as the operational field reported by the OperationalStatus
method, but does not take into account the operational status of each
resource.
Corresponds to the JSON property configured
36841 36842 36843 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 36841 def configured @configured end |
#group_status ⇒ String
Output only. Summarizes the status of the group.
Corresponds to the JSON property groupStatus
36846 36847 36848 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 36846 def group_status @group_status end |
#intent ⇒ Google::Apis::ComputeAlpha::InterconnectGroupIntent
The user's intent for this group. This is the only required field besides
the name that must be specified on group creation.
Corresponds to the JSON property intent
36852 36853 36854 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 36852 def intent @intent end |
#interconnect_statuses ⇒ Array<Google::Apis::ComputeAlpha::InterconnectGroupsOperationalStatusInterconnectStatus>
Corresponds to the JSON property interconnectStatuses
36857 36858 36859 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 36857 def interconnect_statuses @interconnect_statuses end |
#operational ⇒ Google::Apis::ComputeAlpha::InterconnectGroupConfigured
[Output Only] The status of the group as configured. This has the same
structure as the operational field reported by the OperationalStatus
method, but does not take into account the operational status of each
resource.
Corresponds to the JSON property operational
36865 36866 36867 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 36865 def operational @operational end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
36872 36873 36874 36875 36876 36877 36878 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 36872 def update!(**args) @configured = args[:configured] if args.key?(:configured) @group_status = args[:group_status] if args.key?(:group_status) @intent = args[:intent] if args.key?(:intent) @interconnect_statuses = args[:interconnect_statuses] if args.key?(:interconnect_statuses) @operational = args[:operational] if args.key?(:operational) end |