Class: Google::Apis::ComputeAlpha::InterconnectGroupsOperationalStatus

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Request to get the status of the interconnect group with extra detail.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectGroupsOperationalStatus

Returns a new instance of InterconnectGroupsOperationalStatus.



36739
36740
36741
# File 'lib/google/apis/compute_alpha/classes.rb', line 36739

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#configuredGoogle::Apis::ComputeAlpha::InterconnectGroupConfigured

[Output Only] The status of the group as configured. This has the same structure as the operational field reported by the OperationalStatus method, but does not take into account the operational status of each resource. Corresponds to the JSON property configured



36713
36714
36715
# File 'lib/google/apis/compute_alpha/classes.rb', line 36713

def configured
  @configured
end

#group_statusString

Output only. Summarizes the status of the group. Corresponds to the JSON property groupStatus

Returns:

  • (String)


36718
36719
36720
# File 'lib/google/apis/compute_alpha/classes.rb', line 36718

def group_status
  @group_status
end

#intentGoogle::Apis::ComputeAlpha::InterconnectGroupIntent

The user's intent for this group. This is the only required field besides the name that must be specified on group creation. Corresponds to the JSON property intent



36724
36725
36726
# File 'lib/google/apis/compute_alpha/classes.rb', line 36724

def intent
  @intent
end

#interconnect_statusesArray<Google::Apis::ComputeAlpha::InterconnectGroupsOperationalStatusInterconnectStatus>

Corresponds to the JSON property interconnectStatuses



36729
36730
36731
# File 'lib/google/apis/compute_alpha/classes.rb', line 36729

def interconnect_statuses
  @interconnect_statuses
end

#operationalGoogle::Apis::ComputeAlpha::InterconnectGroupConfigured

[Output Only] The status of the group as configured. This has the same structure as the operational field reported by the OperationalStatus method, but does not take into account the operational status of each resource. Corresponds to the JSON property operational



36737
36738
36739
# File 'lib/google/apis/compute_alpha/classes.rb', line 36737

def operational
  @operational
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



36744
36745
36746
36747
36748
36749
36750
# File 'lib/google/apis/compute_alpha/classes.rb', line 36744

def update!(**args)
  @configured = args[:configured] if args.key?(:configured)
  @group_status = args[:group_status] if args.key?(:group_status)
  @intent = args[:intent] if args.key?(:intent)
  @interconnect_statuses = args[:interconnect_statuses] if args.key?(:interconnect_statuses)
  @operational = args[:operational] if args.key?(:operational)
end