Class: Google::Apis::ComputeAlpha::InterconnectGroupsOperationalStatusInterconnectStatus

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

The status of one Interconnect in the group. The order is arbitrary.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectGroupsOperationalStatusInterconnectStatus

Returns a new instance of InterconnectGroupsOperationalStatusInterconnectStatus.



36909
36910
36911
# File 'lib/google/apis/compute_alpha/classes.rb', line 36909

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#admin_enabledBoolean Also known as: admin_enabled?

Output only. Whether the Interconnect is enabled. Corresponds to the JSON property adminEnabled

Returns:

  • (Boolean)


36888
36889
36890
# File 'lib/google/apis/compute_alpha/classes.rb', line 36888

def admin_enabled
  @admin_enabled
end

#diagnosticsGoogle::Apis::ComputeAlpha::InterconnectDiagnostics

Diagnostics information about the Interconnect connection, which contains detailed and current technical information about Google's side of the connection. Corresponds to the JSON property diagnostics



36896
36897
36898
# File 'lib/google/apis/compute_alpha/classes.rb', line 36896

def diagnostics
  @diagnostics
end

#interconnectString

Output only. The URL of the Interconnect being described. Corresponds to the JSON property interconnect

Returns:

  • (String)


36901
36902
36903
# File 'lib/google/apis/compute_alpha/classes.rb', line 36901

def interconnect
  @interconnect
end

#is_activeString

Output only. Whether this interconnect is participating in the redundant configuration. Corresponds to the JSON property isActive

Returns:

  • (String)


36907
36908
36909
# File 'lib/google/apis/compute_alpha/classes.rb', line 36907

def is_active
  @is_active
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



36914
36915
36916
36917
36918
36919
# File 'lib/google/apis/compute_alpha/classes.rb', line 36914

def update!(**args)
  @admin_enabled = args[:admin_enabled] if args.key?(:admin_enabled)
  @diagnostics = args[:diagnostics] if args.key?(:diagnostics)
  @interconnect = args[:interconnect] if args.key?(:interconnect)
  @is_active = args[:is_active] if args.key?(:is_active)
end