Class: Google::Apis::ComputeAlpha::InterconnectList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::InterconnectList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Response to the list request, and contains a list of interconnects.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::Interconnect>
A list of Interconnect resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::InterconnectList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InterconnectList
constructor
A new instance of InterconnectList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InterconnectList
Returns a new instance of InterconnectList.
38441 38442 38443 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 38441 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
38408 38409 38410 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 38408 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::Interconnect>
A list of Interconnect resources.
Corresponds to the JSON property items
38413 38414 38415 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 38413 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#interconnectList
for lists of interconnects.
Corresponds to the JSON property kind
38419 38420 38421 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 38419 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
38429 38430 38431 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 38429 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
38434 38435 38436 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 38434 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::InterconnectList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
38439 38440 38441 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 38439 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
38446 38447 38448 38449 38450 38451 38452 38453 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 38446 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |