Class: Google::Apis::ComputeAlpha::InterconnectList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Response to the list request, and contains a list of interconnects.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectList

Returns a new instance of InterconnectList.



38217
38218
38219
# File 'lib/google/apis/compute_alpha/classes.rb', line 38217

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


38184
38185
38186
# File 'lib/google/apis/compute_alpha/classes.rb', line 38184

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::Interconnect>

A list of Interconnect resources. Corresponds to the JSON property items



38189
38190
38191
# File 'lib/google/apis/compute_alpha/classes.rb', line 38189

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute#interconnectList for lists of interconnects. Corresponds to the JSON property kind

Returns:

  • (String)


38195
38196
38197
# File 'lib/google/apis/compute_alpha/classes.rb', line 38195

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


38205
38206
38207
# File 'lib/google/apis/compute_alpha/classes.rb', line 38205

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


38210
38211
38212
# File 'lib/google/apis/compute_alpha/classes.rb', line 38210

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::InterconnectList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



38215
38216
38217
# File 'lib/google/apis/compute_alpha/classes.rb', line 38215

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



38222
38223
38224
38225
38226
38227
38228
38229
# File 'lib/google/apis/compute_alpha/classes.rb', line 38222

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end