Class: Google::Apis::ComputeAlpha::InterconnectList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Response to the list request, and contains a list of interconnects.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectList

Returns a new instance of InterconnectList.



37178
37179
37180
# File 'lib/google/apis/compute_alpha/classes.rb', line 37178

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


37145
37146
37147
# File 'lib/google/apis/compute_alpha/classes.rb', line 37145

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::Interconnect>

A list of Interconnect resources. Corresponds to the JSON property items



37150
37151
37152
# File 'lib/google/apis/compute_alpha/classes.rb', line 37150

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute#interconnectList for lists of interconnects. Corresponds to the JSON property kind

Returns:

  • (String)


37156
37157
37158
# File 'lib/google/apis/compute_alpha/classes.rb', line 37156

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


37166
37167
37168
# File 'lib/google/apis/compute_alpha/classes.rb', line 37166

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


37171
37172
37173
# File 'lib/google/apis/compute_alpha/classes.rb', line 37171

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::InterconnectList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



37176
37177
37178
# File 'lib/google/apis/compute_alpha/classes.rb', line 37176

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



37183
37184
37185
37186
37187
37188
37189
37190
# File 'lib/google/apis/compute_alpha/classes.rb', line 37183

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end