Class: Google::Apis::ComputeAlpha::InterconnectList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::InterconnectList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Response to the list request, and contains a list of interconnects.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::Interconnect>
A list of Interconnect resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::InterconnectList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InterconnectList
constructor
A new instance of InterconnectList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InterconnectList
Returns a new instance of InterconnectList.
36972 36973 36974 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 36972 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
36939 36940 36941 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 36939 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::Interconnect>
A list of Interconnect resources.
Corresponds to the JSON property items
36944 36945 36946 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 36944 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#interconnectList
for lists of interconnects.
Corresponds to the JSON property kind
36950 36951 36952 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 36950 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
36960 36961 36962 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 36960 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
36965 36966 36967 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 36965 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::InterconnectList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
36970 36971 36972 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 36970 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
36977 36978 36979 36980 36981 36982 36983 36984 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 36977 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |