Class: Google::Apis::ComputeAlpha::InterconnectLocation
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::InterconnectLocation
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Represents an Interconnect Attachment (VLAN) Location resource. You can use this resource to find location details about an Interconnect attachment (VLAN). For more information about interconnect attachments, read Creating VLAN Attachments.
Instance Attribute Summary collapse
-
#address ⇒ String
Output only.
-
#availability_zone ⇒ String
[Output Only] Availability zone for this InterconnectLocation.
-
#available_features ⇒ Array<String>
[Output only] List of features available at this InterconnectLocation, which can take one of the following values:.
-
#available_link_types ⇒ Array<String>
[Output only] List of link types available at this InterconnectLocation, which can take one of the following values:.
-
#city ⇒ String
[Output Only] Metropolitan area designator that indicates which city an interconnect is located.
-
#continent ⇒ String
[Output Only] Continent for this location, which can take one of the following values:.
-
#creation_timestamp ⇒ String
Output only.
-
#cross_site_interconnect_infos ⇒ Array<Google::Apis::ComputeAlpha::InterconnectLocationCrossSiteInterconnectInfo>
[Output Only] A list of InterconnectLocation.CrossSiteInterconnectInfo objects, that describe where Cross-Site Interconnect wires may connect to from this location and associated connection parameters.
-
#description ⇒ String
Output only.
-
#facility_provider ⇒ String
Output only.
-
#facility_provider_facility_id ⇒ String
Output only.
-
#id ⇒ Fixnum
Output only.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
Output only.
-
#peeringdb_facility_id ⇒ String
Output only.
-
#region_infos ⇒ Array<Google::Apis::ComputeAlpha::InterconnectLocationRegionInfo>
Output only.
-
#self_link ⇒ String
Output only.
-
#self_link_with_id ⇒ String
Output only.
-
#single_region_production_critical_peer_locations ⇒ Array<String>
Output only.
-
#status ⇒ String
[Output Only] The status of this InterconnectLocation, which can take one of the following values:.
-
#supports_pzs ⇒ Boolean
(also: #supports_pzs?)
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InterconnectLocation
constructor
A new instance of InterconnectLocation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InterconnectLocation
Returns a new instance of InterconnectLocation.
38462 38463 38464 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 38462 def initialize(**args) update!(**args) end |
Instance Attribute Details
#address ⇒ String
Output only. [Output Only] The postal address of the Point of Presence, each
line in
the address is separated by a newline character.
Corresponds to the JSON property address
38314 38315 38316 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 38314 def address @address end |
#availability_zone ⇒ String
[Output Only] Availability zone for this InterconnectLocation. Within a
metropolitan area (metro), maintenance will not be simultaneously scheduled
in more than one availability zone. Example: "zone1" or "zone2".
Corresponds to the JSON property availabilityZone
38321 38322 38323 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 38321 def availability_zone @availability_zone end |
#available_features ⇒ Array<String>
[Output only] List of features available at this InterconnectLocation, which can take one of the following values:
- IF_MACSEC
- IF_CROSS_SITE_NETWORK
Corresponds to the JSON property
availableFeatures
38330 38331 38332 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 38330 def available_features @available_features end |
#available_link_types ⇒ Array<String>
[Output only] List of link types available at this InterconnectLocation, which can take one of the following values:
- LINK_TYPE_ETHERNET_10G_LR
- LINK_TYPE_ETHERNET_100G_LR
- LINK_TYPE_ETHERNET_400G_LR4
Corresponds to the JSON property
availableLinkTypes
38340 38341 38342 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 38340 def available_link_types @available_link_types end |
#city ⇒ String
[Output Only] Metropolitan area designator that indicates which city an
interconnect is located.
For example: "Chicago, IL", "Amsterdam, Netherlands".
Corresponds to the JSON property city
38347 38348 38349 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 38347 def city @city end |
#continent ⇒ String
[Output Only] Continent for this location, which can take one of the following values:
- AFRICA
- ASIA_PAC
- EUROPE
- NORTH_AMERICA
- SOUTH_AMERICA
Corresponds to the JSON property
continent
38359 38360 38361 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 38359 def continent @continent end |
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
38365 38366 38367 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 38365 def @creation_timestamp end |
#cross_site_interconnect_infos ⇒ Array<Google::Apis::ComputeAlpha::InterconnectLocationCrossSiteInterconnectInfo>
[Output Only] A list of InterconnectLocation.CrossSiteInterconnectInfo
objects, that describe where Cross-Site Interconnect wires may connect to
from this location and associated connection parameters. Cross-Site
Interconnect isn't allowed to locations which are not listed.
Corresponds to the JSON property crossSiteInterconnectInfos
38373 38374 38375 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 38373 def cross_site_interconnect_infos @cross_site_interconnect_infos end |
#description ⇒ String
Output only. [Output Only] An optional description of the resource.
Corresponds to the JSON property description
38378 38379 38380 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 38378 def description @description end |
#facility_provider ⇒ String
Output only. [Output Only] The name of the provider for this facility (e.g.,
EQUINIX).
Corresponds to the JSON property facilityProvider
38384 38385 38386 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 38384 def facility_provider @facility_provider end |
#facility_provider_facility_id ⇒ String
Output only. [Output Only] A provider-assigned Identifier for this facility (e.
g.,
Ashburn-DC1).
Corresponds to the JSON property facilityProviderFacilityId
38391 38392 38393 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 38391 def facility_provider_facility_id @facility_provider_facility_id end |
#id ⇒ Fixnum
Output only. [Output Only] The unique identifier for the resource. This
identifier is
defined by the server.
Corresponds to the JSON property id
38398 38399 38400 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 38398 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#
interconnectLocation for interconnect locations.
Corresponds to the JSON property kind
38404 38405 38406 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 38404 def kind @kind end |
#name ⇒ String
Output only. [Output Only] Name of the resource.
Corresponds to the JSON property name
38409 38410 38411 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 38409 def name @name end |
#peeringdb_facility_id ⇒ String
Output only. [Output Only] The peeringdb identifier for this facility (
corresponding
with a netfac type in peeringdb).
Corresponds to the JSON property peeringdbFacilityId
38416 38417 38418 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 38416 def peeringdb_facility_id @peeringdb_facility_id end |
#region_infos ⇒ Array<Google::Apis::ComputeAlpha::InterconnectLocationRegionInfo>
Output only. [Output Only] A list of InterconnectLocation.RegionInfo objects,
that
describe parameters pertaining to the relation between this
InterconnectLocation and various Google Cloud regions.
Corresponds to the JSON property regionInfos
38424 38425 38426 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 38424 def region_infos @region_infos end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
38429 38430 38431 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 38429 def self_link @self_link end |
#self_link_with_id ⇒ String
Output only. [Output Only] Server-defined URL for this resource with the
resource id.
Corresponds to the JSON property selfLinkWithId
38435 38436 38437 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 38435 def self_link_with_id @self_link_with_id end |
#single_region_production_critical_peer_locations ⇒ Array<String>
Output only. [Output Only] URLs of the other locations that can pair up with
this
location to support Single-Region 99.99% SLA. E.g. iad-zone1-1 and
iad-zone2-5467 are Single-Region 99.99% peer locations of each other.
Corresponds to the JSON property singleRegionProductionCriticalPeerLocations
38443 38444 38445 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 38443 def single_region_production_critical_peer_locations @single_region_production_critical_peer_locations end |
#status ⇒ String
[Output Only] The status of this InterconnectLocation, which can take one of the following values:
- CLOSED: The InterconnectLocation is closed and is unavailable for provisioning new Interconnects.
- AVAILABLE: The InterconnectLocation is available for provisioning new
Interconnects.
Corresponds to the JSON property
status
38454 38455 38456 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 38454 def status @status end |
#supports_pzs ⇒ Boolean Also known as: supports_pzs?
Output only. [Output Only] Reserved for future use.
Corresponds to the JSON property supportsPzs
38459 38460 38461 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 38459 def supports_pzs @supports_pzs end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
38467 38468 38469 38470 38471 38472 38473 38474 38475 38476 38477 38478 38479 38480 38481 38482 38483 38484 38485 38486 38487 38488 38489 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 38467 def update!(**args) @address = args[:address] if args.key?(:address) @availability_zone = args[:availability_zone] if args.key?(:availability_zone) @available_features = args[:available_features] if args.key?(:available_features) @available_link_types = args[:available_link_types] if args.key?(:available_link_types) @city = args[:city] if args.key?(:city) @continent = args[:continent] if args.key?(:continent) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @cross_site_interconnect_infos = args[:cross_site_interconnect_infos] if args.key?(:cross_site_interconnect_infos) @description = args[:description] if args.key?(:description) @facility_provider = args[:facility_provider] if args.key?(:facility_provider) @facility_provider_facility_id = args[:facility_provider_facility_id] if args.key?(:facility_provider_facility_id) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @peeringdb_facility_id = args[:peeringdb_facility_id] if args.key?(:peeringdb_facility_id) @region_infos = args[:region_infos] if args.key?(:region_infos) @self_link = args[:self_link] if args.key?(:self_link) @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id) @single_region_production_critical_peer_locations = args[:single_region_production_critical_peer_locations] if args.key?(:single_region_production_critical_peer_locations) @status = args[:status] if args.key?(:status) @supports_pzs = args[:supports_pzs] if args.key?(:supports_pzs) end |