Class: Google::Apis::ComputeAlpha::InterconnectLocation

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Represents an Interconnect Attachment (VLAN) Location resource. You can use this resource to find location details about an Interconnect attachment (VLAN). For more information about interconnect attachments, read Creating VLAN Attachments.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectLocation

Returns a new instance of InterconnectLocation.



37431
37432
37433
# File 'lib/google/apis/compute_alpha/classes.rb', line 37431

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#addressString

Output only. [Output Only] The postal address of the Point of Presence, each line in the address is separated by a newline character. Corresponds to the JSON property address

Returns:

  • (String)


37283
37284
37285
# File 'lib/google/apis/compute_alpha/classes.rb', line 37283

def address
  @address
end

#availability_zoneString

[Output Only] Availability zone for this InterconnectLocation. Within a metropolitan area (metro), maintenance will not be simultaneously scheduled in more than one availability zone. Example: "zone1" or "zone2". Corresponds to the JSON property availabilityZone

Returns:

  • (String)


37290
37291
37292
# File 'lib/google/apis/compute_alpha/classes.rb', line 37290

def availability_zone
  @availability_zone
end

#available_featuresArray<String>

[Output only] List of features available at this InterconnectLocation, which can take one of the following values:

  • IF_MACSEC
  • IF_CROSS_SITE_NETWORK Corresponds to the JSON property availableFeatures

Returns:

  • (Array<String>)


37299
37300
37301
# File 'lib/google/apis/compute_alpha/classes.rb', line 37299

def available_features
  @available_features
end

[Output only] List of link types available at this InterconnectLocation, which can take one of the following values:

  • LINK_TYPE_ETHERNET_10G_LR
  • LINK_TYPE_ETHERNET_100G_LR
  • LINK_TYPE_ETHERNET_400G_LR4 Corresponds to the JSON property availableLinkTypes

Returns:

  • (Array<String>)


37309
37310
37311
# File 'lib/google/apis/compute_alpha/classes.rb', line 37309

def available_link_types
  @available_link_types
end

#cityString

[Output Only] Metropolitan area designator that indicates which city an interconnect is located. For example: "Chicago, IL", "Amsterdam, Netherlands". Corresponds to the JSON property city

Returns:

  • (String)


37316
37317
37318
# File 'lib/google/apis/compute_alpha/classes.rb', line 37316

def city
  @city
end

#continentString

[Output Only] Continent for this location, which can take one of the following values:

  • AFRICA
  • ASIA_PAC
  • EUROPE
  • NORTH_AMERICA
  • SOUTH_AMERICA Corresponds to the JSON property continent

Returns:

  • (String)


37328
37329
37330
# File 'lib/google/apis/compute_alpha/classes.rb', line 37328

def continent
  @continent
end

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


37334
37335
37336
# File 'lib/google/apis/compute_alpha/classes.rb', line 37334

def creation_timestamp
  @creation_timestamp
end

#cross_site_interconnect_infosArray<Google::Apis::ComputeAlpha::InterconnectLocationCrossSiteInterconnectInfo>

[Output Only] A list of InterconnectLocation.CrossSiteInterconnectInfo objects, that describe where Cross-Site Interconnect wires may connect to from this location and associated connection parameters. Cross-Site Interconnect isn't allowed to locations which are not listed. Corresponds to the JSON property crossSiteInterconnectInfos



37342
37343
37344
# File 'lib/google/apis/compute_alpha/classes.rb', line 37342

def cross_site_interconnect_infos
  @cross_site_interconnect_infos
end

#descriptionString

Output only. [Output Only] An optional description of the resource. Corresponds to the JSON property description

Returns:

  • (String)


37347
37348
37349
# File 'lib/google/apis/compute_alpha/classes.rb', line 37347

def description
  @description
end

#facility_providerString

Output only. [Output Only] The name of the provider for this facility (e.g., EQUINIX). Corresponds to the JSON property facilityProvider

Returns:

  • (String)


37353
37354
37355
# File 'lib/google/apis/compute_alpha/classes.rb', line 37353

def facility_provider
  @facility_provider
end

#facility_provider_facility_idString

Output only. [Output Only] A provider-assigned Identifier for this facility (e. g., Ashburn-DC1). Corresponds to the JSON property facilityProviderFacilityId

Returns:

  • (String)


37360
37361
37362
# File 'lib/google/apis/compute_alpha/classes.rb', line 37360

def facility_provider_facility_id
  @facility_provider_facility_id
end

#idFixnum

Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


37367
37368
37369
# File 'lib/google/apis/compute_alpha/classes.rb', line 37367

def id
  @id
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# interconnectLocation for interconnect locations. Corresponds to the JSON property kind

Returns:

  • (String)


37373
37374
37375
# File 'lib/google/apis/compute_alpha/classes.rb', line 37373

def kind
  @kind
end

#nameString

Output only. [Output Only] Name of the resource. Corresponds to the JSON property name

Returns:

  • (String)


37378
37379
37380
# File 'lib/google/apis/compute_alpha/classes.rb', line 37378

def name
  @name
end

#peeringdb_facility_idString

Output only. [Output Only] The peeringdb identifier for this facility ( corresponding with a netfac type in peeringdb). Corresponds to the JSON property peeringdbFacilityId

Returns:

  • (String)


37385
37386
37387
# File 'lib/google/apis/compute_alpha/classes.rb', line 37385

def peeringdb_facility_id
  @peeringdb_facility_id
end

#region_infosArray<Google::Apis::ComputeAlpha::InterconnectLocationRegionInfo>

Output only. [Output Only] A list of InterconnectLocation.RegionInfo objects, that describe parameters pertaining to the relation between this InterconnectLocation and various Google Cloud regions. Corresponds to the JSON property regionInfos



37393
37394
37395
# File 'lib/google/apis/compute_alpha/classes.rb', line 37393

def region_infos
  @region_infos
end

Output only. [Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


37398
37399
37400
# File 'lib/google/apis/compute_alpha/classes.rb', line 37398

def self_link
  @self_link
end

Output only. [Output Only] Server-defined URL for this resource with the resource id. Corresponds to the JSON property selfLinkWithId

Returns:

  • (String)


37404
37405
37406
# File 'lib/google/apis/compute_alpha/classes.rb', line 37404

def self_link_with_id
  @self_link_with_id
end

#single_region_production_critical_peer_locationsArray<String>

Output only. [Output Only] URLs of the other locations that can pair up with this location to support Single-Region 99.99% SLA. E.g. iad-zone1-1 and iad-zone2-5467 are Single-Region 99.99% peer locations of each other. Corresponds to the JSON property singleRegionProductionCriticalPeerLocations

Returns:

  • (Array<String>)


37412
37413
37414
# File 'lib/google/apis/compute_alpha/classes.rb', line 37412

def single_region_production_critical_peer_locations
  @single_region_production_critical_peer_locations
end

#statusString

[Output Only] The status of this InterconnectLocation, which can take one of the following values:

  • CLOSED: The InterconnectLocation is closed and is unavailable for provisioning new Interconnects.
  • AVAILABLE: The InterconnectLocation is available for provisioning new Interconnects. Corresponds to the JSON property status

Returns:

  • (String)


37423
37424
37425
# File 'lib/google/apis/compute_alpha/classes.rb', line 37423

def status
  @status
end

#supports_pzsBoolean Also known as: supports_pzs?

Output only. [Output Only] Reserved for future use. Corresponds to the JSON property supportsPzs

Returns:

  • (Boolean)


37428
37429
37430
# File 'lib/google/apis/compute_alpha/classes.rb', line 37428

def supports_pzs
  @supports_pzs
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



37436
37437
37438
37439
37440
37441
37442
37443
37444
37445
37446
37447
37448
37449
37450
37451
37452
37453
37454
37455
37456
37457
37458
# File 'lib/google/apis/compute_alpha/classes.rb', line 37436

def update!(**args)
  @address = args[:address] if args.key?(:address)
  @availability_zone = args[:availability_zone] if args.key?(:availability_zone)
  @available_features = args[:available_features] if args.key?(:available_features)
  @available_link_types = args[:available_link_types] if args.key?(:available_link_types)
  @city = args[:city] if args.key?(:city)
  @continent = args[:continent] if args.key?(:continent)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @cross_site_interconnect_infos = args[:cross_site_interconnect_infos] if args.key?(:cross_site_interconnect_infos)
  @description = args[:description] if args.key?(:description)
  @facility_provider = args[:facility_provider] if args.key?(:facility_provider)
  @facility_provider_facility_id = args[:facility_provider_facility_id] if args.key?(:facility_provider_facility_id)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @peeringdb_facility_id = args[:peeringdb_facility_id] if args.key?(:peeringdb_facility_id)
  @region_infos = args[:region_infos] if args.key?(:region_infos)
  @self_link = args[:self_link] if args.key?(:self_link)
  @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id)
  @single_region_production_critical_peer_locations = args[:single_region_production_critical_peer_locations] if args.key?(:single_region_production_critical_peer_locations)
  @status = args[:status] if args.key?(:status)
  @supports_pzs = args[:supports_pzs] if args.key?(:supports_pzs)
end