Class: Google::Apis::ComputeAlpha::InterconnectLocationCrossSiteInterconnectInfo
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::InterconnectLocationCrossSiteInterconnectInfo
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Information about Cross-Site Interconnect wires which may be created between the containing location and another remote location.
Instance Attribute Summary collapse
-
#city ⇒ String
Output only.
-
#max_single_flow_gbps ⇒ Fixnum
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InterconnectLocationCrossSiteInterconnectInfo
constructor
A new instance of InterconnectLocationCrossSiteInterconnectInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InterconnectLocationCrossSiteInterconnectInfo
Returns a new instance of InterconnectLocationCrossSiteInterconnectInfo.
37472 37473 37474 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 37472 def initialize(**args) update!(**args) end |
Instance Attribute Details
#city ⇒ String
Output only. The remote location for Cross-Site Interconnect wires. This
specifies an
InterconnectLocation city (metropolitan area designator), which itself
may match multiple InterconnectLocations.
Corresponds to the JSON property city
37464 37465 37466 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 37464 def city @city end |
#max_single_flow_gbps ⇒ Fixnum
Output only. The maximum gbps for a single flow to this metro.
This limits the total bandwidth which may be configured per wire.
Corresponds to the JSON property maxSingleFlowGbps
37470 37471 37472 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 37470 def max_single_flow_gbps @max_single_flow_gbps end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
37477 37478 37479 37480 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 37477 def update!(**args) @city = args[:city] if args.key?(:city) @max_single_flow_gbps = args[:max_single_flow_gbps] if args.key?(:max_single_flow_gbps) end |