Class: Google::Apis::ComputeAlpha::InterconnectLocationCrossSiteInterconnectInfo

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Information about Cross-Site Interconnect wires which may be created between the containing location and another remote location.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectLocationCrossSiteInterconnectInfo

Returns a new instance of InterconnectLocationCrossSiteInterconnectInfo.



37128
37129
37130
# File 'lib/google/apis/compute_alpha/classes.rb', line 37128

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cityString

Output only. The remote location for Cross-Site Interconnect wires. This specifies an InterconnectLocation city (metropolitan area designator), which itself may match multiple InterconnectLocations. Corresponds to the JSON property city

Returns:

  • (String)


37120
37121
37122
# File 'lib/google/apis/compute_alpha/classes.rb', line 37120

def city
  @city
end

#max_single_flow_gbpsFixnum

Output only. The maximum gbps for a single flow to this metro. This limits the total bandwidth which may be configured per wire. Corresponds to the JSON property maxSingleFlowGbps

Returns:

  • (Fixnum)


37126
37127
37128
# File 'lib/google/apis/compute_alpha/classes.rb', line 37126

def max_single_flow_gbps
  @max_single_flow_gbps
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



37133
37134
37135
37136
# File 'lib/google/apis/compute_alpha/classes.rb', line 37133

def update!(**args)
  @city = args[:city] if args.key?(:city)
  @max_single_flow_gbps = args[:max_single_flow_gbps] if args.key?(:max_single_flow_gbps)
end