Class: Google::Apis::ComputeAlpha::InterconnectLocationCrossSiteInterconnectInfo
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::InterconnectLocationCrossSiteInterconnectInfo
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Information about Cross-Site Interconnect wires which may be created between the containing location and another remote location.
Instance Attribute Summary collapse
-
#city ⇒ String
Output only.
-
#max_single_flow_gbps ⇒ Fixnum
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InterconnectLocationCrossSiteInterconnectInfo
constructor
A new instance of InterconnectLocationCrossSiteInterconnectInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InterconnectLocationCrossSiteInterconnectInfo
Returns a new instance of InterconnectLocationCrossSiteInterconnectInfo.
36411 36412 36413 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 36411 def initialize(**args) update!(**args) end |
Instance Attribute Details
#city ⇒ String
Output only. The remote location for Cross-Site Interconnect wires. This
specifies an
InterconnectLocation city (metropolitan area designator), which itself
may match multiple InterconnectLocations.
Corresponds to the JSON property city
36403 36404 36405 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 36403 def city @city end |
#max_single_flow_gbps ⇒ Fixnum
Output only. The maximum gbps for a single flow to this metro.
This limits the total bandwidth which may be configured per wire.
Corresponds to the JSON property maxSingleFlowGbps
36409 36410 36411 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 36409 def max_single_flow_gbps @max_single_flow_gbps end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
36416 36417 36418 36419 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 36416 def update!(**args) @city = args[:city] if args.key?(:city) @max_single_flow_gbps = args[:max_single_flow_gbps] if args.key?(:max_single_flow_gbps) end |