Class: Google::Apis::ComputeAlpha::InterconnectLocationList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Response to the list request, and contains a list of interconnect locations.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectLocationList

Returns a new instance of InterconnectLocationList.



38284
38285
38286
# File 'lib/google/apis/compute_alpha/classes.rb', line 38284

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


38250
38251
38252
# File 'lib/google/apis/compute_alpha/classes.rb', line 38250

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::InterconnectLocation>

A list of InterconnectLocation resources. Corresponds to the JSON property items



38255
38256
38257
# File 'lib/google/apis/compute_alpha/classes.rb', line 38255

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# interconnectLocationList for lists of interconnect locations. Corresponds to the JSON property kind

Returns:

  • (String)


38262
38263
38264
# File 'lib/google/apis/compute_alpha/classes.rb', line 38262

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


38272
38273
38274
# File 'lib/google/apis/compute_alpha/classes.rb', line 38272

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


38277
38278
38279
# File 'lib/google/apis/compute_alpha/classes.rb', line 38277

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::InterconnectLocationList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



38282
38283
38284
# File 'lib/google/apis/compute_alpha/classes.rb', line 38282

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



38289
38290
38291
38292
38293
38294
38295
38296
# File 'lib/google/apis/compute_alpha/classes.rb', line 38289

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end