Class: Google::Apis::ComputeAlpha::InterconnectLocationList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::InterconnectLocationList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Response to the list request, and contains a list of interconnect locations.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::InterconnectLocation>
A list of InterconnectLocation resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::InterconnectLocationList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InterconnectLocationList
constructor
A new instance of InterconnectLocationList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InterconnectLocationList
Returns a new instance of InterconnectLocationList.
37524 37525 37526 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 37524 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
37490 37491 37492 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 37490 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::InterconnectLocation>
A list of InterconnectLocation resources.
Corresponds to the JSON property items
37495 37496 37497 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 37495 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
interconnectLocationList for lists of interconnect
locations.
Corresponds to the JSON property kind
37502 37503 37504 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 37502 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
37512 37513 37514 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 37512 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
37517 37518 37519 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 37517 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::InterconnectLocationList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
37522 37523 37524 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 37522 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
37529 37530 37531 37532 37533 37534 37535 37536 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 37529 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |