Class: Google::Apis::ComputeAlpha::InterconnectLocationList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Response to the list request, and contains a list of interconnect locations.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectLocationList

Returns a new instance of InterconnectLocationList.



37318
37319
37320
# File 'lib/google/apis/compute_alpha/classes.rb', line 37318

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


37284
37285
37286
# File 'lib/google/apis/compute_alpha/classes.rb', line 37284

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::InterconnectLocation>

A list of InterconnectLocation resources. Corresponds to the JSON property items



37289
37290
37291
# File 'lib/google/apis/compute_alpha/classes.rb', line 37289

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# interconnectLocationList for lists of interconnect locations. Corresponds to the JSON property kind

Returns:

  • (String)


37296
37297
37298
# File 'lib/google/apis/compute_alpha/classes.rb', line 37296

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


37306
37307
37308
# File 'lib/google/apis/compute_alpha/classes.rb', line 37306

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


37311
37312
37313
# File 'lib/google/apis/compute_alpha/classes.rb', line 37311

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::InterconnectLocationList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



37316
37317
37318
# File 'lib/google/apis/compute_alpha/classes.rb', line 37316

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



37323
37324
37325
37326
37327
37328
37329
37330
# File 'lib/google/apis/compute_alpha/classes.rb', line 37323

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end