Class: Google::Apis::ComputeAlpha::InterconnectMacsecConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

MACsec configuration information for the Interconnect connection. Contains the generated Connectivity Association Key Name (CKN) and the key (CAK) for this Interconnect connection.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectMacsecConfig

Returns a new instance of InterconnectMacsecConfig.



37360
37361
37362
# File 'lib/google/apis/compute_alpha/classes.rb', line 37360

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#pre_shared_keysArray<Google::Apis::ComputeAlpha::InterconnectMacsecConfigPreSharedKey>

A keychain placeholder describing a set of named key objects along with their start times. A MACsec CKN/CAK is generated for each key in the key chain. Google router automatically picks the key with the most recent startTime when establishing or re-establishing a MACsec secure link. Corresponds to the JSON property preSharedKeys



37358
37359
37360
# File 'lib/google/apis/compute_alpha/classes.rb', line 37358

def pre_shared_keys
  @pre_shared_keys
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



37365
37366
37367
# File 'lib/google/apis/compute_alpha/classes.rb', line 37365

def update!(**args)
  @pre_shared_keys = args[:pre_shared_keys] if args.key?(:pre_shared_keys)
end