Class: Google::Apis::ComputeAlpha::InterconnectOutageNotification

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Description of a planned outage on this Interconnect.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectOutageNotification

Returns a new instance of InterconnectOutageNotification.



37653
37654
37655
# File 'lib/google/apis/compute_alpha/classes.rb', line 37653

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#affected_circuitsArray<String>

If issue_type is IT_PARTIAL_OUTAGE, a list of the Google-side circuit IDs that will be affected. Corresponds to the JSON property affectedCircuits

Returns:

  • (Array<String>)


37592
37593
37594
# File 'lib/google/apis/compute_alpha/classes.rb', line 37592

def affected_circuits
  @affected_circuits
end

#descriptionString

A description about the purpose of the outage. Corresponds to the JSON property description

Returns:

  • (String)


37597
37598
37599
# File 'lib/google/apis/compute_alpha/classes.rb', line 37597

def description
  @description
end

#end_timeFixnum

Scheduled end time for the outage (milliseconds since Unix epoch). Corresponds to the JSON property endTime

Returns:

  • (Fixnum)


37603
37604
37605
# File 'lib/google/apis/compute_alpha/classes.rb', line 37603

def end_time
  @end_time
end

#issue_typeString

Form this outage is expected to take, which can take one of the following values:

  • OUTAGE: The Interconnect may be completely out of service for some or all of the specified window.
  • PARTIAL_OUTAGE: Some circuits comprising the Interconnect as a whole should remain up, but with reduced bandwidth. Note that the versions of this enum prefixed with "IT_" have been deprecated in favor of the unprefixed values. Corresponds to the JSON property issueType

Returns:

  • (String)


37616
37617
37618
# File 'lib/google/apis/compute_alpha/classes.rb', line 37616

def issue_type
  @issue_type
end

#nameString

Unique identifier for this outage notification. Corresponds to the JSON property name

Returns:

  • (String)


37621
37622
37623
# File 'lib/google/apis/compute_alpha/classes.rb', line 37621

def name
  @name
end

#sourceString

The party that generated this notification, which can take the following value:

  • GOOGLE: this notification as generated by Google. Note that the value of NSRC_GOOGLE has been deprecated in favor of GOOGLE. Corresponds to the JSON property source

Returns:

  • (String)


37631
37632
37633
# File 'lib/google/apis/compute_alpha/classes.rb', line 37631

def source
  @source
end

#start_timeFixnum

Scheduled start time for the outage (milliseconds since Unix epoch). Corresponds to the JSON property startTime

Returns:

  • (Fixnum)


37637
37638
37639
# File 'lib/google/apis/compute_alpha/classes.rb', line 37637

def start_time
  @start_time
end

#stateString

State of this notification, which can take one of the following values:

  • ACTIVE: This outage notification is active. The event could be in the past, present, or future. See start_time and end_time for scheduling.
  • CANCELLED: The outage associated with this notification was cancelled before the outage was due to start.
  • COMPLETED: The outage associated with this notification is complete. Note that the versions of this enum prefixed with "NS_" have been deprecated in favor of the unprefixed values. Corresponds to the JSON property state

Returns:

  • (String)


37651
37652
37653
# File 'lib/google/apis/compute_alpha/classes.rb', line 37651

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



37658
37659
37660
37661
37662
37663
37664
37665
37666
37667
# File 'lib/google/apis/compute_alpha/classes.rb', line 37658

def update!(**args)
  @affected_circuits = args[:affected_circuits] if args.key?(:affected_circuits)
  @description = args[:description] if args.key?(:description)
  @end_time = args[:end_time] if args.key?(:end_time)
  @issue_type = args[:issue_type] if args.key?(:issue_type)
  @name = args[:name] if args.key?(:name)
  @source = args[:source] if args.key?(:source)
  @start_time = args[:start_time] if args.key?(:start_time)
  @state = args[:state] if args.key?(:state)
end