Class: Google::Apis::ComputeAlpha::InterconnectOutageNotification

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Description of a planned outage on this Interconnect.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectOutageNotification

Returns a new instance of InterconnectOutageNotification.



36798
36799
36800
# File 'lib/google/apis/compute_alpha/classes.rb', line 36798

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#affected_circuitsArray<String>

If issue_type is IT_PARTIAL_OUTAGE, a list of the Google-side circuit IDs that will be affected. Corresponds to the JSON property affectedCircuits

Returns:

  • (Array<String>)


36737
36738
36739
# File 'lib/google/apis/compute_alpha/classes.rb', line 36737

def affected_circuits
  @affected_circuits
end

#descriptionString

A description about the purpose of the outage. Corresponds to the JSON property description

Returns:

  • (String)


36742
36743
36744
# File 'lib/google/apis/compute_alpha/classes.rb', line 36742

def description
  @description
end

#end_timeFixnum

Scheduled end time for the outage (milliseconds since Unix epoch). Corresponds to the JSON property endTime

Returns:

  • (Fixnum)


36748
36749
36750
# File 'lib/google/apis/compute_alpha/classes.rb', line 36748

def end_time
  @end_time
end

#issue_typeString

Form this outage is expected to take, which can take one of the following values:

  • OUTAGE: The Interconnect may be completely out of service for some or all of the specified window.
  • PARTIAL_OUTAGE: Some circuits comprising the Interconnect as a whole should remain up, but with reduced bandwidth. Note that the versions of this enum prefixed with "IT_" have been deprecated in favor of the unprefixed values. Corresponds to the JSON property issueType

Returns:

  • (String)


36761
36762
36763
# File 'lib/google/apis/compute_alpha/classes.rb', line 36761

def issue_type
  @issue_type
end

#nameString

Unique identifier for this outage notification. Corresponds to the JSON property name

Returns:

  • (String)


36766
36767
36768
# File 'lib/google/apis/compute_alpha/classes.rb', line 36766

def name
  @name
end

#sourceString

The party that generated this notification, which can take the following value:

  • GOOGLE: this notification as generated by Google. Note that the value of NSRC_GOOGLE has been deprecated in favor of GOOGLE. Corresponds to the JSON property source

Returns:

  • (String)


36776
36777
36778
# File 'lib/google/apis/compute_alpha/classes.rb', line 36776

def source
  @source
end

#start_timeFixnum

Scheduled start time for the outage (milliseconds since Unix epoch). Corresponds to the JSON property startTime

Returns:

  • (Fixnum)


36782
36783
36784
# File 'lib/google/apis/compute_alpha/classes.rb', line 36782

def start_time
  @start_time
end

#stateString

State of this notification, which can take one of the following values:

  • ACTIVE: This outage notification is active. The event could be in the past, present, or future. See start_time and end_time for scheduling.
  • CANCELLED: The outage associated with this notification was cancelled before the outage was due to start.
  • COMPLETED: The outage associated with this notification is complete. Note that the versions of this enum prefixed with "NS_" have been deprecated in favor of the unprefixed values. Corresponds to the JSON property state

Returns:

  • (String)


36796
36797
36798
# File 'lib/google/apis/compute_alpha/classes.rb', line 36796

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



36803
36804
36805
36806
36807
36808
36809
36810
36811
36812
# File 'lib/google/apis/compute_alpha/classes.rb', line 36803

def update!(**args)
  @affected_circuits = args[:affected_circuits] if args.key?(:affected_circuits)
  @description = args[:description] if args.key?(:description)
  @end_time = args[:end_time] if args.key?(:end_time)
  @issue_type = args[:issue_type] if args.key?(:issue_type)
  @name = args[:name] if args.key?(:name)
  @source = args[:source] if args.key?(:source)
  @start_time = args[:start_time] if args.key?(:start_time)
  @state = args[:state] if args.key?(:state)
end