Class: Google::Apis::ComputeAlpha::InterconnectRemoteLocation

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Represents a Cross-Cloud Interconnect Remote Location resource. You can use this resource to find remote location details about an Interconnect attachment (VLAN).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectRemoteLocation

Returns a new instance of InterconnectRemoteLocation.



38073
38074
38075
# File 'lib/google/apis/compute_alpha/classes.rb', line 38073

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#addressString

Output only. [Output Only] The postal address of the Point of Presence, each line in the address is separated by a newline character. Corresponds to the JSON property address

Returns:

  • (String)


37919
37920
37921
# File 'lib/google/apis/compute_alpha/classes.rb', line 37919

def address
  @address
end

#attachment_configuration_constraintsGoogle::Apis::ComputeAlpha::InterconnectAttachmentConfigurationConstraints

Output only. [Output Only] Subset of fields from InterconnectAttachment's |configurationConstraints| field that apply to all attachments for this remote location. Corresponds to the JSON property attachmentConfigurationConstraints



37926
37927
37928
# File 'lib/google/apis/compute_alpha/classes.rb', line 37926

def attachment_configuration_constraints
  @attachment_configuration_constraints
end

#cityString

Output only. [Output Only] Metropolitan area designator that indicates which city an interconnect is located. For example: "Chicago, IL", "Amsterdam, Netherlands". Corresponds to the JSON property city

Returns:

  • (String)


37934
37935
37936
# File 'lib/google/apis/compute_alpha/classes.rb', line 37934

def city
  @city
end

#constraintsGoogle::Apis::ComputeAlpha::InterconnectRemoteLocationConstraints

Output only. [Output Only] Constraints on the parameters for creating Cross- Cloud Interconnect and associated InterconnectAttachments. Corresponds to the JSON property constraints



37941
37942
37943
# File 'lib/google/apis/compute_alpha/classes.rb', line 37941

def constraints
  @constraints
end

#continentString

Output only. [Output Only] Continent for this location, which can take one of the following values:

  • AFRICA
  • ASIA_PAC
  • EUROPE
  • NORTH_AMERICA
  • SOUTH_AMERICA Corresponds to the JSON property continent

Returns:

  • (String)


37954
37955
37956
# File 'lib/google/apis/compute_alpha/classes.rb', line 37954

def continent
  @continent
end

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


37960
37961
37962
# File 'lib/google/apis/compute_alpha/classes.rb', line 37960

def creation_timestamp
  @creation_timestamp
end

#descriptionString

Output only. [Output Only] An optional description of the resource. Corresponds to the JSON property description

Returns:

  • (String)


37965
37966
37967
# File 'lib/google/apis/compute_alpha/classes.rb', line 37965

def description
  @description
end

#facility_providerString

Output only. [Output Only] The name of the provider for this facility (e.g., EQUINIX). Corresponds to the JSON property facilityProvider

Returns:

  • (String)


37971
37972
37973
# File 'lib/google/apis/compute_alpha/classes.rb', line 37971

def facility_provider
  @facility_provider
end

#facility_provider_facility_idString

Output only. [Output Only] A provider-assigned Identifier for this facility (e. g., Ashburn-DC1). Corresponds to the JSON property facilityProviderFacilityId

Returns:

  • (String)


37978
37979
37980
# File 'lib/google/apis/compute_alpha/classes.rb', line 37978

def facility_provider_facility_id
  @facility_provider_facility_id
end

#idFixnum

Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


37985
37986
37987
# File 'lib/google/apis/compute_alpha/classes.rb', line 37985

def id
  @id
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# interconnectRemoteLocation for interconnect remote locations. Corresponds to the JSON property kind

Returns:

  • (String)


37992
37993
37994
# File 'lib/google/apis/compute_alpha/classes.rb', line 37992

def kind
  @kind
end

#lacpString

Output only. [Output Only] Link Aggregation Control Protocol (LACP) constraints, which can take one of the following values: LACP_SUPPORTED, LACP_UNSUPPORTED Corresponds to the JSON property lacp

Returns:

  • (String)


37999
38000
38001
# File 'lib/google/apis/compute_alpha/classes.rb', line 37999

def lacp
  @lacp
end

#max_lag_size100_gbpsFixnum

Output only. [Output Only] The maximum number of 100 Gbps ports supported in a link aggregation group (LAG). When linkType is 100 Gbps, requestedLinkCount cannot exceed max_lag_size_100_gbps. Corresponds to the JSON property maxLagSize100Gbps

Returns:

  • (Fixnum)


38007
38008
38009
# File 'lib/google/apis/compute_alpha/classes.rb', line 38007

def max_lag_size100_gbps
  @max_lag_size100_gbps
end

#max_lag_size10_gbpsFixnum

Output only. [Output Only] The maximum number of 10 Gbps ports supported in a link aggregation group (LAG). When linkType is 10 Gbps, requestedLinkCount cannot exceed max_lag_size_10_gbps. Corresponds to the JSON property maxLagSize10Gbps

Returns:

  • (Fixnum)


38015
38016
38017
# File 'lib/google/apis/compute_alpha/classes.rb', line 38015

def max_lag_size10_gbps
  @max_lag_size10_gbps
end

#max_lag_size400_gbpsFixnum

Output only. [Output Only] The maximum number of 400 Gbps ports supported in a link aggregation group (LAG). When linkType is 400 Gbps, requestedLinkCount cannot exceed max_lag_size_400_gbps. Corresponds to the JSON property maxLagSize400Gbps

Returns:

  • (Fixnum)


38023
38024
38025
# File 'lib/google/apis/compute_alpha/classes.rb', line 38023

def max_lag_size400_gbps
  @max_lag_size400_gbps
end

#nameString

Output only. [Output Only] Name of the resource. Corresponds to the JSON property name

Returns:

  • (String)


38028
38029
38030
# File 'lib/google/apis/compute_alpha/classes.rb', line 38028

def name
  @name
end

#peeringdb_facility_idString

Output only. [Output Only] The peeringdb identifier for this facility ( corresponding with a netfac type in peeringdb). Corresponds to the JSON property peeringdbFacilityId

Returns:

  • (String)


38035
38036
38037
# File 'lib/google/apis/compute_alpha/classes.rb', line 38035

def peeringdb_facility_id
  @peeringdb_facility_id
end

#permitted_connectionsArray<Google::Apis::ComputeAlpha::InterconnectRemoteLocationPermittedConnections>

Output only. [Output Only] Permitted connections. Corresponds to the JSON property permittedConnections



38040
38041
38042
# File 'lib/google/apis/compute_alpha/classes.rb', line 38040

def permitted_connections
  @permitted_connections
end

#remote_serviceString

Output only. [Output Only] Indicates the service provider present at the remote location. Example values: "Amazon Web Services", "Microsoft Azure". Corresponds to the JSON property remoteService

Returns:

  • (String)


38047
38048
38049
# File 'lib/google/apis/compute_alpha/classes.rb', line 38047

def remote_service
  @remote_service
end

Output only. [Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


38052
38053
38054
# File 'lib/google/apis/compute_alpha/classes.rb', line 38052

def self_link
  @self_link
end

Output only. [Output Only] Server-defined URL for this resource with the resource id. Corresponds to the JSON property selfLinkWithId

Returns:

  • (String)


38058
38059
38060
# File 'lib/google/apis/compute_alpha/classes.rb', line 38058

def self_link_with_id
  @self_link_with_id
end

#statusString

Output only. [Output Only] The status of this InterconnectRemoteLocation, which can take one of the following values:

  • CLOSED: The InterconnectRemoteLocation is closed and is unavailable for provisioning new Cross-Cloud Interconnects.
  • AVAILABLE: The InterconnectRemoteLocation is available for provisioning new Cross-Cloud Interconnects. Corresponds to the JSON property status

Returns:

  • (String)


38071
38072
38073
# File 'lib/google/apis/compute_alpha/classes.rb', line 38071

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



38078
38079
38080
38081
38082
38083
38084
38085
38086
38087
38088
38089
38090
38091
38092
38093
38094
38095
38096
38097
38098
38099
38100
38101
# File 'lib/google/apis/compute_alpha/classes.rb', line 38078

def update!(**args)
  @address = args[:address] if args.key?(:address)
  @attachment_configuration_constraints = args[:attachment_configuration_constraints] if args.key?(:attachment_configuration_constraints)
  @city = args[:city] if args.key?(:city)
  @constraints = args[:constraints] if args.key?(:constraints)
  @continent = args[:continent] if args.key?(:continent)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @facility_provider = args[:facility_provider] if args.key?(:facility_provider)
  @facility_provider_facility_id = args[:facility_provider_facility_id] if args.key?(:facility_provider_facility_id)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @lacp = args[:lacp] if args.key?(:lacp)
  @max_lag_size100_gbps = args[:max_lag_size100_gbps] if args.key?(:max_lag_size100_gbps)
  @max_lag_size10_gbps = args[:max_lag_size10_gbps] if args.key?(:max_lag_size10_gbps)
  @max_lag_size400_gbps = args[:max_lag_size400_gbps] if args.key?(:max_lag_size400_gbps)
  @name = args[:name] if args.key?(:name)
  @peeringdb_facility_id = args[:peeringdb_facility_id] if args.key?(:peeringdb_facility_id)
  @permitted_connections = args[:permitted_connections] if args.key?(:permitted_connections)
  @remote_service = args[:remote_service] if args.key?(:remote_service)
  @self_link = args[:self_link] if args.key?(:self_link)
  @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id)
  @status = args[:status] if args.key?(:status)
end