Class: Google::Apis::ComputeAlpha::InterconnectRemoteLocation

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Represents a Cross-Cloud Interconnect Remote Location resource. You can use this resource to find remote location details about an Interconnect attachment (VLAN).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectRemoteLocation

Returns a new instance of InterconnectRemoteLocation.



37729
37730
37731
# File 'lib/google/apis/compute_alpha/classes.rb', line 37729

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#addressString

Output only. [Output Only] The postal address of the Point of Presence, each line in the address is separated by a newline character. Corresponds to the JSON property address

Returns:

  • (String)


37575
37576
37577
# File 'lib/google/apis/compute_alpha/classes.rb', line 37575

def address
  @address
end

#attachment_configuration_constraintsGoogle::Apis::ComputeAlpha::InterconnectAttachmentConfigurationConstraints

Output only. [Output Only] Subset of fields from InterconnectAttachment's |configurationConstraints| field that apply to all attachments for this remote location. Corresponds to the JSON property attachmentConfigurationConstraints



37582
37583
37584
# File 'lib/google/apis/compute_alpha/classes.rb', line 37582

def attachment_configuration_constraints
  @attachment_configuration_constraints
end

#cityString

Output only. [Output Only] Metropolitan area designator that indicates which city an interconnect is located. For example: "Chicago, IL", "Amsterdam, Netherlands". Corresponds to the JSON property city

Returns:

  • (String)


37590
37591
37592
# File 'lib/google/apis/compute_alpha/classes.rb', line 37590

def city
  @city
end

#constraintsGoogle::Apis::ComputeAlpha::InterconnectRemoteLocationConstraints

Output only. [Output Only] Constraints on the parameters for creating Cross- Cloud Interconnect and associated InterconnectAttachments. Corresponds to the JSON property constraints



37597
37598
37599
# File 'lib/google/apis/compute_alpha/classes.rb', line 37597

def constraints
  @constraints
end

#continentString

Output only. [Output Only] Continent for this location, which can take one of the following values:

  • AFRICA
  • ASIA_PAC
  • EUROPE
  • NORTH_AMERICA
  • SOUTH_AMERICA Corresponds to the JSON property continent

Returns:

  • (String)


37610
37611
37612
# File 'lib/google/apis/compute_alpha/classes.rb', line 37610

def continent
  @continent
end

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


37616
37617
37618
# File 'lib/google/apis/compute_alpha/classes.rb', line 37616

def creation_timestamp
  @creation_timestamp
end

#descriptionString

Output only. [Output Only] An optional description of the resource. Corresponds to the JSON property description

Returns:

  • (String)


37621
37622
37623
# File 'lib/google/apis/compute_alpha/classes.rb', line 37621

def description
  @description
end

#facility_providerString

Output only. [Output Only] The name of the provider for this facility (e.g., EQUINIX). Corresponds to the JSON property facilityProvider

Returns:

  • (String)


37627
37628
37629
# File 'lib/google/apis/compute_alpha/classes.rb', line 37627

def facility_provider
  @facility_provider
end

#facility_provider_facility_idString

Output only. [Output Only] A provider-assigned Identifier for this facility (e. g., Ashburn-DC1). Corresponds to the JSON property facilityProviderFacilityId

Returns:

  • (String)


37634
37635
37636
# File 'lib/google/apis/compute_alpha/classes.rb', line 37634

def facility_provider_facility_id
  @facility_provider_facility_id
end

#idFixnum

Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


37641
37642
37643
# File 'lib/google/apis/compute_alpha/classes.rb', line 37641

def id
  @id
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# interconnectRemoteLocation for interconnect remote locations. Corresponds to the JSON property kind

Returns:

  • (String)


37648
37649
37650
# File 'lib/google/apis/compute_alpha/classes.rb', line 37648

def kind
  @kind
end

#lacpString

Output only. [Output Only] Link Aggregation Control Protocol (LACP) constraints, which can take one of the following values: LACP_SUPPORTED, LACP_UNSUPPORTED Corresponds to the JSON property lacp

Returns:

  • (String)


37655
37656
37657
# File 'lib/google/apis/compute_alpha/classes.rb', line 37655

def lacp
  @lacp
end

#max_lag_size100_gbpsFixnum

Output only. [Output Only] The maximum number of 100 Gbps ports supported in a link aggregation group (LAG). When linkType is 100 Gbps, requestedLinkCount cannot exceed max_lag_size_100_gbps. Corresponds to the JSON property maxLagSize100Gbps

Returns:

  • (Fixnum)


37663
37664
37665
# File 'lib/google/apis/compute_alpha/classes.rb', line 37663

def max_lag_size100_gbps
  @max_lag_size100_gbps
end

#max_lag_size10_gbpsFixnum

Output only. [Output Only] The maximum number of 10 Gbps ports supported in a link aggregation group (LAG). When linkType is 10 Gbps, requestedLinkCount cannot exceed max_lag_size_10_gbps. Corresponds to the JSON property maxLagSize10Gbps

Returns:

  • (Fixnum)


37671
37672
37673
# File 'lib/google/apis/compute_alpha/classes.rb', line 37671

def max_lag_size10_gbps
  @max_lag_size10_gbps
end

#max_lag_size400_gbpsFixnum

Output only. [Output Only] The maximum number of 400 Gbps ports supported in a link aggregation group (LAG). When linkType is 400 Gbps, requestedLinkCount cannot exceed max_lag_size_400_gbps. Corresponds to the JSON property maxLagSize400Gbps

Returns:

  • (Fixnum)


37679
37680
37681
# File 'lib/google/apis/compute_alpha/classes.rb', line 37679

def max_lag_size400_gbps
  @max_lag_size400_gbps
end

#nameString

Output only. [Output Only] Name of the resource. Corresponds to the JSON property name

Returns:

  • (String)


37684
37685
37686
# File 'lib/google/apis/compute_alpha/classes.rb', line 37684

def name
  @name
end

#peeringdb_facility_idString

Output only. [Output Only] The peeringdb identifier for this facility ( corresponding with a netfac type in peeringdb). Corresponds to the JSON property peeringdbFacilityId

Returns:

  • (String)


37691
37692
37693
# File 'lib/google/apis/compute_alpha/classes.rb', line 37691

def peeringdb_facility_id
  @peeringdb_facility_id
end

#permitted_connectionsArray<Google::Apis::ComputeAlpha::InterconnectRemoteLocationPermittedConnections>

Output only. [Output Only] Permitted connections. Corresponds to the JSON property permittedConnections



37696
37697
37698
# File 'lib/google/apis/compute_alpha/classes.rb', line 37696

def permitted_connections
  @permitted_connections
end

#remote_serviceString

Output only. [Output Only] Indicates the service provider present at the remote location. Example values: "Amazon Web Services", "Microsoft Azure". Corresponds to the JSON property remoteService

Returns:

  • (String)


37703
37704
37705
# File 'lib/google/apis/compute_alpha/classes.rb', line 37703

def remote_service
  @remote_service
end

Output only. [Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


37708
37709
37710
# File 'lib/google/apis/compute_alpha/classes.rb', line 37708

def self_link
  @self_link
end

Output only. [Output Only] Server-defined URL for this resource with the resource id. Corresponds to the JSON property selfLinkWithId

Returns:

  • (String)


37714
37715
37716
# File 'lib/google/apis/compute_alpha/classes.rb', line 37714

def self_link_with_id
  @self_link_with_id
end

#statusString

Output only. [Output Only] The status of this InterconnectRemoteLocation, which can take one of the following values:

  • CLOSED: The InterconnectRemoteLocation is closed and is unavailable for provisioning new Cross-Cloud Interconnects.
  • AVAILABLE: The InterconnectRemoteLocation is available for provisioning new Cross-Cloud Interconnects. Corresponds to the JSON property status

Returns:

  • (String)


37727
37728
37729
# File 'lib/google/apis/compute_alpha/classes.rb', line 37727

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



37734
37735
37736
37737
37738
37739
37740
37741
37742
37743
37744
37745
37746
37747
37748
37749
37750
37751
37752
37753
37754
37755
37756
37757
# File 'lib/google/apis/compute_alpha/classes.rb', line 37734

def update!(**args)
  @address = args[:address] if args.key?(:address)
  @attachment_configuration_constraints = args[:attachment_configuration_constraints] if args.key?(:attachment_configuration_constraints)
  @city = args[:city] if args.key?(:city)
  @constraints = args[:constraints] if args.key?(:constraints)
  @continent = args[:continent] if args.key?(:continent)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @facility_provider = args[:facility_provider] if args.key?(:facility_provider)
  @facility_provider_facility_id = args[:facility_provider_facility_id] if args.key?(:facility_provider_facility_id)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @lacp = args[:lacp] if args.key?(:lacp)
  @max_lag_size100_gbps = args[:max_lag_size100_gbps] if args.key?(:max_lag_size100_gbps)
  @max_lag_size10_gbps = args[:max_lag_size10_gbps] if args.key?(:max_lag_size10_gbps)
  @max_lag_size400_gbps = args[:max_lag_size400_gbps] if args.key?(:max_lag_size400_gbps)
  @name = args[:name] if args.key?(:name)
  @peeringdb_facility_id = args[:peeringdb_facility_id] if args.key?(:peeringdb_facility_id)
  @permitted_connections = args[:permitted_connections] if args.key?(:permitted_connections)
  @remote_service = args[:remote_service] if args.key?(:remote_service)
  @self_link = args[:self_link] if args.key?(:self_link)
  @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id)
  @status = args[:status] if args.key?(:status)
end