Class: Google::Apis::ComputeAlpha::InterconnectRemoteLocationList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Response to the list request, and contains a list of interconnect remote locations.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectRemoteLocationList

Returns a new instance of InterconnectRemoteLocationList.



39272
39273
39274
# File 'lib/google/apis/compute_alpha/classes.rb', line 39272

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


39238
39239
39240
# File 'lib/google/apis/compute_alpha/classes.rb', line 39238

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::InterconnectRemoteLocation>

A list of InterconnectRemoteLocation resources. Corresponds to the JSON property items



39243
39244
39245
# File 'lib/google/apis/compute_alpha/classes.rb', line 39243

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# interconnectRemoteLocationList for lists of interconnect remote locations. Corresponds to the JSON property kind

Returns:

  • (String)


39250
39251
39252
# File 'lib/google/apis/compute_alpha/classes.rb', line 39250

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token lets you get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


39260
39261
39262
# File 'lib/google/apis/compute_alpha/classes.rb', line 39260

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


39265
39266
39267
# File 'lib/google/apis/compute_alpha/classes.rb', line 39265

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::InterconnectRemoteLocationList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



39270
39271
39272
# File 'lib/google/apis/compute_alpha/classes.rb', line 39270

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



39277
39278
39279
39280
39281
39282
39283
39284
# File 'lib/google/apis/compute_alpha/classes.rb', line 39277

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end