Class: Google::Apis::ComputeAlpha::InterconnectRemoteLocationList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Response to the list request, and contains a list of interconnect remote locations.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectRemoteLocationList

Returns a new instance of InterconnectRemoteLocationList.



38993
38994
38995
# File 'lib/google/apis/compute_alpha/classes.rb', line 38993

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


38959
38960
38961
# File 'lib/google/apis/compute_alpha/classes.rb', line 38959

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::InterconnectRemoteLocation>

A list of InterconnectRemoteLocation resources. Corresponds to the JSON property items



38964
38965
38966
# File 'lib/google/apis/compute_alpha/classes.rb', line 38964

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# interconnectRemoteLocationList for lists of interconnect remote locations. Corresponds to the JSON property kind

Returns:

  • (String)


38971
38972
38973
# File 'lib/google/apis/compute_alpha/classes.rb', line 38971

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token lets you get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


38981
38982
38983
# File 'lib/google/apis/compute_alpha/classes.rb', line 38981

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


38986
38987
38988
# File 'lib/google/apis/compute_alpha/classes.rb', line 38986

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::InterconnectRemoteLocationList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



38991
38992
38993
# File 'lib/google/apis/compute_alpha/classes.rb', line 38991

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



38998
38999
39000
39001
39002
39003
39004
39005
# File 'lib/google/apis/compute_alpha/classes.rb', line 38998

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end