Class: Google::Apis::ComputeAlpha::InterconnectRemoteLocationList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::InterconnectRemoteLocationList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Response to the list request, and contains a list of interconnect remote locations.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::InterconnectRemoteLocation>
A list of InterconnectRemoteLocation resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token lets you get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::InterconnectRemoteLocationList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InterconnectRemoteLocationList
constructor
A new instance of InterconnectRemoteLocationList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InterconnectRemoteLocationList
Returns a new instance of InterconnectRemoteLocationList.
38241 38242 38243 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 38241 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
38207 38208 38209 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 38207 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::InterconnectRemoteLocation>
A list of InterconnectRemoteLocation resources.
Corresponds to the JSON property items
38212 38213 38214 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 38212 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
interconnectRemoteLocationList for lists of
interconnect remote locations.
Corresponds to the JSON property kind
38219 38220 38221 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 38219 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token lets you get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
38229 38230 38231 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 38229 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
38234 38235 38236 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 38234 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::InterconnectRemoteLocationList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
38239 38240 38241 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 38239 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
38246 38247 38248 38249 38250 38251 38252 38253 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 38246 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |