Class: Google::Apis::ComputeAlpha::InterconnectRemoteLocationList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Response to the list request, and contains a list of interconnect remote locations.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectRemoteLocationList

Returns a new instance of InterconnectRemoteLocationList.



38224
38225
38226
# File 'lib/google/apis/compute_alpha/classes.rb', line 38224

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


38190
38191
38192
# File 'lib/google/apis/compute_alpha/classes.rb', line 38190

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::InterconnectRemoteLocation>

A list of InterconnectRemoteLocation resources. Corresponds to the JSON property items



38195
38196
38197
# File 'lib/google/apis/compute_alpha/classes.rb', line 38195

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# interconnectRemoteLocationList for lists of interconnect remote locations. Corresponds to the JSON property kind

Returns:

  • (String)


38202
38203
38204
# File 'lib/google/apis/compute_alpha/classes.rb', line 38202

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token lets you get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


38212
38213
38214
# File 'lib/google/apis/compute_alpha/classes.rb', line 38212

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


38217
38218
38219
# File 'lib/google/apis/compute_alpha/classes.rb', line 38217

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::InterconnectRemoteLocationList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



38222
38223
38224
# File 'lib/google/apis/compute_alpha/classes.rb', line 38222

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



38229
38230
38231
38232
38233
38234
38235
38236
# File 'lib/google/apis/compute_alpha/classes.rb', line 38229

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end