Class: Google::Apis::ComputeAlpha::InterconnectRemoteLocationList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Response to the list request, and contains a list of interconnect remote locations.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectRemoteLocationList

Returns a new instance of InterconnectRemoteLocationList.



37163
37164
37165
# File 'lib/google/apis/compute_alpha/classes.rb', line 37163

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


37129
37130
37131
# File 'lib/google/apis/compute_alpha/classes.rb', line 37129

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::InterconnectRemoteLocation>

A list of InterconnectRemoteLocation resources. Corresponds to the JSON property items



37134
37135
37136
# File 'lib/google/apis/compute_alpha/classes.rb', line 37134

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# interconnectRemoteLocationList for lists of interconnect remote locations. Corresponds to the JSON property kind

Returns:

  • (String)


37141
37142
37143
# File 'lib/google/apis/compute_alpha/classes.rb', line 37141

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token lets you get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


37151
37152
37153
# File 'lib/google/apis/compute_alpha/classes.rb', line 37151

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


37156
37157
37158
# File 'lib/google/apis/compute_alpha/classes.rb', line 37156

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::InterconnectRemoteLocationList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



37161
37162
37163
# File 'lib/google/apis/compute_alpha/classes.rb', line 37161

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



37168
37169
37170
37171
37172
37173
37174
37175
# File 'lib/google/apis/compute_alpha/classes.rb', line 37168

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end