Class: Google::Apis::ComputeAlpha::Interval

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Represents a time interval, encoded as a Timestamp start (inclusive) and a Timestamp end (exclusive). The start must be less than or equal to the end. When the start equals the end, the interval is empty (matches no time). When both start and end are unspecified, the interval matches any time.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Interval

Returns a new instance of Interval.



38492
38493
38494
# File 'lib/google/apis/compute_alpha/classes.rb', line 38492

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#end_timeString

Optional. Exclusive end of the interval. If specified, a Timestamp matching this interval will have to be before the end. Corresponds to the JSON property endTime

Returns:

  • (String)


38483
38484
38485
# File 'lib/google/apis/compute_alpha/classes.rb', line 38483

def end_time
  @end_time
end

#start_timeString

Optional. Inclusive start of the interval. If specified, a Timestamp matching this interval will have to be the same or after the start. Corresponds to the JSON property startTime

Returns:

  • (String)


38490
38491
38492
# File 'lib/google/apis/compute_alpha/classes.rb', line 38490

def start_time
  @start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



38497
38498
38499
38500
# File 'lib/google/apis/compute_alpha/classes.rb', line 38497

def update!(**args)
  @end_time = args[:end_time] if args.key?(:end_time)
  @start_time = args[:start_time] if args.key?(:start_time)
end