Class: Google::Apis::ComputeAlpha::IpAddressesList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::IpAddressesList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::InternalIpAddress>
A list of InternalIpAddress resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::IpAddressesList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ IpAddressesList
constructor
A new instance of IpAddressesList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ IpAddressesList
Returns a new instance of IpAddressesList.
39825 39826 39827 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39825 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
39792 39793 39794 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39792 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::InternalIpAddress>
A list of InternalIpAddress resources.
Corresponds to the JSON property items
39797 39798 39799 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39797 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#ipAddressesList
for IP addresses lists.
Corresponds to the JSON property kind
39803 39804 39805 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39803 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
39813 39814 39815 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39813 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
39818 39819 39820 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39818 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::IpAddressesList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
39823 39824 39825 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39823 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
39830 39831 39832 39833 39834 39835 39836 39837 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39830 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |