Class: Google::Apis::ComputeAlpha::IpAddressesList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ IpAddressesList

Returns a new instance of IpAddressesList.



39601
39602
39603
# File 'lib/google/apis/compute_alpha/classes.rb', line 39601

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


39568
39569
39570
# File 'lib/google/apis/compute_alpha/classes.rb', line 39568

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::InternalIpAddress>

A list of InternalIpAddress resources. Corresponds to the JSON property items



39573
39574
39575
# File 'lib/google/apis/compute_alpha/classes.rb', line 39573

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#ipAddressesList for IP addresses lists. Corresponds to the JSON property kind

Returns:

  • (String)


39579
39580
39581
# File 'lib/google/apis/compute_alpha/classes.rb', line 39579

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


39589
39590
39591
# File 'lib/google/apis/compute_alpha/classes.rb', line 39589

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


39594
39595
39596
# File 'lib/google/apis/compute_alpha/classes.rb', line 39594

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::IpAddressesList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



39599
39600
39601
# File 'lib/google/apis/compute_alpha/classes.rb', line 39599

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



39606
39607
39608
39609
39610
39611
39612
39613
# File 'lib/google/apis/compute_alpha/classes.rb', line 39606

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end