Class: Google::Apis::ComputeAlpha::IpAddressesList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::IpAddressesList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::InternalIpAddress>
A list of InternalIpAddress resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::IpAddressesList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ IpAddressesList
constructor
A new instance of IpAddressesList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ IpAddressesList
Returns a new instance of IpAddressesList.
39322 39323 39324 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39322 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
39289 39290 39291 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39289 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::InternalIpAddress>
A list of InternalIpAddress resources.
Corresponds to the JSON property items
39294 39295 39296 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39294 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#ipAddressesList
for IP addresses lists.
Corresponds to the JSON property kind
39300 39301 39302 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39300 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
39310 39311 39312 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39310 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
39315 39316 39317 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39315 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::IpAddressesList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
39320 39321 39322 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39320 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
39327 39328 39329 39330 39331 39332 39333 39334 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39327 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |