Class: Google::Apis::ComputeAlpha::IpAddressesList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ IpAddressesList

Returns a new instance of IpAddressesList.



38310
38311
38312
# File 'lib/google/apis/compute_alpha/classes.rb', line 38310

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


38277
38278
38279
# File 'lib/google/apis/compute_alpha/classes.rb', line 38277

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::InternalIpAddress>

A list of InternalIpAddress resources. Corresponds to the JSON property items



38282
38283
38284
# File 'lib/google/apis/compute_alpha/classes.rb', line 38282

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#ipAddressesList for IP addresses lists. Corresponds to the JSON property kind

Returns:

  • (String)


38288
38289
38290
# File 'lib/google/apis/compute_alpha/classes.rb', line 38288

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


38298
38299
38300
# File 'lib/google/apis/compute_alpha/classes.rb', line 38298

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


38303
38304
38305
# File 'lib/google/apis/compute_alpha/classes.rb', line 38303

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::IpAddressesList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



38308
38309
38310
# File 'lib/google/apis/compute_alpha/classes.rb', line 38308

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



38315
38316
38317
38318
38319
38320
38321
38322
# File 'lib/google/apis/compute_alpha/classes.rb', line 38315

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end