Class: Google::Apis::ComputeAlpha::IpAddressesList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ IpAddressesList

Returns a new instance of IpAddressesList.



37432
37433
37434
# File 'lib/google/apis/compute_alpha/classes.rb', line 37432

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


37399
37400
37401
# File 'lib/google/apis/compute_alpha/classes.rb', line 37399

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::InternalIpAddress>

A list of InternalIpAddress resources. Corresponds to the JSON property items



37404
37405
37406
# File 'lib/google/apis/compute_alpha/classes.rb', line 37404

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#ipAddressesList for IP addresses lists. Corresponds to the JSON property kind

Returns:

  • (String)


37410
37411
37412
# File 'lib/google/apis/compute_alpha/classes.rb', line 37410

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


37420
37421
37422
# File 'lib/google/apis/compute_alpha/classes.rb', line 37420

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


37425
37426
37427
# File 'lib/google/apis/compute_alpha/classes.rb', line 37425

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::IpAddressesList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



37430
37431
37432
# File 'lib/google/apis/compute_alpha/classes.rb', line 37430

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



37437
37438
37439
37440
37441
37442
37443
37444
# File 'lib/google/apis/compute_alpha/classes.rb', line 37437

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end