Class: Google::Apis::ComputeAlpha::IpOwnerList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of IP owners.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ IpOwnerList

Returns a new instance of IpOwnerList.



38656
38657
38658
# File 'lib/google/apis/compute_alpha/classes.rb', line 38656

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


38618
38619
38620
# File 'lib/google/apis/compute_alpha/classes.rb', line 38618

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::InternalIpOwner>

A list of InternalIpOwner resources. Corresponds to the JSON property items



38623
38624
38625
# File 'lib/google/apis/compute_alpha/classes.rb', line 38623

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#ipOwnerList for lists of IP owners. Corresponds to the JSON property kind

Returns:

  • (String)


38629
38630
38631
# File 'lib/google/apis/compute_alpha/classes.rb', line 38629

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


38639
38640
38641
# File 'lib/google/apis/compute_alpha/classes.rb', line 38639

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


38644
38645
38646
# File 'lib/google/apis/compute_alpha/classes.rb', line 38644

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


38649
38650
38651
# File 'lib/google/apis/compute_alpha/classes.rb', line 38649

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::IpOwnerList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



38654
38655
38656
# File 'lib/google/apis/compute_alpha/classes.rb', line 38654

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



38661
38662
38663
38664
38665
38666
38667
38668
38669
# File 'lib/google/apis/compute_alpha/classes.rb', line 38661

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end