Class: Google::Apis::ComputeAlpha::IpOwnerList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::IpOwnerList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Contains a list of IP owners.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::InternalIpOwner>
A list of InternalIpOwner resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::IpOwnerList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ IpOwnerList
constructor
A new instance of IpOwnerList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ IpOwnerList
Returns a new instance of IpOwnerList.
38440 38441 38442 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 38440 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
38402 38403 38404 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 38402 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::InternalIpOwner>
A list of InternalIpOwner resources.
Corresponds to the JSON property items
38407 38408 38409 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 38407 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#ipOwnerList for
lists of IP owners.
Corresponds to the JSON property kind
38413 38414 38415 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 38413 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
38423 38424 38425 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 38423 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
38428 38429 38430 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 38428 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
38433 38434 38435 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 38433 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::IpOwnerList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
38438 38439 38440 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 38438 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
38445 38446 38447 38448 38449 38450 38451 38452 38453 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 38445 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |