Class: Google::Apis::ComputeAlpha::IpOwnerList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::IpOwnerList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Contains a list of IP owners.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::InternalIpOwner>
A list of InternalIpOwner resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::IpOwnerList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ IpOwnerList
constructor
A new instance of IpOwnerList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ IpOwnerList
Returns a new instance of IpOwnerList.
38450 38451 38452 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 38450 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
38412 38413 38414 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 38412 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::InternalIpOwner>
A list of InternalIpOwner resources.
Corresponds to the JSON property items
38417 38418 38419 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 38417 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#ipOwnerList for
lists of IP owners.
Corresponds to the JSON property kind
38423 38424 38425 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 38423 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
38433 38434 38435 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 38433 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
38438 38439 38440 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 38438 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
38443 38444 38445 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 38443 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::IpOwnerList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
38448 38449 38450 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 38448 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
38455 38456 38457 38458 38459 38460 38461 38462 38463 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 38455 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |