Class: Google::Apis::ComputeAlpha::IpOwnerList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of IP owners.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ IpOwnerList

Returns a new instance of IpOwnerList.



38312
38313
38314
# File 'lib/google/apis/compute_alpha/classes.rb', line 38312

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


38274
38275
38276
# File 'lib/google/apis/compute_alpha/classes.rb', line 38274

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::InternalIpOwner>

A list of InternalIpOwner resources. Corresponds to the JSON property items



38279
38280
38281
# File 'lib/google/apis/compute_alpha/classes.rb', line 38279

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#ipOwnerList for lists of IP owners. Corresponds to the JSON property kind

Returns:

  • (String)


38285
38286
38287
# File 'lib/google/apis/compute_alpha/classes.rb', line 38285

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


38295
38296
38297
# File 'lib/google/apis/compute_alpha/classes.rb', line 38295

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


38300
38301
38302
# File 'lib/google/apis/compute_alpha/classes.rb', line 38300

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


38305
38306
38307
# File 'lib/google/apis/compute_alpha/classes.rb', line 38305

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::IpOwnerList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



38310
38311
38312
# File 'lib/google/apis/compute_alpha/classes.rb', line 38310

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



38317
38318
38319
38320
38321
38322
38323
38324
38325
# File 'lib/google/apis/compute_alpha/classes.rb', line 38317

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end