Class: Google::Apis::ComputeAlpha::IpOwnerList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of IP owners.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ IpOwnerList

Returns a new instance of IpOwnerList.



37562
37563
37564
# File 'lib/google/apis/compute_alpha/classes.rb', line 37562

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


37524
37525
37526
# File 'lib/google/apis/compute_alpha/classes.rb', line 37524

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::InternalIpOwner>

A list of InternalIpOwner resources. Corresponds to the JSON property items



37529
37530
37531
# File 'lib/google/apis/compute_alpha/classes.rb', line 37529

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#ipOwnerList for lists of IP owners. Corresponds to the JSON property kind

Returns:

  • (String)


37535
37536
37537
# File 'lib/google/apis/compute_alpha/classes.rb', line 37535

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


37545
37546
37547
# File 'lib/google/apis/compute_alpha/classes.rb', line 37545

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


37550
37551
37552
# File 'lib/google/apis/compute_alpha/classes.rb', line 37550

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


37555
37556
37557
# File 'lib/google/apis/compute_alpha/classes.rb', line 37555

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::IpOwnerList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



37560
37561
37562
# File 'lib/google/apis/compute_alpha/classes.rb', line 37560

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



37567
37568
37569
37570
37571
37572
37573
37574
37575
# File 'lib/google/apis/compute_alpha/classes.rb', line 37567

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end