Class: Google::Apis::ComputeAlpha::LicenseCode
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::LicenseCode
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Represents a License Code resource. A License Code is a unique identifier used to represent alicense resource. Caution This resource is intended for use only by third-party partners who are creatingCloud Marketplace images.
Instance Attribute Summary collapse
-
#allowed_replacement_licenses ⇒ Array<String>
Specifies licenseCodes of licenses that can replace this license.
-
#appendable_to_disk ⇒ Boolean
(also: #appendable_to_disk?)
If true, this license can be appended to an existing disk's set of licenses.
-
#creation_timestamp ⇒ String
Output only.
-
#description ⇒ String
Output only.
-
#id ⇒ Fixnum
Output only.
-
#incompatible_licenses ⇒ Array<String>
Specifies licenseCodes of licenses that are incompatible with this license.
-
#kind ⇒ String
Output only.
-
#license_alias ⇒ Array<Google::Apis::ComputeAlpha::LicenseCodeLicenseAlias>
[Output Only] URL and description aliases of Licenses with the same License Code.
-
#minimum_retention ⇒ Google::Apis::ComputeAlpha::Duration
A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution.
-
#multi_tenant_only ⇒ Boolean
(also: #multi_tenant_only?)
If true, this license can only be used on VMs on multi tenant nodes.
-
#name ⇒ String
Output only.
-
#os_license ⇒ Boolean
(also: #os_license?)
If true, indicates this is an OS license.
-
#removable_from_disk ⇒ Boolean
(also: #removable_from_disk?)
If true, this license can be removed from a disk's set of licenses, with no replacement license needed.
-
#required_coattached_licenses ⇒ Array<String>
Specifies the set of permissible coattached licenseCodes of licenses that satisfy the coattachment requirement of this license.
-
#self_link ⇒ String
Output only.
-
#sole_tenant_only ⇒ Boolean
(also: #sole_tenant_only?)
If true, this license can only be used on VMs on sole tenant nodes.
-
#state ⇒ String
Output only.
-
#transferable ⇒ Boolean
(also: #transferable?)
Output only.
-
#update_timestamp ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LicenseCode
constructor
A new instance of LicenseCode.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LicenseCode
Returns a new instance of LicenseCode.
40218 40219 40220 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 40218 def initialize(**args) update!(**args) end |
Instance Attribute Details
#allowed_replacement_licenses ⇒ Array<String>
Specifies licenseCodes of licenses that can replace this license. Note:
such replacements are allowed even if removable_from_disk is false.
Corresponds to the JSON property allowedReplacementLicenses
40100 40101 40102 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 40100 def allowed_replacement_licenses @allowed_replacement_licenses end |
#appendable_to_disk ⇒ Boolean Also known as: appendable_to_disk?
If true, this license can be appended to an existing disk's set of
licenses.
Corresponds to the JSON property appendableToDisk
40106 40107 40108 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 40106 def appendable_to_disk @appendable_to_disk end |
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
40113 40114 40115 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 40113 def @creation_timestamp end |
#description ⇒ String
Output only. [Output Only] Description of this License Code.
Corresponds to the JSON property description
40118 40119 40120 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 40118 def description @description end |
#id ⇒ Fixnum
Output only. [Output Only] The unique identifier for the resource. This
identifier is
defined by the server.
Corresponds to the JSON property id
40125 40126 40127 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 40125 def id @id end |
#incompatible_licenses ⇒ Array<String>
Specifies licenseCodes of licenses that are incompatible with this license.
If a license is incompatible with this license, it cannot be attached to
the same disk or image.
Corresponds to the JSON property incompatibleLicenses
40132 40133 40134 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 40132 def incompatible_licenses @incompatible_licenses end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#licenseCode for
licenses.
Corresponds to the JSON property kind
40138 40139 40140 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 40138 def kind @kind end |
#license_alias ⇒ Array<Google::Apis::ComputeAlpha::LicenseCodeLicenseAlias>
[Output Only] URL and description aliases of Licenses with the same
License Code.
Corresponds to the JSON property licenseAlias
40144 40145 40146 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 40144 def license_alias @license_alias end |
#minimum_retention ⇒ Google::Apis::ComputeAlpha::Duration
A Duration represents a fixed-length span of time represented
as a count of seconds and fractions of seconds at nanosecond
resolution. It is independent of any calendar and concepts like "day"
or "month". Range is approximately 10,000 years.
Corresponds to the JSON property minimumRetention
40152 40153 40154 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 40152 def minimum_retention @minimum_retention end |
#multi_tenant_only ⇒ Boolean Also known as: multi_tenant_only?
If true, this license can only be used on VMs on multi tenant nodes.
Corresponds to the JSON property multiTenantOnly
40157 40158 40159 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 40157 def multi_tenant_only @multi_tenant_only end |
#name ⇒ String
Output only. [Output Only] Name of the resource. The name is 1-20 characters
long and
must be a valid 64 bit integer.
Corresponds to the JSON property name
40165 40166 40167 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 40165 def name @name end |
#os_license ⇒ Boolean Also known as: os_license?
If true, indicates this is an OS license. Only one OS license can be
attached to a disk or image at a time.
Corresponds to the JSON property osLicense
40171 40172 40173 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 40171 def os_license @os_license end |
#removable_from_disk ⇒ Boolean Also known as: removable_from_disk?
If true, this license can be removed from a disk's set of licenses, with no
replacement license needed.
Corresponds to the JSON property removableFromDisk
40178 40179 40180 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 40178 def removable_from_disk @removable_from_disk end |
#required_coattached_licenses ⇒ Array<String>
Specifies the set of permissible coattached licenseCodes of licenses that
satisfy the coattachment requirement of this license. At least one license
from the set must be attached to the same disk or image as this license.
Corresponds to the JSON property requiredCoattachedLicenses
40186 40187 40188 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 40186 def required_coattached_licenses @required_coattached_licenses end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
40191 40192 40193 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 40191 def self_link @self_link end |
#sole_tenant_only ⇒ Boolean Also known as: sole_tenant_only?
If true, this license can only be used on VMs on sole tenant nodes.
Corresponds to the JSON property soleTenantOnly
40196 40197 40198 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 40196 def sole_tenant_only @sole_tenant_only end |
#state ⇒ String
Output only. [Output Only] Current state of this License Code.
Corresponds to the JSON property state
40202 40203 40204 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 40202 def state @state end |
#transferable ⇒ Boolean Also known as: transferable?
Output only. [Output Only] If true, the license will remain attached when
creating
images or snapshots from disks. Otherwise, the license is not transferred.
Corresponds to the JSON property transferable
40209 40210 40211 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 40209 def transferable @transferable end |
#update_timestamp ⇒ String
Output only. [Output Only] Last update timestamp inRFC3339
text format.
Corresponds to the JSON property updateTimestamp
40216 40217 40218 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 40216 def @update_timestamp end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
40223 40224 40225 40226 40227 40228 40229 40230 40231 40232 40233 40234 40235 40236 40237 40238 40239 40240 40241 40242 40243 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 40223 def update!(**args) @allowed_replacement_licenses = args[:allowed_replacement_licenses] if args.key?(:allowed_replacement_licenses) @appendable_to_disk = args[:appendable_to_disk] if args.key?(:appendable_to_disk) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @id = args[:id] if args.key?(:id) @incompatible_licenses = args[:incompatible_licenses] if args.key?(:incompatible_licenses) @kind = args[:kind] if args.key?(:kind) @license_alias = args[:license_alias] if args.key?(:license_alias) @minimum_retention = args[:minimum_retention] if args.key?(:minimum_retention) @multi_tenant_only = args[:multi_tenant_only] if args.key?(:multi_tenant_only) @name = args[:name] if args.key?(:name) @os_license = args[:os_license] if args.key?(:os_license) @removable_from_disk = args[:removable_from_disk] if args.key?(:removable_from_disk) @required_coattached_licenses = args[:required_coattached_licenses] if args.key?(:required_coattached_licenses) @self_link = args[:self_link] if args.key?(:self_link) @sole_tenant_only = args[:sole_tenant_only] if args.key?(:sole_tenant_only) @state = args[:state] if args.key?(:state) @transferable = args[:transferable] if args.key?(:transferable) @update_timestamp = args[:update_timestamp] if args.key?(:update_timestamp) end |