Class: Google::Apis::ComputeAlpha::LicensesListResponse
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::LicensesListResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::License>
A list of License resources.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::LicensesListResponse::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LicensesListResponse
constructor
A new instance of LicensesListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LicensesListResponse
Returns a new instance of LicensesListResponse.
40110 40111 40112 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 40110 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
40083 40084 40085 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 40083 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::License>
A list of License resources.
Corresponds to the JSON property items
40088 40089 40090 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 40088 def items @items end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
40098 40099 40100 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 40098 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
40103 40104 40105 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 40103 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::LicensesListResponse::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
40108 40109 40110 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 40108 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
40115 40116 40117 40118 40119 40120 40121 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 40115 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |