Class: Google::Apis::ComputeAlpha::LicensesListResponse
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::LicensesListResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::License>
A list of License resources.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::LicensesListResponse::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LicensesListResponse
constructor
A new instance of LicensesListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LicensesListResponse
Returns a new instance of LicensesListResponse.
39331 39332 39333 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39331 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
39304 39305 39306 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39304 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::License>
A list of License resources.
Corresponds to the JSON property items
39309 39310 39311 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39309 def items @items end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
39319 39320 39321 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39319 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
39324 39325 39326 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39324 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::LicensesListResponse::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
39329 39330 39331 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39329 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
39336 39337 39338 39339 39340 39341 39342 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39336 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |