Class: Google::Apis::ComputeAlpha::LicensesListResponse
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::LicensesListResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::License>
A list of License resources.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::LicensesListResponse::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LicensesListResponse
constructor
A new instance of LicensesListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LicensesListResponse
Returns a new instance of LicensesListResponse.
39098 39099 39100 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39098 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
39071 39072 39073 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39071 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::License>
A list of License resources.
Corresponds to the JSON property items
39076 39077 39078 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39076 def items @items end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
39086 39087 39088 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39086 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
39091 39092 39093 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39091 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::LicensesListResponse::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
39096 39097 39098 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39096 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
39103 39104 39105 39106 39107 39108 39109 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39103 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |