Class: Google::Apis::ComputeAlpha::ListInstantSnapshotGroups
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::ListInstantSnapshotGroups
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Contains a list of InstantSnapshotGroup resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::InstantSnapshotGroup>
A list of InstantSnapshotGroup resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::ListInstantSnapshotGroups::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListInstantSnapshotGroups
constructor
A new instance of ListInstantSnapshotGroups.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListInstantSnapshotGroups
Returns a new instance of ListInstantSnapshotGroups.
40523 40524 40525 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 40523 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
40480 40481 40482 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 40480 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
40485 40486 40487 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 40485 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::InstantSnapshotGroup>
A list of InstantSnapshotGroup resources.
Corresponds to the JSON property items
40490 40491 40492 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 40490 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
40495 40496 40497 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 40495 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
40505 40506 40507 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 40505 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
40510 40511 40512 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 40510 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
end_interface: MixerListResponseWithEtagBuilder
Corresponds to the JSON property unreachables
40516 40517 40518 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 40516 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::ListInstantSnapshotGroups::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
40521 40522 40523 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 40521 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
40528 40529 40530 40531 40532 40533 40534 40535 40536 40537 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 40528 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |