Class: Google::Apis::ComputeAlpha::ListInstantSnapshotGroups

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of InstantSnapshotGroup resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListInstantSnapshotGroups

Returns a new instance of ListInstantSnapshotGroups.



40244
40245
40246
# File 'lib/google/apis/compute_alpha/classes.rb', line 40244

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


40201
40202
40203
# File 'lib/google/apis/compute_alpha/classes.rb', line 40201

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


40206
40207
40208
# File 'lib/google/apis/compute_alpha/classes.rb', line 40206

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::InstantSnapshotGroup>

A list of InstantSnapshotGroup resources. Corresponds to the JSON property items



40211
40212
40213
# File 'lib/google/apis/compute_alpha/classes.rb', line 40211

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


40216
40217
40218
# File 'lib/google/apis/compute_alpha/classes.rb', line 40216

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


40226
40227
40228
# File 'lib/google/apis/compute_alpha/classes.rb', line 40226

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


40231
40232
40233
# File 'lib/google/apis/compute_alpha/classes.rb', line 40231

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


40237
40238
40239
# File 'lib/google/apis/compute_alpha/classes.rb', line 40237

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::ListInstantSnapshotGroups::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



40242
40243
40244
# File 'lib/google/apis/compute_alpha/classes.rb', line 40242

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



40249
40250
40251
40252
40253
40254
40255
40256
40257
40258
# File 'lib/google/apis/compute_alpha/classes.rb', line 40249

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end