Class: Google::Apis::ComputeAlpha::ListInstantSnapshotGroups

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of InstantSnapshotGroup resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListInstantSnapshotGroups

Returns a new instance of ListInstantSnapshotGroups.



39465
39466
39467
# File 'lib/google/apis/compute_alpha/classes.rb', line 39465

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


39422
39423
39424
# File 'lib/google/apis/compute_alpha/classes.rb', line 39422

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


39427
39428
39429
# File 'lib/google/apis/compute_alpha/classes.rb', line 39427

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::InstantSnapshotGroup>

A list of InstantSnapshotGroup resources. Corresponds to the JSON property items



39432
39433
39434
# File 'lib/google/apis/compute_alpha/classes.rb', line 39432

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


39437
39438
39439
# File 'lib/google/apis/compute_alpha/classes.rb', line 39437

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


39447
39448
39449
# File 'lib/google/apis/compute_alpha/classes.rb', line 39447

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


39452
39453
39454
# File 'lib/google/apis/compute_alpha/classes.rb', line 39452

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


39458
39459
39460
# File 'lib/google/apis/compute_alpha/classes.rb', line 39458

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::ListInstantSnapshotGroups::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



39463
39464
39465
# File 'lib/google/apis/compute_alpha/classes.rb', line 39463

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



39470
39471
39472
39473
39474
39475
39476
39477
39478
39479
# File 'lib/google/apis/compute_alpha/classes.rb', line 39470

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end