Class: Google::Apis::ComputeAlpha::ListInstantSnapshotGroups
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::ListInstantSnapshotGroups
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Contains a list of InstantSnapshotGroup resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::InstantSnapshotGroup>
A list of InstantSnapshotGroup resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::ListInstantSnapshotGroups::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListInstantSnapshotGroups
constructor
A new instance of ListInstantSnapshotGroups.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListInstantSnapshotGroups
Returns a new instance of ListInstantSnapshotGroups.
39448 39449 39450 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39448 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
39405 39406 39407 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39405 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
39410 39411 39412 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39410 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::InstantSnapshotGroup>
A list of InstantSnapshotGroup resources.
Corresponds to the JSON property items
39415 39416 39417 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39415 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
39420 39421 39422 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39420 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
39430 39431 39432 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39430 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
39435 39436 39437 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39435 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
end_interface: MixerListResponseWithEtagBuilder
Corresponds to the JSON property unreachables
39441 39442 39443 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39441 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::ListInstantSnapshotGroups::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
39446 39447 39448 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39446 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
39453 39454 39455 39456 39457 39458 39459 39460 39461 39462 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39453 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |