Class: Google::Apis::ComputeAlpha::ListInstantSnapshotGroups

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of InstantSnapshotGroup resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListInstantSnapshotGroups

Returns a new instance of ListInstantSnapshotGroups.



39232
39233
39234
# File 'lib/google/apis/compute_alpha/classes.rb', line 39232

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


39189
39190
39191
# File 'lib/google/apis/compute_alpha/classes.rb', line 39189

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


39194
39195
39196
# File 'lib/google/apis/compute_alpha/classes.rb', line 39194

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::InstantSnapshotGroup>

A list of InstantSnapshotGroup resources. Corresponds to the JSON property items



39199
39200
39201
# File 'lib/google/apis/compute_alpha/classes.rb', line 39199

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


39204
39205
39206
# File 'lib/google/apis/compute_alpha/classes.rb', line 39204

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


39214
39215
39216
# File 'lib/google/apis/compute_alpha/classes.rb', line 39214

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


39219
39220
39221
# File 'lib/google/apis/compute_alpha/classes.rb', line 39219

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


39225
39226
39227
# File 'lib/google/apis/compute_alpha/classes.rb', line 39225

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::ListInstantSnapshotGroups::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



39230
39231
39232
# File 'lib/google/apis/compute_alpha/classes.rb', line 39230

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



39237
39238
39239
39240
39241
39242
39243
39244
39245
39246
# File 'lib/google/apis/compute_alpha/classes.rb', line 39237

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end