Class: Google::Apis::ComputeAlpha::ListInstantSnapshotGroups
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::ListInstantSnapshotGroups
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Contains a list of InstantSnapshotGroup resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::InstantSnapshotGroup>
A list of InstantSnapshotGroup resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::ListInstantSnapshotGroups::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListInstantSnapshotGroups
constructor
A new instance of ListInstantSnapshotGroups.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListInstantSnapshotGroups
Returns a new instance of ListInstantSnapshotGroups.
39104 39105 39106 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39104 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
39061 39062 39063 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39061 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
39066 39067 39068 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39066 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::InstantSnapshotGroup>
A list of InstantSnapshotGroup resources.
Corresponds to the JSON property items
39071 39072 39073 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39071 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
39076 39077 39078 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39076 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
39086 39087 39088 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39086 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
39091 39092 39093 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39091 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
end_interface: MixerListResponseWithEtagBuilder
Corresponds to the JSON property unreachables
39097 39098 39099 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39097 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::ListInstantSnapshotGroups::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
39102 39103 39104 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39102 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
39109 39110 39111 39112 39113 39114 39115 39116 39117 39118 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39109 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |