Class: Google::Apis::ComputeAlpha::ListInstantSnapshotGroups

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of InstantSnapshotGroup resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListInstantSnapshotGroups

Returns a new instance of ListInstantSnapshotGroups.



38354
38355
38356
# File 'lib/google/apis/compute_alpha/classes.rb', line 38354

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


38311
38312
38313
# File 'lib/google/apis/compute_alpha/classes.rb', line 38311

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


38316
38317
38318
# File 'lib/google/apis/compute_alpha/classes.rb', line 38316

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::InstantSnapshotGroup>

A list of InstantSnapshotGroup resources. Corresponds to the JSON property items



38321
38322
38323
# File 'lib/google/apis/compute_alpha/classes.rb', line 38321

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


38326
38327
38328
# File 'lib/google/apis/compute_alpha/classes.rb', line 38326

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


38336
38337
38338
# File 'lib/google/apis/compute_alpha/classes.rb', line 38336

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


38341
38342
38343
# File 'lib/google/apis/compute_alpha/classes.rb', line 38341

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


38347
38348
38349
# File 'lib/google/apis/compute_alpha/classes.rb', line 38347

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::ListInstantSnapshotGroups::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



38352
38353
38354
# File 'lib/google/apis/compute_alpha/classes.rb', line 38352

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



38359
38360
38361
38362
38363
38364
38365
38366
38367
38368
# File 'lib/google/apis/compute_alpha/classes.rb', line 38359

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end