Class: Google::Apis::ComputeAlpha::ListSnapshotGroups
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::ListSnapshotGroups
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Contains a list of SnapshotGroup resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::SnapshotGroup>
A list of SnapshotGroup resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::ListSnapshotGroups::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListSnapshotGroups
constructor
A new instance of ListSnapshotGroups.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListSnapshotGroups
Returns a new instance of ListSnapshotGroups.
40884 40885 40886 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 40884 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
40841 40842 40843 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 40841 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
40846 40847 40848 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 40846 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::SnapshotGroup>
A list of SnapshotGroup resources.
Corresponds to the JSON property items
40851 40852 40853 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 40851 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
40856 40857 40858 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 40856 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
40866 40867 40868 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 40866 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
40871 40872 40873 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 40871 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
end_interface: MixerListResponseWithEtagBuilder
Corresponds to the JSON property unreachables
40877 40878 40879 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 40877 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::ListSnapshotGroups::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
40882 40883 40884 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 40882 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
40889 40890 40891 40892 40893 40894 40895 40896 40897 40898 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 40889 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |