Class: Google::Apis::ComputeAlpha::ListSnapshotGroups

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of SnapshotGroup resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListSnapshotGroups

Returns a new instance of ListSnapshotGroups.



40381
40382
40383
# File 'lib/google/apis/compute_alpha/classes.rb', line 40381

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


40338
40339
40340
# File 'lib/google/apis/compute_alpha/classes.rb', line 40338

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


40343
40344
40345
# File 'lib/google/apis/compute_alpha/classes.rb', line 40343

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::SnapshotGroup>

A list of SnapshotGroup resources. Corresponds to the JSON property items



40348
40349
40350
# File 'lib/google/apis/compute_alpha/classes.rb', line 40348

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


40353
40354
40355
# File 'lib/google/apis/compute_alpha/classes.rb', line 40353

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


40363
40364
40365
# File 'lib/google/apis/compute_alpha/classes.rb', line 40363

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


40368
40369
40370
# File 'lib/google/apis/compute_alpha/classes.rb', line 40368

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


40374
40375
40376
# File 'lib/google/apis/compute_alpha/classes.rb', line 40374

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::ListSnapshotGroups::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



40379
40380
40381
# File 'lib/google/apis/compute_alpha/classes.rb', line 40379

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



40386
40387
40388
40389
40390
40391
40392
40393
40394
40395
# File 'lib/google/apis/compute_alpha/classes.rb', line 40386

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end