Class: Google::Apis::ComputeAlpha::ListSnapshotGroups

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of SnapshotGroup resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListSnapshotGroups

Returns a new instance of ListSnapshotGroups.



39585
39586
39587
# File 'lib/google/apis/compute_alpha/classes.rb', line 39585

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


39542
39543
39544
# File 'lib/google/apis/compute_alpha/classes.rb', line 39542

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


39547
39548
39549
# File 'lib/google/apis/compute_alpha/classes.rb', line 39547

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::SnapshotGroup>

A list of SnapshotGroup resources. Corresponds to the JSON property items



39552
39553
39554
# File 'lib/google/apis/compute_alpha/classes.rb', line 39552

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


39557
39558
39559
# File 'lib/google/apis/compute_alpha/classes.rb', line 39557

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


39567
39568
39569
# File 'lib/google/apis/compute_alpha/classes.rb', line 39567

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


39572
39573
39574
# File 'lib/google/apis/compute_alpha/classes.rb', line 39572

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


39578
39579
39580
# File 'lib/google/apis/compute_alpha/classes.rb', line 39578

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::ListSnapshotGroups::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



39583
39584
39585
# File 'lib/google/apis/compute_alpha/classes.rb', line 39583

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



39590
39591
39592
39593
39594
39595
39596
39597
39598
39599
# File 'lib/google/apis/compute_alpha/classes.rb', line 39590

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end