Class: Google::Apis::ComputeAlpha::ListSnapshotGroups

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of SnapshotGroup resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListSnapshotGroups

Returns a new instance of ListSnapshotGroups.



39241
39242
39243
# File 'lib/google/apis/compute_alpha/classes.rb', line 39241

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


39198
39199
39200
# File 'lib/google/apis/compute_alpha/classes.rb', line 39198

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


39203
39204
39205
# File 'lib/google/apis/compute_alpha/classes.rb', line 39203

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::SnapshotGroup>

A list of SnapshotGroup resources. Corresponds to the JSON property items



39208
39209
39210
# File 'lib/google/apis/compute_alpha/classes.rb', line 39208

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


39213
39214
39215
# File 'lib/google/apis/compute_alpha/classes.rb', line 39213

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


39223
39224
39225
# File 'lib/google/apis/compute_alpha/classes.rb', line 39223

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


39228
39229
39230
# File 'lib/google/apis/compute_alpha/classes.rb', line 39228

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


39234
39235
39236
# File 'lib/google/apis/compute_alpha/classes.rb', line 39234

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::ListSnapshotGroups::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



39239
39240
39241
# File 'lib/google/apis/compute_alpha/classes.rb', line 39239

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



39246
39247
39248
39249
39250
39251
39252
39253
39254
39255
# File 'lib/google/apis/compute_alpha/classes.rb', line 39246

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end