Class: Google::Apis::ComputeAlpha::ListSnapshotGroups

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of SnapshotGroup resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListSnapshotGroups

Returns a new instance of ListSnapshotGroups.



38491
38492
38493
# File 'lib/google/apis/compute_alpha/classes.rb', line 38491

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


38448
38449
38450
# File 'lib/google/apis/compute_alpha/classes.rb', line 38448

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


38453
38454
38455
# File 'lib/google/apis/compute_alpha/classes.rb', line 38453

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::SnapshotGroup>

A list of SnapshotGroup resources. Corresponds to the JSON property items



38458
38459
38460
# File 'lib/google/apis/compute_alpha/classes.rb', line 38458

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


38463
38464
38465
# File 'lib/google/apis/compute_alpha/classes.rb', line 38463

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


38473
38474
38475
# File 'lib/google/apis/compute_alpha/classes.rb', line 38473

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


38478
38479
38480
# File 'lib/google/apis/compute_alpha/classes.rb', line 38478

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


38484
38485
38486
# File 'lib/google/apis/compute_alpha/classes.rb', line 38484

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::ListSnapshotGroups::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



38489
38490
38491
# File 'lib/google/apis/compute_alpha/classes.rb', line 38489

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



38496
38497
38498
38499
38500
38501
38502
38503
38504
38505
# File 'lib/google/apis/compute_alpha/classes.rb', line 38496

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end