Class: Google::Apis::ComputeAlpha::ListVmExtensionStatesResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListVmExtensionStatesResponse

Returns a new instance of ListVmExtensionStatesResponse.



40801
40802
40803
# File 'lib/google/apis/compute_alpha/classes.rb', line 40801

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Output only. Fingerprint of this resource. A hash of the contents stored in this object. This field is used in optimistic locking. This field will be ignored when inserting a VmExtensionPolicy. An up-to-date fingerprint must be provided in order to update the VmExtensionPolicy. To see the latest value of the fingerprint, make a get() request to retrieve a VmExtensionPolicy. Corresponds to the JSON property etag

Returns:

  • (String)


40759
40760
40761
# File 'lib/google/apis/compute_alpha/classes.rb', line 40759

def etag
  @etag
end

#idString

Output only. Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


40764
40765
40766
# File 'lib/google/apis/compute_alpha/classes.rb', line 40764

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::VmExtensionState>

Output only. A list of VM extension policy resources. Corresponds to the JSON property items



40769
40770
40771
# File 'lib/google/apis/compute_alpha/classes.rb', line 40769

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


40774
40775
40776
# File 'lib/google/apis/compute_alpha/classes.rb', line 40774

def kind
  @kind
end

#next_page_tokenString

Output only. This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


40784
40785
40786
# File 'lib/google/apis/compute_alpha/classes.rb', line 40784

def next_page_token
  @next_page_token
end

Output only. Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


40789
40790
40791
# File 'lib/google/apis/compute_alpha/classes.rb', line 40789

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


40794
40795
40796
# File 'lib/google/apis/compute_alpha/classes.rb', line 40794

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::ListVmExtensionStatesResponse::Warning

Output only. Informational warning message. Corresponds to the JSON property warning



40799
40800
40801
# File 'lib/google/apis/compute_alpha/classes.rb', line 40799

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



40806
40807
40808
40809
40810
40811
40812
40813
40814
40815
# File 'lib/google/apis/compute_alpha/classes.rb', line 40806

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end