Class: Google::Apis::ComputeAlpha::ListVmExtensionStatesResponse
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::ListVmExtensionStatesResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Output only.
-
#id ⇒ String
Output only.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::VmExtensionState>
Output only.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
Output only.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::ListVmExtensionStatesResponse::Warning
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListVmExtensionStatesResponse
constructor
A new instance of ListVmExtensionStatesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListVmExtensionStatesResponse
Returns a new instance of ListVmExtensionStatesResponse.
39726 39727 39728 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39726 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Output only. Fingerprint of this resource. A hash of the contents stored
in this object. This field is used in optimistic locking. This field will
be ignored when inserting a VmExtensionPolicy. An up-to-date
fingerprint must be provided in order to update the VmExtensionPolicy.
To see the latest value of the fingerprint, make a get() request to
retrieve a VmExtensionPolicy.
Corresponds to the JSON property etag
39684 39685 39686 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39684 def etag @etag end |
#id ⇒ String
Output only. Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
39689 39690 39691 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39689 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::VmExtensionState>
Output only. A list of VM extension policy resources.
Corresponds to the JSON property items
39694 39695 39696 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39694 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
39699 39700 39701 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39699 def kind @kind end |
#next_page_token ⇒ String
Output only. This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
39709 39710 39711 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39709 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. Server-defined URL for this resource.
Corresponds to the JSON property selfLink
39714 39715 39716 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39714 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. Unreachable resources.
Corresponds to the JSON property unreachables
39719 39720 39721 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39719 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::ListVmExtensionStatesResponse::Warning
Output only. Informational warning message.
Corresponds to the JSON property warning
39724 39725 39726 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39724 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
39731 39732 39733 39734 39735 39736 39737 39738 39739 39740 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39731 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |