Class: Google::Apis::ComputeAlpha::ListVmExtensionStatesResponse
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::ListVmExtensionStatesResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Output only.
-
#id ⇒ String
Output only.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::VmExtensionState>
Output only.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
Output only.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::ListVmExtensionStatesResponse::Warning
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListVmExtensionStatesResponse
constructor
A new instance of ListVmExtensionStatesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListVmExtensionStatesResponse
Returns a new instance of ListVmExtensionStatesResponse.
39520 39521 39522 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39520 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Output only. Fingerprint of this resource. A hash of the contents stored
in this object. This field is used in optimistic locking. This field will
be ignored when inserting a VmExtensionPolicy. An up-to-date
fingerprint must be provided in order to update the VmExtensionPolicy.
To see the latest value of the fingerprint, make a get() request to
retrieve a VmExtensionPolicy.
Corresponds to the JSON property etag
39478 39479 39480 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39478 def etag @etag end |
#id ⇒ String
Output only. Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
39483 39484 39485 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39483 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::VmExtensionState>
Output only. A list of VM extension policy resources.
Corresponds to the JSON property items
39488 39489 39490 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39488 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
39493 39494 39495 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39493 def kind @kind end |
#next_page_token ⇒ String
Output only. This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
39503 39504 39505 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39503 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. Server-defined URL for this resource.
Corresponds to the JSON property selfLink
39508 39509 39510 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39508 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. Unreachable resources.
Corresponds to the JSON property unreachables
39513 39514 39515 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39513 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::ListVmExtensionStatesResponse::Warning
Output only. Informational warning message.
Corresponds to the JSON property warning
39518 39519 39520 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39518 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
39525 39526 39527 39528 39529 39530 39531 39532 39533 39534 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39525 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |