Class: Google::Apis::ComputeAlpha::ListVmExtensionStatesResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListVmExtensionStatesResponse

Returns a new instance of ListVmExtensionStatesResponse.



39382
39383
39384
# File 'lib/google/apis/compute_alpha/classes.rb', line 39382

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Output only. Fingerprint of this resource. A hash of the contents stored in this object. This field is used in optimistic locking. This field will be ignored when inserting a VmExtensionPolicy. An up-to-date fingerprint must be provided in order to update the VmExtensionPolicy. To see the latest value of the fingerprint, make a get() request to retrieve a VmExtensionPolicy. Corresponds to the JSON property etag

Returns:

  • (String)


39340
39341
39342
# File 'lib/google/apis/compute_alpha/classes.rb', line 39340

def etag
  @etag
end

#idString

Output only. Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


39345
39346
39347
# File 'lib/google/apis/compute_alpha/classes.rb', line 39345

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::VmExtensionState>

Output only. A list of VM extension policy resources. Corresponds to the JSON property items



39350
39351
39352
# File 'lib/google/apis/compute_alpha/classes.rb', line 39350

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


39355
39356
39357
# File 'lib/google/apis/compute_alpha/classes.rb', line 39355

def kind
  @kind
end

#next_page_tokenString

Output only. This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


39365
39366
39367
# File 'lib/google/apis/compute_alpha/classes.rb', line 39365

def next_page_token
  @next_page_token
end

Output only. Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


39370
39371
39372
# File 'lib/google/apis/compute_alpha/classes.rb', line 39370

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


39375
39376
39377
# File 'lib/google/apis/compute_alpha/classes.rb', line 39375

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::ListVmExtensionStatesResponse::Warning

Output only. Informational warning message. Corresponds to the JSON property warning



39380
39381
39382
# File 'lib/google/apis/compute_alpha/classes.rb', line 39380

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



39387
39388
39389
39390
39391
39392
39393
39394
39395
39396
# File 'lib/google/apis/compute_alpha/classes.rb', line 39387

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end