Class: Google::Apis::ComputeAlpha::ListVmExtensionsResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListVmExtensionsResponse

Returns a new instance of ListVmExtensionsResponse.



40942
40943
40944
# File 'lib/google/apis/compute_alpha/classes.rb', line 40942

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Output only. Fingerprint of this resource. A hash of the contents stored in this object. This field is used in optimistic locking. This field will be ignored when inserting a VmExtensionPolicy. An up-to-date fingerprint must be provided in order to update the VmExtensionPolicy. To see the latest value of the fingerprint, make a get() request to retrieve a VmExtensionPolicy. Corresponds to the JSON property etag

Returns:

  • (String)


40900
40901
40902
# File 'lib/google/apis/compute_alpha/classes.rb', line 40900

def etag
  @etag
end

#idString

Output only. Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


40905
40906
40907
# File 'lib/google/apis/compute_alpha/classes.rb', line 40905

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::VmExtension>

Output only. A list of VM extensions. Corresponds to the JSON property items



40910
40911
40912
# File 'lib/google/apis/compute_alpha/classes.rb', line 40910

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


40915
40916
40917
# File 'lib/google/apis/compute_alpha/classes.rb', line 40915

def kind
  @kind
end

#next_page_tokenString

Output only. This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


40925
40926
40927
# File 'lib/google/apis/compute_alpha/classes.rb', line 40925

def next_page_token
  @next_page_token
end

Output only. Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


40930
40931
40932
# File 'lib/google/apis/compute_alpha/classes.rb', line 40930

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


40935
40936
40937
# File 'lib/google/apis/compute_alpha/classes.rb', line 40935

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::ListVmExtensionsResponse::Warning

Output only. Informational warning message. Corresponds to the JSON property warning



40940
40941
40942
# File 'lib/google/apis/compute_alpha/classes.rb', line 40940

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



40947
40948
40949
40950
40951
40952
40953
40954
40955
40956
# File 'lib/google/apis/compute_alpha/classes.rb', line 40947

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end