Class: Google::Apis::ComputeAlpha::ListVmExtensionsResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListVmExtensionsResponse

Returns a new instance of ListVmExtensionsResponse.



40663
40664
40665
# File 'lib/google/apis/compute_alpha/classes.rb', line 40663

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Output only. Fingerprint of this resource. A hash of the contents stored in this object. This field is used in optimistic locking. This field will be ignored when inserting a VmExtensionPolicy. An up-to-date fingerprint must be provided in order to update the VmExtensionPolicy. To see the latest value of the fingerprint, make a get() request to retrieve a VmExtensionPolicy. Corresponds to the JSON property etag

Returns:

  • (String)


40621
40622
40623
# File 'lib/google/apis/compute_alpha/classes.rb', line 40621

def etag
  @etag
end

#idString

Output only. Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


40626
40627
40628
# File 'lib/google/apis/compute_alpha/classes.rb', line 40626

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::VmExtension>

Output only. A list of VM extensions. Corresponds to the JSON property items



40631
40632
40633
# File 'lib/google/apis/compute_alpha/classes.rb', line 40631

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


40636
40637
40638
# File 'lib/google/apis/compute_alpha/classes.rb', line 40636

def kind
  @kind
end

#next_page_tokenString

Output only. This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


40646
40647
40648
# File 'lib/google/apis/compute_alpha/classes.rb', line 40646

def next_page_token
  @next_page_token
end

Output only. Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


40651
40652
40653
# File 'lib/google/apis/compute_alpha/classes.rb', line 40651

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


40656
40657
40658
# File 'lib/google/apis/compute_alpha/classes.rb', line 40656

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::ListVmExtensionsResponse::Warning

Output only. Informational warning message. Corresponds to the JSON property warning



40661
40662
40663
# File 'lib/google/apis/compute_alpha/classes.rb', line 40661

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



40668
40669
40670
40671
40672
40673
40674
40675
40676
40677
# File 'lib/google/apis/compute_alpha/classes.rb', line 40668

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end