Class: Google::Apis::ComputeAlpha::ListVmExtensionsResponse
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::ListVmExtensionsResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Output only.
-
#id ⇒ String
Output only.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::VmExtension>
Output only.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
Output only.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::ListVmExtensionsResponse::Warning
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListVmExtensionsResponse
constructor
A new instance of ListVmExtensionsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListVmExtensionsResponse
Returns a new instance of ListVmExtensionsResponse.
39884 39885 39886 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39884 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Output only. Fingerprint of this resource. A hash of the contents stored
in this object. This field is used in optimistic locking. This field will
be ignored when inserting a VmExtensionPolicy. An up-to-date
fingerprint must be provided in order to update the VmExtensionPolicy.
To see the latest value of the fingerprint, make a get() request to
retrieve a VmExtensionPolicy.
Corresponds to the JSON property etag
39842 39843 39844 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39842 def etag @etag end |
#id ⇒ String
Output only. Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
39847 39848 39849 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39847 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::VmExtension>
Output only. A list of VM extensions.
Corresponds to the JSON property items
39852 39853 39854 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39852 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
39857 39858 39859 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39857 def kind @kind end |
#next_page_token ⇒ String
Output only. This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
39867 39868 39869 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39867 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. Server-defined URL for this resource.
Corresponds to the JSON property selfLink
39872 39873 39874 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39872 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. Unreachable resources.
Corresponds to the JSON property unreachables
39877 39878 39879 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39877 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::ListVmExtensionsResponse::Warning
Output only. Informational warning message.
Corresponds to the JSON property warning
39882 39883 39884 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39882 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
39889 39890 39891 39892 39893 39894 39895 39896 39897 39898 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39889 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |