Class: Google::Apis::ComputeAlpha::ListVmExtensionsResponse
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::ListVmExtensionsResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Output only.
-
#id ⇒ String
Output only.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::VmExtension>
Output only.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
Output only.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::ListVmExtensionsResponse::Warning
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListVmExtensionsResponse
constructor
A new instance of ListVmExtensionsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListVmExtensionsResponse
Returns a new instance of ListVmExtensionsResponse.
39651 39652 39653 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39651 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Output only. Fingerprint of this resource. A hash of the contents stored
in this object. This field is used in optimistic locking. This field will
be ignored when inserting a VmExtensionPolicy. An up-to-date
fingerprint must be provided in order to update the VmExtensionPolicy.
To see the latest value of the fingerprint, make a get() request to
retrieve a VmExtensionPolicy.
Corresponds to the JSON property etag
39609 39610 39611 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39609 def etag @etag end |
#id ⇒ String
Output only. Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
39614 39615 39616 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39614 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::VmExtension>
Output only. A list of VM extensions.
Corresponds to the JSON property items
39619 39620 39621 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39619 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
39624 39625 39626 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39624 def kind @kind end |
#next_page_token ⇒ String
Output only. This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
39634 39635 39636 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39634 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. Server-defined URL for this resource.
Corresponds to the JSON property selfLink
39639 39640 39641 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39639 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. Unreachable resources.
Corresponds to the JSON property unreachables
39644 39645 39646 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39644 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::ListVmExtensionsResponse::Warning
Output only. Informational warning message.
Corresponds to the JSON property warning
39649 39650 39651 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39649 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
39656 39657 39658 39659 39660 39661 39662 39663 39664 39665 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39656 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |