Class: Google::Apis::ComputeAlpha::ListVmExtensionsResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListVmExtensionsResponse

Returns a new instance of ListVmExtensionsResponse.



39523
39524
39525
# File 'lib/google/apis/compute_alpha/classes.rb', line 39523

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Output only. Fingerprint of this resource. A hash of the contents stored in this object. This field is used in optimistic locking. This field will be ignored when inserting a VmExtensionPolicy. An up-to-date fingerprint must be provided in order to update the VmExtensionPolicy. To see the latest value of the fingerprint, make a get() request to retrieve a VmExtensionPolicy. Corresponds to the JSON property etag

Returns:

  • (String)


39481
39482
39483
# File 'lib/google/apis/compute_alpha/classes.rb', line 39481

def etag
  @etag
end

#idString

Output only. Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


39486
39487
39488
# File 'lib/google/apis/compute_alpha/classes.rb', line 39486

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::VmExtension>

Output only. A list of VM extensions. Corresponds to the JSON property items



39491
39492
39493
# File 'lib/google/apis/compute_alpha/classes.rb', line 39491

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


39496
39497
39498
# File 'lib/google/apis/compute_alpha/classes.rb', line 39496

def kind
  @kind
end

#next_page_tokenString

Output only. This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


39506
39507
39508
# File 'lib/google/apis/compute_alpha/classes.rb', line 39506

def next_page_token
  @next_page_token
end

Output only. Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


39511
39512
39513
# File 'lib/google/apis/compute_alpha/classes.rb', line 39511

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


39516
39517
39518
# File 'lib/google/apis/compute_alpha/classes.rb', line 39516

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::ListVmExtensionsResponse::Warning

Output only. Informational warning message. Corresponds to the JSON property warning



39521
39522
39523
# File 'lib/google/apis/compute_alpha/classes.rb', line 39521

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



39528
39529
39530
39531
39532
39533
39534
39535
39536
39537
# File 'lib/google/apis/compute_alpha/classes.rb', line 39528

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end