Class: Google::Apis::ComputeAlpha::LocationPolicyLocation
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::LocationPolicyLocation
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#constraints ⇒ Google::Apis::ComputeAlpha::LocationPolicyLocationConstraints
Per-zone constraints on location policy for this zone.
-
#names ⇒ Array<String>
Names of resources to be put in the location.
-
#preference ⇒ String
Preference for a given location.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LocationPolicyLocation
constructor
A new instance of LocationPolicyLocation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LocationPolicyLocation
Returns a new instance of LocationPolicyLocation.
40097 40098 40099 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 40097 def initialize(**args) update!(**args) end |
Instance Attribute Details
#constraints ⇒ Google::Apis::ComputeAlpha::LocationPolicyLocationConstraints
Per-zone constraints on location policy for this zone.
Corresponds to the JSON property constraints
40083 40084 40085 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 40083 def constraints @constraints end |
#names ⇒ Array<String>
Names of resources to be put in the location.
Must contain unique, correct resource names.
If used, targetShape must be left unset.
Corresponds to the JSON property names
40090 40091 40092 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 40090 def names @names end |
#preference ⇒ String
Preference for a given location. Set to either ALLOW orDENY.
Corresponds to the JSON property preference
40095 40096 40097 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 40095 def preference @preference end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
40102 40103 40104 40105 40106 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 40102 def update!(**args) @constraints = args[:constraints] if args.key?(:constraints) @names = args[:names] if args.key?(:names) @preference = args[:preference] if args.key?(:preference) end |