Class: Google::Apis::ComputeAlpha::LocationPolicyLocation
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::LocationPolicyLocation
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#constraints ⇒ Google::Apis::ComputeAlpha::LocationPolicyLocationConstraints
Per-zone constraints on location policy for this zone.
-
#names ⇒ Array<String>
Names of resources to be put in the location.
-
#preference ⇒ String
Preference for a given location.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LocationPolicyLocation
constructor
A new instance of LocationPolicyLocation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LocationPolicyLocation
Returns a new instance of LocationPolicyLocation.
39864 39865 39866 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39864 def initialize(**args) update!(**args) end |
Instance Attribute Details
#constraints ⇒ Google::Apis::ComputeAlpha::LocationPolicyLocationConstraints
Per-zone constraints on location policy for this zone.
Corresponds to the JSON property constraints
39850 39851 39852 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39850 def constraints @constraints end |
#names ⇒ Array<String>
Names of resources to be put in the location.
Must contain unique, correct resource names.
If used, targetShape must be left unset.
Corresponds to the JSON property names
39857 39858 39859 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39857 def names @names end |
#preference ⇒ String
Preference for a given location. Set to either ALLOW orDENY.
Corresponds to the JSON property preference
39862 39863 39864 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39862 def preference @preference end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
39869 39870 39871 39872 39873 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39869 def update!(**args) @constraints = args[:constraints] if args.key?(:constraints) @names = args[:names] if args.key?(:names) @preference = args[:preference] if args.key?(:preference) end |