Class: Google::Apis::ComputeAlpha::MachineImage

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Represents a machine image resource. A machine image is a Compute Engine resource that stores all the configuration, metadata, permissions, and data from one or more disks required to create a Virtual machine (VM) instance. For more information, seeMachine images.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MachineImage

Returns a new instance of MachineImage.



40087
40088
40089
# File 'lib/google/apis/compute_alpha/classes.rb', line 40087

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#creation_timestampString

Output only. [Output Only] The creation timestamp for this machine image inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


39931
39932
39933
# File 'lib/google/apis/compute_alpha/classes.rb', line 39931

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


39937
39938
39939
# File 'lib/google/apis/compute_alpha/classes.rb', line 39937

def description
  @description
end

#guest_flushBoolean Also known as: guest_flush?

[Input Only] Whether to attempt an application consistent machine image by informing the OS to prepare for the snapshot process. Corresponds to the JSON property guestFlush

Returns:

  • (Boolean)


39943
39944
39945
# File 'lib/google/apis/compute_alpha/classes.rb', line 39943

def guest_flush
  @guest_flush
end

#idFixnum

Output only. [Output Only] A unique identifier for this machine image. The server defines this identifier. Corresponds to the JSON property id

Returns:

  • (Fixnum)


39951
39952
39953
# File 'lib/google/apis/compute_alpha/classes.rb', line 39951

def id
  @id
end

#instance_propertiesGoogle::Apis::ComputeAlpha::InstanceProperties

[Output Only] Properties of source instance Corresponds to the JSON property instanceProperties



39956
39957
39958
# File 'lib/google/apis/compute_alpha/classes.rb', line 39956

def instance_properties
  @instance_properties
end

#kindString

Output only. [Output Only] The resource type, which is alwayscompute# machineImage for machine image. Corresponds to the JSON property kind

Returns:

  • (String)


39962
39963
39964
# File 'lib/google/apis/compute_alpha/classes.rb', line 39962

def kind
  @kind
end

#label_fingerprintString

A fingerprint for the labels being applied to this machine image, which is essentially a hash of the labels set used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update labels. You must always provide an up-to-date fingerprint hash in order to update or change labels. To see the latest fingerprint, make get() request to the machine image. Corresponds to the JSON property labelFingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


39974
39975
39976
# File 'lib/google/apis/compute_alpha/classes.rb', line 39974

def label_fingerprint
  @label_fingerprint
end

#labelsHash<String,String>

Labels to apply to this machine image. These can be later modified by the setLabels method. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


39980
39981
39982
# File 'lib/google/apis/compute_alpha/classes.rb', line 39980

def labels
  @labels
end

#machine_image_encryption_keyGoogle::Apis::ComputeAlpha::CustomerEncryptionKey

Encrypts the machine image using acustomer-supplied encryption key. After you encrypt a machine image using a customer-supplied key, you must provide the same key if you use the machine image later. For example, you must provide the encryption key when you create an instance from the encrypted machine image in a future request. Customer-supplied encryption keys do not protect access to metadata of the machine image. If you do not provide an encryption key when creating the machine image, then the machine image will be encrypted using an automatically generated key and you do not need to provide a key to use the machine image later. Corresponds to the JSON property machineImageEncryptionKey



39995
39996
39997
# File 'lib/google/apis/compute_alpha/classes.rb', line 39995

def machine_image_encryption_key
  @machine_image_encryption_key
end

#nameString

Name of the resource; provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


40006
40007
40008
# File 'lib/google/apis/compute_alpha/classes.rb', line 40006

def name
  @name
end

#paramsGoogle::Apis::ComputeAlpha::MachineImageParams

Machine Image parameters Corresponds to the JSON property params



40011
40012
40013
# File 'lib/google/apis/compute_alpha/classes.rb', line 40011

def params
  @params
end

#satisfies_pziBoolean Also known as: satisfies_pzi?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzi

Returns:

  • (Boolean)


40016
40017
40018
# File 'lib/google/apis/compute_alpha/classes.rb', line 40016

def satisfies_pzi
  @satisfies_pzi
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

Output only. [Output Only] Reserved for future use. Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


40022
40023
40024
# File 'lib/google/apis/compute_alpha/classes.rb', line 40022

def satisfies_pzs
  @satisfies_pzs
end

#saved_disksArray<Google::Apis::ComputeAlpha::SavedDisk>

Output only. An array of Machine Image specific properties for disks attached to the source instance Corresponds to the JSON property savedDisks



40030
40031
40032
# File 'lib/google/apis/compute_alpha/classes.rb', line 40030

def saved_disks
  @saved_disks
end

Output only. [Output Only] The URL for this machine image. The server defines this URL. Corresponds to the JSON property selfLink

Returns:

  • (String)


40036
40037
40038
# File 'lib/google/apis/compute_alpha/classes.rb', line 40036

def self_link
  @self_link
end

Output only. [Output Only] Server-defined URL for this resource with the resource id. Corresponds to the JSON property selfLinkWithId

Returns:

  • (String)


40042
40043
40044
# File 'lib/google/apis/compute_alpha/classes.rb', line 40042

def self_link_with_id
  @self_link_with_id
end

#source_disk_encryption_keysArray<Google::Apis::ComputeAlpha::SourceDiskEncryptionKey>

[Input Only] Thecustomer-supplied encryption key of the disks attached to the source instance. Required if the source disk is protected by a customer-supplied encryption key. Corresponds to the JSON property sourceDiskEncryptionKeys



40049
40050
40051
# File 'lib/google/apis/compute_alpha/classes.rb', line 40049

def source_disk_encryption_keys
  @source_disk_encryption_keys
end

#source_instanceString

The source instance used to create the machine image. You can provide this as a partial or full URL to the resource. For example, the following are valid values:

Returns:

  • (String)


40061
40062
40063
# File 'lib/google/apis/compute_alpha/classes.rb', line 40061

def source_instance
  @source_instance
end

#source_instance_propertiesGoogle::Apis::ComputeAlpha::SourceInstanceProperties

DEPRECATED: Please use compute#instanceProperties instead. New properties will not be added to this field. Corresponds to the JSON property sourceInstanceProperties



40067
40068
40069
# File 'lib/google/apis/compute_alpha/classes.rb', line 40067

def source_instance_properties
  @source_instance_properties
end

#statusString

Output only. [Output Only] The status of the machine image. One of the following values:INVALID, CREATING, READY,DELETING, and UPLOADING. Corresponds to the JSON property status

Returns:

  • (String)


40073
40074
40075
# File 'lib/google/apis/compute_alpha/classes.rb', line 40073

def status
  @status
end

#storage_locationsArray<String>

The regional or multi-regional Cloud Storage bucket location where themachine image is stored. Corresponds to the JSON property storageLocations

Returns:

  • (Array<String>)


40080
40081
40082
# File 'lib/google/apis/compute_alpha/classes.rb', line 40080

def storage_locations
  @storage_locations
end

#total_storage_bytesFixnum

Output only. [Output Only] Total size of the storage used by the machine image. Corresponds to the JSON property totalStorageBytes

Returns:

  • (Fixnum)


40085
40086
40087
# File 'lib/google/apis/compute_alpha/classes.rb', line 40085

def total_storage_bytes
  @total_storage_bytes
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



40092
40093
40094
40095
40096
40097
40098
40099
40100
40101
40102
40103
40104
40105
40106
40107
40108
40109
40110
40111
40112
40113
40114
40115
# File 'lib/google/apis/compute_alpha/classes.rb', line 40092

def update!(**args)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @guest_flush = args[:guest_flush] if args.key?(:guest_flush)
  @id = args[:id] if args.key?(:id)
  @instance_properties = args[:instance_properties] if args.key?(:instance_properties)
  @kind = args[:kind] if args.key?(:kind)
  @label_fingerprint = args[:label_fingerprint] if args.key?(:label_fingerprint)
  @labels = args[:labels] if args.key?(:labels)
  @machine_image_encryption_key = args[:machine_image_encryption_key] if args.key?(:machine_image_encryption_key)
  @name = args[:name] if args.key?(:name)
  @params = args[:params] if args.key?(:params)
  @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @saved_disks = args[:saved_disks] if args.key?(:saved_disks)
  @self_link = args[:self_link] if args.key?(:self_link)
  @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id)
  @source_disk_encryption_keys = args[:source_disk_encryption_keys] if args.key?(:source_disk_encryption_keys)
  @source_instance = args[:source_instance] if args.key?(:source_instance)
  @source_instance_properties = args[:source_instance_properties] if args.key?(:source_instance_properties)
  @status = args[:status] if args.key?(:status)
  @storage_locations = args[:storage_locations] if args.key?(:storage_locations)
  @total_storage_bytes = args[:total_storage_bytes] if args.key?(:total_storage_bytes)
end