Class: Google::Apis::ComputeAlpha::MachineImage
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::MachineImage
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Represents a machine image resource. A machine image is a Compute Engine resource that stores all the configuration, metadata, permissions, and data from one or more disks required to create a Virtual machine (VM) instance. For more information, seeMachine images.
Instance Attribute Summary collapse
-
#creation_timestamp ⇒ String
Output only.
-
#description ⇒ String
An optional description of this resource.
-
#guest_flush ⇒ Boolean
(also: #guest_flush?)
[Input Only] Whether to attempt an application consistent machine image by informing the OS to prepare for the snapshot process.
-
#id ⇒ Fixnum
Output only.
-
#instance_properties ⇒ Google::Apis::ComputeAlpha::InstanceProperties
[Output Only] Properties of source instance Corresponds to the JSON property
instanceProperties. -
#kind ⇒ String
Output only.
-
#label_fingerprint ⇒ String
A fingerprint for the labels being applied to this machine image, which is essentially a hash of the labels set used for optimistic locking.
-
#labels ⇒ Hash<String,String>
Labels to apply to this machine image.
-
#machine_image_encryption_key ⇒ Google::Apis::ComputeAlpha::CustomerEncryptionKey
Encrypts the machine image using acustomer-supplied encryption key.
-
#name ⇒ String
Name of the resource; provided by the client when the resource is created.
-
#params ⇒ Google::Apis::ComputeAlpha::MachineImageParams
Machine Image parameters Corresponds to the JSON property
params. -
#satisfies_pzi ⇒ Boolean
(also: #satisfies_pzi?)
Output only.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
Output only.
-
#saved_disks ⇒ Array<Google::Apis::ComputeAlpha::SavedDisk>
Output only.
-
#self_link ⇒ String
Output only.
-
#self_link_with_id ⇒ String
Output only.
-
#source_disk_encryption_keys ⇒ Array<Google::Apis::ComputeAlpha::SourceDiskEncryptionKey>
[Input Only] Thecustomer-supplied encryption key of the disks attached to the source instance.
-
#source_instance ⇒ String
The source instance used to create the machine image.
-
#source_instance_properties ⇒ Google::Apis::ComputeAlpha::SourceInstanceProperties
DEPRECATED: Please use compute#instanceProperties instead.
-
#status ⇒ String
Output only.
-
#storage_locations ⇒ Array<String>
The regional or multi-regional Cloud Storage bucket location where themachine image is stored.
-
#total_storage_bytes ⇒ Fixnum
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MachineImage
constructor
A new instance of MachineImage.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MachineImage
Returns a new instance of MachineImage.
40097 40098 40099 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 40097 def initialize(**args) update!(**args) end |
Instance Attribute Details
#creation_timestamp ⇒ String
Output only. [Output Only] The creation timestamp for this machine image
inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
39941 39942 39943 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39941 def @creation_timestamp end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
39947 39948 39949 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39947 def description @description end |
#guest_flush ⇒ Boolean Also known as: guest_flush?
[Input Only] Whether to attempt an application consistent machine image by
informing the OS to prepare for the snapshot process.
Corresponds to the JSON property guestFlush
39953 39954 39955 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39953 def guest_flush @guest_flush end |
#id ⇒ Fixnum
Output only. [Output Only] A unique identifier for this machine image. The
server
defines this identifier.
Corresponds to the JSON property id
39961 39962 39963 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39961 def id @id end |
#instance_properties ⇒ Google::Apis::ComputeAlpha::InstanceProperties
[Output Only] Properties of source instance
Corresponds to the JSON property instanceProperties
39966 39967 39968 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39966 def instance_properties @instance_properties end |
#kind ⇒ String
Output only. [Output Only] The resource type, which is alwayscompute#
machineImage for machine image.
Corresponds to the JSON property kind
39972 39973 39974 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39972 def kind @kind end |
#label_fingerprint ⇒ String
A fingerprint for the labels being applied to this machine image, which is
essentially a hash of the labels set used for optimistic locking. The
fingerprint is initially generated by Compute Engine and changes after
every request to modify or update labels. You must always provide an
up-to-date fingerprint hash in order to update or change labels.
To see the latest fingerprint, make get() request to the
machine image.
Corresponds to the JSON property labelFingerprint
NOTE: Values are automatically base64 encoded/decoded in the client library.
39984 39985 39986 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39984 def label_fingerprint @label_fingerprint end |
#labels ⇒ Hash<String,String>
Labels to apply to this machine image. These can be later modified by
the setLabels method.
Corresponds to the JSON property labels
39990 39991 39992 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39990 def labels @labels end |
#machine_image_encryption_key ⇒ Google::Apis::ComputeAlpha::CustomerEncryptionKey
Encrypts the machine image using acustomer-supplied
encryption key.
After you encrypt a machine image using a customer-supplied key, you must
provide the same key if you use the machine image later. For example, you
must provide the encryption key when you create an instance from the
encrypted machine image in a future request.
Customer-supplied encryption keys do not protect access to metadata of the
machine image.
If you do not provide an encryption key when creating the machine image,
then the machine image will be encrypted using an automatically generated
key and you do not need to provide a key to use the machine image later.
Corresponds to the JSON property machineImageEncryptionKey
40005 40006 40007 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 40005 def machine_image_encryption_key @machine_image_encryption_key end |
#name ⇒ String
Name of the resource; provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must be
a dash, lowercase letter, or digit, except the last character, which cannot
be a dash.
Corresponds to the JSON property name
40016 40017 40018 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 40016 def name @name end |
#params ⇒ Google::Apis::ComputeAlpha::MachineImageParams
Machine Image parameters
Corresponds to the JSON property params
40021 40022 40023 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 40021 def params @params end |
#satisfies_pzi ⇒ Boolean Also known as: satisfies_pzi?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzi
40026 40027 40028 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 40026 def satisfies_pzi @satisfies_pzi end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
Output only. [Output Only] Reserved for future use.
Corresponds to the JSON property satisfiesPzs
40032 40033 40034 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 40032 def satisfies_pzs @satisfies_pzs end |
#saved_disks ⇒ Array<Google::Apis::ComputeAlpha::SavedDisk>
Output only. An array of Machine Image specific properties for disks attached
to the
source instance
Corresponds to the JSON property savedDisks
40040 40041 40042 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 40040 def saved_disks @saved_disks end |
#self_link ⇒ String
Output only. [Output Only] The URL for this machine image. The server defines
this URL.
Corresponds to the JSON property selfLink
40046 40047 40048 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 40046 def self_link @self_link end |
#self_link_with_id ⇒ String
Output only. [Output Only] Server-defined URL for this resource with the
resource id.
Corresponds to the JSON property selfLinkWithId
40052 40053 40054 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 40052 def self_link_with_id @self_link_with_id end |
#source_disk_encryption_keys ⇒ Array<Google::Apis::ComputeAlpha::SourceDiskEncryptionKey>
[Input Only] Thecustomer-supplied
encryption key of the disks attached to the source instance. Required
if the source disk is protected by a customer-supplied encryption key.
Corresponds to the JSON property sourceDiskEncryptionKeys
40059 40060 40061 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 40059 def source_disk_encryption_keys @source_disk_encryption_keys end |
#source_instance ⇒ String
The source instance used to create the machine image. You can provide this as a partial or full URL to the resource. For example, the following are valid values:
- https://www.googleapis.com/compute/v1/projects/project/zones/zone/ instances/instance
- projects/project/zones/zone/instances/instance
Corresponds to the JSON property
sourceInstance
40071 40072 40073 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 40071 def source_instance @source_instance end |
#source_instance_properties ⇒ Google::Apis::ComputeAlpha::SourceInstanceProperties
DEPRECATED: Please use compute#instanceProperties instead.
New properties will not be added to this field.
Corresponds to the JSON property sourceInstanceProperties
40077 40078 40079 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 40077 def source_instance_properties @source_instance_properties end |
#status ⇒ String
Output only. [Output Only] The status of the machine image. One of the
following values:INVALID, CREATING, READY,DELETING, and UPLOADING.
Corresponds to the JSON property status
40083 40084 40085 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 40083 def status @status end |
#storage_locations ⇒ Array<String>
The regional or multi-regional Cloud Storage bucket location where themachine
image is
stored.
Corresponds to the JSON property storageLocations
40090 40091 40092 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 40090 def storage_locations @storage_locations end |
#total_storage_bytes ⇒ Fixnum
Output only. [Output Only] Total size of the storage used by the machine image.
Corresponds to the JSON property totalStorageBytes
40095 40096 40097 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 40095 def total_storage_bytes @total_storage_bytes end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
40102 40103 40104 40105 40106 40107 40108 40109 40110 40111 40112 40113 40114 40115 40116 40117 40118 40119 40120 40121 40122 40123 40124 40125 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 40102 def update!(**args) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @guest_flush = args[:guest_flush] if args.key?(:guest_flush) @id = args[:id] if args.key?(:id) @instance_properties = args[:instance_properties] if args.key?(:instance_properties) @kind = args[:kind] if args.key?(:kind) @label_fingerprint = args[:label_fingerprint] if args.key?(:label_fingerprint) @labels = args[:labels] if args.key?(:labels) @machine_image_encryption_key = args[:machine_image_encryption_key] if args.key?(:machine_image_encryption_key) @name = args[:name] if args.key?(:name) @params = args[:params] if args.key?(:params) @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @saved_disks = args[:saved_disks] if args.key?(:saved_disks) @self_link = args[:self_link] if args.key?(:self_link) @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id) @source_disk_encryption_keys = args[:source_disk_encryption_keys] if args.key?(:source_disk_encryption_keys) @source_instance = args[:source_instance] if args.key?(:source_instance) @source_instance_properties = args[:source_instance_properties] if args.key?(:source_instance_properties) @status = args[:status] if args.key?(:status) @storage_locations = args[:storage_locations] if args.key?(:storage_locations) @total_storage_bytes = args[:total_storage_bytes] if args.key?(:total_storage_bytes) end |