Class: Google::Apis::ComputeAlpha::MachineImageList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

A list of machine images.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MachineImageList

Returns a new instance of MachineImageList.



41170
41171
41172
# File 'lib/google/apis/compute_alpha/classes.rb', line 41170

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


41137
41138
41139
# File 'lib/google/apis/compute_alpha/classes.rb', line 41137

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::MachineImage>

A list of MachineImage resources. Corresponds to the JSON property items



41142
41143
41144
# File 'lib/google/apis/compute_alpha/classes.rb', line 41142

def items
  @items
end

#kindString

Output only. [Output Only] The resource type, which is alwayscompute# machineImagesListResponse for machine image lists. Corresponds to the JSON property kind

Returns:

  • (String)


41148
41149
41150
# File 'lib/google/apis/compute_alpha/classes.rb', line 41148

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


41158
41159
41160
# File 'lib/google/apis/compute_alpha/classes.rb', line 41158

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


41163
41164
41165
# File 'lib/google/apis/compute_alpha/classes.rb', line 41163

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::MachineImageList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



41168
41169
41170
# File 'lib/google/apis/compute_alpha/classes.rb', line 41168

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



41175
41176
41177
41178
41179
41180
41181
41182
# File 'lib/google/apis/compute_alpha/classes.rb', line 41175

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end