Class: Google::Apis::ComputeAlpha::MachineImageList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::MachineImageList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
A list of machine images.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::MachineImage>
A list of MachineImage resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::MachineImageList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MachineImageList
constructor
A new instance of MachineImageList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MachineImageList
Returns a new instance of MachineImageList.
40391 40392 40393 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 40391 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
40358 40359 40360 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 40358 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::MachineImage>
A list of MachineImage resources.
Corresponds to the JSON property items
40363 40364 40365 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 40363 def items @items end |
#kind ⇒ String
Output only. [Output Only] The resource type, which is alwayscompute#
machineImagesListResponse for machine image lists.
Corresponds to the JSON property kind
40369 40370 40371 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 40369 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
40379 40380 40381 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 40379 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
40384 40385 40386 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 40384 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::MachineImageList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
40389 40390 40391 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 40389 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
40396 40397 40398 40399 40400 40401 40402 40403 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 40396 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |