Class: Google::Apis::ComputeAlpha::MachineImageList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

A list of machine images.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MachineImageList

Returns a new instance of MachineImageList.



40168
40169
40170
# File 'lib/google/apis/compute_alpha/classes.rb', line 40168

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


40135
40136
40137
# File 'lib/google/apis/compute_alpha/classes.rb', line 40135

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::MachineImage>

A list of MachineImage resources. Corresponds to the JSON property items



40140
40141
40142
# File 'lib/google/apis/compute_alpha/classes.rb', line 40140

def items
  @items
end

#kindString

Output only. [Output Only] The resource type, which is alwayscompute# machineImagesListResponse for machine image lists. Corresponds to the JSON property kind

Returns:

  • (String)


40146
40147
40148
# File 'lib/google/apis/compute_alpha/classes.rb', line 40146

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


40156
40157
40158
# File 'lib/google/apis/compute_alpha/classes.rb', line 40156

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


40161
40162
40163
# File 'lib/google/apis/compute_alpha/classes.rb', line 40161

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::MachineImageList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



40166
40167
40168
# File 'lib/google/apis/compute_alpha/classes.rb', line 40166

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



40173
40174
40175
40176
40177
40178
40179
40180
# File 'lib/google/apis/compute_alpha/classes.rb', line 40173

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end