Class: Google::Apis::ComputeAlpha::MachineImageList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

A list of machine images.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MachineImageList

Returns a new instance of MachineImageList.



40030
40031
40032
# File 'lib/google/apis/compute_alpha/classes.rb', line 40030

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


39997
39998
39999
# File 'lib/google/apis/compute_alpha/classes.rb', line 39997

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::MachineImage>

A list of MachineImage resources. Corresponds to the JSON property items



40002
40003
40004
# File 'lib/google/apis/compute_alpha/classes.rb', line 40002

def items
  @items
end

#kindString

Output only. [Output Only] The resource type, which is alwayscompute# machineImagesListResponse for machine image lists. Corresponds to the JSON property kind

Returns:

  • (String)


40008
40009
40010
# File 'lib/google/apis/compute_alpha/classes.rb', line 40008

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


40018
40019
40020
# File 'lib/google/apis/compute_alpha/classes.rb', line 40018

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


40023
40024
40025
# File 'lib/google/apis/compute_alpha/classes.rb', line 40023

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::MachineImageList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



40028
40029
40030
# File 'lib/google/apis/compute_alpha/classes.rb', line 40028

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



40035
40036
40037
40038
40039
40040
40041
40042
# File 'lib/google/apis/compute_alpha/classes.rb', line 40035

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end