Class: Google::Apis::ComputeAlpha::MachineImageParams

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Machine Image parameters

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MachineImageParams

Returns a new instance of MachineImageParams.



41283
41284
41285
# File 'lib/google/apis/compute_alpha/classes.rb', line 41283

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#excluded_disksArray<String>

Input only. [Input Only] Specifies the list of disk device names that must be excluded from the new machine image. Corresponds to the JSON property excludedDisks

Returns:

  • (Array<String>)


41263
41264
41265
# File 'lib/google/apis/compute_alpha/classes.rb', line 41263

def excluded_disks
  @excluded_disks
end

#included_disksArray<String>

Input only. [Input Only] Specifies the list of disk device names that must be included with the new machine image. Corresponds to the JSON property includedDisks

Returns:

  • (Array<String>)


41269
41270
41271
# File 'lib/google/apis/compute_alpha/classes.rb', line 41269

def included_disks
  @included_disks
end

#resource_manager_tagsHash<String,String>

Input only. Resource manager tags to be bound to the machine image. Tag keys and values have the same definition as resource manager tags. Keys and values can be either in numeric format, such as tagKeys/tag_key_idand `tagValues/`tag_value_id or in namespaced format such as org_id|project_id`/`tag_key_short_name and tag_value_short_name. The field is ignored (both PUT & PATCH) when empty. Corresponds to the JSON property resourceManagerTags

Returns:

  • (Hash<String,String>)


41281
41282
41283
# File 'lib/google/apis/compute_alpha/classes.rb', line 41281

def resource_manager_tags
  @resource_manager_tags
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



41288
41289
41290
41291
41292
# File 'lib/google/apis/compute_alpha/classes.rb', line 41288

def update!(**args)
  @excluded_disks = args[:excluded_disks] if args.key?(:excluded_disks)
  @included_disks = args[:included_disks] if args.key?(:included_disks)
  @resource_manager_tags = args[:resource_manager_tags] if args.key?(:resource_manager_tags)
end