Class: Google::Apis::ComputeAlpha::MachineImageParams
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::MachineImageParams
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Machine Image parameters
Instance Attribute Summary collapse
-
#excluded_disks ⇒ Array<String>
Input only.
-
#included_disks ⇒ Array<String>
Input only.
-
#resource_manager_tags ⇒ Hash<String,String>
Input only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MachineImageParams
constructor
A new instance of MachineImageParams.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MachineImageParams
Returns a new instance of MachineImageParams.
40271 40272 40273 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 40271 def initialize(**args) update!(**args) end |
Instance Attribute Details
#excluded_disks ⇒ Array<String>
Input only. [Input Only] Specifies the list of disk device names that must be
excluded from the new machine image.
Corresponds to the JSON property excludedDisks
40251 40252 40253 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 40251 def excluded_disks @excluded_disks end |
#included_disks ⇒ Array<String>
Input only. [Input Only] Specifies the list of disk device names that must be
included with the new machine image.
Corresponds to the JSON property includedDisks
40257 40258 40259 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 40257 def included_disks @included_disks end |
#resource_manager_tags ⇒ Hash<String,String>
Input only. Resource manager tags to be bound to the machine image. Tag keys
and values
have the same definition as resource
manager tags. Keys and values can be either in numeric format,
such as tagKeys/tag_key_idand `tagValues/`tag_value_id or in
namespaced format such as org_id|project_id`/`tag_key_short_name and
tag_value_short_name. The field is ignored (both PUT &
PATCH) when empty.
Corresponds to the JSON property resourceManagerTags
40269 40270 40271 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 40269 def @resource_manager_tags end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
40276 40277 40278 40279 40280 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 40276 def update!(**args) @excluded_disks = args[:excluded_disks] if args.key?(:excluded_disks) @included_disks = args[:included_disks] if args.key?(:included_disks) @resource_manager_tags = args[:resource_manager_tags] if args.key?(:resource_manager_tags) end |