Class: Google::Apis::ComputeAlpha::MachineType
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::MachineType
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Represents a Machine Type resource. You can use specific machine types for your VM instances based on performance and pricing requirements. For more information, readMachine Types.
Defined Under Namespace
Classes: Accelerator
Instance Attribute Summary collapse
-
#accelerators ⇒ Array<Google::Apis::ComputeAlpha::MachineType::Accelerator>
[Output Only] A list of accelerator configurations assigned to this machine type.
-
#architecture ⇒ String
[Output Only] The architecture of the machine type.
-
#bundled_local_ssds ⇒ Google::Apis::ComputeAlpha::BundledLocalSsds
[Output Only] The configuration of bundled local SSD for the machine type.
-
#creation_timestamp ⇒ String
[Output Only] Creation timestamp inRFC3339 text format.
-
#deprecated ⇒ Google::Apis::ComputeAlpha::DeprecationStatus
Deprecation status for a public resource.
-
#description ⇒ String
[Output Only] An optional textual description of the resource.
-
#guest_cpus ⇒ Fixnum
[Output Only] The number of virtual CPUs that are available to the instance.
-
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource.
-
#is_shared_cpu ⇒ Boolean
(also: #is_shared_cpu?)
[Output Only] Whether this machine type has a shared CPU.
-
#kind ⇒ String
Output only.
-
#maximum_persistent_disks ⇒ Fixnum
[Output Only] Maximum persistent disks allowed.
-
#maximum_persistent_disks_size_gb ⇒ Fixnum
[Output Only] Maximum total persistent disks size (GB) allowed.
-
#memory_mb ⇒ Fixnum
[Output Only] The amount of physical memory available to the instance, defined in MB.
-
#name ⇒ String
[Output Only] Name of the resource.
-
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
-
#self_link_with_id ⇒ String
Output only.
-
#zone ⇒ String
[Output Only] The name of the zone where the machine type resides, such as us-central1-a.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MachineType
constructor
A new instance of MachineType.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MachineType
Returns a new instance of MachineType.
39507 39508 39509 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39507 def initialize(**args) update!(**args) end |
Instance Attribute Details
#accelerators ⇒ Array<Google::Apis::ComputeAlpha::MachineType::Accelerator>
[Output Only] A list of accelerator configurations assigned to this
machine type.
Corresponds to the JSON property accelerators
39415 39416 39417 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39415 def accelerators @accelerators end |
#architecture ⇒ String
[Output Only] The architecture of the machine type.
Corresponds to the JSON property architecture
39420 39421 39422 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39420 def architecture @architecture end |
#bundled_local_ssds ⇒ Google::Apis::ComputeAlpha::BundledLocalSsds
[Output Only] The configuration of bundled local SSD for the machine type.
Corresponds to the JSON property bundledLocalSsds
39425 39426 39427 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39425 def bundled_local_ssds @bundled_local_ssds end |
#creation_timestamp ⇒ String
[Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
39431 39432 39433 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39431 def @creation_timestamp end |
#deprecated ⇒ Google::Apis::ComputeAlpha::DeprecationStatus
Deprecation status for a public resource.
Corresponds to the JSON property deprecated
39436 39437 39438 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39436 def deprecated @deprecated end |
#description ⇒ String
[Output Only] An optional textual description of the resource.
Corresponds to the JSON property description
39441 39442 39443 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39441 def description @description end |
#guest_cpus ⇒ Fixnum
[Output Only] The number of virtual CPUs that are available to the
instance.
Corresponds to the JSON property guestCpus
39447 39448 39449 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39447 def guest_cpus @guest_cpus end |
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
39453 39454 39455 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39453 def id @id end |
#is_shared_cpu ⇒ Boolean Also known as:
[Output Only] Whether this machine type has a shared CPU. SeeShared-core
machine
types for more information.
Corresponds to the JSON property isSharedCpu
39460 39461 39462 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39460 def is_shared_cpu @is_shared_cpu end |
#kind ⇒ String
Output only. [Output Only] The type of the resource. Alwayscompute#machineType
for machine types.
Corresponds to the JSON property kind
39467 39468 39469 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39467 def kind @kind end |
#maximum_persistent_disks ⇒ Fixnum
[Output Only] Maximum persistent disks allowed.
Corresponds to the JSON property maximumPersistentDisks
39472 39473 39474 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39472 def maximum_persistent_disks @maximum_persistent_disks end |
#maximum_persistent_disks_size_gb ⇒ Fixnum
[Output Only] Maximum total persistent disks size (GB) allowed.
Corresponds to the JSON property maximumPersistentDisksSizeGb
39477 39478 39479 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39477 def maximum_persistent_disks_size_gb @maximum_persistent_disks_size_gb end |
#memory_mb ⇒ Fixnum
[Output Only] The amount of physical memory available to the instance,
defined in MB.
Corresponds to the JSON property memoryMb
39483 39484 39485 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39483 def memory_mb @memory_mb end |
#name ⇒ String
[Output Only] Name of the resource.
Corresponds to the JSON property name
39488 39489 39490 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39488 def name @name end |
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
39493 39494 39495 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39493 def self_link @self_link end |
#self_link_with_id ⇒ String
Output only. [Output Only] Server-defined URL for this resource with the
resource id.
Corresponds to the JSON property selfLinkWithId
39499 39500 39501 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39499 def self_link_with_id @self_link_with_id end |
#zone ⇒ String
[Output Only] The name of the zone where the machine type resides,
such as us-central1-a.
Corresponds to the JSON property zone
39505 39506 39507 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39505 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
39512 39513 39514 39515 39516 39517 39518 39519 39520 39521 39522 39523 39524 39525 39526 39527 39528 39529 39530 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 39512 def update!(**args) @accelerators = args[:accelerators] if args.key?(:accelerators) @architecture = args[:architecture] if args.key?(:architecture) @bundled_local_ssds = args[:bundled_local_ssds] if args.key?(:bundled_local_ssds) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @deprecated = args[:deprecated] if args.key?(:deprecated) @description = args[:description] if args.key?(:description) @guest_cpus = args[:guest_cpus] if args.key?(:guest_cpus) @id = args[:id] if args.key?(:id) @is_shared_cpu = args[:is_shared_cpu] if args.key?(:is_shared_cpu) @kind = args[:kind] if args.key?(:kind) @maximum_persistent_disks = args[:maximum_persistent_disks] if args.key?(:maximum_persistent_disks) @maximum_persistent_disks_size_gb = args[:maximum_persistent_disks_size_gb] if args.key?(:maximum_persistent_disks_size_gb) @memory_mb = args[:memory_mb] if args.key?(:memory_mb) @name = args[:name] if args.key?(:name) @self_link = args[:self_link] if args.key?(:self_link) @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id) @zone = args[:zone] if args.key?(:zone) end |