Class: Google::Apis::ComputeAlpha::ManagedInstance
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::ManagedInstance
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
A Managed Instance resource.
Instance Attribute Summary collapse
-
#all_instances_config ⇒ Google::Apis::ComputeAlpha::ManagedInstanceAllInstancesConfig
Output only.
-
#current_action ⇒ String
Output only.
-
#current_action_details ⇒ Google::Apis::ComputeAlpha::ManagedInstanceCurrentActionDetails
Corresponds to the JSON property
currentActionDetails. -
#id ⇒ Fixnum
Output only.
-
#instance ⇒ String
Output only.
-
#instance_flexibility_override ⇒ Google::Apis::ComputeAlpha::ManagedInstanceInstanceFlexibilityOverride
Output only.
-
#instance_health ⇒ Array<Google::Apis::ComputeAlpha::ManagedInstanceInstanceHealth>
Output only.
-
#instance_status ⇒ String
Output only.
-
#instance_template ⇒ String
Output only.
-
#last_attempt ⇒ Google::Apis::ComputeAlpha::ManagedInstanceLastAttempt
Output only.
-
#name ⇒ String
Output only.
-
#preserved_state_from_config ⇒ Google::Apis::ComputeAlpha::PreservedState
Preserved state for a given instance.
-
#preserved_state_from_policy ⇒ Google::Apis::ComputeAlpha::PreservedState
Preserved state for a given instance.
-
#properties_from_flexibility_policy ⇒ Google::Apis::ComputeAlpha::ManagedInstancePropertiesFromFlexibilityPolicy
Output only.
-
#scheduling ⇒ Google::Apis::ComputeAlpha::ManagedInstanceScheduling
Output only.
-
#shutdown_details ⇒ Google::Apis::ComputeAlpha::ManagedInstanceShutdownDetails
Output only.
-
#size_in_unit ⇒ Float
Output only.
-
#tag ⇒ String
Output only.
-
#target_status ⇒ String
Output only.
-
#version ⇒ Google::Apis::ComputeAlpha::ManagedInstanceVersion
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ManagedInstance
constructor
A new instance of ManagedInstance.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ManagedInstance
Returns a new instance of ManagedInstance.
42237 42238 42239 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 42237 def initialize(**args) update!(**args) end |
Instance Attribute Details
#all_instances_config ⇒ Google::Apis::ComputeAlpha::ManagedInstanceAllInstancesConfig
Output only. [Output Only] Current all-instances configuration revision
applied to this
instance.
Corresponds to the JSON property allInstancesConfig
42090 42091 42092 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 42090 def all_instances_config @all_instances_config end |
#current_action ⇒ String
Output only. [Output Only] The current action that the managed instance group has scheduled for the instance. Possible values:
- NONE The instance is running, and the managed instance group does not have any scheduled actions for this instance.
- CREATING The managed instance group is creating this instance. If the group fails to create this instance, it will try again until it is successful.
- CREATING_WITHOUT_RETRIES The managed instance group is attempting to create this instance only once. If the group fails to create this instance, it does not try again and the group'stargetSize value is decreased instead.
- RECREATING The managed instance group is recreating this instance.
- DELETING The managed instance group is permanently deleting this instance.
- ABANDONING The managed instance group is abandoning this instance. The instance will be removed from the instance group and from any target pools that are associated with this group.
- RESTARTING The managed instance group is restarting the instance.
- REFRESHING The managed instance group is applying configuration changes to the instance without stopping it. For example, the group can update the target pool list for an instance without stopping that instance.
- VERIFYING The managed instance group has created the
instance and it is in the process of being verified.
Corresponds to the JSON property
currentAction
42122 42123 42124 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 42122 def current_action @current_action end |
#current_action_details ⇒ Google::Apis::ComputeAlpha::ManagedInstanceCurrentActionDetails
Corresponds to the JSON property currentActionDetails
42127 42128 42129 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 42127 def current_action_details @current_action_details end |
#id ⇒ Fixnum
Output only. [Output only] The unique identifier for this resource. This field
is empty
when instance does not exist.
Corresponds to the JSON property id
42134 42135 42136 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 42134 def id @id end |
#instance ⇒ String
Output only. [Output Only] The URL of the instance. The URL can exist even if
the
instance has not yet been created.
Corresponds to the JSON property instance
42141 42142 42143 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 42141 def instance @instance end |
#instance_flexibility_override ⇒ Google::Apis::ComputeAlpha::ManagedInstanceInstanceFlexibilityOverride
Output only. [Output Only] The overrides to instance properties resulting from
InstanceFlexibilityPolicy.
Corresponds to the JSON property instanceFlexibilityOverride
42147 42148 42149 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 42147 def instance_flexibility_override @instance_flexibility_override end |
#instance_health ⇒ Array<Google::Apis::ComputeAlpha::ManagedInstanceInstanceHealth>
Output only. [Output Only] Health state of the instance per health-check.
Corresponds to the JSON property instanceHealth
42152 42153 42154 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 42152 def instance_health @instance_health end |
#instance_status ⇒ String
Output only. [Output Only] The status of the instance. This field is empty
when
the instance does not exist.
Corresponds to the JSON property instanceStatus
42159 42160 42161 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 42159 def instance_status @instance_status end |
#instance_template ⇒ String
Output only. [Output Only] The intended template of the instance. This field
is empty
when current_action is one of DELETING, ABANDONING.
Corresponds to the JSON property instanceTemplate
42166 42167 42168 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 42166 def instance_template @instance_template end |
#last_attempt ⇒ Google::Apis::ComputeAlpha::ManagedInstanceLastAttempt
Output only. [Output Only] Information about the last attempt to create or
delete
the instance.
Corresponds to the JSON property lastAttempt
42173 42174 42175 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 42173 def last_attempt @last_attempt end |
#name ⇒ String
Output only. [Output Only] The name of the instance. The name always exists
even if the
instance has not yet been created.
Corresponds to the JSON property name
42180 42181 42182 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 42180 def name @name end |
#preserved_state_from_config ⇒ Google::Apis::ComputeAlpha::PreservedState
Preserved state for a given instance.
Corresponds to the JSON property preservedStateFromConfig
42185 42186 42187 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 42185 def preserved_state_from_config @preserved_state_from_config end |
#preserved_state_from_policy ⇒ Google::Apis::ComputeAlpha::PreservedState
Preserved state for a given instance.
Corresponds to the JSON property preservedStateFromPolicy
42190 42191 42192 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 42190 def preserved_state_from_policy @preserved_state_from_policy end |
#properties_from_flexibility_policy ⇒ Google::Apis::ComputeAlpha::ManagedInstancePropertiesFromFlexibilityPolicy
Output only. [Output Only] Instance properties selected for this instance
resulting from
InstanceFlexibilityPolicy.
Corresponds to the JSON property propertiesFromFlexibilityPolicy
42197 42198 42199 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 42197 def properties_from_flexibility_policy @properties_from_flexibility_policy end |
#scheduling ⇒ Google::Apis::ComputeAlpha::ManagedInstanceScheduling
Output only. Information about the termination timestamp of the instance, if
applicable.
Corresponds to the JSON property scheduling
42203 42204 42205 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 42203 def scheduling @scheduling end |
#shutdown_details ⇒ Google::Apis::ComputeAlpha::ManagedInstanceShutdownDetails
Output only. Specifies the graceful shutdown details if the instance is in
PENDING_STOP state or there is a programmed stop scheduled.
Corresponds to the JSON property shutdownDetails
42209 42210 42211 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 42209 def shutdown_details @shutdown_details end |
#size_in_unit ⇒ Float
Output only. [Output only] The size of the VM represented by this Managed
Instance.
This is how much this Managed Instance contributes to the
size of the group.
Corresponds to the JSON property sizeInUnit
42217 42218 42219 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 42217 def size_in_unit @size_in_unit end |
#tag ⇒ String
Output only. [Output Only] Tag describing the version.
Corresponds to the JSON property tag
42222 42223 42224 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 42222 def tag @tag end |
#target_status ⇒ String
Output only. [Output Only] The eventual status of the instance. The instance
group
manager will not be identified as stable till each managed instance reaches
its targetStatus.
Corresponds to the JSON property targetStatus
42230 42231 42232 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 42230 def target_status @target_status end |
#version ⇒ Google::Apis::ComputeAlpha::ManagedInstanceVersion
Output only. [Output Only] Intended version of this instance.
Corresponds to the JSON property version
42235 42236 42237 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 42235 def version @version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
42242 42243 42244 42245 42246 42247 42248 42249 42250 42251 42252 42253 42254 42255 42256 42257 42258 42259 42260 42261 42262 42263 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 42242 def update!(**args) @all_instances_config = args[:all_instances_config] if args.key?(:all_instances_config) @current_action = args[:current_action] if args.key?(:current_action) @current_action_details = args[:current_action_details] if args.key?(:current_action_details) @id = args[:id] if args.key?(:id) @instance = args[:instance] if args.key?(:instance) @instance_flexibility_override = args[:instance_flexibility_override] if args.key?(:instance_flexibility_override) @instance_health = args[:instance_health] if args.key?(:instance_health) @instance_status = args[:instance_status] if args.key?(:instance_status) @instance_template = args[:instance_template] if args.key?(:instance_template) @last_attempt = args[:last_attempt] if args.key?(:last_attempt) @name = args[:name] if args.key?(:name) @preserved_state_from_config = args[:preserved_state_from_config] if args.key?(:preserved_state_from_config) @preserved_state_from_policy = args[:preserved_state_from_policy] if args.key?(:preserved_state_from_policy) @properties_from_flexibility_policy = args[:properties_from_flexibility_policy] if args.key?(:properties_from_flexibility_policy) @scheduling = args[:scheduling] if args.key?(:scheduling) @shutdown_details = args[:shutdown_details] if args.key?(:shutdown_details) @size_in_unit = args[:size_in_unit] if args.key?(:size_in_unit) @tag = args[:tag] if args.key?(:tag) @target_status = args[:target_status] if args.key?(:target_status) @version = args[:version] if args.key?(:version) end |