Class: Google::Apis::ComputeAlpha::ManagedInstance

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

A Managed Instance resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ManagedInstance

Returns a new instance of ManagedInstance.



41181
41182
41183
# File 'lib/google/apis/compute_alpha/classes.rb', line 41181

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#all_instances_configGoogle::Apis::ComputeAlpha::ManagedInstanceAllInstancesConfig

Output only. [Output Only] Current all-instances configuration revision applied to this instance. Corresponds to the JSON property allInstancesConfig



41032
41033
41034
# File 'lib/google/apis/compute_alpha/classes.rb', line 41032

def all_instances_config
  @all_instances_config
end

#current_actionString

Output only. [Output Only] The current action that the managed instance group has scheduled for the instance. Possible values:

  • NONE The instance is running, and the managed instance group does not have any scheduled actions for this instance.
  • CREATING The managed instance group is creating this instance. If the group fails to create this instance, it will try again until it is successful.
  • CREATING_WITHOUT_RETRIES The managed instance group is attempting to create this instance only once. If the group fails to create this instance, it does not try again and the group'stargetSize value is decreased instead.
  • RECREATING The managed instance group is recreating this instance.
  • DELETING The managed instance group is permanently deleting this instance.
  • ABANDONING The managed instance group is abandoning this instance. The instance will be removed from the instance group and from any target pools that are associated with this group.
  • RESTARTING The managed instance group is restarting the instance.
  • REFRESHING The managed instance group is applying configuration changes to the instance without stopping it. For example, the group can update the target pool list for an instance without stopping that instance.
  • VERIFYING The managed instance group has created the instance and it is in the process of being verified. Corresponds to the JSON property currentAction

Returns:

  • (String)


41064
41065
41066
# File 'lib/google/apis/compute_alpha/classes.rb', line 41064

def current_action
  @current_action
end

#current_action_detailsGoogle::Apis::ComputeAlpha::ManagedInstanceCurrentActionDetails

Corresponds to the JSON property currentActionDetails



41069
41070
41071
# File 'lib/google/apis/compute_alpha/classes.rb', line 41069

def current_action_details
  @current_action_details
end

#idFixnum

Output only. [Output only] The unique identifier for this resource. This field is empty when instance does not exist. Corresponds to the JSON property id

Returns:

  • (Fixnum)


41076
41077
41078
# File 'lib/google/apis/compute_alpha/classes.rb', line 41076

def id
  @id
end

#instanceString

Output only. [Output Only] The URL of the instance. The URL can exist even if the instance has not yet been created. Corresponds to the JSON property instance

Returns:

  • (String)


41083
41084
41085
# File 'lib/google/apis/compute_alpha/classes.rb', line 41083

def instance
  @instance
end

#instance_flexibility_overrideGoogle::Apis::ComputeAlpha::ManagedInstanceInstanceFlexibilityOverride

Output only. [Output Only] The overrides to instance properties resulting from InstanceFlexibilityPolicy. Corresponds to the JSON property instanceFlexibilityOverride



41089
41090
41091
# File 'lib/google/apis/compute_alpha/classes.rb', line 41089

def instance_flexibility_override
  @instance_flexibility_override
end

#instance_healthArray<Google::Apis::ComputeAlpha::ManagedInstanceInstanceHealth>

Output only. [Output Only] Health state of the instance per health-check. Corresponds to the JSON property instanceHealth



41094
41095
41096
# File 'lib/google/apis/compute_alpha/classes.rb', line 41094

def instance_health
  @instance_health
end

#instance_statusString

Output only. [Output Only] The status of the instance. This field is empty when the instance does not exist. Corresponds to the JSON property instanceStatus

Returns:

  • (String)


41101
41102
41103
# File 'lib/google/apis/compute_alpha/classes.rb', line 41101

def instance_status
  @instance_status
end

#instance_templateString

Output only. [Output Only] The intended template of the instance. This field is empty when current_action is one of DELETING, ABANDONING. Corresponds to the JSON property instanceTemplate

Returns:

  • (String)


41108
41109
41110
# File 'lib/google/apis/compute_alpha/classes.rb', line 41108

def instance_template
  @instance_template
end

#last_attemptGoogle::Apis::ComputeAlpha::ManagedInstanceLastAttempt

Output only. [Output Only] Information about the last attempt to create or delete the instance. Corresponds to the JSON property lastAttempt



41115
41116
41117
# File 'lib/google/apis/compute_alpha/classes.rb', line 41115

def last_attempt
  @last_attempt
end

#nameString

Output only. [Output Only] The name of the instance. The name always exists even if the instance has not yet been created. Corresponds to the JSON property name

Returns:

  • (String)


41122
41123
41124
# File 'lib/google/apis/compute_alpha/classes.rb', line 41122

def name
  @name
end

#preserved_state_from_configGoogle::Apis::ComputeAlpha::PreservedState

Preserved state for a given instance. Corresponds to the JSON property preservedStateFromConfig



41127
41128
41129
# File 'lib/google/apis/compute_alpha/classes.rb', line 41127

def preserved_state_from_config
  @preserved_state_from_config
end

#preserved_state_from_policyGoogle::Apis::ComputeAlpha::PreservedState

Preserved state for a given instance. Corresponds to the JSON property preservedStateFromPolicy



41132
41133
41134
# File 'lib/google/apis/compute_alpha/classes.rb', line 41132

def preserved_state_from_policy
  @preserved_state_from_policy
end

#properties_from_flexibility_policyGoogle::Apis::ComputeAlpha::ManagedInstancePropertiesFromFlexibilityPolicy

Output only. [Output Only] Instance properties selected for this instance resulting from InstanceFlexibilityPolicy. Corresponds to the JSON property propertiesFromFlexibilityPolicy



41139
41140
41141
# File 'lib/google/apis/compute_alpha/classes.rb', line 41139

def properties_from_flexibility_policy
  @properties_from_flexibility_policy
end

#schedulingGoogle::Apis::ComputeAlpha::ManagedInstanceScheduling

Output only. [Output Only] Information about the termination timestamp of the instance, if applicable. Corresponds to the JSON property scheduling



41146
41147
41148
# File 'lib/google/apis/compute_alpha/classes.rb', line 41146

def scheduling
  @scheduling
end

#shutdown_detailsGoogle::Apis::ComputeAlpha::ManagedInstanceShutdownDetails

Output only. [Output Only] Specifies the graceful shutdown details if the instance is in PENDING_STOP state or there is a programmed stop scheduled. Corresponds to the JSON property shutdownDetails



41153
41154
41155
# File 'lib/google/apis/compute_alpha/classes.rb', line 41153

def shutdown_details
  @shutdown_details
end

#size_in_unitFloat

Output only. [Output only] The size of the VM represented by this Managed Instance. This is how much this Managed Instance contributes to the size of the group. Corresponds to the JSON property sizeInUnit

Returns:

  • (Float)


41161
41162
41163
# File 'lib/google/apis/compute_alpha/classes.rb', line 41161

def size_in_unit
  @size_in_unit
end

#tagString

Output only. [Output Only] Tag describing the version. Corresponds to the JSON property tag

Returns:

  • (String)


41166
41167
41168
# File 'lib/google/apis/compute_alpha/classes.rb', line 41166

def tag
  @tag
end

#target_statusString

Output only. [Output Only] The eventual status of the instance. The instance group manager will not be identified as stable till each managed instance reaches its targetStatus. Corresponds to the JSON property targetStatus

Returns:

  • (String)


41174
41175
41176
# File 'lib/google/apis/compute_alpha/classes.rb', line 41174

def target_status
  @target_status
end

#versionGoogle::Apis::ComputeAlpha::ManagedInstanceVersion

Output only. [Output Only] Intended version of this instance. Corresponds to the JSON property version



41179
41180
41181
# File 'lib/google/apis/compute_alpha/classes.rb', line 41179

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



41186
41187
41188
41189
41190
41191
41192
41193
41194
41195
41196
41197
41198
41199
41200
41201
41202
41203
41204
41205
41206
41207
# File 'lib/google/apis/compute_alpha/classes.rb', line 41186

def update!(**args)
  @all_instances_config = args[:all_instances_config] if args.key?(:all_instances_config)
  @current_action = args[:current_action] if args.key?(:current_action)
  @current_action_details = args[:current_action_details] if args.key?(:current_action_details)
  @id = args[:id] if args.key?(:id)
  @instance = args[:instance] if args.key?(:instance)
  @instance_flexibility_override = args[:instance_flexibility_override] if args.key?(:instance_flexibility_override)
  @instance_health = args[:instance_health] if args.key?(:instance_health)
  @instance_status = args[:instance_status] if args.key?(:instance_status)
  @instance_template = args[:instance_template] if args.key?(:instance_template)
  @last_attempt = args[:last_attempt] if args.key?(:last_attempt)
  @name = args[:name] if args.key?(:name)
  @preserved_state_from_config = args[:preserved_state_from_config] if args.key?(:preserved_state_from_config)
  @preserved_state_from_policy = args[:preserved_state_from_policy] if args.key?(:preserved_state_from_policy)
  @properties_from_flexibility_policy = args[:properties_from_flexibility_policy] if args.key?(:properties_from_flexibility_policy)
  @scheduling = args[:scheduling] if args.key?(:scheduling)
  @shutdown_details = args[:shutdown_details] if args.key?(:shutdown_details)
  @size_in_unit = args[:size_in_unit] if args.key?(:size_in_unit)
  @tag = args[:tag] if args.key?(:tag)
  @target_status = args[:target_status] if args.key?(:target_status)
  @version = args[:version] if args.key?(:version)
end