Class: Google::Apis::ComputeAlpha::ManagedInstance
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::ManagedInstance
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
A Managed Instance resource.
Instance Attribute Summary collapse
-
#all_instances_config ⇒ Google::Apis::ComputeAlpha::ManagedInstanceAllInstancesConfig
Output only.
-
#current_action ⇒ String
Output only.
-
#current_action_details ⇒ Google::Apis::ComputeAlpha::ManagedInstanceCurrentActionDetails
Corresponds to the JSON property
currentActionDetails. -
#id ⇒ Fixnum
Output only.
-
#instance ⇒ String
Output only.
-
#instance_flexibility_override ⇒ Google::Apis::ComputeAlpha::ManagedInstanceInstanceFlexibilityOverride
Output only.
-
#instance_health ⇒ Array<Google::Apis::ComputeAlpha::ManagedInstanceInstanceHealth>
Output only.
-
#instance_status ⇒ String
Output only.
-
#instance_template ⇒ String
Output only.
-
#last_attempt ⇒ Google::Apis::ComputeAlpha::ManagedInstanceLastAttempt
Output only.
-
#name ⇒ String
Output only.
-
#preserved_state_from_config ⇒ Google::Apis::ComputeAlpha::PreservedState
Preserved state for a given instance.
-
#preserved_state_from_policy ⇒ Google::Apis::ComputeAlpha::PreservedState
Preserved state for a given instance.
-
#properties_from_flexibility_policy ⇒ Google::Apis::ComputeAlpha::ManagedInstancePropertiesFromFlexibilityPolicy
Output only.
-
#scheduling ⇒ Google::Apis::ComputeAlpha::ManagedInstanceScheduling
Output only.
-
#shutdown_details ⇒ Google::Apis::ComputeAlpha::ManagedInstanceShutdownDetails
Output only.
-
#size_in_unit ⇒ Float
Output only.
-
#tag ⇒ String
Output only.
-
#target_status ⇒ String
Output only.
-
#version ⇒ Google::Apis::ComputeAlpha::ManagedInstanceVersion
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ManagedInstance
constructor
A new instance of ManagedInstance.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ManagedInstance
Returns a new instance of ManagedInstance.
40948 40949 40950 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 40948 def initialize(**args) update!(**args) end |
Instance Attribute Details
#all_instances_config ⇒ Google::Apis::ComputeAlpha::ManagedInstanceAllInstancesConfig
Output only. [Output Only] Current all-instances configuration revision
applied to this
instance.
Corresponds to the JSON property allInstancesConfig
40799 40800 40801 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 40799 def all_instances_config @all_instances_config end |
#current_action ⇒ String
Output only. [Output Only] The current action that the managed instance group has scheduled for the instance. Possible values:
- NONE The instance is running, and the managed instance group does not have any scheduled actions for this instance.
- CREATING The managed instance group is creating this instance. If the group fails to create this instance, it will try again until it is successful.
- CREATING_WITHOUT_RETRIES The managed instance group is attempting to create this instance only once. If the group fails to create this instance, it does not try again and the group'stargetSize value is decreased instead.
- RECREATING The managed instance group is recreating this instance.
- DELETING The managed instance group is permanently deleting this instance.
- ABANDONING The managed instance group is abandoning this instance. The instance will be removed from the instance group and from any target pools that are associated with this group.
- RESTARTING The managed instance group is restarting the instance.
- REFRESHING The managed instance group is applying configuration changes to the instance without stopping it. For example, the group can update the target pool list for an instance without stopping that instance.
- VERIFYING The managed instance group has created the
instance and it is in the process of being verified.
Corresponds to the JSON property
currentAction
40831 40832 40833 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 40831 def current_action @current_action end |
#current_action_details ⇒ Google::Apis::ComputeAlpha::ManagedInstanceCurrentActionDetails
Corresponds to the JSON property currentActionDetails
40836 40837 40838 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 40836 def current_action_details @current_action_details end |
#id ⇒ Fixnum
Output only. [Output only] The unique identifier for this resource. This field
is empty
when instance does not exist.
Corresponds to the JSON property id
40843 40844 40845 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 40843 def id @id end |
#instance ⇒ String
Output only. [Output Only] The URL of the instance. The URL can exist even if
the
instance has not yet been created.
Corresponds to the JSON property instance
40850 40851 40852 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 40850 def instance @instance end |
#instance_flexibility_override ⇒ Google::Apis::ComputeAlpha::ManagedInstanceInstanceFlexibilityOverride
Output only. [Output Only] The overrides to instance properties resulting from
InstanceFlexibilityPolicy.
Corresponds to the JSON property instanceFlexibilityOverride
40856 40857 40858 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 40856 def instance_flexibility_override @instance_flexibility_override end |
#instance_health ⇒ Array<Google::Apis::ComputeAlpha::ManagedInstanceInstanceHealth>
Output only. [Output Only] Health state of the instance per health-check.
Corresponds to the JSON property instanceHealth
40861 40862 40863 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 40861 def instance_health @instance_health end |
#instance_status ⇒ String
Output only. [Output Only] The status of the instance. This field is empty
when
the instance does not exist.
Corresponds to the JSON property instanceStatus
40868 40869 40870 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 40868 def instance_status @instance_status end |
#instance_template ⇒ String
Output only. [Output Only] The intended template of the instance. This field
is empty
when current_action is one of DELETING, ABANDONING.
Corresponds to the JSON property instanceTemplate
40875 40876 40877 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 40875 def instance_template @instance_template end |
#last_attempt ⇒ Google::Apis::ComputeAlpha::ManagedInstanceLastAttempt
Output only. [Output Only] Information about the last attempt to create or
delete
the instance.
Corresponds to the JSON property lastAttempt
40882 40883 40884 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 40882 def last_attempt @last_attempt end |
#name ⇒ String
Output only. [Output Only] The name of the instance. The name always exists
even if the
instance has not yet been created.
Corresponds to the JSON property name
40889 40890 40891 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 40889 def name @name end |
#preserved_state_from_config ⇒ Google::Apis::ComputeAlpha::PreservedState
Preserved state for a given instance.
Corresponds to the JSON property preservedStateFromConfig
40894 40895 40896 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 40894 def preserved_state_from_config @preserved_state_from_config end |
#preserved_state_from_policy ⇒ Google::Apis::ComputeAlpha::PreservedState
Preserved state for a given instance.
Corresponds to the JSON property preservedStateFromPolicy
40899 40900 40901 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 40899 def preserved_state_from_policy @preserved_state_from_policy end |
#properties_from_flexibility_policy ⇒ Google::Apis::ComputeAlpha::ManagedInstancePropertiesFromFlexibilityPolicy
Output only. [Output Only] Instance properties selected for this instance
resulting from
InstanceFlexibilityPolicy.
Corresponds to the JSON property propertiesFromFlexibilityPolicy
40906 40907 40908 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 40906 def properties_from_flexibility_policy @properties_from_flexibility_policy end |
#scheduling ⇒ Google::Apis::ComputeAlpha::ManagedInstanceScheduling
Output only. [Output Only] Information about the termination timestamp of the
instance,
if applicable.
Corresponds to the JSON property scheduling
40913 40914 40915 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 40913 def scheduling @scheduling end |
#shutdown_details ⇒ Google::Apis::ComputeAlpha::ManagedInstanceShutdownDetails
Output only. [Output Only] Specifies the graceful shutdown details if the
instance is in
PENDING_STOP state or there is a programmed stop scheduled.
Corresponds to the JSON property shutdownDetails
40920 40921 40922 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 40920 def shutdown_details @shutdown_details end |
#size_in_unit ⇒ Float
Output only. [Output only] The size of the VM represented by this Managed
Instance.
This is how much this Managed Instance contributes to the
size of the group.
Corresponds to the JSON property sizeInUnit
40928 40929 40930 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 40928 def size_in_unit @size_in_unit end |
#tag ⇒ String
Output only. [Output Only] Tag describing the version.
Corresponds to the JSON property tag
40933 40934 40935 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 40933 def tag @tag end |
#target_status ⇒ String
Output only. [Output Only] The eventual status of the instance. The instance
group
manager will not be identified as stable till each managed instance reaches
its targetStatus.
Corresponds to the JSON property targetStatus
40941 40942 40943 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 40941 def target_status @target_status end |
#version ⇒ Google::Apis::ComputeAlpha::ManagedInstanceVersion
Output only. [Output Only] Intended version of this instance.
Corresponds to the JSON property version
40946 40947 40948 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 40946 def version @version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
40953 40954 40955 40956 40957 40958 40959 40960 40961 40962 40963 40964 40965 40966 40967 40968 40969 40970 40971 40972 40973 40974 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 40953 def update!(**args) @all_instances_config = args[:all_instances_config] if args.key?(:all_instances_config) @current_action = args[:current_action] if args.key?(:current_action) @current_action_details = args[:current_action_details] if args.key?(:current_action_details) @id = args[:id] if args.key?(:id) @instance = args[:instance] if args.key?(:instance) @instance_flexibility_override = args[:instance_flexibility_override] if args.key?(:instance_flexibility_override) @instance_health = args[:instance_health] if args.key?(:instance_health) @instance_status = args[:instance_status] if args.key?(:instance_status) @instance_template = args[:instance_template] if args.key?(:instance_template) @last_attempt = args[:last_attempt] if args.key?(:last_attempt) @name = args[:name] if args.key?(:name) @preserved_state_from_config = args[:preserved_state_from_config] if args.key?(:preserved_state_from_config) @preserved_state_from_policy = args[:preserved_state_from_policy] if args.key?(:preserved_state_from_policy) @properties_from_flexibility_policy = args[:properties_from_flexibility_policy] if args.key?(:properties_from_flexibility_policy) @scheduling = args[:scheduling] if args.key?(:scheduling) @shutdown_details = args[:shutdown_details] if args.key?(:shutdown_details) @size_in_unit = args[:size_in_unit] if args.key?(:size_in_unit) @tag = args[:tag] if args.key?(:tag) @target_status = args[:target_status] if args.key?(:target_status) @version = args[:version] if args.key?(:version) end |