Class: Google::Apis::ComputeAlpha::ManagedInstanceCurrentActionDetails

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ManagedInstanceCurrentActionDetails

Returns a new instance of ManagedInstanceCurrentActionDetails.



42050
42051
42052
# File 'lib/google/apis/compute_alpha/classes.rb', line 42050

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#method_nameString

Corresponds to the JSON property methodName

Returns:

  • (String)


42014
42015
42016
# File 'lib/google/apis/compute_alpha/classes.rb', line 42014

def method_name
  @method_name
end

#triggerString

Output only. [Output Only] Details of the current action that the managed instance group has scheduled for the instance. Contains trigger for the current action, and methodName in case it was triggered by API call. Possible values for trigger:

  • API Any API call.
  • PROACTIVE_UPDATE Proactive updater scheduled an update on this managed instance.
  • AUTOSCALING Instance being deleted/created after a decision from the Autoscaler.
  • REDISTRIBUTION The regional managed instance group is moving instances between zones to restore balance.
  • STANDBY_REFILL The managed instance group is refilling the Standby Pool (stopped/suspended virtual machines) after scale up.
  • MAINTENANCE Manual maintenance.
  • FAILED_CREATION The managed instance group is handling failed instance creation.
  • INSTANCE_FAILURE The managed instance group is handling instance failure, according to the Instance Lifecycle Policy.
  • FAILED_HEALTH_CHECK The managed instance group is handling failed health check, according to the Instance Lifecycle Policy.
  • TERMINATION_TIMESTAMP Instance reached termination time, thus managed instance group stops/deletes it.
  • GRACEFUL_SHUTDOWN_TIMESTAMP Instance reached graceful shutdown time, thus managed instance group stops/deletes it to gracefully shut it down. Corresponds to the JSON property trigger

Returns:

  • (String)


42048
42049
42050
# File 'lib/google/apis/compute_alpha/classes.rb', line 42048

def trigger
  @trigger
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



42055
42056
42057
42058
# File 'lib/google/apis/compute_alpha/classes.rb', line 42055

def update!(**args)
  @method_name = args[:method_name] if args.key?(:method_name)
  @trigger = args[:trigger] if args.key?(:trigger)
end