Class: Google::Apis::ComputeAlpha::ManagedInstanceCurrentActionDetails
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::ManagedInstanceCurrentActionDetails
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#method_name ⇒ String
Corresponds to the JSON property
methodName. -
#trigger ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ManagedInstanceCurrentActionDetails
constructor
A new instance of ManagedInstanceCurrentActionDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ManagedInstanceCurrentActionDetails
Returns a new instance of ManagedInstanceCurrentActionDetails.
41253 41254 41255 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 41253 def initialize(**args) update!(**args) end |
Instance Attribute Details
#method_name ⇒ String
Corresponds to the JSON property methodName
41220 41221 41222 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 41220 def method_name @method_name end |
#trigger ⇒ String
Output only. [Output Only] Details of the current action that the managed instance group has scheduled for the instance. Contains trigger for the current action, and methodName in case it was triggered by API call. Possible values for trigger:
- API Any API call.
- PROACTIVE_UPDATE Proactive updater scheduled an update on this managed instance.
- AUTOSCALING Instance being deleted/created after a decision from the Autoscaler.
- REDISTRIBUTION The regional managed instance group is moving instances between zones to restore balance.
- STANDBY_REFILL The managed instance group is refilling the Standby Pool (stopped/suspended virtual machines) after scale up.
- MAINTENANCE Manual maintenance.
- FAILED_CREATION The managed instance group is handling failed instance creation.
- INSTANCE_FAILURE The managed instance group is handling instance failure, according to the Instance Lifecycle Policy.
- FAILED_HEALTH_CHECK The managed instance group is handling failed health check, according to the Instance Lifecycle Policy.
- TERMINATION_TIMESTAMP Instance reached termination time,
thus managed instance group stops/deletes it.
Corresponds to the JSON property
trigger
41251 41252 41253 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 41251 def trigger @trigger end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
41258 41259 41260 41261 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 41258 def update!(**args) @method_name = args[:method_name] if args.key?(:method_name) @trigger = args[:trigger] if args.key?(:trigger) end |