Class: Google::Apis::ComputeAlpha::ManagedInstanceInstanceFlexibilityOverride
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::ManagedInstanceInstanceFlexibilityOverride
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#disks ⇒ Array<Google::Apis::ComputeAlpha::AttachedDisk>
List of disks to be attached to the instance.
-
#machine_type ⇒ String
The machine type to be used for this instance.
-
#min_cpu_platform ⇒ String
Name of the minimum CPU platform to be used by this instance.
-
#provisioning_model ⇒ String
The provisioning model to be used for this instance.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ManagedInstanceInstanceFlexibilityOverride
constructor
A new instance of ManagedInstanceInstanceFlexibilityOverride.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ManagedInstanceInstanceFlexibilityOverride
Returns a new instance of ManagedInstanceInstanceFlexibilityOverride.
41289 41290 41291 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 41289 def initialize(**args) update!(**args) end |
Instance Attribute Details
#disks ⇒ Array<Google::Apis::ComputeAlpha::AttachedDisk>
List of disks to be attached to the instance.
Corresponds to the JSON property disks
41271 41272 41273 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 41271 def disks @disks end |
#machine_type ⇒ String
The machine type to be used for this instance.
Corresponds to the JSON property machineType
41276 41277 41278 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 41276 def machine_type @machine_type end |
#min_cpu_platform ⇒ String
Name of the minimum CPU platform to be used by this instance.
e.g. 'Intel Ice Lake'.
Corresponds to the JSON property minCpuPlatform
41282 41283 41284 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 41282 def min_cpu_platform @min_cpu_platform end |
#provisioning_model ⇒ String
The provisioning model to be used for this instance.
Corresponds to the JSON property provisioningModel
41287 41288 41289 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 41287 def provisioning_model @provisioning_model end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
41294 41295 41296 41297 41298 41299 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 41294 def update!(**args) @disks = args[:disks] if args.key?(:disks) @machine_type = args[:machine_type] if args.key?(:machine_type) @min_cpu_platform = args[:min_cpu_platform] if args.key?(:min_cpu_platform) @provisioning_model = args[:provisioning_model] if args.key?(:provisioning_model) end |