Class: Google::Apis::ComputeAlpha::ManagedInstanceInstanceFlexibilityOverride
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::ManagedInstanceInstanceFlexibilityOverride
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#disks ⇒ Array<Google::Apis::ComputeAlpha::AttachedDisk>
List of disks to be attached to the instance.
-
#machine_type ⇒ String
The machine type to be used for this instance.
-
#min_cpu_platform ⇒ String
Name of the minimum CPU platform to be used by this instance.
-
#provisioning_model ⇒ String
The provisioning model to be used for this instance.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ManagedInstanceInstanceFlexibilityOverride
constructor
A new instance of ManagedInstanceInstanceFlexibilityOverride.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ManagedInstanceInstanceFlexibilityOverride
Returns a new instance of ManagedInstanceInstanceFlexibilityOverride.
41083 41084 41085 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 41083 def initialize(**args) update!(**args) end |
Instance Attribute Details
#disks ⇒ Array<Google::Apis::ComputeAlpha::AttachedDisk>
List of disks to be attached to the instance.
Corresponds to the JSON property disks
41065 41066 41067 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 41065 def disks @disks end |
#machine_type ⇒ String
The machine type to be used for this instance.
Corresponds to the JSON property machineType
41070 41071 41072 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 41070 def machine_type @machine_type end |
#min_cpu_platform ⇒ String
Name of the minimum CPU platform to be used by this instance.
e.g. 'Intel Ice Lake'.
Corresponds to the JSON property minCpuPlatform
41076 41077 41078 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 41076 def min_cpu_platform @min_cpu_platform end |
#provisioning_model ⇒ String
The provisioning model to be used for this instance.
Corresponds to the JSON property provisioningModel
41081 41082 41083 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 41081 def provisioning_model @provisioning_model end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
41088 41089 41090 41091 41092 41093 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 41088 def update!(**args) @disks = args[:disks] if args.key?(:disks) @machine_type = args[:machine_type] if args.key?(:machine_type) @min_cpu_platform = args[:min_cpu_platform] if args.key?(:min_cpu_platform) @provisioning_model = args[:provisioning_model] if args.key?(:provisioning_model) end |