Class: Google::Apis::ComputeAlpha::ManagedInstanceInstanceFlexibilityOverride
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::ManagedInstanceInstanceFlexibilityOverride
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#disks ⇒ Array<Google::Apis::ComputeAlpha::AttachedDisk>
List of disks to be attached to the instance.
-
#machine_type ⇒ String
The machine type to be used for this instance.
-
#min_cpu_platform ⇒ String
Name of the minimum CPU platform to be used by this instance.
-
#provisioning_model ⇒ String
The provisioning model to be used for this instance.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ManagedInstanceInstanceFlexibilityOverride
constructor
A new instance of ManagedInstanceInstanceFlexibilityOverride.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ManagedInstanceInstanceFlexibilityOverride
Returns a new instance of ManagedInstanceInstanceFlexibilityOverride.
40937 40938 40939 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 40937 def initialize(**args) update!(**args) end |
Instance Attribute Details
#disks ⇒ Array<Google::Apis::ComputeAlpha::AttachedDisk>
List of disks to be attached to the instance.
Corresponds to the JSON property disks
40919 40920 40921 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 40919 def disks @disks end |
#machine_type ⇒ String
The machine type to be used for this instance.
Corresponds to the JSON property machineType
40924 40925 40926 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 40924 def machine_type @machine_type end |
#min_cpu_platform ⇒ String
Name of the minimum CPU platform to be used by this instance.
e.g. 'Intel Ice Lake'.
Corresponds to the JSON property minCpuPlatform
40930 40931 40932 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 40930 def min_cpu_platform @min_cpu_platform end |
#provisioning_model ⇒ String
The provisioning model to be used for this instance.
Corresponds to the JSON property provisioningModel
40935 40936 40937 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 40935 def provisioning_model @provisioning_model end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
40942 40943 40944 40945 40946 40947 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 40942 def update!(**args) @disks = args[:disks] if args.key?(:disks) @machine_type = args[:machine_type] if args.key?(:machine_type) @min_cpu_platform = args[:min_cpu_platform] if args.key?(:min_cpu_platform) @provisioning_model = args[:provisioning_model] if args.key?(:provisioning_model) end |