Class: Google::Apis::ComputeAlpha::ManagedInstanceInstanceFlexibilityOverride

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ManagedInstanceInstanceFlexibilityOverride

Returns a new instance of ManagedInstanceInstanceFlexibilityOverride.



40187
40188
40189
# File 'lib/google/apis/compute_alpha/classes.rb', line 40187

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#disksArray<Google::Apis::ComputeAlpha::AttachedDisk>

List of disks to be attached to the instance. Corresponds to the JSON property disks



40169
40170
40171
# File 'lib/google/apis/compute_alpha/classes.rb', line 40169

def disks
  @disks
end

#machine_typeString

The machine type to be used for this instance. Corresponds to the JSON property machineType

Returns:

  • (String)


40174
40175
40176
# File 'lib/google/apis/compute_alpha/classes.rb', line 40174

def machine_type
  @machine_type
end

#min_cpu_platformString

Name of the minimum CPU platform to be used by this instance. e.g. 'Intel Ice Lake'. Corresponds to the JSON property minCpuPlatform

Returns:

  • (String)


40180
40181
40182
# File 'lib/google/apis/compute_alpha/classes.rb', line 40180

def min_cpu_platform
  @min_cpu_platform
end

#provisioning_modelString

The provisioning model to be used for this instance. Corresponds to the JSON property provisioningModel

Returns:

  • (String)


40185
40186
40187
# File 'lib/google/apis/compute_alpha/classes.rb', line 40185

def provisioning_model
  @provisioning_model
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



40192
40193
40194
40195
40196
40197
# File 'lib/google/apis/compute_alpha/classes.rb', line 40192

def update!(**args)
  @disks = args[:disks] if args.key?(:disks)
  @machine_type = args[:machine_type] if args.key?(:machine_type)
  @min_cpu_platform = args[:min_cpu_platform] if args.key?(:min_cpu_platform)
  @provisioning_model = args[:provisioning_model] if args.key?(:provisioning_model)
end