Class: Google::Apis::ComputeAlpha::ManagedInstancePropertiesFromFlexibilityPolicy

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ManagedInstancePropertiesFromFlexibilityPolicy

Returns a new instance of ManagedInstancePropertiesFromFlexibilityPolicy.



41301
41302
41303
# File 'lib/google/apis/compute_alpha/classes.rb', line 41301

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#disksArray<Google::Apis::ComputeAlpha::AttachedDisk>

List of disks to be attached to the instance. Corresponds to the JSON property disks



41283
41284
41285
# File 'lib/google/apis/compute_alpha/classes.rb', line 41283

def disks
  @disks
end

#machine_typeString

Output only. The machine type to be used for this instance. Corresponds to the JSON property machineType

Returns:

  • (String)


41288
41289
41290
# File 'lib/google/apis/compute_alpha/classes.rb', line 41288

def machine_type
  @machine_type
end

#min_cpu_platformString

Name of the minimum CPU platform to be used by this instance. e.g. 'Intel Ice Lake'. Corresponds to the JSON property minCpuPlatform

Returns:

  • (String)


41294
41295
41296
# File 'lib/google/apis/compute_alpha/classes.rb', line 41294

def min_cpu_platform
  @min_cpu_platform
end

#provisioning_modelString

Output only. The provisioning model to be used for this instance. Corresponds to the JSON property provisioningModel

Returns:

  • (String)


41299
41300
41301
# File 'lib/google/apis/compute_alpha/classes.rb', line 41299

def provisioning_model
  @provisioning_model
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



41306
41307
41308
41309
41310
41311
# File 'lib/google/apis/compute_alpha/classes.rb', line 41306

def update!(**args)
  @disks = args[:disks] if args.key?(:disks)
  @machine_type = args[:machine_type] if args.key?(:machine_type)
  @min_cpu_platform = args[:min_cpu_platform] if args.key?(:min_cpu_platform)
  @provisioning_model = args[:provisioning_model] if args.key?(:provisioning_model)
end