Class: Google::Apis::ComputeAlpha::ManagedInstanceScheduling

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ManagedInstanceScheduling

Returns a new instance of ManagedInstanceScheduling.



42617
42618
42619
# File 'lib/google/apis/compute_alpha/classes.rb', line 42617

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#graceful_shutdown_timestampString

Output only. The timestamp at which the underlying instance will be triggered for graceful shutdown if it is configured. This is in RFC3339 text format. Corresponds to the JSON property gracefulShutdownTimestamp

Returns:

  • (String)


42607
42608
42609
# File 'lib/google/apis/compute_alpha/classes.rb', line 42607

def graceful_shutdown_timestamp
  @graceful_shutdown_timestamp
end

#termination_timestampString

Output only. The timestamp at which the managed instance will be terminated. This is in RFC3339 text format. Corresponds to the JSON property terminationTimestamp

Returns:

  • (String)


42615
42616
42617
# File 'lib/google/apis/compute_alpha/classes.rb', line 42615

def termination_timestamp
  @termination_timestamp
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



42622
42623
42624
42625
# File 'lib/google/apis/compute_alpha/classes.rb', line 42622

def update!(**args)
  @graceful_shutdown_timestamp = args[:graceful_shutdown_timestamp] if args.key?(:graceful_shutdown_timestamp)
  @termination_timestamp = args[:termination_timestamp] if args.key?(:termination_timestamp)
end