Class: Google::Apis::ComputeAlpha::ManagedInstanceScheduling

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ManagedInstanceScheduling

Returns a new instance of ManagedInstanceScheduling.



42338
42339
42340
# File 'lib/google/apis/compute_alpha/classes.rb', line 42338

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#graceful_shutdown_timestampString

Output only. The timestamp at which the underlying instance will be triggered for graceful shutdown if it is configured. This is in RFC3339 text format. Corresponds to the JSON property gracefulShutdownTimestamp

Returns:

  • (String)


42328
42329
42330
# File 'lib/google/apis/compute_alpha/classes.rb', line 42328

def graceful_shutdown_timestamp
  @graceful_shutdown_timestamp
end

#termination_timestampString

Output only. The timestamp at which the managed instance will be terminated. This is in RFC3339 text format. Corresponds to the JSON property terminationTimestamp

Returns:

  • (String)


42336
42337
42338
# File 'lib/google/apis/compute_alpha/classes.rb', line 42336

def termination_timestamp
  @termination_timestamp
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



42343
42344
42345
42346
# File 'lib/google/apis/compute_alpha/classes.rb', line 42343

def update!(**args)
  @graceful_shutdown_timestamp = args[:graceful_shutdown_timestamp] if args.key?(:graceful_shutdown_timestamp)
  @termination_timestamp = args[:termination_timestamp] if args.key?(:termination_timestamp)
end