Class: Google::Apis::ComputeAlpha::ManagedInstanceShutdownDetails
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::ManagedInstanceShutdownDetails
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#max_duration ⇒ Google::Apis::ComputeAlpha::Duration
A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution.
-
#request_timestamp ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ManagedInstanceShutdownDetails
constructor
A new instance of ManagedInstanceShutdownDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ManagedInstanceShutdownDetails
Returns a new instance of ManagedInstanceShutdownDetails.
42872 42873 42874 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 42872 def initialize(**args) update!(**args) end |
Instance Attribute Details
#max_duration ⇒ Google::Apis::ComputeAlpha::Duration
A Duration represents a fixed-length span of time represented
as a count of seconds and fractions of seconds at nanosecond
resolution. It is independent of any calendar and concepts like "day"
or "month". Range is approximately 10,000 years.
Corresponds to the JSON property maxDuration
42862 42863 42864 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 42862 def max_duration @max_duration end |
#request_timestamp ⇒ String
Output only. Past timestamp indicating the beginning of PENDING_STOP state
of
instance in RFC3339
text format.
Corresponds to the JSON property requestTimestamp
42870 42871 42872 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 42870 def @request_timestamp end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
42877 42878 42879 42880 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 42877 def update!(**args) @max_duration = args[:max_duration] if args.key?(:max_duration) @request_timestamp = args[:request_timestamp] if args.key?(:request_timestamp) end |