Class: Google::Apis::ComputeAlpha::ManagedInstanceShutdownDetails
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::ManagedInstanceShutdownDetails
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#max_duration ⇒ Google::Apis::ComputeAlpha::Duration
A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution.
-
#request_timestamp ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ManagedInstanceShutdownDetails
constructor
A new instance of ManagedInstanceShutdownDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ManagedInstanceShutdownDetails
Returns a new instance of ManagedInstanceShutdownDetails.
42369 42370 42371 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 42369 def initialize(**args) update!(**args) end |
Instance Attribute Details
#max_duration ⇒ Google::Apis::ComputeAlpha::Duration
A Duration represents a fixed-length span of time represented
as a count of seconds and fractions of seconds at nanosecond
resolution. It is independent of any calendar and concepts like "day"
or "month". Range is approximately 10,000 years.
Corresponds to the JSON property maxDuration
42359 42360 42361 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 42359 def max_duration @max_duration end |
#request_timestamp ⇒ String
Output only. Past timestamp indicating the beginning of PENDING_STOP state
of
instance in RFC3339
text format.
Corresponds to the JSON property requestTimestamp
42367 42368 42369 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 42367 def @request_timestamp end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
42374 42375 42376 42377 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 42374 def update!(**args) @max_duration = args[:max_duration] if args.key?(:max_duration) @request_timestamp = args[:request_timestamp] if args.key?(:request_timestamp) end |