Class: Google::Apis::ComputeAlpha::ManagedInstanceShutdownDetails

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ManagedInstanceShutdownDetails

Returns a new instance of ManagedInstanceShutdownDetails.



41352
41353
41354
# File 'lib/google/apis/compute_alpha/classes.rb', line 41352

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#max_durationGoogle::Apis::ComputeAlpha::Duration

A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution. It is independent of any calendar and concepts like "day" or "month". Range is approximately 10,000 years. Corresponds to the JSON property maxDuration



41343
41344
41345
# File 'lib/google/apis/compute_alpha/classes.rb', line 41343

def max_duration
  @max_duration
end

#request_timestampString

Output only. [Output Only] Past timestamp indicating the beginning of PENDING_STOP state of instance in RFC3339 text format. Corresponds to the JSON property requestTimestamp

Returns:

  • (String)


41350
41351
41352
# File 'lib/google/apis/compute_alpha/classes.rb', line 41350

def request_timestamp
  @request_timestamp
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



41357
41358
41359
41360
# File 'lib/google/apis/compute_alpha/classes.rb', line 41357

def update!(**args)
  @max_duration = args[:max_duration] if args.key?(:max_duration)
  @request_timestamp = args[:request_timestamp] if args.key?(:request_timestamp)
end