Class: Google::Apis::ComputeAlpha::ManagedRuleset

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Represents a ManagedRuleset resource. Managed internally by Cloud Armor CLH for Managed Rules features. Customers can only view these resources to modify their Security Policies. For more information, see https://cloud.google.com/armor/docs/.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ManagedRuleset

Returns a new instance of ManagedRuleset.



42466
42467
42468
# File 'lib/google/apis/compute_alpha/classes.rb', line 42466

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#change_logString

Output only. [Output Only] The change log for this managed ruleset. Corresponds to the JSON property changeLog

Returns:

  • (String)


42418
42419
42420
# File 'lib/google/apis/compute_alpha/classes.rb', line 42418

def change_log
  @change_log
end

#creation_timestampString

Output only. [Output Only] Creation timestamp in RFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


42423
42424
42425
# File 'lib/google/apis/compute_alpha/classes.rb', line 42423

def creation_timestamp
  @creation_timestamp
end

#descriptionString

[Output Only] An optional description of this resource. Corresponds to the JSON property description

Returns:

  • (String)


42428
42429
42430
# File 'lib/google/apis/compute_alpha/classes.rb', line 42428

def description
  @description
end

#idFixnum

Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


42435
42436
42437
# File 'lib/google/apis/compute_alpha/classes.rb', line 42435

def id
  @id
end

#nameString

Name of the resource. Generated internally when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


42446
42447
42448
# File 'lib/google/apis/compute_alpha/classes.rb', line 42446

def name
  @name
end

#rule_idsArray<String>

Output only. [Output Only] The list of managed rule IDs that are included in this managed ruleset. Corresponds to the JSON property ruleIds

Returns:

  • (Array<String>)


42452
42453
42454
# File 'lib/google/apis/compute_alpha/classes.rb', line 42452

def rule_ids
  @rule_ids
end

#ruleset_idString

Output only. [Output Only] The managed ruleset identifier that can be configured in Security Policy rules. Corresponds to the JSON property rulesetId

Returns:

  • (String)


42459
42460
42461
# File 'lib/google/apis/compute_alpha/classes.rb', line 42459

def ruleset_id
  @ruleset_id
end

Output only. [Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


42464
42465
42466
# File 'lib/google/apis/compute_alpha/classes.rb', line 42464

def self_link
  @self_link
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



42471
42472
42473
42474
42475
42476
42477
42478
42479
42480
# File 'lib/google/apis/compute_alpha/classes.rb', line 42471

def update!(**args)
  @change_log = args[:change_log] if args.key?(:change_log)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @id = args[:id] if args.key?(:id)
  @name = args[:name] if args.key?(:name)
  @rule_ids = args[:rule_ids] if args.key?(:rule_ids)
  @ruleset_id = args[:ruleset_id] if args.key?(:ruleset_id)
  @self_link = args[:self_link] if args.key?(:self_link)
end