Class: Google::Apis::ComputeAlpha::ManagementInterface

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Represents a managed interface for an accelerator domain. It defines the network endpoint and authentication configuration needed to access specific management services like NMX-C or gNMI.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ManagementInterface

Returns a new instance of ManagementInterface.



42921
42922
42923
# File 'lib/google/apis/compute_alpha/classes.rb', line 42921

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#authentication_configGoogle::Apis::ComputeAlpha::AuthenticationConfig

Authentication configuration for the management interface, typically using mTLS. Corresponds to the JSON property authenticationConfig



42879
42880
42881
# File 'lib/google/apis/compute_alpha/classes.rb', line 42879

def authentication_config
  @authentication_config
end

#ipv4_addressString

The IPv4 internal IP address assigned to this management interface endpoint. This address will be used by the customer to route traffic to the management interface. Corresponds to the JSON property ipv4Address

Returns:

  • (String)


42886
42887
42888
# File 'lib/google/apis/compute_alpha/classes.rb', line 42886

def ipv4_address
  @ipv4_address
end

#ipv6_addressString

The IPv6 internal IP address assigned to this management interface endpoint. This address will be used by the customer to route traffic to the management interface if IPv6 is supported and configured. Corresponds to the JSON property ipv6Address

Returns:

  • (String)


42893
42894
42895
# File 'lib/google/apis/compute_alpha/classes.rb', line 42893

def ipv6_address
  @ipv6_address
end

#networkString

The URL of the VPC network to which the management interface endpoint is attached. The customer must ensure that this network is correctly configured for routing to the accelerator domain. Corresponds to the JSON property network

Returns:

  • (String)


42900
42901
42902
# File 'lib/google/apis/compute_alpha/classes.rb', line 42900

def network
  @network
end

#stateString

Corresponds to the JSON property state

Returns:

  • (String)


42905
42906
42907
# File 'lib/google/apis/compute_alpha/classes.rb', line 42905

def state
  @state
end

#subnetworkString

The URL of the subnetwork from which to assign the IP address for the endpoint. The subnetwork must belong to the specified network and have available IP addresses. Corresponds to the JSON property subnetwork

Returns:

  • (String)


42912
42913
42914
# File 'lib/google/apis/compute_alpha/classes.rb', line 42912

def subnetwork
  @subnetwork
end

#typeString

Required. The type of management service this interface provides. Supported types include NMX-C for partition management, gNMI for switch monitoring, and TPU slice management. Corresponds to the JSON property type

Returns:

  • (String)


42919
42920
42921
# File 'lib/google/apis/compute_alpha/classes.rb', line 42919

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



42926
42927
42928
42929
42930
42931
42932
42933
42934
# File 'lib/google/apis/compute_alpha/classes.rb', line 42926

def update!(**args)
  @authentication_config = args[:authentication_config] if args.key?(:authentication_config)
  @ipv4_address = args[:ipv4_address] if args.key?(:ipv4_address)
  @ipv6_address = args[:ipv6_address] if args.key?(:ipv6_address)
  @network = args[:network] if args.key?(:network)
  @state = args[:state] if args.key?(:state)
  @subnetwork = args[:subnetwork] if args.key?(:subnetwork)
  @type = args[:type] if args.key?(:type)
end