Class: Google::Apis::ComputeAlpha::Metadata
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::Metadata
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
A metadata key/value entry.
Defined Under Namespace
Classes: Item
Instance Attribute Summary collapse
-
#fingerprint ⇒ String
Specifies a fingerprint for this request, which is essentially a hash of the metadata's contents and used for optimistic locking.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::Metadata::Item>
Array of key/value pairs.
-
#kind ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Metadata
constructor
A new instance of Metadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Metadata
Returns a new instance of Metadata.
41429 41430 41431 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 41429 def initialize(**args) update!(**args) end |
Instance Attribute Details
#fingerprint ⇒ String
Specifies a fingerprint for this request, which is essentially a hash of
the metadata's contents and used for optimistic locking. The
fingerprint is initially generated by Compute Engine and changes after
every request to modify or update metadata. You must always provide an
up-to-date fingerprint hash in order to update or change metadata,
otherwise the request will fail with error412 conditionNotMet.
To see the latest fingerprint, make a get() request to
retrieve the resource.
Corresponds to the JSON property fingerprint
NOTE: Values are automatically base64 encoded/decoded in the client library.
41415 41416 41417 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 41415 def fingerprint @fingerprint end |
#items ⇒ Array<Google::Apis::ComputeAlpha::Metadata::Item>
Array of key/value pairs. The total size of all keys and values must be
less than 512 KB.
Corresponds to the JSON property items
41421 41422 41423 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 41421 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Always compute#metadata
for metadata.
Corresponds to the JSON property kind
41427 41428 41429 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 41427 def kind @kind end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
41434 41435 41436 41437 41438 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 41434 def update!(**args) @fingerprint = args[:fingerprint] if args.key?(:fingerprint) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) end |