Class: Google::Apis::ComputeAlpha::Metadata

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

A metadata key/value entry.

Defined Under Namespace

Classes: Item

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Metadata

Returns a new instance of Metadata.



40494
40495
40496
# File 'lib/google/apis/compute_alpha/classes.rb', line 40494

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#fingerprintString

Specifies a fingerprint for this request, which is essentially a hash of the metadata's contents and used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update metadata. You must always provide an up-to-date fingerprint hash in order to update or change metadata, otherwise the request will fail with error412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve the resource. Corresponds to the JSON property fingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


40480
40481
40482
# File 'lib/google/apis/compute_alpha/classes.rb', line 40480

def fingerprint
  @fingerprint
end

#itemsArray<Google::Apis::ComputeAlpha::Metadata::Item>

Array of key/value pairs. The total size of all keys and values must be less than 512 KB. Corresponds to the JSON property items



40486
40487
40488
# File 'lib/google/apis/compute_alpha/classes.rb', line 40486

def items
  @items
end

#kindString

Output only. [Output Only] Type of the resource. Always compute#metadata for metadata. Corresponds to the JSON property kind

Returns:

  • (String)


40492
40493
40494
# File 'lib/google/apis/compute_alpha/classes.rb', line 40492

def kind
  @kind
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



40499
40500
40501
40502
40503
# File 'lib/google/apis/compute_alpha/classes.rb', line 40499

def update!(**args)
  @fingerprint = args[:fingerprint] if args.key?(:fingerprint)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
end