Class: Google::Apis::ComputeAlpha::Metadata::Item
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::Metadata::Item
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Metadata
Instance Attribute Summary collapse
-
#key ⇒ String
Key for the metadata entry.
-
#value ⇒ String
Value for the metadata entry.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Item
constructor
A new instance of Item.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Item
Returns a new instance of Item.
42719 42720 42721 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 42719 def initialize(**args) update!(**args) end |
Instance Attribute Details
#key ⇒ String
Key for the metadata entry. Keys must conform to the following
regexp: [a-zA-Z0-9-_]+, and be less than 128 bytes in length.
This is reflected as part of a URL in the metadata server. Additionally, to
avoid ambiguity, keys must not conflict with any other metadata keys
for the project.
Corresponds to the JSON property key
42709 42710 42711 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 42709 def key @key end |
#value ⇒ String
Value for the metadata entry. These are free-form strings, and only
have meaning as interpreted by the image running in the instance. The
only restriction placed on values is that their size must be less than
or equal to 262144 bytes (256 KiB).
Corresponds to the JSON property value
42717 42718 42719 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 42717 def value @value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
42724 42725 42726 42727 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 42724 def update!(**args) @key = args[:key] if args.key?(:key) @value = args[:value] if args.key?(:value) end |