Class: Google::Apis::ComputeAlpha::MetadataFilterLabelMatch

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

MetadataFilter label name value pairs that are expected to match corresponding labels presented as metadata to the load balancer.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MetadataFilterLabelMatch

Returns a new instance of MetadataFilterLabelMatch.



41774
41775
41776
# File 'lib/google/apis/compute_alpha/classes.rb', line 41774

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nameString

Name of metadata label. The name can have a maximum length of 1024 characters and must be at least 1 character long. Corresponds to the JSON property name

Returns:

  • (String)


41766
41767
41768
# File 'lib/google/apis/compute_alpha/classes.rb', line 41766

def name
  @name
end

#valueString

The value of the label must match the specified value. value can have a maximum length of 1024 characters. Corresponds to the JSON property value

Returns:

  • (String)


41772
41773
41774
# File 'lib/google/apis/compute_alpha/classes.rb', line 41772

def value
  @value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



41779
41780
41781
41782
# File 'lib/google/apis/compute_alpha/classes.rb', line 41779

def update!(**args)
  @name = args[:name] if args.key?(:name)
  @value = args[:value] if args.key?(:value)
end