Class: Google::Apis::ComputeAlpha::Money
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::Money
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Represents an amount of money with its currency type.
Instance Attribute Summary collapse
-
#currency_code ⇒ String
The three-letter currency code defined in ISO 4217.
-
#nanos ⇒ Fixnum
Number of nano (10^-9) units of the amount.
-
#units ⇒ Fixnum
The whole units of the amount.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Money
constructor
A new instance of Money.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Money
Returns a new instance of Money.
41810 41811 41812 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 41810 def initialize(**args) update!(**args) end |
Instance Attribute Details
#currency_code ⇒ String
The three-letter currency code defined in ISO 4217.
Corresponds to the JSON property currencyCode
41792 41793 41794 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 41792 def currency_code @currency_code end |
#nanos ⇒ Fixnum
Number of nano (10^-9) units of the amount.
The value must be between -999,999,999 and +999,999,999 inclusive.
If units is positive, nanos must be positive or zero.
If units is zero, nanos can be positive, zero, or negative.
If units is negative, nanos must be negative or zero.
For example $-1.75 is represented as units=-1 and nanos=-750,000,000.
Corresponds to the JSON property nanos
41802 41803 41804 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 41802 def nanos @nanos end |
#units ⇒ Fixnum
The whole units of the amount.
For example if currencyCode is "USD", then 1 unit is one US dollar.
Corresponds to the JSON property units
41808 41809 41810 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 41808 def units @units end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
41815 41816 41817 41818 41819 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 41815 def update!(**args) @currency_code = args[:currency_code] if args.key?(:currency_code) @nanos = args[:nanos] if args.key?(:nanos) @units = args[:units] if args.key?(:units) end |