Class: Google::Apis::ComputeAlpha::MultiMig
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::MultiMig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Multi-MIG represents a group of managed instance groups.
Instance Attribute Summary collapse
-
#creation_timestamp ⇒ String
Output only.
-
#description ⇒ String
An optional description of this resource.
-
#id ⇒ Fixnum
Output only.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
The name of the multi-MIG.
-
#region ⇒ String
Output only.
-
#resource_policies ⇒ Google::Apis::ComputeAlpha::MultiMigResourcePolicies
Resource policies message for a multi-MIG.
-
#self_link ⇒ String
Output only.
-
#status ⇒ Google::Apis::ComputeAlpha::MultiMigStatus
Corresponds to the JSON property
status.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MultiMig
constructor
A new instance of MultiMig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MultiMig
Returns a new instance of MultiMig.
41902 41903 41904 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 41902 def initialize(**args) update!(**args) end |
Instance Attribute Details
#creation_timestamp ⇒ String
Output only. [Output only] The creation timestamp of this multi-MIG in RFC3339
text format.
Corresponds to the JSON property creationTimestamp
41847 41848 41849 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 41847 def @creation_timestamp end |
#description ⇒ String
An optional description of this resource.
Corresponds to the JSON property description
41852 41853 41854 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 41852 def description @description end |
#id ⇒ Fixnum
Output only. [Output only] The unique identifier for this resource type. The
server
generates this identifier.
Corresponds to the JSON property id
41859 41860 41861 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 41859 def id @id end |
#kind ⇒ String
Output only. [Output only] Type of the resource. Alwayscompute#multiMig for
multi-MIGs.
Corresponds to the JSON property kind
41865 41866 41867 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 41865 def kind @kind end |
#name ⇒ String
The name of the multi-MIG.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character
must be a lowercase letter, and all following characters must be a dash,
lowercase letter, or digit, except the last character, which cannot be a
dash.
Corresponds to the JSON property name
41876 41877 41878 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 41876 def name @name end |
#region ⇒ String
Output only. [Output only] The URL of the region where the resource resides.
You must
specify this field as part of the HTTP request URL. You cannot set the
region as a field in the request body.
Corresponds to the JSON property region
41884 41885 41886 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 41884 def region @region end |
#resource_policies ⇒ Google::Apis::ComputeAlpha::MultiMigResourcePolicies
Resource policies message for a multi-MIG. Specifies the workload policy
configuration of the multi-MIG.
Corresponds to the JSON property resourcePolicies
41890 41891 41892 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 41890 def resource_policies @resource_policies end |
#self_link ⇒ String
Output only. [Output only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
41895 41896 41897 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 41895 def self_link @self_link end |
#status ⇒ Google::Apis::ComputeAlpha::MultiMigStatus
Corresponds to the JSON property status
41900 41901 41902 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 41900 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
41907 41908 41909 41910 41911 41912 41913 41914 41915 41916 41917 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 41907 def update!(**args) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @region = args[:region] if args.key?(:region) @resource_policies = args[:resource_policies] if args.key?(:resource_policies) @self_link = args[:self_link] if args.key?(:self_link) @status = args[:status] if args.key?(:status) end |