Class: Google::Apis::ComputeAlpha::MultiMig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Multi-MIG represents a group of managed instance groups.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MultiMig

Returns a new instance of MultiMig.



41679
41680
41681
# File 'lib/google/apis/compute_alpha/classes.rb', line 41679

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#creation_timestampString

Output only. [Output only] The creation timestamp of this multi-MIG in RFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


41624
41625
41626
# File 'lib/google/apis/compute_alpha/classes.rb', line 41624

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Corresponds to the JSON property description

Returns:

  • (String)


41629
41630
41631
# File 'lib/google/apis/compute_alpha/classes.rb', line 41629

def description
  @description
end

#idFixnum

Output only. [Output only] The unique identifier for this resource type. The server generates this identifier. Corresponds to the JSON property id

Returns:

  • (Fixnum)


41636
41637
41638
# File 'lib/google/apis/compute_alpha/classes.rb', line 41636

def id
  @id
end

#kindString

Output only. [Output only] Type of the resource. Alwayscompute#multiMig for multi-MIGs. Corresponds to the JSON property kind

Returns:

  • (String)


41642
41643
41644
# File 'lib/google/apis/compute_alpha/classes.rb', line 41642

def kind
  @kind
end

#nameString

The name of the multi-MIG. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


41653
41654
41655
# File 'lib/google/apis/compute_alpha/classes.rb', line 41653

def name
  @name
end

#regionString

Output only. [Output only] The URL of the region where the resource resides. You must specify this field as part of the HTTP request URL. You cannot set the region as a field in the request body. Corresponds to the JSON property region

Returns:

  • (String)


41661
41662
41663
# File 'lib/google/apis/compute_alpha/classes.rb', line 41661

def region
  @region
end

#resource_policiesGoogle::Apis::ComputeAlpha::MultiMigResourcePolicies

Resource policies message for a multi-MIG. Specifies the workload policy configuration of the multi-MIG. Corresponds to the JSON property resourcePolicies



41667
41668
41669
# File 'lib/google/apis/compute_alpha/classes.rb', line 41667

def resource_policies
  @resource_policies
end

Output only. [Output only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


41672
41673
41674
# File 'lib/google/apis/compute_alpha/classes.rb', line 41672

def self_link
  @self_link
end

#statusGoogle::Apis::ComputeAlpha::MultiMigStatus

Corresponds to the JSON property status



41677
41678
41679
# File 'lib/google/apis/compute_alpha/classes.rb', line 41677

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



41684
41685
41686
41687
41688
41689
41690
41691
41692
41693
41694
# File 'lib/google/apis/compute_alpha/classes.rb', line 41684

def update!(**args)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @region = args[:region] if args.key?(:region)
  @resource_policies = args[:resource_policies] if args.key?(:resource_policies)
  @self_link = args[:self_link] if args.key?(:self_link)
  @status = args[:status] if args.key?(:status)
end