Class: Google::Apis::ComputeAlpha::MultiMigMemberList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::MultiMigMemberList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::MultiMigMember>
A list of multi-MIG member resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::MultiMigMemberList::Warning
Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MultiMigMemberList
constructor
A new instance of MultiMigMemberList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MultiMigMemberList
Returns a new instance of MultiMigMemberList.
43334 43335 43336 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 43334 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
43301 43302 43303 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 43301 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::MultiMigMember>
A list of multi-MIG member resources.
Corresponds to the JSON property items
43306 43307 43308 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 43306 def items @items end |
#kind ⇒ String
Output only. Type of the resource. Alwayscompute#multiMigMember for a list of
multi-MIG members.
Corresponds to the JSON property kind
43312 43313 43314 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 43312 def kind @kind end |
#next_page_token ⇒ String
This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
43322 43323 43324 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 43322 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
43327 43328 43329 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 43327 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::MultiMigMemberList::Warning
Informational warning message.
Corresponds to the JSON property warning
43332 43333 43334 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 43332 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
43339 43340 43341 43342 43343 43344 43345 43346 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 43339 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |