Class: Google::Apis::ComputeAlpha::MultiMigMemberList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::MultiMigMemberList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::MultiMigMember>
A list of multi-MIG member resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::MultiMigMemberList::Warning
Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MultiMigMemberList
constructor
A new instance of MultiMigMemberList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MultiMigMemberList
Returns a new instance of MultiMigMemberList.
43055 43056 43057 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 43055 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
43022 43023 43024 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 43022 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::MultiMigMember>
A list of multi-MIG member resources.
Corresponds to the JSON property items
43027 43028 43029 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 43027 def items @items end |
#kind ⇒ String
Output only. Type of the resource. Alwayscompute#multiMigMember for a list of
multi-MIG members.
Corresponds to the JSON property kind
43033 43034 43035 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 43033 def kind @kind end |
#next_page_token ⇒ String
This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
43043 43044 43045 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 43043 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
43048 43049 43050 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 43048 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::MultiMigMemberList::Warning
Informational warning message.
Corresponds to the JSON property warning
43053 43054 43055 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 43053 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
43060 43061 43062 43063 43064 43065 43066 43067 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 43060 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |