Class: Google::Apis::ComputeAlpha::MultiMigMemberList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MultiMigMemberList

Returns a new instance of MultiMigMemberList.



42003
42004
42005
# File 'lib/google/apis/compute_alpha/classes.rb', line 42003

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


41970
41971
41972
# File 'lib/google/apis/compute_alpha/classes.rb', line 41970

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::MultiMigMember>

A list of multi-MIG member resources. Corresponds to the JSON property items



41975
41976
41977
# File 'lib/google/apis/compute_alpha/classes.rb', line 41975

def items
  @items
end

#kindString

Output only. Type of the resource. Alwayscompute#multiMigMember for a list of multi-MIG members. Corresponds to the JSON property kind

Returns:

  • (String)


41981
41982
41983
# File 'lib/google/apis/compute_alpha/classes.rb', line 41981

def kind
  @kind
end

#next_page_tokenString

This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


41991
41992
41993
# File 'lib/google/apis/compute_alpha/classes.rb', line 41991

def next_page_token
  @next_page_token
end

Output only. [Output only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


41996
41997
41998
# File 'lib/google/apis/compute_alpha/classes.rb', line 41996

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::MultiMigMemberList::Warning

Informational warning message. Corresponds to the JSON property warning



42001
42002
42003
# File 'lib/google/apis/compute_alpha/classes.rb', line 42001

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



42008
42009
42010
42011
42012
42013
42014
42015
# File 'lib/google/apis/compute_alpha/classes.rb', line 42008

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end