Class: Google::Apis::ComputeAlpha::MultiMigMemberList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MultiMigMemberList

Returns a new instance of MultiMigMemberList.



41612
41613
41614
# File 'lib/google/apis/compute_alpha/classes.rb', line 41612

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


41579
41580
41581
# File 'lib/google/apis/compute_alpha/classes.rb', line 41579

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::MultiMigMember>

A list of multi-MIG member resources. Corresponds to the JSON property items



41584
41585
41586
# File 'lib/google/apis/compute_alpha/classes.rb', line 41584

def items
  @items
end

#kindString

Output only. Type of the resource. Alwayscompute#multiMigMember for a list of multi-MIG members. Corresponds to the JSON property kind

Returns:

  • (String)


41590
41591
41592
# File 'lib/google/apis/compute_alpha/classes.rb', line 41590

def kind
  @kind
end

#next_page_tokenString

This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


41600
41601
41602
# File 'lib/google/apis/compute_alpha/classes.rb', line 41600

def next_page_token
  @next_page_token
end

Output only. [Output only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


41605
41606
41607
# File 'lib/google/apis/compute_alpha/classes.rb', line 41605

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::MultiMigMemberList::Warning

Informational warning message. Corresponds to the JSON property warning



41610
41611
41612
# File 'lib/google/apis/compute_alpha/classes.rb', line 41610

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



41617
41618
41619
41620
41621
41622
41623
41624
# File 'lib/google/apis/compute_alpha/classes.rb', line 41617

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end