Class: Google::Apis::ComputeAlpha::MultiMigsList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MultiMigsList

Returns a new instance of MultiMigsList.



43443
43444
43445
# File 'lib/google/apis/compute_alpha/classes.rb', line 43443

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


43412
43413
43414
# File 'lib/google/apis/compute_alpha/classes.rb', line 43412

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::MultiMig>

A list of multi-MIGs in the specified project and region. Corresponds to the JSON property items



43417
43418
43419
# File 'lib/google/apis/compute_alpha/classes.rb', line 43417

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


43422
43423
43424
# File 'lib/google/apis/compute_alpha/classes.rb', line 43422

def kind
  @kind
end

#next_page_tokenString

This token allows you to get the next page of results formaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


43431
43432
43433
# File 'lib/google/apis/compute_alpha/classes.rb', line 43431

def next_page_token
  @next_page_token
end

Output only. [Output only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


43436
43437
43438
# File 'lib/google/apis/compute_alpha/classes.rb', line 43436

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::MultiMigsList::Warning

Informational warning message. Corresponds to the JSON property warning



43441
43442
43443
# File 'lib/google/apis/compute_alpha/classes.rb', line 43441

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



43448
43449
43450
43451
43452
43453
43454
43455
# File 'lib/google/apis/compute_alpha/classes.rb', line 43448

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end