Class: Google::Apis::ComputeAlpha::MultiMigsList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::MultiMigsList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::MultiMig>
A list of multi-MIGs in the specified project and region.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
This token allows you to get the next page of results formaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::MultiMigsList::Warning
Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MultiMigsList
constructor
A new instance of MultiMigsList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MultiMigsList
Returns a new instance of MultiMigsList.
42406 42407 42408 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 42406 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
42375 42376 42377 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 42375 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::MultiMig>
A list of multi-MIGs in the specified project and region.
Corresponds to the JSON property items
42380 42381 42382 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 42380 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
42385 42386 42387 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 42385 def kind @kind end |
#next_page_token ⇒ String
This token allows you to get the next page of results formaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
42394 42395 42396 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 42394 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
42399 42400 42401 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 42399 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::MultiMigsList::Warning
Informational warning message.
Corresponds to the JSON property warning
42404 42405 42406 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 42404 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
42411 42412 42413 42414 42415 42416 42417 42418 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 42411 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |