Class: Google::Apis::ComputeAlpha::MultiMigsList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::MultiMigsList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::MultiMig>
A list of multi-MIGs in the specified project and region.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
This token allows you to get the next page of results formaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::MultiMigsList::Warning
Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MultiMigsList
constructor
A new instance of MultiMigsList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MultiMigsList
Returns a new instance of MultiMigsList.
42389 42390 42391 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 42389 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
42358 42359 42360 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 42358 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::MultiMig>
A list of multi-MIGs in the specified project and region.
Corresponds to the JSON property items
42363 42364 42365 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 42363 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
42368 42369 42370 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 42368 def kind @kind end |
#next_page_token ⇒ String
This token allows you to get the next page of results formaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
42377 42378 42379 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 42377 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
42382 42383 42384 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 42382 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::MultiMigsList::Warning
Informational warning message.
Corresponds to the JSON property warning
42387 42388 42389 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 42387 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
42394 42395 42396 42397 42398 42399 42400 42401 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 42394 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |