Class: Google::Apis::ComputeAlpha::MultiMigsList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MultiMigsList

Returns a new instance of MultiMigsList.



42173
42174
42175
# File 'lib/google/apis/compute_alpha/classes.rb', line 42173

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


42142
42143
42144
# File 'lib/google/apis/compute_alpha/classes.rb', line 42142

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::MultiMig>

A list of multi-MIGs in the specified project and region. Corresponds to the JSON property items



42147
42148
42149
# File 'lib/google/apis/compute_alpha/classes.rb', line 42147

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


42152
42153
42154
# File 'lib/google/apis/compute_alpha/classes.rb', line 42152

def kind
  @kind
end

#next_page_tokenString

This token allows you to get the next page of results formaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


42161
42162
42163
# File 'lib/google/apis/compute_alpha/classes.rb', line 42161

def next_page_token
  @next_page_token
end

Output only. [Output only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


42166
42167
42168
# File 'lib/google/apis/compute_alpha/classes.rb', line 42166

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::MultiMigsList::Warning

Informational warning message. Corresponds to the JSON property warning



42171
42172
42173
# File 'lib/google/apis/compute_alpha/classes.rb', line 42171

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



42178
42179
42180
42181
42182
42183
42184
42185
# File 'lib/google/apis/compute_alpha/classes.rb', line 42178

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end