Class: Google::Apis::ComputeAlpha::MultiMigsList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::MultiMigsList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::MultiMig>
A list of multi-MIGs in the specified project and region.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
This token allows you to get the next page of results formaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::MultiMigsList::Warning
Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MultiMigsList
constructor
A new instance of MultiMigsList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MultiMigsList
Returns a new instance of MultiMigsList.
41998 41999 42000 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 41998 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
41967 41968 41969 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 41967 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::MultiMig>
A list of multi-MIGs in the specified project and region.
Corresponds to the JSON property items
41972 41973 41974 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 41972 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
41977 41978 41979 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 41977 def kind @kind end |
#next_page_token ⇒ String
This token allows you to get the next page of results formaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
41986 41987 41988 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 41986 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
41991 41992 41993 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 41991 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::MultiMigsList::Warning
Informational warning message.
Corresponds to the JSON property warning
41996 41997 41998 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 41996 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
42003 42004 42005 42006 42007 42008 42009 42010 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 42003 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |