Class: Google::Apis::ComputeAlpha::MultiMigsList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MultiMigsList

Returns a new instance of MultiMigsList.



41248
41249
41250
# File 'lib/google/apis/compute_alpha/classes.rb', line 41248

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


41217
41218
41219
# File 'lib/google/apis/compute_alpha/classes.rb', line 41217

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::MultiMig>

A list of multi-MIGs in the specified project and region. Corresponds to the JSON property items



41222
41223
41224
# File 'lib/google/apis/compute_alpha/classes.rb', line 41222

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


41227
41228
41229
# File 'lib/google/apis/compute_alpha/classes.rb', line 41227

def kind
  @kind
end

#next_page_tokenString

This token allows you to get the next page of results formaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


41236
41237
41238
# File 'lib/google/apis/compute_alpha/classes.rb', line 41236

def next_page_token
  @next_page_token
end

Output only. [Output only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


41241
41242
41243
# File 'lib/google/apis/compute_alpha/classes.rb', line 41241

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::MultiMigsList::Warning

Informational warning message. Corresponds to the JSON property warning



41246
41247
41248
# File 'lib/google/apis/compute_alpha/classes.rb', line 41246

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



41253
41254
41255
41256
41257
41258
41259
41260
# File 'lib/google/apis/compute_alpha/classes.rb', line 41253

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end