Class: Google::Apis::ComputeAlpha::NamedSet
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::NamedSet
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#description ⇒ String
An optional description of named set.
-
#elements ⇒ Array<Google::Apis::ComputeAlpha::Expr>
CEL expressions that are comparable to constructs of this set's type (see Policy Language).
-
#fingerprint ⇒ String
A fingerprint for the Named Set being applied to this Router, which is essentially a hash of the Named Set used for optimistic locking.
-
#name ⇒ String
This set's name, which must be a resource ID segment and unique within all named sets owned by the Router.
-
#type ⇒ String
This named set's type Corresponds to the JSON property
type.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NamedSet
constructor
A new instance of NamedSet.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NamedSet
Returns a new instance of NamedSet.
43617 43618 43619 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 43617 def initialize(**args) update!(**args) end |
Instance Attribute Details
#description ⇒ String
An optional description of named set.
Corresponds to the JSON property description
43585 43586 43587 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 43585 def description @description end |
#elements ⇒ Array<Google::Apis::ComputeAlpha::Expr>
CEL expressions that are comparable to constructs of this set's type
(see Policy Language).
Corresponds to the JSON property elements
43591 43592 43593 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 43591 def elements @elements end |
#fingerprint ⇒ String
A fingerprint for the Named Set being applied to this Router, which is
essentially a hash of the Named Set used for optimistic locking.
The fingerprint is initially generated by Compute Engine and changes
after every request to modify or update the Named Set. You must always
provide an up-to-date fingerprint hash in order to update or change
labels.
To see the latest fingerprint, make a getNamedSet() request
to retrieve a Named Set.
Corresponds to the JSON property fingerprint
NOTE: Values are automatically base64 encoded/decoded in the client library.
43604 43605 43606 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 43604 def fingerprint @fingerprint end |
#name ⇒ String
This set's name, which must be a resource ID segment and unique within all
named sets owned by the Router. Name should conform to RFC1035.
Corresponds to the JSON property name
43610 43611 43612 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 43610 def name @name end |
#type ⇒ String
This named set's type
Corresponds to the JSON property type
43615 43616 43617 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 43615 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
43622 43623 43624 43625 43626 43627 43628 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 43622 def update!(**args) @description = args[:description] if args.key?(:description) @elements = args[:elements] if args.key?(:elements) @fingerprint = args[:fingerprint] if args.key?(:fingerprint) @name = args[:name] if args.key?(:name) @type = args[:type] if args.key?(:type) end |