Class: Google::Apis::ComputeAlpha::NamedSet
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::NamedSet
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#description ⇒ String
An optional description of named set.
-
#elements ⇒ Array<Google::Apis::ComputeAlpha::Expr>
CEL expressions that are comparable to constructs of this set's type (see Policy Language).
-
#fingerprint ⇒ String
A fingerprint for the Named Set being applied to this Router, which is essentially a hash of the Named Set used for optimistic locking.
-
#name ⇒ String
This set's name, which must be a resource ID segment and unique within all named sets owned by the Router.
-
#type ⇒ String
This named set's type Corresponds to the JSON property
type.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NamedSet
constructor
A new instance of NamedSet.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NamedSet
Returns a new instance of NamedSet.
42580 42581 42582 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 42580 def initialize(**args) update!(**args) end |
Instance Attribute Details
#description ⇒ String
An optional description of named set.
Corresponds to the JSON property description
42548 42549 42550 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 42548 def description @description end |
#elements ⇒ Array<Google::Apis::ComputeAlpha::Expr>
CEL expressions that are comparable to constructs of this set's type
(see Policy Language).
Corresponds to the JSON property elements
42554 42555 42556 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 42554 def elements @elements end |
#fingerprint ⇒ String
A fingerprint for the Named Set being applied to this Router, which is
essentially a hash of the Named Set used for optimistic locking.
The fingerprint is initially generated by Compute Engine and changes
after every request to modify or update the Named Set. You must always
provide an up-to-date fingerprint hash in order to update or change
labels.
To see the latest fingerprint, make a getNamedSet() request
to retrieve a Named Set.
Corresponds to the JSON property fingerprint
NOTE: Values are automatically base64 encoded/decoded in the client library.
42567 42568 42569 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 42567 def fingerprint @fingerprint end |
#name ⇒ String
This set's name, which must be a resource ID segment and unique within all
named sets owned by the Router. Name should conform to RFC1035.
Corresponds to the JSON property name
42573 42574 42575 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 42573 def name @name end |
#type ⇒ String
This named set's type
Corresponds to the JSON property type
42578 42579 42580 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 42578 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
42585 42586 42587 42588 42589 42590 42591 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 42585 def update!(**args) @description = args[:description] if args.key?(:description) @elements = args[:elements] if args.key?(:elements) @fingerprint = args[:fingerprint] if args.key?(:fingerprint) @name = args[:name] if args.key?(:name) @type = args[:type] if args.key?(:type) end |