Class: Google::Apis::ComputeAlpha::NamedSet

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NamedSet

Returns a new instance of NamedSet.



42563
42564
42565
# File 'lib/google/apis/compute_alpha/classes.rb', line 42563

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

An optional description of named set. Corresponds to the JSON property description

Returns:

  • (String)


42531
42532
42533
# File 'lib/google/apis/compute_alpha/classes.rb', line 42531

def description
  @description
end

#elementsArray<Google::Apis::ComputeAlpha::Expr>

CEL expressions that are comparable to constructs of this set's type (see Policy Language). Corresponds to the JSON property elements



42537
42538
42539
# File 'lib/google/apis/compute_alpha/classes.rb', line 42537

def elements
  @elements
end

#fingerprintString

A fingerprint for the Named Set being applied to this Router, which is essentially a hash of the Named Set used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update the Named Set. You must always provide an up-to-date fingerprint hash in order to update or change labels. To see the latest fingerprint, make a getNamedSet() request to retrieve a Named Set. Corresponds to the JSON property fingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


42550
42551
42552
# File 'lib/google/apis/compute_alpha/classes.rb', line 42550

def fingerprint
  @fingerprint
end

#nameString

This set's name, which must be a resource ID segment and unique within all named sets owned by the Router. Name should conform to RFC1035. Corresponds to the JSON property name

Returns:

  • (String)


42556
42557
42558
# File 'lib/google/apis/compute_alpha/classes.rb', line 42556

def name
  @name
end

#typeString

This named set's type Corresponds to the JSON property type

Returns:

  • (String)


42561
42562
42563
# File 'lib/google/apis/compute_alpha/classes.rb', line 42561

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



42568
42569
42570
42571
42572
42573
42574
# File 'lib/google/apis/compute_alpha/classes.rb', line 42568

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @elements = args[:elements] if args.key?(:elements)
  @fingerprint = args[:fingerprint] if args.key?(:fingerprint)
  @name = args[:name] if args.key?(:name)
  @type = args[:type] if args.key?(:type)
end