Class: Google::Apis::ComputeAlpha::NamedSet

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NamedSet

Returns a new instance of NamedSet.



42357
42358
42359
# File 'lib/google/apis/compute_alpha/classes.rb', line 42357

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

An optional description of named set. Corresponds to the JSON property description

Returns:

  • (String)


42325
42326
42327
# File 'lib/google/apis/compute_alpha/classes.rb', line 42325

def description
  @description
end

#elementsArray<Google::Apis::ComputeAlpha::Expr>

CEL expressions that are comparable to constructs of this set's type (see Policy Language). Corresponds to the JSON property elements



42331
42332
42333
# File 'lib/google/apis/compute_alpha/classes.rb', line 42331

def elements
  @elements
end

#fingerprintString

A fingerprint for the Named Set being applied to this Router, which is essentially a hash of the Named Set used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update the Named Set. You must always provide an up-to-date fingerprint hash in order to update or change labels. To see the latest fingerprint, make a getNamedSet() request to retrieve a Named Set. Corresponds to the JSON property fingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


42344
42345
42346
# File 'lib/google/apis/compute_alpha/classes.rb', line 42344

def fingerprint
  @fingerprint
end

#nameString

This set's name, which must be a resource ID segment and unique within all named sets owned by the Router. Name should conform to RFC1035. Corresponds to the JSON property name

Returns:

  • (String)


42350
42351
42352
# File 'lib/google/apis/compute_alpha/classes.rb', line 42350

def name
  @name
end

#typeString

This named set's type Corresponds to the JSON property type

Returns:

  • (String)


42355
42356
42357
# File 'lib/google/apis/compute_alpha/classes.rb', line 42355

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



42362
42363
42364
42365
42366
42367
42368
# File 'lib/google/apis/compute_alpha/classes.rb', line 42362

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @elements = args[:elements] if args.key?(:elements)
  @fingerprint = args[:fingerprint] if args.key?(:fingerprint)
  @name = args[:name] if args.key?(:name)
  @type = args[:type] if args.key?(:type)
end