Class: Google::Apis::ComputeAlpha::NamedSet

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NamedSet

Returns a new instance of NamedSet.



41422
41423
41424
# File 'lib/google/apis/compute_alpha/classes.rb', line 41422

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

An optional description of named set. Corresponds to the JSON property description

Returns:

  • (String)


41390
41391
41392
# File 'lib/google/apis/compute_alpha/classes.rb', line 41390

def description
  @description
end

#elementsArray<Google::Apis::ComputeAlpha::Expr>

CEL expressions that are comparable to constructs of this set's type (see Policy Language). Corresponds to the JSON property elements



41396
41397
41398
# File 'lib/google/apis/compute_alpha/classes.rb', line 41396

def elements
  @elements
end

#fingerprintString

A fingerprint for the Named Set being applied to this Router, which is essentially a hash of the Named Set used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update the Named Set. You must always provide an up-to-date fingerprint hash in order to update or change labels. To see the latest fingerprint, make a getNamedSet() request to retrieve a Named Set. Corresponds to the JSON property fingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


41409
41410
41411
# File 'lib/google/apis/compute_alpha/classes.rb', line 41409

def fingerprint
  @fingerprint
end

#nameString

This set's name, which must be a resource ID segment and unique within all named sets owned by the Router. Name should conform to RFC1035. Corresponds to the JSON property name

Returns:

  • (String)


41415
41416
41417
# File 'lib/google/apis/compute_alpha/classes.rb', line 41415

def name
  @name
end

#typeString

This named set's type Corresponds to the JSON property type

Returns:

  • (String)


41420
41421
41422
# File 'lib/google/apis/compute_alpha/classes.rb', line 41420

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



41427
41428
41429
41430
41431
41432
41433
# File 'lib/google/apis/compute_alpha/classes.rb', line 41427

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @elements = args[:elements] if args.key?(:elements)
  @fingerprint = args[:fingerprint] if args.key?(:fingerprint)
  @name = args[:name] if args.key?(:name)
  @type = args[:type] if args.key?(:type)
end