Class: Google::Apis::ComputeAlpha::Network

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Represents a VPC Network resource. Networks connect resources to each other and to the internet. For more information, readVirtual Private Cloud (VPC) Network.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Network

Returns a new instance of Network.



42613
42614
42615
# File 'lib/google/apis/compute_alpha/classes.rb', line 42613

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#auto_create_subnetworksBoolean Also known as: auto_create_subnetworks?

Must be set to create a VPC network. If not set, a legacy network is created. When set to true, the VPC network is created in auto mode. When set to false, the VPC network is created in custom mode. An auto mode VPC network starts with one subnet per region. Each subnet has a predetermined range as described inAuto mode VPC network IP ranges. For custom mode VPC networks, you can add subnets using the subnetworksinsert method. Corresponds to the JSON property autoCreateSubnetworks

Returns:

  • (Boolean)


42473
42474
42475
# File 'lib/google/apis/compute_alpha/classes.rb', line 42473

def auto_create_subnetworks
  @auto_create_subnetworks
end

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


42480
42481
42482
# File 'lib/google/apis/compute_alpha/classes.rb', line 42480

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Provide this field when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


42486
42487
42488
# File 'lib/google/apis/compute_alpha/classes.rb', line 42486

def description
  @description
end

#enable_ula_internal_ipv6Boolean Also known as: enable_ula_internal_ipv6?

Enable ULA internal ipv6 on this network. Enabling this feature will assign a /48 from google defined ULA prefix fd20::/20. . Corresponds to the JSON property enableUlaInternalIpv6

Returns:

  • (Boolean)


42493
42494
42495
# File 'lib/google/apis/compute_alpha/classes.rb', line 42493

def enable_ula_internal_ipv6
  @enable_ula_internal_ipv6
end

#firewall_policyString

Output only. [Output Only] URL of the firewall policy the network is associated with. Corresponds to the JSON property firewallPolicy

Returns:

  • (String)


42500
42501
42502
# File 'lib/google/apis/compute_alpha/classes.rb', line 42500

def firewall_policy
  @firewall_policy
end

#gateway_i_pv4String

[Output Only] The gateway address for default routing out of the network, selected by Google Cloud. Corresponds to the JSON property gatewayIPv4

Returns:

  • (String)


42506
42507
42508
# File 'lib/google/apis/compute_alpha/classes.rb', line 42506

def gateway_i_pv4
  @gateway_i_pv4
end

#i_pv4_rangeString

Deprecated in favor of subnet mode networks. The range of internal addresses that are legal on this network. This range is aCIDR specification, for example:192.168.0.0/16. Provided by the client when the network is created. Corresponds to the JSON property IPv4Range

Returns:

  • (String)


42461
42462
42463
# File 'lib/google/apis/compute_alpha/classes.rb', line 42461

def i_pv4_range
  @i_pv4_range
end

#idFixnum

Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


42513
42514
42515
# File 'lib/google/apis/compute_alpha/classes.rb', line 42513

def id
  @id
end

#internal_ipv6_rangeString

When enabling ula internal ipv6, caller optionally can specify the /48 range they want from the google defined ULA prefix fd20::/20. The input must be a valid /48 ULA IPv6 address and must be within the fd20::/20. Operation will fail if the speficied /48 is already in used by another resource. If the field is not speficied, then a /48 range will be randomly allocated from fd20::/20 and returned via this field. . Corresponds to the JSON property internalIpv6Range

Returns:

  • (String)


42524
42525
42526
# File 'lib/google/apis/compute_alpha/classes.rb', line 42524

def internal_ipv6_range
  @internal_ipv6_range
end

#kindString

Output only. [Output Only] Type of the resource. Always compute#network for networks. Corresponds to the JSON property kind

Returns:

  • (String)


42530
42531
42532
# File 'lib/google/apis/compute_alpha/classes.rb', line 42530

def kind
  @kind
end

#mtuFixnum

Maximum Transmission Unit in bytes. The minimum value for this field is 1300 and the maximum value is 8896. The suggested value is 1500, which is the default MTU used on the Internet, or 8896 if you want to use Jumbo frames. If unspecified, the value defaults to 1460. Corresponds to the JSON property mtu

Returns:

  • (Fixnum)


42539
42540
42541
# File 'lib/google/apis/compute_alpha/classes.rb', line 42539

def mtu
  @mtu
end

#nameString

Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])?. The first character must be a lowercase letter, and all following characters (except for the last character) must be a dash, lowercase letter, or digit. The last character must be a lowercase letter or digit. Corresponds to the JSON property name

Returns:

  • (String)


42550
42551
42552
# File 'lib/google/apis/compute_alpha/classes.rb', line 42550

def name
  @name
end

#network_firewall_policy_enforcement_orderString

The network firewall policy enforcement order. Can be either AFTER_CLASSIC_FIREWALL or BEFORE_CLASSIC_FIREWALL. Defaults to AFTER_CLASSIC_FIREWALL if the field is not specified. Corresponds to the JSON property networkFirewallPolicyEnforcementOrder

Returns:

  • (String)


42557
42558
42559
# File 'lib/google/apis/compute_alpha/classes.rb', line 42557

def network_firewall_policy_enforcement_order
  @network_firewall_policy_enforcement_order
end

#network_profileString

A full or partial URL of the network profile to apply to this network. This field can be set only at resource creation time. For example, the following are valid URLs:

Returns:

  • (String)


42568
42569
42570
# File 'lib/google/apis/compute_alpha/classes.rb', line 42568

def network_profile
  @network_profile
end

#paramsGoogle::Apis::ComputeAlpha::NetworkParams

Additional network parameters. Corresponds to the JSON property params



42573
42574
42575
# File 'lib/google/apis/compute_alpha/classes.rb', line 42573

def params
  @params
end

#peeringsArray<Google::Apis::ComputeAlpha::NetworkPeering>

Output only. [Output Only] A list of network peerings for the resource. Corresponds to the JSON property peerings



42578
42579
42580
# File 'lib/google/apis/compute_alpha/classes.rb', line 42578

def peerings
  @peerings
end

#regionString

Output only. [Output Only] URL of the region where the regional network resides. This field is not applicable to global network. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body. Corresponds to the JSON property region

Returns:

  • (String)


42587
42588
42589
# File 'lib/google/apis/compute_alpha/classes.rb', line 42587

def region
  @region
end

#routing_configGoogle::Apis::ComputeAlpha::NetworkRoutingConfig

A routing configuration attached to a network resource. The message includes the list of routers associated with the network, and a flag indicating the type of routing behavior to enforce network-wide. Corresponds to the JSON property routingConfig



42594
42595
42596
# File 'lib/google/apis/compute_alpha/classes.rb', line 42594

def routing_config
  @routing_config
end

[Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


42599
42600
42601
# File 'lib/google/apis/compute_alpha/classes.rb', line 42599

def self_link
  @self_link
end

Output only. [Output Only] Server-defined URL for this resource with the resource id. Corresponds to the JSON property selfLinkWithId

Returns:

  • (String)


42605
42606
42607
# File 'lib/google/apis/compute_alpha/classes.rb', line 42605

def self_link_with_id
  @self_link_with_id
end

#subnetworksArray<String>

[Output Only] Server-defined fully-qualified URLs for all subnetworks in this VPC network. Corresponds to the JSON property subnetworks

Returns:

  • (Array<String>)


42611
42612
42613
# File 'lib/google/apis/compute_alpha/classes.rb', line 42611

def subnetworks
  @subnetworks
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



42618
42619
42620
42621
42622
42623
42624
42625
42626
42627
42628
42629
42630
42631
42632
42633
42634
42635
42636
42637
42638
42639
42640
# File 'lib/google/apis/compute_alpha/classes.rb', line 42618

def update!(**args)
  @i_pv4_range = args[:i_pv4_range] if args.key?(:i_pv4_range)
  @auto_create_subnetworks = args[:auto_create_subnetworks] if args.key?(:auto_create_subnetworks)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @enable_ula_internal_ipv6 = args[:enable_ula_internal_ipv6] if args.key?(:enable_ula_internal_ipv6)
  @firewall_policy = args[:firewall_policy] if args.key?(:firewall_policy)
  @gateway_i_pv4 = args[:gateway_i_pv4] if args.key?(:gateway_i_pv4)
  @id = args[:id] if args.key?(:id)
  @internal_ipv6_range = args[:internal_ipv6_range] if args.key?(:internal_ipv6_range)
  @kind = args[:kind] if args.key?(:kind)
  @mtu = args[:mtu] if args.key?(:mtu)
  @name = args[:name] if args.key?(:name)
  @network_firewall_policy_enforcement_order = args[:network_firewall_policy_enforcement_order] if args.key?(:network_firewall_policy_enforcement_order)
  @network_profile = args[:network_profile] if args.key?(:network_profile)
  @params = args[:params] if args.key?(:params)
  @peerings = args[:peerings] if args.key?(:peerings)
  @region = args[:region] if args.key?(:region)
  @routing_config = args[:routing_config] if args.key?(:routing_config)
  @self_link = args[:self_link] if args.key?(:self_link)
  @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id)
  @subnetworks = args[:subnetworks] if args.key?(:subnetworks)
end