Class: Google::Apis::ComputeAlpha::NetworkAttachmentList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::NetworkAttachmentList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::NetworkAttachment>
A list of NetworkAttachment resources.
-
#kind ⇒ String
Corresponds to the JSON property
kind. -
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
-
#warning ⇒ Google::Apis::ComputeAlpha::NetworkAttachmentList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NetworkAttachmentList
constructor
A new instance of NetworkAttachmentList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NetworkAttachmentList
Returns a new instance of NetworkAttachmentList.
44546 44547 44548 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 44546 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
44514 44515 44516 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 44514 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::NetworkAttachment>
A list of NetworkAttachment resources.
Corresponds to the JSON property items
44519 44520 44521 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 44519 def items @items end |
#kind ⇒ String
Corresponds to the JSON property kind
44524 44525 44526 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 44524 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
44534 44535 44536 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 44534 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
44539 44540 44541 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 44539 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::NetworkAttachmentList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
44544 44545 44546 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 44544 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
44551 44552 44553 44554 44555 44556 44557 44558 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 44551 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |