Class: Google::Apis::ComputeAlpha::NetworkAttachmentList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkAttachmentList

Returns a new instance of NetworkAttachmentList.



44267
44268
44269
# File 'lib/google/apis/compute_alpha/classes.rb', line 44267

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


44235
44236
44237
# File 'lib/google/apis/compute_alpha/classes.rb', line 44235

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::NetworkAttachment>

A list of NetworkAttachment resources. Corresponds to the JSON property items



44240
44241
44242
# File 'lib/google/apis/compute_alpha/classes.rb', line 44240

def items
  @items
end

#kindString

Corresponds to the JSON property kind

Returns:

  • (String)


44245
44246
44247
# File 'lib/google/apis/compute_alpha/classes.rb', line 44245

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


44255
44256
44257
# File 'lib/google/apis/compute_alpha/classes.rb', line 44255

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


44260
44261
44262
# File 'lib/google/apis/compute_alpha/classes.rb', line 44260

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::NetworkAttachmentList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



44265
44266
44267
# File 'lib/google/apis/compute_alpha/classes.rb', line 44265

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



44272
44273
44274
44275
44276
44277
44278
44279
# File 'lib/google/apis/compute_alpha/classes.rb', line 44272

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end