Class: Google::Apis::ComputeAlpha::NetworkAttachmentList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkAttachmentList

Returns a new instance of NetworkAttachmentList.



43211
43212
43213
# File 'lib/google/apis/compute_alpha/classes.rb', line 43211

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


43179
43180
43181
# File 'lib/google/apis/compute_alpha/classes.rb', line 43179

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::NetworkAttachment>

A list of NetworkAttachment resources. Corresponds to the JSON property items



43184
43185
43186
# File 'lib/google/apis/compute_alpha/classes.rb', line 43184

def items
  @items
end

#kindString

Corresponds to the JSON property kind

Returns:

  • (String)


43189
43190
43191
# File 'lib/google/apis/compute_alpha/classes.rb', line 43189

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


43199
43200
43201
# File 'lib/google/apis/compute_alpha/classes.rb', line 43199

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


43204
43205
43206
# File 'lib/google/apis/compute_alpha/classes.rb', line 43204

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::NetworkAttachmentList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



43209
43210
43211
# File 'lib/google/apis/compute_alpha/classes.rb', line 43209

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



43216
43217
43218
43219
43220
43221
43222
43223
# File 'lib/google/apis/compute_alpha/classes.rb', line 43216

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end