Class: Google::Apis::ComputeAlpha::NetworkAttachmentList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkAttachmentList

Returns a new instance of NetworkAttachmentList.



42820
42821
42822
# File 'lib/google/apis/compute_alpha/classes.rb', line 42820

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


42788
42789
42790
# File 'lib/google/apis/compute_alpha/classes.rb', line 42788

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::NetworkAttachment>

A list of NetworkAttachment resources. Corresponds to the JSON property items



42793
42794
42795
# File 'lib/google/apis/compute_alpha/classes.rb', line 42793

def items
  @items
end

#kindString

Corresponds to the JSON property kind

Returns:

  • (String)


42798
42799
42800
# File 'lib/google/apis/compute_alpha/classes.rb', line 42798

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


42808
42809
42810
# File 'lib/google/apis/compute_alpha/classes.rb', line 42808

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


42813
42814
42815
# File 'lib/google/apis/compute_alpha/classes.rb', line 42813

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::NetworkAttachmentList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



42818
42819
42820
# File 'lib/google/apis/compute_alpha/classes.rb', line 42818

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



42825
42826
42827
42828
42829
42830
42831
42832
# File 'lib/google/apis/compute_alpha/classes.rb', line 42825

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end