Class: Google::Apis::ComputeAlpha::NetworkAttachmentList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkAttachmentList

Returns a new instance of NetworkAttachmentList.



42070
42071
42072
# File 'lib/google/apis/compute_alpha/classes.rb', line 42070

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


42038
42039
42040
# File 'lib/google/apis/compute_alpha/classes.rb', line 42038

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::NetworkAttachment>

A list of NetworkAttachment resources. Corresponds to the JSON property items



42043
42044
42045
# File 'lib/google/apis/compute_alpha/classes.rb', line 42043

def items
  @items
end

#kindString

Corresponds to the JSON property kind

Returns:

  • (String)


42048
42049
42050
# File 'lib/google/apis/compute_alpha/classes.rb', line 42048

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


42058
42059
42060
# File 'lib/google/apis/compute_alpha/classes.rb', line 42058

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


42063
42064
42065
# File 'lib/google/apis/compute_alpha/classes.rb', line 42063

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::NetworkAttachmentList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



42068
42069
42070
# File 'lib/google/apis/compute_alpha/classes.rb', line 42068

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



42075
42076
42077
42078
42079
42080
42081
42082
# File 'lib/google/apis/compute_alpha/classes.rb', line 42075

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end