Class: Google::Apis::ComputeAlpha::NetworkEdgeSecurityServiceAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkEdgeSecurityServiceAggregatedList

Returns a new instance of NetworkEdgeSecurityServiceAggregatedList.



43541
43542
43543
# File 'lib/google/apis/compute_alpha/classes.rb', line 43541

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


43497
43498
43499
# File 'lib/google/apis/compute_alpha/classes.rb', line 43497

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


43502
43503
43504
# File 'lib/google/apis/compute_alpha/classes.rb', line 43502

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::NetworkEdgeSecurityServicesScopedList>

A list of NetworkEdgeSecurityServicesScopedList resources. Corresponds to the JSON property items



43507
43508
43509
# File 'lib/google/apis/compute_alpha/classes.rb', line 43507

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# networkEdgeSecurityServiceAggregatedList for lists of Network Edge Security Services. Corresponds to the JSON property kind

Returns:

  • (String)


43514
43515
43516
# File 'lib/google/apis/compute_alpha/classes.rb', line 43514

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


43524
43525
43526
# File 'lib/google/apis/compute_alpha/classes.rb', line 43524

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


43529
43530
43531
# File 'lib/google/apis/compute_alpha/classes.rb', line 43529

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


43534
43535
43536
# File 'lib/google/apis/compute_alpha/classes.rb', line 43534

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::NetworkEdgeSecurityServiceAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



43539
43540
43541
# File 'lib/google/apis/compute_alpha/classes.rb', line 43539

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



43546
43547
43548
43549
43550
43551
43552
43553
43554
43555
# File 'lib/google/apis/compute_alpha/classes.rb', line 43546

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end