Class: Google::Apis::ComputeAlpha::NetworkEdgeSecurityServiceAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkEdgeSecurityServiceAggregatedList

Returns a new instance of NetworkEdgeSecurityServiceAggregatedList.



43335
43336
43337
# File 'lib/google/apis/compute_alpha/classes.rb', line 43335

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


43291
43292
43293
# File 'lib/google/apis/compute_alpha/classes.rb', line 43291

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


43296
43297
43298
# File 'lib/google/apis/compute_alpha/classes.rb', line 43296

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::NetworkEdgeSecurityServicesScopedList>

A list of NetworkEdgeSecurityServicesScopedList resources. Corresponds to the JSON property items



43301
43302
43303
# File 'lib/google/apis/compute_alpha/classes.rb', line 43301

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# networkEdgeSecurityServiceAggregatedList for lists of Network Edge Security Services. Corresponds to the JSON property kind

Returns:

  • (String)


43308
43309
43310
# File 'lib/google/apis/compute_alpha/classes.rb', line 43308

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


43318
43319
43320
# File 'lib/google/apis/compute_alpha/classes.rb', line 43318

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


43323
43324
43325
# File 'lib/google/apis/compute_alpha/classes.rb', line 43323

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


43328
43329
43330
# File 'lib/google/apis/compute_alpha/classes.rb', line 43328

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::NetworkEdgeSecurityServiceAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



43333
43334
43335
# File 'lib/google/apis/compute_alpha/classes.rb', line 43333

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



43340
43341
43342
43343
43344
43345
43346
43347
43348
43349
# File 'lib/google/apis/compute_alpha/classes.rb', line 43340

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end