Class: Google::Apis::ComputeAlpha::NetworkEdgeSecurityServiceAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkEdgeSecurityServiceAggregatedList

Returns a new instance of NetworkEdgeSecurityServiceAggregatedList.



43150
43151
43152
# File 'lib/google/apis/compute_alpha/classes.rb', line 43150

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


43106
43107
43108
# File 'lib/google/apis/compute_alpha/classes.rb', line 43106

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


43111
43112
43113
# File 'lib/google/apis/compute_alpha/classes.rb', line 43111

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::NetworkEdgeSecurityServicesScopedList>

A list of NetworkEdgeSecurityServicesScopedList resources. Corresponds to the JSON property items



43116
43117
43118
# File 'lib/google/apis/compute_alpha/classes.rb', line 43116

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# networkEdgeSecurityServiceAggregatedList for lists of Network Edge Security Services. Corresponds to the JSON property kind

Returns:

  • (String)


43123
43124
43125
# File 'lib/google/apis/compute_alpha/classes.rb', line 43123

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


43133
43134
43135
# File 'lib/google/apis/compute_alpha/classes.rb', line 43133

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


43138
43139
43140
# File 'lib/google/apis/compute_alpha/classes.rb', line 43138

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


43143
43144
43145
# File 'lib/google/apis/compute_alpha/classes.rb', line 43143

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::NetworkEdgeSecurityServiceAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



43148
43149
43150
# File 'lib/google/apis/compute_alpha/classes.rb', line 43148

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



43155
43156
43157
43158
43159
43160
43161
43162
43163
43164
# File 'lib/google/apis/compute_alpha/classes.rb', line 43155

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end