Class: Google::Apis::ComputeAlpha::NetworkEdgeSecurityServiceAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::NetworkEdgeSecurityServiceAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::NetworkEdgeSecurityServicesScopedList>
A list of NetworkEdgeSecurityServicesScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::NetworkEdgeSecurityServiceAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NetworkEdgeSecurityServiceAggregatedList
constructor
A new instance of NetworkEdgeSecurityServiceAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NetworkEdgeSecurityServiceAggregatedList
Returns a new instance of NetworkEdgeSecurityServiceAggregatedList.
42400 42401 42402 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 42400 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
42356 42357 42358 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 42356 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
42361 42362 42363 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 42361 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::NetworkEdgeSecurityServicesScopedList>
A list of NetworkEdgeSecurityServicesScopedList resources.
Corresponds to the JSON property items
42366 42367 42368 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 42366 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
networkEdgeSecurityServiceAggregatedList for lists of
Network Edge Security Services.
Corresponds to the JSON property kind
42373 42374 42375 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 42373 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
42383 42384 42385 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 42383 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
42388 42389 42390 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 42388 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
42393 42394 42395 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 42393 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::NetworkEdgeSecurityServiceAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
42398 42399 42400 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 42398 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
42405 42406 42407 42408 42409 42410 42411 42412 42413 42414 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 42405 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |