Class: Google::Apis::ComputeAlpha::NetworkEndpointGroupAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::NetworkEndpointGroupAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::NetworkEndpointGroupsScopedList>
A list of NetworkEndpointGroupsScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::NetworkEndpointGroupAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NetworkEndpointGroupAggregatedList
constructor
A new instance of NetworkEndpointGroupAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NetworkEndpointGroupAggregatedList
Returns a new instance of NetworkEndpointGroupAggregatedList.
44083 44084 44085 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 44083 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
44044 44045 44046 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 44044 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::NetworkEndpointGroupsScopedList>
A list of NetworkEndpointGroupsScopedList resources.
Corresponds to the JSON property items
44049 44050 44051 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 44049 def items @items end |
#kind ⇒ String
Output only. [Output Only] The resource type, which is alwayscompute#
networkEndpointGroupAggregatedList for aggregated
lists of network endpoint groups.
Corresponds to the JSON property kind
44056 44057 44058 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 44056 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
44066 44067 44068 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 44066 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
44071 44072 44073 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 44071 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
44076 44077 44078 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 44076 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::NetworkEndpointGroupAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
44081 44082 44083 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 44081 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
44088 44089 44090 44091 44092 44093 44094 44095 44096 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 44088 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |