Class: Google::Apis::ComputeAlpha::NetworkEndpointGroupAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkEndpointGroupAggregatedList

Returns a new instance of NetworkEndpointGroupAggregatedList.



43854
43855
43856
# File 'lib/google/apis/compute_alpha/classes.rb', line 43854

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


43815
43816
43817
# File 'lib/google/apis/compute_alpha/classes.rb', line 43815

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::NetworkEndpointGroupsScopedList>

A list of NetworkEndpointGroupsScopedList resources. Corresponds to the JSON property items



43820
43821
43822
# File 'lib/google/apis/compute_alpha/classes.rb', line 43820

def items
  @items
end

#kindString

Output only. [Output Only] The resource type, which is alwayscompute# networkEndpointGroupAggregatedList for aggregated lists of network endpoint groups. Corresponds to the JSON property kind

Returns:

  • (String)


43827
43828
43829
# File 'lib/google/apis/compute_alpha/classes.rb', line 43827

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


43837
43838
43839
# File 'lib/google/apis/compute_alpha/classes.rb', line 43837

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


43842
43843
43844
# File 'lib/google/apis/compute_alpha/classes.rb', line 43842

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


43847
43848
43849
# File 'lib/google/apis/compute_alpha/classes.rb', line 43847

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::NetworkEndpointGroupAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



43852
43853
43854
# File 'lib/google/apis/compute_alpha/classes.rb', line 43852

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



43859
43860
43861
43862
43863
43864
43865
43866
43867
# File 'lib/google/apis/compute_alpha/classes.rb', line 43859

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end