Class: Google::Apis::ComputeAlpha::NetworkEndpointGroupAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkEndpointGroupAggregatedList

Returns a new instance of NetworkEndpointGroupAggregatedList.



42919
42920
42921
# File 'lib/google/apis/compute_alpha/classes.rb', line 42919

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


42880
42881
42882
# File 'lib/google/apis/compute_alpha/classes.rb', line 42880

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::NetworkEndpointGroupsScopedList>

A list of NetworkEndpointGroupsScopedList resources. Corresponds to the JSON property items



42885
42886
42887
# File 'lib/google/apis/compute_alpha/classes.rb', line 42885

def items
  @items
end

#kindString

Output only. [Output Only] The resource type, which is alwayscompute# networkEndpointGroupAggregatedList for aggregated lists of network endpoint groups. Corresponds to the JSON property kind

Returns:

  • (String)


42892
42893
42894
# File 'lib/google/apis/compute_alpha/classes.rb', line 42892

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


42902
42903
42904
# File 'lib/google/apis/compute_alpha/classes.rb', line 42902

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


42907
42908
42909
# File 'lib/google/apis/compute_alpha/classes.rb', line 42907

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


42912
42913
42914
# File 'lib/google/apis/compute_alpha/classes.rb', line 42912

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::NetworkEndpointGroupAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



42917
42918
42919
# File 'lib/google/apis/compute_alpha/classes.rb', line 42917

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



42924
42925
42926
42927
42928
42929
42930
42931
42932
# File 'lib/google/apis/compute_alpha/classes.rb', line 42924

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end