Class: Google::Apis::ComputeAlpha::NetworkEndpointGroupCloudRun
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::NetworkEndpointGroupCloudRun
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Configuration for a Cloud Run network endpoint group (NEG). The service must be provided explicitly or in the URL mask. The tag is optional, may be provided explicitly or in the URL mask. Note: Cloud Run service must be in the same project and located in the same region as the Serverless NEG.
Instance Attribute Summary collapse
-
#service ⇒ String
Cloud Run service is the main resource of Cloud Run.
-
#tag ⇒ String
Optional Cloud Run tag represents the "named-revision" to provide additional fine-grained traffic routing information.
-
#url_mask ⇒ String
An URL mask is one of the main components of the Cloud Function.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NetworkEndpointGroupCloudRun
constructor
A new instance of NetworkEndpointGroupCloudRun.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NetworkEndpointGroupCloudRun
Returns a new instance of NetworkEndpointGroupCloudRun.
45844 45845 45846 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 45844 def initialize(**args) update!(**args) end |
Instance Attribute Details
#service ⇒ String
Cloud Run service is the main resource of Cloud Run.
The service must be 1-63 characters long, and comply withRFC1035.
Example value: "run-service".
Corresponds to the JSON property service
45818 45819 45820 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 45818 def service @service end |
#tag ⇒ String
Optional Cloud Run tag represents the "named-revision" to provide additional
fine-grained traffic routing information.
The tag must be 1-63 characters long, and comply withRFC1035.
Example value: "revision-0010".
Corresponds to the JSON property tag
45826 45827 45828 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 45826 def tag @tag end |
#url_mask ⇒ String
An URL
mask is one of the main components of the Cloud Function.
A template to parse service="bar1", tag="foo1" and
service="bar2", tag="foo2" respectively.
Corresponds to the JSON property urlMask
45842 45843 45844 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 45842 def url_mask @url_mask end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
45849 45850 45851 45852 45853 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 45849 def update!(**args) @service = args[:service] if args.key?(:service) @tag = args[:tag] if args.key?(:tag) @url_mask = args[:url_mask] if args.key?(:url_mask) end |