Class: Google::Apis::ComputeAlpha::NetworkEndpointGroupCloudRun
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::NetworkEndpointGroupCloudRun
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Configuration for a Cloud Run network endpoint group (NEG). The service must be provided explicitly or in the URL mask. The tag is optional, may be provided explicitly or in the URL mask. Note: Cloud Run service must be in the same project and located in the same region as the Serverless NEG.
Instance Attribute Summary collapse
-
#service ⇒ String
Cloud Run service is the main resource of Cloud Run.
-
#tag ⇒ String
Optional Cloud Run tag represents the "named-revision" to provide additional fine-grained traffic routing information.
-
#url_mask ⇒ String
An URL mask is one of the main components of the Cloud Function.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NetworkEndpointGroupCloudRun
constructor
A new instance of NetworkEndpointGroupCloudRun.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NetworkEndpointGroupCloudRun
Returns a new instance of NetworkEndpointGroupCloudRun.
45341 45342 45343 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 45341 def initialize(**args) update!(**args) end |
Instance Attribute Details
#service ⇒ String
Cloud Run service is the main resource of Cloud Run.
The service must be 1-63 characters long, and comply withRFC1035.
Example value: "run-service".
Corresponds to the JSON property service
45315 45316 45317 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 45315 def service @service end |
#tag ⇒ String
Optional Cloud Run tag represents the "named-revision" to provide additional
fine-grained traffic routing information.
The tag must be 1-63 characters long, and comply withRFC1035.
Example value: "revision-0010".
Corresponds to the JSON property tag
45323 45324 45325 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 45323 def tag @tag end |
#url_mask ⇒ String
An URL
mask is one of the main components of the Cloud Function.
A template to parse service="bar1", tag="foo1" and
service="bar2", tag="foo2" respectively.
Corresponds to the JSON property urlMask
45339 45340 45341 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 45339 def url_mask @url_mask end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
45346 45347 45348 45349 45350 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 45346 def update!(**args) @service = args[:service] if args.key?(:service) @tag = args[:tag] if args.key?(:tag) @url_mask = args[:url_mask] if args.key?(:url_mask) end |