Class: Google::Apis::ComputeAlpha::NetworkEndpointGroupLbNetworkEndpointGroup
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::NetworkEndpointGroupLbNetworkEndpointGroup
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Load balancing specific fields for network endpoint group.
Instance Attribute Summary collapse
-
#default_port ⇒ Fixnum
The default port used if the port number is not specified in the network endpoint.
-
#network ⇒ String
The URL of the network to which all network endpoints in the NEG belong.
-
#subnetwork ⇒ String
Optional URL of the subnetwork to which all network endpoints in the NEG belong.
-
#zone ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NetworkEndpointGroupLbNetworkEndpointGroup
constructor
A new instance of NetworkEndpointGroupLbNetworkEndpointGroup.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NetworkEndpointGroupLbNetworkEndpointGroup
Returns a new instance of NetworkEndpointGroupLbNetworkEndpointGroup.
44122 44123 44124 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 44122 def initialize(**args) update!(**args) end |
Instance Attribute Details
#default_port ⇒ Fixnum
The default port used if the port number is not specified in the network
endpoint.
If the network endpoint type is either GCE_VM_IP,SERVERLESS or
PRIVATE_SERVICE_CONNECT, this
field must not be specified.
[Deprecated] This field is deprecated.
Corresponds to the JSON property defaultPort
44093 44094 44095 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 44093 def default_port @default_port end |
#network ⇒ String
The URL of the network to which all network endpoints in the NEG belong.
For networkEndpointType GCE_VM_IP_PORT,GCE_VM_IP_PORTMAP or
NON_GCP_PRIVATE_IP_PORT,
if this field is not specified, a default network will be used.
This field cannot be set for NEGs with networkEndpointType set toSERVERLESS or
PRIVATE_SERVICE_CONNECT and for
global NEGs.
For all other network endpoint types, this field is required.
[Deprecated] This field is deprecated.
Corresponds to the JSON property network
44106 44107 44108 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 44106 def network @network end |
#subnetwork ⇒ String
Optional URL of the subnetwork to which all network endpoints in the NEG
belong.
[Deprecated] This field is deprecated.
Corresponds to the JSON property subnetwork
44113 44114 44115 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 44113 def subnetwork @subnetwork end |
#zone ⇒ String
Output only. [Output Only] The URL of thezone
where the network endpoint group is located.
[Deprecated] This field is deprecated.
Corresponds to the JSON property zone
44120 44121 44122 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 44120 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
44127 44128 44129 44130 44131 44132 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 44127 def update!(**args) @default_port = args[:default_port] if args.key?(:default_port) @network = args[:network] if args.key?(:network) @subnetwork = args[:subnetwork] if args.key?(:subnetwork) @zone = args[:zone] if args.key?(:zone) end |