Class: Google::Apis::ComputeAlpha::NetworkEndpointGroupLbNetworkEndpointGroup

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Load balancing specific fields for network endpoint group.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkEndpointGroupLbNetworkEndpointGroup

Returns a new instance of NetworkEndpointGroupLbNetworkEndpointGroup.



44120
44121
44122
# File 'lib/google/apis/compute_alpha/classes.rb', line 44120

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#default_portFixnum

The default port used if the port number is not specified in the network endpoint. If the network endpoint type is either GCE_VM_IP,SERVERLESS or PRIVATE_SERVICE_CONNECT, this field must not be specified. [Deprecated] This field is deprecated. Corresponds to the JSON property defaultPort

Returns:

  • (Fixnum)


44097
44098
44099
# File 'lib/google/apis/compute_alpha/classes.rb', line 44097

def default_port
  @default_port
end

#networkString

The URL of the network to which all network endpoints in the NEG belong. Uses default project network if unspecified. [Deprecated] This field is deprecated. Corresponds to the JSON property network

Returns:

  • (String)


44104
44105
44106
# File 'lib/google/apis/compute_alpha/classes.rb', line 44104

def network
  @network
end

#subnetworkString

Optional URL of the subnetwork to which all network endpoints in the NEG belong. [Deprecated] This field is deprecated. Corresponds to the JSON property subnetwork

Returns:

  • (String)


44111
44112
44113
# File 'lib/google/apis/compute_alpha/classes.rb', line 44111

def subnetwork
  @subnetwork
end

#zoneString

Output only. [Output Only] The URL of thezone where the network endpoint group is located. [Deprecated] This field is deprecated. Corresponds to the JSON property zone

Returns:

  • (String)


44118
44119
44120
# File 'lib/google/apis/compute_alpha/classes.rb', line 44118

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



44125
44126
44127
44128
44129
44130
# File 'lib/google/apis/compute_alpha/classes.rb', line 44125

def update!(**args)
  @default_port = args[:default_port] if args.key?(:default_port)
  @network = args[:network] if args.key?(:network)
  @subnetwork = args[:subnetwork] if args.key?(:subnetwork)
  @zone = args[:zone] if args.key?(:zone)
end