Class: Google::Apis::ComputeAlpha::NetworkEndpointGroupLbNetworkEndpointGroup

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Load balancing specific fields for network endpoint group.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkEndpointGroupLbNetworkEndpointGroup

Returns a new instance of NetworkEndpointGroupLbNetworkEndpointGroup.



43185
43186
43187
# File 'lib/google/apis/compute_alpha/classes.rb', line 43185

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#default_portFixnum

The default port used if the port number is not specified in the network endpoint. If the network endpoint type is either GCE_VM_IP,SERVERLESS or PRIVATE_SERVICE_CONNECT, this field must not be specified. [Deprecated] This field is deprecated. Corresponds to the JSON property defaultPort

Returns:

  • (Fixnum)


43162
43163
43164
# File 'lib/google/apis/compute_alpha/classes.rb', line 43162

def default_port
  @default_port
end

#networkString

The URL of the network to which all network endpoints in the NEG belong. Uses default project network if unspecified. [Deprecated] This field is deprecated. Corresponds to the JSON property network

Returns:

  • (String)


43169
43170
43171
# File 'lib/google/apis/compute_alpha/classes.rb', line 43169

def network
  @network
end

#subnetworkString

Optional URL of the subnetwork to which all network endpoints in the NEG belong. [Deprecated] This field is deprecated. Corresponds to the JSON property subnetwork

Returns:

  • (String)


43176
43177
43178
# File 'lib/google/apis/compute_alpha/classes.rb', line 43176

def subnetwork
  @subnetwork
end

#zoneString

Output only. [Output Only] The URL of thezone where the network endpoint group is located. [Deprecated] This field is deprecated. Corresponds to the JSON property zone

Returns:

  • (String)


43183
43184
43185
# File 'lib/google/apis/compute_alpha/classes.rb', line 43183

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



43190
43191
43192
43193
43194
43195
# File 'lib/google/apis/compute_alpha/classes.rb', line 43190

def update!(**args)
  @default_port = args[:default_port] if args.key?(:default_port)
  @network = args[:network] if args.key?(:network)
  @subnetwork = args[:subnetwork] if args.key?(:subnetwork)
  @zone = args[:zone] if args.key?(:zone)
end