Class: Google::Apis::ComputeAlpha::NetworkEndpointGroupList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkEndpointGroupList

Returns a new instance of NetworkEndpointGroupList.



45448
45449
45450
# File 'lib/google/apis/compute_alpha/classes.rb', line 45448

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


45414
45415
45416
# File 'lib/google/apis/compute_alpha/classes.rb', line 45414

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::NetworkEndpointGroup>

A list of NetworkEndpointGroup resources. Corresponds to the JSON property items



45419
45420
45421
# File 'lib/google/apis/compute_alpha/classes.rb', line 45419

def items
  @items
end

#kindString

Output only. [Output Only] The resource type, which is alwayscompute# networkEndpointGroupList for network endpoint group lists. Corresponds to the JSON property kind

Returns:

  • (String)


45426
45427
45428
# File 'lib/google/apis/compute_alpha/classes.rb', line 45426

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


45436
45437
45438
# File 'lib/google/apis/compute_alpha/classes.rb', line 45436

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


45441
45442
45443
# File 'lib/google/apis/compute_alpha/classes.rb', line 45441

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::NetworkEndpointGroupList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



45446
45447
45448
# File 'lib/google/apis/compute_alpha/classes.rb', line 45446

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



45453
45454
45455
45456
45457
45458
45459
45460
# File 'lib/google/apis/compute_alpha/classes.rb', line 45453

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end