Class: Google::Apis::ComputeAlpha::NetworkEndpointGroupList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkEndpointGroupList

Returns a new instance of NetworkEndpointGroupList.



44174
44175
44176
# File 'lib/google/apis/compute_alpha/classes.rb', line 44174

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


44140
44141
44142
# File 'lib/google/apis/compute_alpha/classes.rb', line 44140

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::NetworkEndpointGroup>

A list of NetworkEndpointGroup resources. Corresponds to the JSON property items



44145
44146
44147
# File 'lib/google/apis/compute_alpha/classes.rb', line 44145

def items
  @items
end

#kindString

Output only. [Output Only] The resource type, which is alwayscompute# networkEndpointGroupList for network endpoint group lists. Corresponds to the JSON property kind

Returns:

  • (String)


44152
44153
44154
# File 'lib/google/apis/compute_alpha/classes.rb', line 44152

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


44162
44163
44164
# File 'lib/google/apis/compute_alpha/classes.rb', line 44162

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


44167
44168
44169
# File 'lib/google/apis/compute_alpha/classes.rb', line 44167

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::NetworkEndpointGroupList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



44172
44173
44174
# File 'lib/google/apis/compute_alpha/classes.rb', line 44172

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



44179
44180
44181
44182
44183
44184
44185
44186
# File 'lib/google/apis/compute_alpha/classes.rb', line 44179

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end