Class: Google::Apis::ComputeAlpha::NetworkEndpointGroupList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkEndpointGroupList

Returns a new instance of NetworkEndpointGroupList.



43989
43990
43991
# File 'lib/google/apis/compute_alpha/classes.rb', line 43989

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


43955
43956
43957
# File 'lib/google/apis/compute_alpha/classes.rb', line 43955

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::NetworkEndpointGroup>

A list of NetworkEndpointGroup resources. Corresponds to the JSON property items



43960
43961
43962
# File 'lib/google/apis/compute_alpha/classes.rb', line 43960

def items
  @items
end

#kindString

Output only. [Output Only] The resource type, which is alwayscompute# networkEndpointGroupList for network endpoint group lists. Corresponds to the JSON property kind

Returns:

  • (String)


43967
43968
43969
# File 'lib/google/apis/compute_alpha/classes.rb', line 43967

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


43977
43978
43979
# File 'lib/google/apis/compute_alpha/classes.rb', line 43977

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


43982
43983
43984
# File 'lib/google/apis/compute_alpha/classes.rb', line 43982

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::NetworkEndpointGroupList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



43987
43988
43989
# File 'lib/google/apis/compute_alpha/classes.rb', line 43987

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



43994
43995
43996
43997
43998
43999
44000
44001
# File 'lib/google/apis/compute_alpha/classes.rb', line 43994

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end