Class: Google::Apis::ComputeAlpha::NetworkEndpointGroupList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::NetworkEndpointGroupList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::NetworkEndpointGroup>
A list of NetworkEndpointGroup resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::NetworkEndpointGroupList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NetworkEndpointGroupList
constructor
A new instance of NetworkEndpointGroupList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NetworkEndpointGroupList
Returns a new instance of NetworkEndpointGroupList.
43239 43240 43241 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 43239 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
43205 43206 43207 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 43205 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::NetworkEndpointGroup>
A list of NetworkEndpointGroup resources.
Corresponds to the JSON property items
43210 43211 43212 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 43210 def items @items end |
#kind ⇒ String
Output only. [Output Only] The resource type, which is alwayscompute#
networkEndpointGroupList for network endpoint group
lists.
Corresponds to the JSON property kind
43217 43218 43219 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 43217 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
43227 43228 43229 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 43227 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
43232 43233 43234 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 43232 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::NetworkEndpointGroupList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
43237 43238 43239 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 43237 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
43244 43245 43246 43247 43248 43249 43250 43251 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 43244 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |