Class: Google::Apis::ComputeAlpha::NetworkEndpointGroupServerlessDeployment
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::NetworkEndpointGroupServerlessDeployment
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Configuration for a serverless network endpoint group (NEG). Theplatform must be provided. Note: The target backend service must be in the same project and located in the same region as the Serverless NEG.
Instance Attribute Summary collapse
-
#platform ⇒ String
The platform of the backend target(s) of this NEG.
-
#resource ⇒ String
The user-defined name of the workload/instance.
-
#url_mask ⇒ String
An URL mask is one of the main components of the Cloud Function.
-
#version ⇒ String
The optional resource version.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NetworkEndpointGroupServerlessDeployment
constructor
A new instance of NetworkEndpointGroupServerlessDeployment.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NetworkEndpointGroupServerlessDeployment
Returns a new instance of NetworkEndpointGroupServerlessDeployment.
45634 45635 45636 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 45634 def initialize(**args) update!(**args) end |
Instance Attribute Details
#platform ⇒ String
The platform of the backend target(s) of this NEG.
The only supported value is
API Gateway: apigateway.googleapis.com.
Corresponds to the JSON property platform
45590 45591 45592 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 45590 def platform @platform end |
#resource ⇒ String
The user-defined name of the workload/instance. This value must be provided explicitly or in the urlMask. The resource identified by this value is platform-specific and is as follows:
- API Gateway: The gateway ID
- App Engine: The service name
- Cloud Functions: The function name
- Cloud Run: The service name
Corresponds to the JSON property
resource
45603 45604 45605 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 45603 def resource @resource end |
#url_mask ⇒ String
An URL mask is one of the main components of the Cloud Function. A template to parse platform-specific fields from a request URL. URL mask allows for routing to multiple resources on the same serverless platform without having to create multiple Network Endpoint Groups and backend resources. The fields parsed by this template are platform-specific and are as follows:
- API Gateway: The gateway ID
- App Engine: The service and version
- Cloud Functions: The function name
- Cloud Run: The service and tag
Corresponds to the JSON property
urlMask
45620 45621 45622 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 45620 def url_mask @url_mask end |
#version ⇒ String
The optional resource version. The version identified by this value is platform-specific and is follows:
- API Gateway: Unused
- App Engine: The service version
- Cloud Functions: Unused
- Cloud Run: The service tag
Corresponds to the JSON property
version
45632 45633 45634 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 45632 def version @version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
45639 45640 45641 45642 45643 45644 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 45639 def update!(**args) @platform = args[:platform] if args.key?(:platform) @resource = args[:resource] if args.key?(:resource) @url_mask = args[:url_mask] if args.key?(:url_mask) @version = args[:version] if args.key?(:version) end |