Class: Google::Apis::ComputeAlpha::NetworkEndpointGroupsListNetworkEndpoints

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkEndpointGroupsListNetworkEndpoints

Returns a new instance of NetworkEndpointGroupsListNetworkEndpoints.



46050
46051
46052
# File 'lib/google/apis/compute_alpha/classes.rb', line 46050

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


46021
46022
46023
# File 'lib/google/apis/compute_alpha/classes.rb', line 46021

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::NetworkEndpointWithHealthStatus>

A list of NetworkEndpointWithHealthStatus resources. Corresponds to the JSON property items



46026
46027
46028
# File 'lib/google/apis/compute_alpha/classes.rb', line 46026

def items
  @items
end

#kindString

Output only. [Output Only] The resource type, which is alwayscompute# networkEndpointGroupsListNetworkEndpoints for the list of network endpoints in the specified network endpoint group. Corresponds to the JSON property kind

Returns:

  • (String)


46033
46034
46035
# File 'lib/google/apis/compute_alpha/classes.rb', line 46033

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


46043
46044
46045
# File 'lib/google/apis/compute_alpha/classes.rb', line 46043

def next_page_token
  @next_page_token
end

#warningGoogle::Apis::ComputeAlpha::NetworkEndpointGroupsListNetworkEndpoints::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



46048
46049
46050
# File 'lib/google/apis/compute_alpha/classes.rb', line 46048

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



46055
46056
46057
46058
46059
46060
46061
# File 'lib/google/apis/compute_alpha/classes.rb', line 46055

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @warning = args[:warning] if args.key?(:warning)
end