Class: Google::Apis::ComputeAlpha::NetworkEndpointGroupsListNetworkEndpoints

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkEndpointGroupsListNetworkEndpoints

Returns a new instance of NetworkEndpointGroupsListNetworkEndpoints.



44497
44498
44499
# File 'lib/google/apis/compute_alpha/classes.rb', line 44497

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


44468
44469
44470
# File 'lib/google/apis/compute_alpha/classes.rb', line 44468

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::NetworkEndpointWithHealthStatus>

A list of NetworkEndpointWithHealthStatus resources. Corresponds to the JSON property items



44473
44474
44475
# File 'lib/google/apis/compute_alpha/classes.rb', line 44473

def items
  @items
end

#kindString

Output only. [Output Only] The resource type, which is alwayscompute# networkEndpointGroupsListNetworkEndpoints for the list of network endpoints in the specified network endpoint group. Corresponds to the JSON property kind

Returns:

  • (String)


44480
44481
44482
# File 'lib/google/apis/compute_alpha/classes.rb', line 44480

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


44490
44491
44492
# File 'lib/google/apis/compute_alpha/classes.rb', line 44490

def next_page_token
  @next_page_token
end

#warningGoogle::Apis::ComputeAlpha::NetworkEndpointGroupsListNetworkEndpoints::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



44495
44496
44497
# File 'lib/google/apis/compute_alpha/classes.rb', line 44495

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



44502
44503
44504
44505
44506
44507
44508
# File 'lib/google/apis/compute_alpha/classes.rb', line 44502

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @warning = args[:warning] if args.key?(:warning)
end