Class: Google::Apis::ComputeAlpha::NetworkEndpointGroupsListNetworkEndpoints

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkEndpointGroupsListNetworkEndpoints

Returns a new instance of NetworkEndpointGroupsListNetworkEndpoints.



44312
44313
44314
# File 'lib/google/apis/compute_alpha/classes.rb', line 44312

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


44283
44284
44285
# File 'lib/google/apis/compute_alpha/classes.rb', line 44283

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::NetworkEndpointWithHealthStatus>

A list of NetworkEndpointWithHealthStatus resources. Corresponds to the JSON property items



44288
44289
44290
# File 'lib/google/apis/compute_alpha/classes.rb', line 44288

def items
  @items
end

#kindString

Output only. [Output Only] The resource type, which is alwayscompute# networkEndpointGroupsListNetworkEndpoints for the list of network endpoints in the specified network endpoint group. Corresponds to the JSON property kind

Returns:

  • (String)


44295
44296
44297
# File 'lib/google/apis/compute_alpha/classes.rb', line 44295

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


44305
44306
44307
# File 'lib/google/apis/compute_alpha/classes.rb', line 44305

def next_page_token
  @next_page_token
end

#warningGoogle::Apis::ComputeAlpha::NetworkEndpointGroupsListNetworkEndpoints::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



44310
44311
44312
# File 'lib/google/apis/compute_alpha/classes.rb', line 44310

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



44317
44318
44319
44320
44321
44322
44323
# File 'lib/google/apis/compute_alpha/classes.rb', line 44317

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @warning = args[:warning] if args.key?(:warning)
end