Class: Google::Apis::ComputeAlpha::NetworkEndpointGroupsScopedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkEndpointGroupsScopedList

Returns a new instance of NetworkEndpointGroupsScopedList.



44413
44414
44415
# File 'lib/google/apis/compute_alpha/classes.rb', line 44413

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#network_endpoint_groupsArray<Google::Apis::ComputeAlpha::NetworkEndpointGroup>

Output only. [Output Only] The list ofnetwork endpoint groups that are contained in this scope. Corresponds to the JSON property networkEndpointGroups



44404
44405
44406
# File 'lib/google/apis/compute_alpha/classes.rb', line 44404

def network_endpoint_groups
  @network_endpoint_groups
end

#warningGoogle::Apis::ComputeAlpha::NetworkEndpointGroupsScopedList::Warning

Output only. [Output Only] An informational warning that replaces the list of network endpoint groups when the list is empty. Corresponds to the JSON property warning



44411
44412
44413
# File 'lib/google/apis/compute_alpha/classes.rb', line 44411

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



44418
44419
44420
44421
# File 'lib/google/apis/compute_alpha/classes.rb', line 44418

def update!(**args)
  @network_endpoint_groups = args[:network_endpoint_groups] if args.key?(:network_endpoint_groups)
  @warning = args[:warning] if args.key?(:warning)
end