Class: Google::Apis::ComputeAlpha::NetworkFirewallPolicyAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkFirewallPolicyAggregatedList

Returns a new instance of NetworkFirewallPolicyAggregatedList.



46028
46029
46030
# File 'lib/google/apis/compute_alpha/classes.rb', line 46028

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


45989
45990
45991
# File 'lib/google/apis/compute_alpha/classes.rb', line 45989

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::FirewallPoliciesScopedList>

A list of FirewallPoliciesScopedList resources. Corresponds to the JSON property items



45994
45995
45996
# File 'lib/google/apis/compute_alpha/classes.rb', line 45994

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# networkFirewallPoliciesAggregatedList for lists of network firewall policies. Corresponds to the JSON property kind

Returns:

  • (String)


46001
46002
46003
# File 'lib/google/apis/compute_alpha/classes.rb', line 46001

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


46011
46012
46013
# File 'lib/google/apis/compute_alpha/classes.rb', line 46011

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


46016
46017
46018
# File 'lib/google/apis/compute_alpha/classes.rb', line 46016

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


46021
46022
46023
# File 'lib/google/apis/compute_alpha/classes.rb', line 46021

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::NetworkFirewallPolicyAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



46026
46027
46028
# File 'lib/google/apis/compute_alpha/classes.rb', line 46026

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



46033
46034
46035
46036
46037
46038
46039
46040
46041
# File 'lib/google/apis/compute_alpha/classes.rb', line 46033

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end