Class: Google::Apis::ComputeAlpha::NetworkFirewallPolicyAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkFirewallPolicyAggregatedList

Returns a new instance of NetworkFirewallPolicyAggregatedList.



44989
44990
44991
# File 'lib/google/apis/compute_alpha/classes.rb', line 44989

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


44950
44951
44952
# File 'lib/google/apis/compute_alpha/classes.rb', line 44950

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::FirewallPoliciesScopedList>

A list of FirewallPoliciesScopedList resources. Corresponds to the JSON property items



44955
44956
44957
# File 'lib/google/apis/compute_alpha/classes.rb', line 44955

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# networkFirewallPoliciesAggregatedList for lists of network firewall policies. Corresponds to the JSON property kind

Returns:

  • (String)


44962
44963
44964
# File 'lib/google/apis/compute_alpha/classes.rb', line 44962

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


44972
44973
44974
# File 'lib/google/apis/compute_alpha/classes.rb', line 44972

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


44977
44978
44979
# File 'lib/google/apis/compute_alpha/classes.rb', line 44977

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


44982
44983
44984
# File 'lib/google/apis/compute_alpha/classes.rb', line 44982

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::NetworkFirewallPolicyAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



44987
44988
44989
# File 'lib/google/apis/compute_alpha/classes.rb', line 44987

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



44994
44995
44996
44997
44998
44999
45000
45001
45002
# File 'lib/google/apis/compute_alpha/classes.rb', line 44994

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end