Class: Google::Apis::ComputeAlpha::NetworkFirewallPolicyAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkFirewallPolicyAggregatedList

Returns a new instance of NetworkFirewallPolicyAggregatedList.



44756
44757
44758
# File 'lib/google/apis/compute_alpha/classes.rb', line 44756

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


44717
44718
44719
# File 'lib/google/apis/compute_alpha/classes.rb', line 44717

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::FirewallPoliciesScopedList>

A list of FirewallPoliciesScopedList resources. Corresponds to the JSON property items



44722
44723
44724
# File 'lib/google/apis/compute_alpha/classes.rb', line 44722

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# networkFirewallPoliciesAggregatedList for lists of network firewall policies. Corresponds to the JSON property kind

Returns:

  • (String)


44729
44730
44731
# File 'lib/google/apis/compute_alpha/classes.rb', line 44729

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


44739
44740
44741
# File 'lib/google/apis/compute_alpha/classes.rb', line 44739

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


44744
44745
44746
# File 'lib/google/apis/compute_alpha/classes.rb', line 44744

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


44749
44750
44751
# File 'lib/google/apis/compute_alpha/classes.rb', line 44749

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::NetworkFirewallPolicyAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



44754
44755
44756
# File 'lib/google/apis/compute_alpha/classes.rb', line 44754

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



44761
44762
44763
44764
44765
44766
44767
44768
44769
# File 'lib/google/apis/compute_alpha/classes.rb', line 44761

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end