Class: Google::Apis::ComputeAlpha::NetworkFirewallPolicyAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkFirewallPolicyAggregatedList

Returns a new instance of NetworkFirewallPolicyAggregatedList.



43819
43820
43821
# File 'lib/google/apis/compute_alpha/classes.rb', line 43819

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


43780
43781
43782
# File 'lib/google/apis/compute_alpha/classes.rb', line 43780

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::FirewallPoliciesScopedList>

A list of FirewallPoliciesScopedList resources. Corresponds to the JSON property items



43785
43786
43787
# File 'lib/google/apis/compute_alpha/classes.rb', line 43785

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# networkFirewallPoliciesAggregatedList for lists of network firewall policies. Corresponds to the JSON property kind

Returns:

  • (String)


43792
43793
43794
# File 'lib/google/apis/compute_alpha/classes.rb', line 43792

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


43802
43803
43804
# File 'lib/google/apis/compute_alpha/classes.rb', line 43802

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


43807
43808
43809
# File 'lib/google/apis/compute_alpha/classes.rb', line 43807

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


43812
43813
43814
# File 'lib/google/apis/compute_alpha/classes.rb', line 43812

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::NetworkFirewallPolicyAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



43817
43818
43819
# File 'lib/google/apis/compute_alpha/classes.rb', line 43817

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



43824
43825
43826
43827
43828
43829
43830
43831
43832
# File 'lib/google/apis/compute_alpha/classes.rb', line 43824

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end