Class: Google::Apis::ComputeAlpha::NetworkInterface
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::NetworkInterface
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
A network interface resource attached to an instance.
Instance Attribute Summary collapse
-
#access_configs ⇒ Array<Google::Apis::ComputeAlpha::AccessConfig>
An array of configurations for this interface.
-
#alias_ip_ranges ⇒ Array<Google::Apis::ComputeAlpha::AliasIpRange>
An array of alias IP ranges for this network interface.
-
#alias_ipv6_ranges ⇒ Array<Google::Apis::ComputeAlpha::AliasIpRange>
An array of alias IPv6 ranges for this network interface.
-
#dns64_eligible ⇒ Boolean
(also: #dns64_eligible?)
If true, this network interface is eligible for DNS64.
-
#enable_vpc_scoped_dns ⇒ Boolean
(also: #enable_vpc_scoped_dns?)
Optional.
-
#fingerprint ⇒ String
Fingerprint hash of contents stored in this network interface.
-
#igmp_query ⇒ String
Indicate whether igmp query is enabled on the network interface or not.
-
#internal_ipv6_prefix_length ⇒ Fixnum
The prefix length of the primary internal IPv6 range.
-
#ipv6_access_configs ⇒ Array<Google::Apis::ComputeAlpha::AccessConfig>
An array of IPv6 access configurations for this interface.
-
#ipv6_access_type ⇒ String
Output only.
-
#ipv6_address ⇒ String
An IPv6 internal network address for this network interface.
-
#kind ⇒ String
Output only.
-
#mac_address ⇒ String
Output only.
-
#name ⇒ String
[Output Only] The name of the network interface, which is generated by the server.
-
#nat64_eligible ⇒ Boolean
(also: #nat64_eligible?)
If true, this network interface is eligible for NAT64.
-
#network ⇒ String
URL of the VPC network resource for this instance.
-
#network_attachment ⇒ String
The URL of the network attachment that this interface should connect to in the following format: projects/
project_number/regions/region_name/networkAttachments/network_attachment_name. -
#network_ip ⇒ String
An IPv4 internal IP address to assign to the instance for this network interface.
-
#nic_type ⇒ String
The type of vNIC to be used on this interface.
-
#parent_nic_name ⇒ String
Name of the parent network interface of a dynamic network interface.
-
#queue_count ⇒ Fixnum
The networking queue count that's specified by users for the network interface.
-
#service_class_id ⇒ String
Optional.
-
#stack_type ⇒ String
The stack type for this network interface.
-
#subinterfaces ⇒ Array<Google::Apis::ComputeAlpha::NetworkInterfaceSubInterface>
SubInterfaces help enable L2 communication for the instance over subnetworks that support L2.
-
#subnetwork ⇒ String
The URL of the Subnetwork resource for this instance.
-
#vlan ⇒ Fixnum
VLAN tag of a dynamic network interface, must be an integer in the range from 2 to 255 inclusively.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NetworkInterface
constructor
A new instance of NetworkInterface.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NetworkInterface
Returns a new instance of NetworkInterface.
45051 45052 45053 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 45051 def initialize(**args) update!(**args) end |
Instance Attribute Details
#access_configs ⇒ Array<Google::Apis::ComputeAlpha::AccessConfig>
An array of configurations for this interface. Currently, only one access
config, ONE_TO_ONE_NAT, is supported. If there are noaccessConfigs specified,
then this instance will have
no external internet access.
Corresponds to the JSON property accessConfigs
44852 44853 44854 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 44852 def access_configs @access_configs end |
#alias_ip_ranges ⇒ Array<Google::Apis::ComputeAlpha::AliasIpRange>
An array of alias IP ranges for this network interface.
You can only specify this field for network interfaces in VPC networks.
Corresponds to the JSON property aliasIpRanges
44858 44859 44860 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 44858 def alias_ip_ranges @alias_ip_ranges end |
#alias_ipv6_ranges ⇒ Array<Google::Apis::ComputeAlpha::AliasIpRange>
An array of alias IPv6 ranges for this network interface.
You can only specify this field for network interfaces in VPC networks.
Corresponds to the JSON property aliasIpv6Ranges
44864 44865 44866 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 44864 def alias_ipv6_ranges @alias_ipv6_ranges end |
#dns64_eligible ⇒ Boolean Also known as: dns64_eligible?
If true, this network interface is eligible for DNS64.
This field is only supported for dual-stack (IPV4_IPV6) network interfaces.
Corresponds to the JSON property dns64Eligible
44870 44871 44872 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 44870 def dns64_eligible @dns64_eligible end |
#enable_vpc_scoped_dns ⇒ Boolean Also known as: enable_vpc_scoped_dns?
Optional. If true, DNS resolution will be enabled over this interface. Only
valid
with network_attachment.
Corresponds to the JSON property enableVpcScopedDns
44878 44879 44880 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 44878 def enable_vpc_scoped_dns @enable_vpc_scoped_dns end |
#fingerprint ⇒ String
Fingerprint hash of contents stored in this network interface.
This field will be ignored when inserting an Instance or
adding a NetworkInterface. An up-to-date
fingerprint must be provided in order to update theNetworkInterface. The
request will fail with error400 Bad Request if the fingerprint is not provided,
or412 Precondition Failed if the fingerprint is out of date.
Corresponds to the JSON property fingerprint
NOTE: Values are automatically base64 encoded/decoded in the client library.
44890 44891 44892 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 44890 def fingerprint @fingerprint end |
#igmp_query ⇒ String
Indicate whether igmp query is enabled on the network interface
or not. If enabled, also indicates the version of IGMP supported.
Corresponds to the JSON property igmpQuery
44896 44897 44898 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 44896 def igmp_query @igmp_query end |
#internal_ipv6_prefix_length ⇒ Fixnum
The prefix length of the primary internal IPv6 range.
Corresponds to the JSON property internalIpv6PrefixLength
44901 44902 44903 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 44901 def internal_ipv6_prefix_length @internal_ipv6_prefix_length end |
#ipv6_access_configs ⇒ Array<Google::Apis::ComputeAlpha::AccessConfig>
An array of IPv6 access configurations for this interface. Currently, only
one IPv6 access config, DIRECT_IPV6, is supported. If there
is no ipv6AccessConfig specified, then this instance will
have no external IPv6 Internet access.
Corresponds to the JSON property ipv6AccessConfigs
44909 44910 44911 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 44909 def ipv6_access_configs @ipv6_access_configs end |
#ipv6_access_type ⇒ String
Output only. [Output Only] One of EXTERNAL, INTERNAL to indicate whether the
IP can be
accessed from the Internet. This field is always inherited from its
subnetwork.
Valid only if stackType is IPV4_IPV6.
Corresponds to the JSON property ipv6AccessType
44918 44919 44920 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 44918 def ipv6_access_type @ipv6_access_type end |
#ipv6_address ⇒ String
An IPv6 internal network address for this network interface. To
use a static internal IP address, it must be unused and in the same region
as the instance's zone. If not specified, Google Cloud will automatically
assign an internal IPv6 address from the instance's subnetwork.
Corresponds to the JSON property ipv6Address
44926 44927 44928 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 44926 def ipv6_address @ipv6_address end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#
networkInterface for network interfaces.
Corresponds to the JSON property kind
44932 44933 44934 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 44932 def kind @kind end |
#mac_address ⇒ String
Output only. [Output Only] MAC address assigned to this network interface.
Corresponds to the JSON property macAddress
44937 44938 44939 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 44937 def mac_address @mac_address end |
#name ⇒ String
[Output Only] The name of the network interface, which is generated by the
server. For a VM, the network interface uses the nicN naming
format. Where N is a value between 0 and7. The default interface value is nic0.
Corresponds to the JSON property name
44944 44945 44946 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 44944 def name @name end |
#nat64_eligible ⇒ Boolean Also known as: nat64_eligible?
If true, this network interface is eligible for NAT64.
This field is only supported for dual-stack (IPV4_IPV6) network interfaces.
Corresponds to the JSON property nat64Eligible
44950 44951 44952 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 44950 def nat64_eligible @nat64_eligible end |
#network ⇒ String
URL of the VPC network resource for this instance. When creating an instance, if neither the network nor the subnetwork is specified, the default network global/networks/default is used. If the selected project doesn't have the default network, you must specify a network or subnet. If the network is not specified but the subnetwork is specified, the network is inferred. If you specify this property, you can specify the network as a full or partial URL. For example, the following are all valid URLs:
- https://www.googleapis.com/compute/v1/projects/project/global/networks/ network
- projects/project/global/networks/network
- global/networks/default
Corresponds to the JSON property
network
44969 44970 44971 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 44969 def network @network end |
#network_attachment ⇒ String
The URL of the network attachment that this interface should connect
to in the following format:
projects/project_number/regions/region_name/networkAttachments/
network_attachment_name.
Corresponds to the JSON property networkAttachment
44977 44978 44979 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 44977 def @network_attachment end |
#network_ip ⇒ String
An IPv4 internal IP address to assign to the instance for this network
interface. If not specified by the user, an unused internal IP is
assigned by the system.
Corresponds to the JSON property networkIP
44984 44985 44986 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 44984 def network_ip @network_ip end |
#nic_type ⇒ String
The type of vNIC to be used on this interface. This may be gVNIC or
VirtioNet.
Corresponds to the JSON property nicType
44990 44991 44992 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 44990 def nic_type @nic_type end |
#parent_nic_name ⇒ String
Name of the parent network interface of a dynamic network interface.
Corresponds to the JSON property parentNicName
44995 44996 44997 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 44995 def parent_nic_name @parent_nic_name end |
#queue_count ⇒ Fixnum
The networking queue count that's specified by users for the network
interface. Both Rx and Tx queues will be set to this number. It'll be empty
if not specified by the users.
Corresponds to the JSON property queueCount
45002 45003 45004 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 45002 def queue_count @queue_count end |
#service_class_id ⇒ String
Optional. Producer Service's Service class Id for the region of this network
interface. Can only be used with network_attachment. It is not possible to
use on its own however, network_attachment can be used without
service_class_id.
Corresponds to the JSON property serviceClassId
45010 45011 45012 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 45010 def service_class_id @service_class_id end |
#stack_type ⇒ String
The stack type for this network interface. To assign only IPv4 addresses,
use IPV4_ONLY. To assign both IPv4 and IPv6 addresses, useIPV4_IPV6. If not
specified, IPV4_ONLY is used.
This field can be both set at instance creation and update network
interface operations.
Corresponds to the JSON property stackType
45019 45020 45021 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 45019 def stack_type @stack_type end |
#subinterfaces ⇒ Array<Google::Apis::ComputeAlpha::NetworkInterfaceSubInterface>
SubInterfaces help enable L2 communication for the instance over
subnetworks that support L2. Every network interface will get a default
untagged (vlan not specified) subinterface. Users can specify additional
tagged subinterfaces which are sub-fields to the Network Interface.
Corresponds to the JSON property subinterfaces
45027 45028 45029 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 45027 def subinterfaces @subinterfaces end |
#subnetwork ⇒ String
The URL of the Subnetwork resource for this instance. If the network resource is inlegacy mode, do not specify this field. If the network is in auto subnet mode, specifying the subnetwork is optional. If the network is in custom subnet mode, specifying the subnetwork is required. If you specify this field, you can specify the subnetwork as a full or partial URL. For example, the following are all valid URLs:
- https://www.googleapis.com/compute/v1/projects/project/regions/region/ subnetworks/subnetwork
- regions/region/subnetworks/subnetwork
Corresponds to the JSON property
subnetwork
45043 45044 45045 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 45043 def subnetwork @subnetwork end |
#vlan ⇒ Fixnum
VLAN tag of a dynamic network interface, must be an integer in the range
from 2 to 255 inclusively.
Corresponds to the JSON property vlan
45049 45050 45051 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 45049 def vlan @vlan end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
45056 45057 45058 45059 45060 45061 45062 45063 45064 45065 45066 45067 45068 45069 45070 45071 45072 45073 45074 45075 45076 45077 45078 45079 45080 45081 45082 45083 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 45056 def update!(**args) @access_configs = args[:access_configs] if args.key?(:access_configs) @alias_ip_ranges = args[:alias_ip_ranges] if args.key?(:alias_ip_ranges) @alias_ipv6_ranges = args[:alias_ipv6_ranges] if args.key?(:alias_ipv6_ranges) @dns64_eligible = args[:dns64_eligible] if args.key?(:dns64_eligible) @enable_vpc_scoped_dns = args[:enable_vpc_scoped_dns] if args.key?(:enable_vpc_scoped_dns) @fingerprint = args[:fingerprint] if args.key?(:fingerprint) @igmp_query = args[:igmp_query] if args.key?(:igmp_query) @internal_ipv6_prefix_length = args[:internal_ipv6_prefix_length] if args.key?(:internal_ipv6_prefix_length) @ipv6_access_configs = args[:ipv6_access_configs] if args.key?(:ipv6_access_configs) @ipv6_access_type = args[:ipv6_access_type] if args.key?(:ipv6_access_type) @ipv6_address = args[:ipv6_address] if args.key?(:ipv6_address) @kind = args[:kind] if args.key?(:kind) @mac_address = args[:mac_address] if args.key?(:mac_address) @name = args[:name] if args.key?(:name) @nat64_eligible = args[:nat64_eligible] if args.key?(:nat64_eligible) @network = args[:network] if args.key?(:network) @network_attachment = args[:network_attachment] if args.key?(:network_attachment) @network_ip = args[:network_ip] if args.key?(:network_ip) @nic_type = args[:nic_type] if args.key?(:nic_type) @parent_nic_name = args[:parent_nic_name] if args.key?(:parent_nic_name) @queue_count = args[:queue_count] if args.key?(:queue_count) @service_class_id = args[:service_class_id] if args.key?(:service_class_id) @stack_type = args[:stack_type] if args.key?(:stack_type) @subinterfaces = args[:subinterfaces] if args.key?(:subinterfaces) @subnetwork = args[:subnetwork] if args.key?(:subnetwork) @vlan = args[:vlan] if args.key?(:vlan) end |