Class: Google::Apis::ComputeAlpha::NetworkInterface

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

A network interface resource attached to an instance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkInterface

Returns a new instance of NetworkInterface.



44850
44851
44852
# File 'lib/google/apis/compute_alpha/classes.rb', line 44850

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#access_configsArray<Google::Apis::ComputeAlpha::AccessConfig>

An array of configurations for this interface. Currently, only one access config, ONE_TO_ONE_NAT, is supported. If there are noaccessConfigs specified, then this instance will have no external internet access. Corresponds to the JSON property accessConfigs



44665
44666
44667
# File 'lib/google/apis/compute_alpha/classes.rb', line 44665

def access_configs
  @access_configs
end

#alias_ip_rangesArray<Google::Apis::ComputeAlpha::AliasIpRange>

An array of alias IP ranges for this network interface. You can only specify this field for network interfaces in VPC networks. Corresponds to the JSON property aliasIpRanges



44671
44672
44673
# File 'lib/google/apis/compute_alpha/classes.rb', line 44671

def alias_ip_ranges
  @alias_ip_ranges
end

#alias_ipv6_rangesArray<Google::Apis::ComputeAlpha::AliasIpRange>

An array of alias IPv6 ranges for this network interface. You can only specify this field for network interfaces in VPC networks. Corresponds to the JSON property aliasIpv6Ranges



44677
44678
44679
# File 'lib/google/apis/compute_alpha/classes.rb', line 44677

def alias_ipv6_ranges
  @alias_ipv6_ranges
end

#enable_vpc_scoped_dnsBoolean Also known as: enable_vpc_scoped_dns?

Optional. If true, DNS resolution will be enabled over this interface. Only valid with network_attachment. Corresponds to the JSON property enableVpcScopedDns

Returns:

  • (Boolean)


44684
44685
44686
# File 'lib/google/apis/compute_alpha/classes.rb', line 44684

def enable_vpc_scoped_dns
  @enable_vpc_scoped_dns
end

#fingerprintString

Fingerprint hash of contents stored in this network interface. This field will be ignored when inserting an Instance or adding a NetworkInterface. An up-to-date fingerprint must be provided in order to update theNetworkInterface. The request will fail with error400 Bad Request if the fingerprint is not provided, or412 Precondition Failed if the fingerprint is out of date. Corresponds to the JSON property fingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


44696
44697
44698
# File 'lib/google/apis/compute_alpha/classes.rb', line 44696

def fingerprint
  @fingerprint
end

#igmp_queryString

Indicate whether igmp query is enabled on the network interface or not. If enabled, also indicates the version of IGMP supported. Corresponds to the JSON property igmpQuery

Returns:

  • (String)


44702
44703
44704
# File 'lib/google/apis/compute_alpha/classes.rb', line 44702

def igmp_query
  @igmp_query
end

#internal_ipv6_prefix_lengthFixnum

The prefix length of the primary internal IPv6 range. Corresponds to the JSON property internalIpv6PrefixLength

Returns:

  • (Fixnum)


44707
44708
44709
# File 'lib/google/apis/compute_alpha/classes.rb', line 44707

def internal_ipv6_prefix_length
  @internal_ipv6_prefix_length
end

#ipv6_access_configsArray<Google::Apis::ComputeAlpha::AccessConfig>

An array of IPv6 access configurations for this interface. Currently, only one IPv6 access config, DIRECT_IPV6, is supported. If there is no ipv6AccessConfig specified, then this instance will have no external IPv6 Internet access. Corresponds to the JSON property ipv6AccessConfigs



44715
44716
44717
# File 'lib/google/apis/compute_alpha/classes.rb', line 44715

def ipv6_access_configs
  @ipv6_access_configs
end

#ipv6_access_typeString

Output only. [Output Only] One of EXTERNAL, INTERNAL to indicate whether the IP can be accessed from the Internet. This field is always inherited from its subnetwork. Valid only if stackType is IPV4_IPV6. Corresponds to the JSON property ipv6AccessType

Returns:

  • (String)


44724
44725
44726
# File 'lib/google/apis/compute_alpha/classes.rb', line 44724

def ipv6_access_type
  @ipv6_access_type
end

#ipv6_addressString

An IPv6 internal network address for this network interface. To use a static internal IP address, it must be unused and in the same region as the instance's zone. If not specified, Google Cloud will automatically assign an internal IPv6 address from the instance's subnetwork. Corresponds to the JSON property ipv6Address

Returns:

  • (String)


44732
44733
44734
# File 'lib/google/apis/compute_alpha/classes.rb', line 44732

def ipv6_address
  @ipv6_address
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# networkInterface for network interfaces. Corresponds to the JSON property kind

Returns:

  • (String)


44738
44739
44740
# File 'lib/google/apis/compute_alpha/classes.rb', line 44738

def kind
  @kind
end

#mac_addressString

Output only. [Output Only] MAC address assigned to this network interface. Corresponds to the JSON property macAddress

Returns:

  • (String)


44743
44744
44745
# File 'lib/google/apis/compute_alpha/classes.rb', line 44743

def mac_address
  @mac_address
end

#nameString

[Output Only] The name of the network interface, which is generated by the server. For a VM, the network interface uses the nicN naming format. Where N is a value between 0 and7. The default interface value is nic0. Corresponds to the JSON property name

Returns:

  • (String)


44750
44751
44752
# File 'lib/google/apis/compute_alpha/classes.rb', line 44750

def name
  @name
end

#networkString

URL of the VPC network resource for this instance. When creating an instance, if neither the network nor the subnetwork is specified, the default network global/networks/default is used. If the selected project doesn't have the default network, you must specify a network or subnet. If the network is not specified but the subnetwork is specified, the network is inferred. If you specify this property, you can specify the network as a full or partial URL. For example, the following are all valid URLs:

Returns:

  • (String)


44768
44769
44770
# File 'lib/google/apis/compute_alpha/classes.rb', line 44768

def network
  @network
end

#network_attachmentString

The URL of the network attachment that this interface should connect to in the following format: projects/project_number/regions/region_name/networkAttachments/ network_attachment_name. Corresponds to the JSON property networkAttachment

Returns:

  • (String)


44776
44777
44778
# File 'lib/google/apis/compute_alpha/classes.rb', line 44776

def network_attachment
  @network_attachment
end

#network_ipString

An IPv4 internal IP address to assign to the instance for this network interface. If not specified by the user, an unused internal IP is assigned by the system. Corresponds to the JSON property networkIP

Returns:

  • (String)


44783
44784
44785
# File 'lib/google/apis/compute_alpha/classes.rb', line 44783

def network_ip
  @network_ip
end

#nic_typeString

The type of vNIC to be used on this interface. This may be gVNIC or VirtioNet. Corresponds to the JSON property nicType

Returns:

  • (String)


44789
44790
44791
# File 'lib/google/apis/compute_alpha/classes.rb', line 44789

def nic_type
  @nic_type
end

#parent_nic_nameString

Name of the parent network interface of a dynamic network interface. Corresponds to the JSON property parentNicName

Returns:

  • (String)


44794
44795
44796
# File 'lib/google/apis/compute_alpha/classes.rb', line 44794

def parent_nic_name
  @parent_nic_name
end

#queue_countFixnum

The networking queue count that's specified by users for the network interface. Both Rx and Tx queues will be set to this number. It'll be empty if not specified by the users. Corresponds to the JSON property queueCount

Returns:

  • (Fixnum)


44801
44802
44803
# File 'lib/google/apis/compute_alpha/classes.rb', line 44801

def queue_count
  @queue_count
end

#service_class_idString

Optional. Producer Service's Service class Id for the region of this network interface. Can only be used with network_attachment. It is not possible to use on its own however, network_attachment can be used without service_class_id. Corresponds to the JSON property serviceClassId

Returns:

  • (String)


44809
44810
44811
# File 'lib/google/apis/compute_alpha/classes.rb', line 44809

def service_class_id
  @service_class_id
end

#stack_typeString

The stack type for this network interface. To assign only IPv4 addresses, use IPV4_ONLY. To assign both IPv4 and IPv6 addresses, useIPV4_IPV6. If not specified, IPV4_ONLY is used. This field can be both set at instance creation and update network interface operations. Corresponds to the JSON property stackType

Returns:

  • (String)


44818
44819
44820
# File 'lib/google/apis/compute_alpha/classes.rb', line 44818

def stack_type
  @stack_type
end

#subinterfacesArray<Google::Apis::ComputeAlpha::NetworkInterfaceSubInterface>

SubInterfaces help enable L2 communication for the instance over subnetworks that support L2. Every network interface will get a default untagged (vlan not specified) subinterface. Users can specify additional tagged subinterfaces which are sub-fields to the Network Interface. Corresponds to the JSON property subinterfaces



44826
44827
44828
# File 'lib/google/apis/compute_alpha/classes.rb', line 44826

def subinterfaces
  @subinterfaces
end

#subnetworkString

The URL of the Subnetwork resource for this instance. If the network resource is inlegacy mode, do not specify this field. If the network is in auto subnet mode, specifying the subnetwork is optional. If the network is in custom subnet mode, specifying the subnetwork is required. If you specify this field, you can specify the subnetwork as a full or partial URL. For example, the following are all valid URLs:

Returns:

  • (String)


44842
44843
44844
# File 'lib/google/apis/compute_alpha/classes.rb', line 44842

def subnetwork
  @subnetwork
end

#vlanFixnum

VLAN tag of a dynamic network interface, must be an integer in the range from 2 to 255 inclusively. Corresponds to the JSON property vlan

Returns:

  • (Fixnum)


44848
44849
44850
# File 'lib/google/apis/compute_alpha/classes.rb', line 44848

def vlan
  @vlan
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



44855
44856
44857
44858
44859
44860
44861
44862
44863
44864
44865
44866
44867
44868
44869
44870
44871
44872
44873
44874
44875
44876
44877
44878
44879
44880
# File 'lib/google/apis/compute_alpha/classes.rb', line 44855

def update!(**args)
  @access_configs = args[:access_configs] if args.key?(:access_configs)
  @alias_ip_ranges = args[:alias_ip_ranges] if args.key?(:alias_ip_ranges)
  @alias_ipv6_ranges = args[:alias_ipv6_ranges] if args.key?(:alias_ipv6_ranges)
  @enable_vpc_scoped_dns = args[:enable_vpc_scoped_dns] if args.key?(:enable_vpc_scoped_dns)
  @fingerprint = args[:fingerprint] if args.key?(:fingerprint)
  @igmp_query = args[:igmp_query] if args.key?(:igmp_query)
  @internal_ipv6_prefix_length = args[:internal_ipv6_prefix_length] if args.key?(:internal_ipv6_prefix_length)
  @ipv6_access_configs = args[:ipv6_access_configs] if args.key?(:ipv6_access_configs)
  @ipv6_access_type = args[:ipv6_access_type] if args.key?(:ipv6_access_type)
  @ipv6_address = args[:ipv6_address] if args.key?(:ipv6_address)
  @kind = args[:kind] if args.key?(:kind)
  @mac_address = args[:mac_address] if args.key?(:mac_address)
  @name = args[:name] if args.key?(:name)
  @network = args[:network] if args.key?(:network)
  @network_attachment = args[:network_attachment] if args.key?(:network_attachment)
  @network_ip = args[:network_ip] if args.key?(:network_ip)
  @nic_type = args[:nic_type] if args.key?(:nic_type)
  @parent_nic_name = args[:parent_nic_name] if args.key?(:parent_nic_name)
  @queue_count = args[:queue_count] if args.key?(:queue_count)
  @service_class_id = args[:service_class_id] if args.key?(:service_class_id)
  @stack_type = args[:stack_type] if args.key?(:stack_type)
  @subinterfaces = args[:subinterfaces] if args.key?(:subinterfaces)
  @subnetwork = args[:subnetwork] if args.key?(:subnetwork)
  @vlan = args[:vlan] if args.key?(:vlan)
end