Class: Google::Apis::ComputeAlpha::NetworkInterfaceSubInterface
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::NetworkInterfaceSubInterface
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#ip_address ⇒ String
An IPv4 internal IP address to assign to the instance for this subinterface.
-
#ip_allocation_mode ⇒ String
Corresponds to the JSON property
ipAllocationMode. -
#subnetwork ⇒ String
If specified, this subnetwork must belong to the same network as that of the network interface.
-
#vlan ⇒ Fixnum
VLAN tag.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NetworkInterfaceSubInterface
constructor
A new instance of NetworkInterfaceSubInterface.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NetworkInterfaceSubInterface
Returns a new instance of NetworkInterfaceSubInterface.
46914 46915 46916 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 46914 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ip_address ⇒ String
An IPv4 internal IP address to assign to the instance for this
subinterface. If specified, ip_allocation_mode should be set to
ALLOCATE_IP.
Corresponds to the JSON property ipAddress
46887 46888 46889 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 46887 def ip_address @ip_address end |
#ip_allocation_mode ⇒ String
Corresponds to the JSON property ipAllocationMode
46892 46893 46894 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 46892 def ip_allocation_mode @ip_allocation_mode end |
#subnetwork ⇒ String
If specified, this subnetwork must belong to the same network as that of the network interface. If not specified the subnet of network interface will be used. If you specify this property, you can specify the subnetwork as a full or partial URL. For example, the following are all valid URLs:
- https://www.googleapis.com/compute/v1/projects/project/regions/region/ subnetworks/subnetwork
- regions/region/subnetworks/subnetwork
Corresponds to the JSON property
subnetwork
46906 46907 46908 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 46906 def subnetwork @subnetwork end |
#vlan ⇒ Fixnum
VLAN tag. Should match the VLAN(s) supported by the subnetwork to which
this subinterface is connecting.
Corresponds to the JSON property vlan
46912 46913 46914 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 46912 def vlan @vlan end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
46919 46920 46921 46922 46923 46924 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 46919 def update!(**args) @ip_address = args[:ip_address] if args.key?(:ip_address) @ip_allocation_mode = args[:ip_allocation_mode] if args.key?(:ip_allocation_mode) @subnetwork = args[:subnetwork] if args.key?(:subnetwork) @vlan = args[:vlan] if args.key?(:vlan) end |