Class: Google::Apis::ComputeAlpha::NetworkInterfaceSubInterface
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::NetworkInterfaceSubInterface
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#ip_address ⇒ String
An IPv4 internal IP address to assign to the instance for this subinterface.
-
#ip_allocation_mode ⇒ String
Corresponds to the JSON property
ipAllocationMode. -
#subnetwork ⇒ String
If specified, this subnetwork must belong to the same network as that of the network interface.
-
#vlan ⇒ Fixnum
VLAN tag.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NetworkInterfaceSubInterface
constructor
A new instance of NetworkInterfaceSubInterface.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NetworkInterfaceSubInterface
Returns a new instance of NetworkInterfaceSubInterface.
46673 46674 46675 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 46673 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ip_address ⇒ String
An IPv4 internal IP address to assign to the instance for this
subinterface. If specified, ip_allocation_mode should be set to
ALLOCATE_IP.
Corresponds to the JSON property ipAddress
46646 46647 46648 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 46646 def ip_address @ip_address end |
#ip_allocation_mode ⇒ String
Corresponds to the JSON property ipAllocationMode
46651 46652 46653 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 46651 def ip_allocation_mode @ip_allocation_mode end |
#subnetwork ⇒ String
If specified, this subnetwork must belong to the same network as that of the network interface. If not specified the subnet of network interface will be used. If you specify this property, you can specify the subnetwork as a full or partial URL. For example, the following are all valid URLs:
- https://www.googleapis.com/compute/v1/projects/project/regions/region/ subnetworks/subnetwork
- regions/region/subnetworks/subnetwork
Corresponds to the JSON property
subnetwork
46665 46666 46667 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 46665 def subnetwork @subnetwork end |
#vlan ⇒ Fixnum
VLAN tag. Should match the VLAN(s) supported by the subnetwork to which
this subinterface is connecting.
Corresponds to the JSON property vlan
46671 46672 46673 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 46671 def vlan @vlan end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
46678 46679 46680 46681 46682 46683 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 46678 def update!(**args) @ip_address = args[:ip_address] if args.key?(:ip_address) @ip_allocation_mode = args[:ip_allocation_mode] if args.key?(:ip_allocation_mode) @subnetwork = args[:subnetwork] if args.key?(:subnetwork) @vlan = args[:vlan] if args.key?(:vlan) end |