Class: Google::Apis::ComputeAlpha::NetworkInterfaceSubInterface
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::NetworkInterfaceSubInterface
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#ip_address ⇒ String
An IPv4 internal IP address to assign to the instance for this subinterface.
-
#ip_allocation_mode ⇒ String
Corresponds to the JSON property
ipAllocationMode. -
#subnetwork ⇒ String
If specified, this subnetwork must belong to the same network as that of the network interface.
-
#vlan ⇒ Fixnum
VLAN tag.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NetworkInterfaceSubInterface
constructor
A new instance of NetworkInterfaceSubInterface.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NetworkInterfaceSubInterface
Returns a new instance of NetworkInterfaceSubInterface.
46394 46395 46396 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 46394 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ip_address ⇒ String
An IPv4 internal IP address to assign to the instance for this
subinterface. If specified, ip_allocation_mode should be set to
ALLOCATE_IP.
Corresponds to the JSON property ipAddress
46367 46368 46369 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 46367 def ip_address @ip_address end |
#ip_allocation_mode ⇒ String
Corresponds to the JSON property ipAllocationMode
46372 46373 46374 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 46372 def ip_allocation_mode @ip_allocation_mode end |
#subnetwork ⇒ String
If specified, this subnetwork must belong to the same network as that of the network interface. If not specified the subnet of network interface will be used. If you specify this property, you can specify the subnetwork as a full or partial URL. For example, the following are all valid URLs:
- https://www.googleapis.com/compute/v1/projects/project/regions/region/ subnetworks/subnetwork
- regions/region/subnetworks/subnetwork
Corresponds to the JSON property
subnetwork
46386 46387 46388 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 46386 def subnetwork @subnetwork end |
#vlan ⇒ Fixnum
VLAN tag. Should match the VLAN(s) supported by the subnetwork to which
this subinterface is connecting.
Corresponds to the JSON property vlan
46392 46393 46394 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 46392 def vlan @vlan end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
46399 46400 46401 46402 46403 46404 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 46399 def update!(**args) @ip_address = args[:ip_address] if args.key?(:ip_address) @ip_allocation_mode = args[:ip_allocation_mode] if args.key?(:ip_allocation_mode) @subnetwork = args[:subnetwork] if args.key?(:subnetwork) @vlan = args[:vlan] if args.key?(:vlan) end |