Class: Google::Apis::ComputeAlpha::NetworkInterfaceSubInterface
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::NetworkInterfaceSubInterface
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#ip_address ⇒ String
An IPv4 internal IP address to assign to the instance for this subinterface.
-
#ip_allocation_mode ⇒ String
Corresponds to the JSON property
ipAllocationMode. -
#subnetwork ⇒ String
If specified, this subnetwork must belong to the same network as that of the network interface.
-
#vlan ⇒ Fixnum
VLAN tag.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NetworkInterfaceSubInterface
constructor
A new instance of NetworkInterfaceSubInterface.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NetworkInterfaceSubInterface
Returns a new instance of NetworkInterfaceSubInterface.
45120 45121 45122 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 45120 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ip_address ⇒ String
An IPv4 internal IP address to assign to the instance for this
subinterface. If specified, ip_allocation_mode should be set to
ALLOCATE_IP.
Corresponds to the JSON property ipAddress
45093 45094 45095 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 45093 def ip_address @ip_address end |
#ip_allocation_mode ⇒ String
Corresponds to the JSON property ipAllocationMode
45098 45099 45100 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 45098 def ip_allocation_mode @ip_allocation_mode end |
#subnetwork ⇒ String
If specified, this subnetwork must belong to the same network as that of the network interface. If not specified the subnet of network interface will be used. If you specify this property, you can specify the subnetwork as a full or partial URL. For example, the following are all valid URLs:
- https://www.googleapis.com/compute/v1/projects/project/regions/region/ subnetworks/subnetwork
- regions/region/subnetworks/subnetwork
Corresponds to the JSON property
subnetwork
45112 45113 45114 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 45112 def subnetwork @subnetwork end |
#vlan ⇒ Fixnum
VLAN tag. Should match the VLAN(s) supported by the subnetwork to which
this subinterface is connecting.
Corresponds to the JSON property vlan
45118 45119 45120 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 45118 def vlan @vlan end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
45125 45126 45127 45128 45129 45130 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 45125 def update!(**args) @ip_address = args[:ip_address] if args.key?(:ip_address) @ip_allocation_mode = args[:ip_allocation_mode] if args.key?(:ip_allocation_mode) @subnetwork = args[:subnetwork] if args.key?(:subnetwork) @vlan = args[:vlan] if args.key?(:vlan) end |