Class: Google::Apis::ComputeAlpha::NetworkList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::NetworkList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Contains a list of networks.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::Network>
A list of Network resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::NetworkList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NetworkList
constructor
A new instance of NetworkList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NetworkList
Returns a new instance of NetworkList.
46967 46968 46969 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 46967 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
46934 46935 46936 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 46934 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::Network>
A list of Network resources.
Corresponds to the JSON property items
46939 46940 46941 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 46939 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#networkList for
lists of networks.
Corresponds to the JSON property kind
46945 46946 46947 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 46945 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
46955 46956 46957 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 46955 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
46960 46961 46962 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 46960 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::NetworkList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
46965 46966 46967 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 46965 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
46972 46973 46974 46975 46976 46977 46978 46979 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 46972 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |