Class: Google::Apis::ComputeAlpha::NetworkList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of networks.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkList

Returns a new instance of NetworkList.



46726
46727
46728
# File 'lib/google/apis/compute_alpha/classes.rb', line 46726

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


46693
46694
46695
# File 'lib/google/apis/compute_alpha/classes.rb', line 46693

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::Network>

A list of Network resources. Corresponds to the JSON property items



46698
46699
46700
# File 'lib/google/apis/compute_alpha/classes.rb', line 46698

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#networkList for lists of networks. Corresponds to the JSON property kind

Returns:

  • (String)


46704
46705
46706
# File 'lib/google/apis/compute_alpha/classes.rb', line 46704

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


46714
46715
46716
# File 'lib/google/apis/compute_alpha/classes.rb', line 46714

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


46719
46720
46721
# File 'lib/google/apis/compute_alpha/classes.rb', line 46719

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::NetworkList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



46724
46725
46726
# File 'lib/google/apis/compute_alpha/classes.rb', line 46724

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



46731
46732
46733
46734
46735
46736
46737
46738
# File 'lib/google/apis/compute_alpha/classes.rb', line 46731

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end