Class: Google::Apis::ComputeAlpha::NetworkList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::NetworkList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Contains a list of networks.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::Network>
A list of Network resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::NetworkList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NetworkList
constructor
A new instance of NetworkList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NetworkList
Returns a new instance of NetworkList.
45175 45176 45177 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 45175 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
45142 45143 45144 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 45142 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::Network>
A list of Network resources.
Corresponds to the JSON property items
45147 45148 45149 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 45147 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#networkList for
lists of networks.
Corresponds to the JSON property kind
45153 45154 45155 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 45153 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
45163 45164 45165 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 45163 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
45168 45169 45170 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 45168 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::NetworkList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
45173 45174 45175 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 45173 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
45180 45181 45182 45183 45184 45185 45186 45187 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 45180 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |