Class: Google::Apis::ComputeAlpha::NetworkList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of networks.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkList

Returns a new instance of NetworkList.



45173
45174
45175
# File 'lib/google/apis/compute_alpha/classes.rb', line 45173

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


45140
45141
45142
# File 'lib/google/apis/compute_alpha/classes.rb', line 45140

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::Network>

A list of Network resources. Corresponds to the JSON property items



45145
45146
45147
# File 'lib/google/apis/compute_alpha/classes.rb', line 45145

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#networkList for lists of networks. Corresponds to the JSON property kind

Returns:

  • (String)


45151
45152
45153
# File 'lib/google/apis/compute_alpha/classes.rb', line 45151

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


45161
45162
45163
# File 'lib/google/apis/compute_alpha/classes.rb', line 45161

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


45166
45167
45168
# File 'lib/google/apis/compute_alpha/classes.rb', line 45166

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::NetworkList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



45171
45172
45173
# File 'lib/google/apis/compute_alpha/classes.rb', line 45171

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



45178
45179
45180
45181
45182
45183
45184
45185
# File 'lib/google/apis/compute_alpha/classes.rb', line 45178

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end