Class: Google::Apis::ComputeAlpha::NetworkList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of networks.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkList

Returns a new instance of NetworkList.



44972
44973
44974
# File 'lib/google/apis/compute_alpha/classes.rb', line 44972

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


44939
44940
44941
# File 'lib/google/apis/compute_alpha/classes.rb', line 44939

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::Network>

A list of Network resources. Corresponds to the JSON property items



44944
44945
44946
# File 'lib/google/apis/compute_alpha/classes.rb', line 44944

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#networkList for lists of networks. Corresponds to the JSON property kind

Returns:

  • (String)


44950
44951
44952
# File 'lib/google/apis/compute_alpha/classes.rb', line 44950

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


44960
44961
44962
# File 'lib/google/apis/compute_alpha/classes.rb', line 44960

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


44965
44966
44967
# File 'lib/google/apis/compute_alpha/classes.rb', line 44965

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::NetworkList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



44970
44971
44972
# File 'lib/google/apis/compute_alpha/classes.rb', line 44970

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



44977
44978
44979
44980
44981
44982
44983
44984
# File 'lib/google/apis/compute_alpha/classes.rb', line 44977

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end