Class: Google::Apis::ComputeAlpha::NetworkPeeringConnectionStatus

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

[Output Only] Describes the state of a peering connection, not just the local peering. This field provides information about the effective settings for the connection as a whole, including pending delete/update requests for CONSENSUS peerings.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkPeeringConnectionStatus

Returns a new instance of NetworkPeeringConnectionStatus.



44501
44502
44503
# File 'lib/google/apis/compute_alpha/classes.rb', line 44501

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#consensus_stateGoogle::Apis::ComputeAlpha::NetworkPeeringConnectionStatusConsensusState

The status of update/delete for a consensus peering connection. Only set when connection_status.update_strategy isCONSENSUS or a network peering is proposing to update the strategy to CONSENSUS. Corresponds to the JSON property consensusState



44487
44488
44489
# File 'lib/google/apis/compute_alpha/classes.rb', line 44487

def consensus_state
  @consensus_state
end

#traffic_configurationGoogle::Apis::ComputeAlpha::NetworkPeeringConnectionStatusTrafficConfiguration

The active connectivity settings for the peering connection based on the settings of the network peerings. Corresponds to the JSON property trafficConfiguration



44493
44494
44495
# File 'lib/google/apis/compute_alpha/classes.rb', line 44493

def traffic_configuration
  @traffic_configuration
end

#update_strategyString

The update strategy determines the update/delete semantics for this peering connection. Corresponds to the JSON property updateStrategy

Returns:

  • (String)


44499
44500
44501
# File 'lib/google/apis/compute_alpha/classes.rb', line 44499

def update_strategy
  @update_strategy
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



44506
44507
44508
44509
44510
# File 'lib/google/apis/compute_alpha/classes.rb', line 44506

def update!(**args)
  @consensus_state = args[:consensus_state] if args.key?(:consensus_state)
  @traffic_configuration = args[:traffic_configuration] if args.key?(:traffic_configuration)
  @update_strategy = args[:update_strategy] if args.key?(:update_strategy)
end