Class: Google::Apis::ComputeAlpha::NetworkPeeringConnectionStatusTrafficConfiguration

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkPeeringConnectionStatusTrafficConfiguration

Returns a new instance of NetworkPeeringConnectionStatusTrafficConfiguration.



45334
45335
45336
# File 'lib/google/apis/compute_alpha/classes.rb', line 45334

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#export_custom_routes_to_peerBoolean Also known as: export_custom_routes_to_peer?

Whether custom routes are being exported to the peer network. Corresponds to the JSON property exportCustomRoutesToPeer

Returns:

  • (Boolean)


45305
45306
45307
# File 'lib/google/apis/compute_alpha/classes.rb', line 45305

def export_custom_routes_to_peer
  @export_custom_routes_to_peer
end

#export_subnet_routes_with_public_ip_to_peerBoolean Also known as: export_subnet_routes_with_public_ip_to_peer?

Whether subnet routes with public IP ranges are being exported to the peer network. Corresponds to the JSON property exportSubnetRoutesWithPublicIpToPeer

Returns:

  • (Boolean)


45312
45313
45314
# File 'lib/google/apis/compute_alpha/classes.rb', line 45312

def export_subnet_routes_with_public_ip_to_peer
  @export_subnet_routes_with_public_ip_to_peer
end

#import_custom_routes_from_peerBoolean Also known as: import_custom_routes_from_peer?

Whether custom routes are being imported from the peer network. Corresponds to the JSON property importCustomRoutesFromPeer

Returns:

  • (Boolean)


45318
45319
45320
# File 'lib/google/apis/compute_alpha/classes.rb', line 45318

def import_custom_routes_from_peer
  @import_custom_routes_from_peer
end

#import_subnet_routes_with_public_ip_from_peerBoolean Also known as: import_subnet_routes_with_public_ip_from_peer?

Whether subnet routes with public IP ranges are being imported from the peer network. Corresponds to the JSON property importSubnetRoutesWithPublicIpFromPeer

Returns:

  • (Boolean)


45325
45326
45327
# File 'lib/google/apis/compute_alpha/classes.rb', line 45325

def import_subnet_routes_with_public_ip_from_peer
  @import_subnet_routes_with_public_ip_from_peer
end

#stack_typeString

Which IP version(s) of traffic and routes are being imported or exported between peer networks. Corresponds to the JSON property stackType

Returns:

  • (String)


45332
45333
45334
# File 'lib/google/apis/compute_alpha/classes.rb', line 45332

def stack_type
  @stack_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



45339
45340
45341
45342
45343
45344
45345
# File 'lib/google/apis/compute_alpha/classes.rb', line 45339

def update!(**args)
  @export_custom_routes_to_peer = args[:export_custom_routes_to_peer] if args.key?(:export_custom_routes_to_peer)
  @export_subnet_routes_with_public_ip_to_peer = args[:export_subnet_routes_with_public_ip_to_peer] if args.key?(:export_subnet_routes_with_public_ip_to_peer)
  @import_custom_routes_from_peer = args[:import_custom_routes_from_peer] if args.key?(:import_custom_routes_from_peer)
  @import_subnet_routes_with_public_ip_from_peer = args[:import_subnet_routes_with_public_ip_from_peer] if args.key?(:import_subnet_routes_with_public_ip_from_peer)
  @stack_type = args[:stack_type] if args.key?(:stack_type)
end