Class: Google::Apis::ComputeAlpha::NetworkPolicy

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Represents a Network Policy resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkPolicy

Returns a new instance of NetworkPolicy.



45961
45962
45963
# File 'lib/google/apis/compute_alpha/classes.rb', line 45961

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#associationsArray<Google::Apis::ComputeAlpha::NetworkPolicyAssociation>

Output only. [Output Only] A list of associations that belong to this network policy. Corresponds to the JSON property associations



45897
45898
45899
# File 'lib/google/apis/compute_alpha/classes.rb', line 45897

def associations
  @associations
end

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


45903
45904
45905
# File 'lib/google/apis/compute_alpha/classes.rb', line 45903

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


45909
45910
45911
# File 'lib/google/apis/compute_alpha/classes.rb', line 45909

def description
  @description
end

#idFixnum

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


45915
45916
45917
# File 'lib/google/apis/compute_alpha/classes.rb', line 45915

def id
  @id
end

#kindString

Output only. [Output only] Type of the resource. Alwayscompute#networkPolicy for network policies Corresponds to the JSON property kind

Returns:

  • (String)


45921
45922
45923
# File 'lib/google/apis/compute_alpha/classes.rb', line 45921

def kind
  @kind
end

#nameString

Name of the resource. Corresponds to the JSON property name

Returns:

  • (String)


45926
45927
45928
# File 'lib/google/apis/compute_alpha/classes.rb', line 45926

def name
  @name
end

#regionString

Output only. [Output Only] URL of the region where the regional network policy resides. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body. Corresponds to the JSON property region

Returns:

  • (String)


45934
45935
45936
# File 'lib/google/apis/compute_alpha/classes.rb', line 45934

def region
  @region
end

#rule_tuple_countFixnum

Output only. [Output Only] Total count of all network policy rule tuples. A network policy can not exceed a set number of tuples. Corresponds to the JSON property ruleTupleCount

Returns:

  • (Fixnum)


45941
45942
45943
# File 'lib/google/apis/compute_alpha/classes.rb', line 45941

def rule_tuple_count
  @rule_tuple_count
end

Output only. [Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


45946
45947
45948
# File 'lib/google/apis/compute_alpha/classes.rb', line 45946

def self_link
  @self_link
end

Output only. [Output Only] Server-defined URL for this resource with the resource id. Corresponds to the JSON property selfLinkWithId

Returns:

  • (String)


45952
45953
45954
# File 'lib/google/apis/compute_alpha/classes.rb', line 45952

def self_link_with_id
  @self_link_with_id
end

#traffic_classification_rulesArray<Google::Apis::ComputeAlpha::NetworkPolicyTrafficClassificationRule>

Output only. [Output Only] A list of traffic classification rules that belong to this policy. Corresponds to the JSON property trafficClassificationRules



45959
45960
45961
# File 'lib/google/apis/compute_alpha/classes.rb', line 45959

def traffic_classification_rules
  @traffic_classification_rules
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



45966
45967
45968
45969
45970
45971
45972
45973
45974
45975
45976
45977
45978
# File 'lib/google/apis/compute_alpha/classes.rb', line 45966

def update!(**args)
  @associations = args[:associations] if args.key?(:associations)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @region = args[:region] if args.key?(:region)
  @rule_tuple_count = args[:rule_tuple_count] if args.key?(:rule_tuple_count)
  @self_link = args[:self_link] if args.key?(:self_link)
  @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id)
  @traffic_classification_rules = args[:traffic_classification_rules] if args.key?(:traffic_classification_rules)
end