Class: Google::Apis::ComputeAlpha::NetworkPolicy
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::NetworkPolicy
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Represents a Network Policy resource.
Instance Attribute Summary collapse
-
#associations ⇒ Array<Google::Apis::ComputeAlpha::NetworkPolicyAssociation>
Output only.
-
#creation_timestamp ⇒ String
Output only.
-
#description ⇒ String
An optional description of this resource.
-
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
Name of the resource.
-
#region ⇒ String
Output only.
-
#rule_tuple_count ⇒ Fixnum
Output only.
-
#self_link ⇒ String
Output only.
-
#self_link_with_id ⇒ String
Output only.
-
#traffic_classification_rules ⇒ Array<Google::Apis::ComputeAlpha::NetworkPolicyTrafficClassificationRule>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NetworkPolicy
constructor
A new instance of NetworkPolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NetworkPolicy
Returns a new instance of NetworkPolicy.
44785 44786 44787 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 44785 def initialize(**args) update!(**args) end |
Instance Attribute Details
#associations ⇒ Array<Google::Apis::ComputeAlpha::NetworkPolicyAssociation>
Output only. [Output Only] A list of associations that belong to this network
policy.
Corresponds to the JSON property associations
44721 44722 44723 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 44721 def associations @associations end |
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
44727 44728 44729 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 44727 def @creation_timestamp end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
44733 44734 44735 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 44733 def description @description end |
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
44739 44740 44741 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 44739 def id @id end |
#kind ⇒ String
Output only. [Output only] Type of the resource. Alwayscompute#networkPolicy
for network policies
Corresponds to the JSON property kind
44745 44746 44747 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 44745 def kind @kind end |
#name ⇒ String
Name of the resource.
Corresponds to the JSON property name
44750 44751 44752 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 44750 def name @name end |
#region ⇒ String
Output only. [Output Only] URL of the region where the regional network policy
resides.
You must specify this field as part of the HTTP request URL. It is
not settable as a field in the request body.
Corresponds to the JSON property region
44758 44759 44760 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 44758 def region @region end |
#rule_tuple_count ⇒ Fixnum
Output only. [Output Only] Total count of all network policy rule tuples. A
network
policy can not exceed a set number of tuples.
Corresponds to the JSON property ruleTupleCount
44765 44766 44767 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 44765 def rule_tuple_count @rule_tuple_count end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
44770 44771 44772 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 44770 def self_link @self_link end |
#self_link_with_id ⇒ String
Output only. [Output Only] Server-defined URL for this resource with the
resource id.
Corresponds to the JSON property selfLinkWithId
44776 44777 44778 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 44776 def self_link_with_id @self_link_with_id end |
#traffic_classification_rules ⇒ Array<Google::Apis::ComputeAlpha::NetworkPolicyTrafficClassificationRule>
Output only. [Output Only] A list of traffic classification rules that belong
to this
policy.
Corresponds to the JSON property trafficClassificationRules
44783 44784 44785 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 44783 def traffic_classification_rules @traffic_classification_rules end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
44790 44791 44792 44793 44794 44795 44796 44797 44798 44799 44800 44801 44802 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 44790 def update!(**args) @associations = args[:associations] if args.key?(:associations) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @region = args[:region] if args.key?(:region) @rule_tuple_count = args[:rule_tuple_count] if args.key?(:rule_tuple_count) @self_link = args[:self_link] if args.key?(:self_link) @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id) @traffic_classification_rules = args[:traffic_classification_rules] if args.key?(:traffic_classification_rules) end |