Class: Google::Apis::ComputeAlpha::NetworkPolicyAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkPolicyAggregatedList

Returns a new instance of NetworkPolicyAggregatedList.



47362
47363
47364
# File 'lib/google/apis/compute_alpha/classes.rb', line 47362

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


47323
47324
47325
# File 'lib/google/apis/compute_alpha/classes.rb', line 47323

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::NetworkPoliciesScopedList>

A list of NetworkPoliciesScopedList resources. Corresponds to the JSON property items



47328
47329
47330
# File 'lib/google/apis/compute_alpha/classes.rb', line 47328

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# networkPolicyAggregatedList for lists of network policies. Corresponds to the JSON property kind

Returns:

  • (String)


47335
47336
47337
# File 'lib/google/apis/compute_alpha/classes.rb', line 47335

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


47345
47346
47347
# File 'lib/google/apis/compute_alpha/classes.rb', line 47345

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


47350
47351
47352
# File 'lib/google/apis/compute_alpha/classes.rb', line 47350

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


47355
47356
47357
# File 'lib/google/apis/compute_alpha/classes.rb', line 47355

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::NetworkPolicyAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



47360
47361
47362
# File 'lib/google/apis/compute_alpha/classes.rb', line 47360

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



47367
47368
47369
47370
47371
47372
47373
47374
47375
# File 'lib/google/apis/compute_alpha/classes.rb', line 47367

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end