Class: Google::Apis::ComputeAlpha::NetworkPolicyAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::NetworkPolicyAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::NetworkPoliciesScopedList>
A list of NetworkPoliciesScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::NetworkPolicyAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NetworkPolicyAggregatedList
constructor
A new instance of NetworkPolicyAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NetworkPolicyAggregatedList
Returns a new instance of NetworkPolicyAggregatedList.
47083 47084 47085 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 47083 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
47044 47045 47046 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 47044 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::NetworkPoliciesScopedList>
A list of NetworkPoliciesScopedList resources.
Corresponds to the JSON property items
47049 47050 47051 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 47049 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
networkPolicyAggregatedList for lists of
network policies.
Corresponds to the JSON property kind
47056 47057 47058 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 47056 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
47066 47067 47068 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 47066 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
47071 47072 47073 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 47071 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
47076 47077 47078 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 47076 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::NetworkPolicyAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
47081 47082 47083 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 47081 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
47088 47089 47090 47091 47092 47093 47094 47095 47096 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 47088 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |