Class: Google::Apis::ComputeAlpha::NetworkPolicyAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkPolicyAggregatedList

Returns a new instance of NetworkPolicyAggregatedList.



46044
46045
46046
# File 'lib/google/apis/compute_alpha/classes.rb', line 46044

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


46005
46006
46007
# File 'lib/google/apis/compute_alpha/classes.rb', line 46005

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::NetworkPoliciesScopedList>

A list of NetworkPoliciesScopedList resources. Corresponds to the JSON property items



46010
46011
46012
# File 'lib/google/apis/compute_alpha/classes.rb', line 46010

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# networkPolicyAggregatedList for lists of network policies. Corresponds to the JSON property kind

Returns:

  • (String)


46017
46018
46019
# File 'lib/google/apis/compute_alpha/classes.rb', line 46017

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


46027
46028
46029
# File 'lib/google/apis/compute_alpha/classes.rb', line 46027

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


46032
46033
46034
# File 'lib/google/apis/compute_alpha/classes.rb', line 46032

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


46037
46038
46039
# File 'lib/google/apis/compute_alpha/classes.rb', line 46037

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::NetworkPolicyAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



46042
46043
46044
# File 'lib/google/apis/compute_alpha/classes.rb', line 46042

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



46049
46050
46051
46052
46053
46054
46055
46056
46057
# File 'lib/google/apis/compute_alpha/classes.rb', line 46049

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end