Class: Google::Apis::ComputeAlpha::NetworkPolicyAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::NetworkPolicyAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::NetworkPoliciesScopedList>
A list of NetworkPoliciesScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::NetworkPolicyAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NetworkPolicyAggregatedList
constructor
A new instance of NetworkPolicyAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NetworkPolicyAggregatedList
Returns a new instance of NetworkPolicyAggregatedList.
45811 45812 45813 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 45811 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
45772 45773 45774 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 45772 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::NetworkPoliciesScopedList>
A list of NetworkPoliciesScopedList resources.
Corresponds to the JSON property items
45777 45778 45779 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 45777 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
networkPolicyAggregatedList for lists of
network policies.
Corresponds to the JSON property kind
45784 45785 45786 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 45784 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
45794 45795 45796 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 45794 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
45799 45800 45801 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 45799 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
45804 45805 45806 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 45804 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::NetworkPolicyAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
45809 45810 45811 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 45809 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
45816 45817 45818 45819 45820 45821 45822 45823 45824 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 45816 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |