Class: Google::Apis::ComputeAlpha::NetworkPolicyList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkPolicyList

Returns a new instance of NetworkPolicyList.



45957
45958
45959
# File 'lib/google/apis/compute_alpha/classes.rb', line 45957

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


45929
45930
45931
# File 'lib/google/apis/compute_alpha/classes.rb', line 45929

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::NetworkPolicy>

A list of NetworkPolicy resources. Corresponds to the JSON property items



45934
45935
45936
# File 'lib/google/apis/compute_alpha/classes.rb', line 45934

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute#networkPolicyList for lists of network policies. Corresponds to the JSON property kind

Returns:

  • (String)


45940
45941
45942
# File 'lib/google/apis/compute_alpha/classes.rb', line 45940

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


45950
45951
45952
# File 'lib/google/apis/compute_alpha/classes.rb', line 45950

def next_page_token
  @next_page_token
end

#warningGoogle::Apis::ComputeAlpha::NetworkPolicyList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



45955
45956
45957
# File 'lib/google/apis/compute_alpha/classes.rb', line 45955

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



45962
45963
45964
45965
45966
45967
45968
# File 'lib/google/apis/compute_alpha/classes.rb', line 45962

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @warning = args[:warning] if args.key?(:warning)
end