Class: Google::Apis::ComputeAlpha::NetworkPolicyList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::NetworkPolicyList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::NetworkPolicy>
A list of NetworkPolicy resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#warning ⇒ Google::Apis::ComputeAlpha::NetworkPolicyList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NetworkPolicyList
constructor
A new instance of NetworkPolicyList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NetworkPolicyList
Returns a new instance of NetworkPolicyList.
45754 45755 45756 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 45754 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
45726 45727 45728 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 45726 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::NetworkPolicy>
A list of NetworkPolicy resources.
Corresponds to the JSON property items
45731 45732 45733 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 45731 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#networkPolicyList
for lists of network policies.
Corresponds to the JSON property kind
45737 45738 45739 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 45737 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
45747 45748 45749 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 45747 def next_page_token @next_page_token end |
#warning ⇒ Google::Apis::ComputeAlpha::NetworkPolicyList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
45752 45753 45754 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 45752 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
45759 45760 45761 45762 45763 45764 45765 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 45759 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @warning = args[:warning] if args.key?(:warning) end |