Class: Google::Apis::ComputeAlpha::NetworkPolicyTrafficClassificationRule

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Represents a traffic classification rule that describes one or more match conditions along with the action to be taken when traffic matches this condition.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkPolicyTrafficClassificationRule

Returns a new instance of NetworkPolicyTrafficClassificationRule.



47674
47675
47676
# File 'lib/google/apis/compute_alpha/classes.rb', line 47674

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#actionGoogle::Apis::ComputeAlpha::NetworkPolicyTrafficClassificationRuleAction

The Action to perform when the client connection triggers the rule. Corresponds to the JSON property action



47601
47602
47603
# File 'lib/google/apis/compute_alpha/classes.rb', line 47601

def action
  @action
end

#descriptionString

An optional description for this resource. Corresponds to the JSON property description

Returns:

  • (String)


47606
47607
47608
# File 'lib/google/apis/compute_alpha/classes.rb', line 47606

def description
  @description
end

#disabledBoolean Also known as: disabled?

Denotes whether the network policy rule is disabled. When set to true, the network policy rule is not enforced and traffic behaves as if it did not exist. If this is unspecified, the network policy rule will be enabled. Corresponds to the JSON property disabled

Returns:

  • (Boolean)


47614
47615
47616
# File 'lib/google/apis/compute_alpha/classes.rb', line 47614

def disabled
  @disabled
end

#kindString

Output only. [Output only] Type of the resource. Alwayscompute# networkPolicyTrafficClassificationRule for network policy traffic classification rules Corresponds to the JSON property kind

Returns:

  • (String)


47622
47623
47624
# File 'lib/google/apis/compute_alpha/classes.rb', line 47622

def kind
  @kind
end

#matchGoogle::Apis::ComputeAlpha::NetworkPolicyTrafficClassificationRuleMatcher

Represents a match condition that incoming traffic is evaluated against. Exactly one field must be specified. Corresponds to the JSON property match



47628
47629
47630
# File 'lib/google/apis/compute_alpha/classes.rb', line 47628

def match
  @match
end

#priorityFixnum

An integer indicating the priority of a rule in the list. The priority must be a positive value between 1 and 2147482647. The priority values from 2147482648 to 2147483647 (1000) are reserved for system default network policy rules. Rules are evaluated from highest to lowest priority where 1 is the highest priority and 2147483647 is the lowest priority. Corresponds to the JSON property priority

Returns:

  • (Fixnum)


47638
47639
47640
# File 'lib/google/apis/compute_alpha/classes.rb', line 47638

def priority
  @priority
end

#rule_nameString

An optional name for the rule. This field is not a unique identifier and can be updated. Corresponds to the JSON property ruleName

Returns:

  • (String)


47644
47645
47646
# File 'lib/google/apis/compute_alpha/classes.rb', line 47644

def rule_name
  @rule_name
end

#rule_tuple_countFixnum

Output only. [Output Only] Calculation of the complexity of a single network policy rule. Corresponds to the JSON property ruleTupleCount

Returns:

  • (Fixnum)


47651
47652
47653
# File 'lib/google/apis/compute_alpha/classes.rb', line 47651

def rule_tuple_count
  @rule_tuple_count
end

#target_secure_tagsArray<Google::Apis::ComputeAlpha::NetworkPolicyTrafficClassificationRuleSecureTag>

A list of secure tags that controls which instances the traffic classification rule applies to. If targetSecureTag are specified, then the traffic classification rule applies only to instances in the VPC network that have one of those EFFECTIVE secure tags, if all the targetSecureTag are in INEFFECTIVE state, then this rule will be ignored. targetSecureTag may not be set at the same time as targetServiceAccounts. If neithertargetServiceAccounts nor targetSecureTag are specified, the traffic classification rule applies to all instances on the specified network. Maximum number of target label tags allowed is 256. Corresponds to the JSON property targetSecureTags



47666
47667
47668
# File 'lib/google/apis/compute_alpha/classes.rb', line 47666

def target_secure_tags
  @target_secure_tags
end

#target_service_accountsArray<String>

A list of service accounts indicating the sets of instances that are applied with this rule. Corresponds to the JSON property targetServiceAccounts

Returns:

  • (Array<String>)


47672
47673
47674
# File 'lib/google/apis/compute_alpha/classes.rb', line 47672

def target_service_accounts
  @target_service_accounts
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



47679
47680
47681
47682
47683
47684
47685
47686
47687
47688
47689
47690
# File 'lib/google/apis/compute_alpha/classes.rb', line 47679

def update!(**args)
  @action = args[:action] if args.key?(:action)
  @description = args[:description] if args.key?(:description)
  @disabled = args[:disabled] if args.key?(:disabled)
  @kind = args[:kind] if args.key?(:kind)
  @match = args[:match] if args.key?(:match)
  @priority = args[:priority] if args.key?(:priority)
  @rule_name = args[:rule_name] if args.key?(:rule_name)
  @rule_tuple_count = args[:rule_tuple_count] if args.key?(:rule_tuple_count)
  @target_secure_tags = args[:target_secure_tags] if args.key?(:target_secure_tags)
  @target_service_accounts = args[:target_service_accounts] if args.key?(:target_service_accounts)
end