Class: Google::Apis::ComputeAlpha::NetworkPolicyTrafficClassificationRuleAction
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::NetworkPolicyTrafficClassificationRuleAction
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#dscp_mode ⇒ String
DSCP mode.
-
#dscp_value ⇒ Fixnum
Custom DSCP value from 0-63 range.
-
#traffic_class ⇒ String
The traffic class that should be applied to the matching packet.
-
#type ⇒ String
Always "apply_traffic_classification" for traffic classification rules.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NetworkPolicyTrafficClassificationRuleAction
constructor
A new instance of NetworkPolicyTrafficClassificationRuleAction.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NetworkPolicyTrafficClassificationRuleAction
Returns a new instance of NetworkPolicyTrafficClassificationRuleAction.
47960 47961 47962 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 47960 def initialize(**args) update!(**args) end |
Instance Attribute Details
#dscp_mode ⇒ String
DSCP mode. When set to AUTO, the DSCP value will be picked
automatically based on selected trafficClass. Otherwise,dscpValue needs to be
explicitly specified.
Corresponds to the JSON property dscpMode
47943 47944 47945 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 47943 def dscp_mode @dscp_mode end |
#dscp_value ⇒ Fixnum
Custom DSCP value from 0-63 range.
Corresponds to the JSON property dscpValue
47948 47949 47950 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 47948 def dscp_value @dscp_value end |
#traffic_class ⇒ String
The traffic class that should be applied to the matching packet.
Corresponds to the JSON property trafficClass
47953 47954 47955 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 47953 def traffic_class @traffic_class end |
#type ⇒ String
Always "apply_traffic_classification" for traffic classification rules.
Corresponds to the JSON property type
47958 47959 47960 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 47958 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
47965 47966 47967 47968 47969 47970 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 47965 def update!(**args) @dscp_mode = args[:dscp_mode] if args.key?(:dscp_mode) @dscp_value = args[:dscp_value] if args.key?(:dscp_value) @traffic_class = args[:traffic_class] if args.key?(:traffic_class) @type = args[:type] if args.key?(:type) end |