Class: Google::Apis::ComputeAlpha::NetworkPolicyTrafficClassificationRuleAction

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkPolicyTrafficClassificationRuleAction

Returns a new instance of NetworkPolicyTrafficClassificationRuleAction.



46166
46167
46168
# File 'lib/google/apis/compute_alpha/classes.rb', line 46166

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dscp_modeString

DSCP mode. When set to AUTO, the DSCP value will be picked automatically based on selected trafficClass. Otherwise,dscpValue needs to be explicitly specified. Corresponds to the JSON property dscpMode

Returns:

  • (String)


46149
46150
46151
# File 'lib/google/apis/compute_alpha/classes.rb', line 46149

def dscp_mode
  @dscp_mode
end

#dscp_valueFixnum

Custom DSCP value from 0-63 range. Corresponds to the JSON property dscpValue

Returns:

  • (Fixnum)


46154
46155
46156
# File 'lib/google/apis/compute_alpha/classes.rb', line 46154

def dscp_value
  @dscp_value
end

#traffic_classString

The traffic class that should be applied to the matching packet. Corresponds to the JSON property trafficClass

Returns:

  • (String)


46159
46160
46161
# File 'lib/google/apis/compute_alpha/classes.rb', line 46159

def traffic_class
  @traffic_class
end

#typeString

Always "apply_traffic_classification" for traffic classification rules. Corresponds to the JSON property type

Returns:

  • (String)


46164
46165
46166
# File 'lib/google/apis/compute_alpha/classes.rb', line 46164

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



46171
46172
46173
46174
46175
46176
# File 'lib/google/apis/compute_alpha/classes.rb', line 46171

def update!(**args)
  @dscp_mode = args[:dscp_mode] if args.key?(:dscp_mode)
  @dscp_value = args[:dscp_value] if args.key?(:dscp_value)
  @traffic_class = args[:traffic_class] if args.key?(:traffic_class)
  @type = args[:type] if args.key?(:type)
end