Class: Google::Apis::ComputeAlpha::NetworkPolicyTrafficClassificationRuleAction

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkPolicyTrafficClassificationRuleAction

Returns a new instance of NetworkPolicyTrafficClassificationRuleAction.



45208
45209
45210
# File 'lib/google/apis/compute_alpha/classes.rb', line 45208

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dscp_modeString

DSCP mode. When set to AUTO, the DSCP value will be picked automatically based on selected trafficClass. Otherwise,dscpValue needs to be explicitly specified. Corresponds to the JSON property dscpMode

Returns:

  • (String)


45191
45192
45193
# File 'lib/google/apis/compute_alpha/classes.rb', line 45191

def dscp_mode
  @dscp_mode
end

#dscp_valueFixnum

Custom DSCP value from 0-63 range. Corresponds to the JSON property dscpValue

Returns:

  • (Fixnum)


45196
45197
45198
# File 'lib/google/apis/compute_alpha/classes.rb', line 45196

def dscp_value
  @dscp_value
end

#traffic_classString

The traffic class that should be applied to the matching packet. Corresponds to the JSON property trafficClass

Returns:

  • (String)


45201
45202
45203
# File 'lib/google/apis/compute_alpha/classes.rb', line 45201

def traffic_class
  @traffic_class
end

#typeString

Always "apply_traffic_classification" for traffic classification rules. Corresponds to the JSON property type

Returns:

  • (String)


45206
45207
45208
# File 'lib/google/apis/compute_alpha/classes.rb', line 45206

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



45213
45214
45215
45216
45217
45218
# File 'lib/google/apis/compute_alpha/classes.rb', line 45213

def update!(**args)
  @dscp_mode = args[:dscp_mode] if args.key?(:dscp_mode)
  @dscp_value = args[:dscp_value] if args.key?(:dscp_value)
  @traffic_class = args[:traffic_class] if args.key?(:traffic_class)
  @type = args[:type] if args.key?(:type)
end