Class: Google::Apis::ComputeAlpha::NetworkPolicyTrafficClassificationRuleMatcher

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Represents a match condition that incoming traffic is evaluated against. Exactly one field must be specified.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkPolicyTrafficClassificationRuleMatcher

Returns a new instance of NetworkPolicyTrafficClassificationRuleMatcher.



47762
47763
47764
# File 'lib/google/apis/compute_alpha/classes.rb', line 47762

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dest_address_groupsArray<String>

Address groups which should be matched against the traffic destination. Maximum number of destination address groups is 10. Example: projects//locations//addressGroups/. Corresponds to the JSON property destAddressGroups

Returns:

  • (Array<String>)


47743
47744
47745
# File 'lib/google/apis/compute_alpha/classes.rb', line 47743

def dest_address_groups
  @dest_address_groups
end

#dest_ip_rangesArray<String>

CIDR IP address range. Maximum number of destination CIDR IP ranges allowed is 5000. Corresponds to the JSON property destIpRanges

Returns:

  • (Array<String>)


47749
47750
47751
# File 'lib/google/apis/compute_alpha/classes.rb', line 47749

def dest_ip_ranges
  @dest_ip_ranges
end

#layer4_configsArray<Google::Apis::ComputeAlpha::NetworkPolicyTrafficClassificationRuleMatcherLayer4Config>

Pairs of IP protocols and ports that the rule should match. Corresponds to the JSON property layer4Configs



47754
47755
47756
# File 'lib/google/apis/compute_alpha/classes.rb', line 47754

def layer4_configs
  @layer4_configs
end

#src_ip_rangesArray<String>

CIDR IP address range. Maximum number of source CIDR IP ranges allowed is 5000. Corresponds to the JSON property srcIpRanges

Returns:

  • (Array<String>)


47760
47761
47762
# File 'lib/google/apis/compute_alpha/classes.rb', line 47760

def src_ip_ranges
  @src_ip_ranges
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



47767
47768
47769
47770
47771
47772
# File 'lib/google/apis/compute_alpha/classes.rb', line 47767

def update!(**args)
  @dest_address_groups = args[:dest_address_groups] if args.key?(:dest_address_groups)
  @dest_ip_ranges = args[:dest_ip_ranges] if args.key?(:dest_ip_ranges)
  @layer4_configs = args[:layer4_configs] if args.key?(:layer4_configs)
  @src_ip_ranges = args[:src_ip_ranges] if args.key?(:src_ip_ranges)
end