Class: Google::Apis::ComputeAlpha::NetworkPolicyTrafficClassificationRuleMatcher
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::NetworkPolicyTrafficClassificationRuleMatcher
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Represents a match condition that incoming traffic is evaluated against. Exactly one field must be specified.
Instance Attribute Summary collapse
-
#dest_address_groups ⇒ Array<String>
Address groups which should be matched against the traffic destination.
-
#dest_ip_ranges ⇒ Array<String>
CIDR IP address range.
-
#layer4_configs ⇒ Array<Google::Apis::ComputeAlpha::NetworkPolicyTrafficClassificationRuleMatcherLayer4Config>
Pairs of IP protocols and ports that the rule should match.
-
#src_ip_ranges ⇒ Array<String>
CIDR IP address range.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NetworkPolicyTrafficClassificationRuleMatcher
constructor
A new instance of NetworkPolicyTrafficClassificationRuleMatcher.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NetworkPolicyTrafficClassificationRuleMatcher
Returns a new instance of NetworkPolicyTrafficClassificationRuleMatcher.
47483 47484 47485 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 47483 def initialize(**args) update!(**args) end |
Instance Attribute Details
#dest_address_groups ⇒ Array<String>
Address groups which should be matched against the traffic destination.
Maximum number of destination address groups is 10.
Example:
projects//locations//addressGroups/.
Corresponds to the JSON property destAddressGroups
47464 47465 47466 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 47464 def dest_address_groups @dest_address_groups end |
#dest_ip_ranges ⇒ Array<String>
CIDR IP address range.
Maximum number of destination CIDR IP ranges allowed is 5000.
Corresponds to the JSON property destIpRanges
47470 47471 47472 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 47470 def dest_ip_ranges @dest_ip_ranges end |
#layer4_configs ⇒ Array<Google::Apis::ComputeAlpha::NetworkPolicyTrafficClassificationRuleMatcherLayer4Config>
Pairs of IP protocols and ports that the rule should match.
Corresponds to the JSON property layer4Configs
47475 47476 47477 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 47475 def layer4_configs @layer4_configs end |
#src_ip_ranges ⇒ Array<String>
CIDR IP address range.
Maximum number of source CIDR IP ranges allowed is 5000.
Corresponds to the JSON property srcIpRanges
47481 47482 47483 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 47481 def src_ip_ranges @src_ip_ranges end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
47488 47489 47490 47491 47492 47493 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 47488 def update!(**args) @dest_address_groups = args[:dest_address_groups] if args.key?(:dest_address_groups) @dest_ip_ranges = args[:dest_ip_ranges] if args.key?(:dest_ip_ranges) @layer4_configs = args[:layer4_configs] if args.key?(:layer4_configs) @src_ip_ranges = args[:src_ip_ranges] if args.key?(:src_ip_ranges) end |