Class: Google::Apis::ComputeAlpha::NetworkPolicyTrafficClassificationRuleMatcher

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Represents a match condition that incoming traffic is evaluated against. Exactly one field must be specified.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkPolicyTrafficClassificationRuleMatcher

Returns a new instance of NetworkPolicyTrafficClassificationRuleMatcher.



46436
46437
46438
# File 'lib/google/apis/compute_alpha/classes.rb', line 46436

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dest_ip_rangesArray<String>

CIDR IP address range. Maximum number of destination CIDR IP ranges allowed is 5000. Corresponds to the JSON property destIpRanges

Returns:

  • (Array<String>)


46423
46424
46425
# File 'lib/google/apis/compute_alpha/classes.rb', line 46423

def dest_ip_ranges
  @dest_ip_ranges
end

#layer4_configsArray<Google::Apis::ComputeAlpha::NetworkPolicyTrafficClassificationRuleMatcherLayer4Config>

Pairs of IP protocols and ports that the rule should match. Corresponds to the JSON property layer4Configs



46428
46429
46430
# File 'lib/google/apis/compute_alpha/classes.rb', line 46428

def layer4_configs
  @layer4_configs
end

#src_ip_rangesArray<String>

CIDR IP address range. Maximum number of source CIDR IP ranges allowed is 5000. Corresponds to the JSON property srcIpRanges

Returns:

  • (Array<String>)


46434
46435
46436
# File 'lib/google/apis/compute_alpha/classes.rb', line 46434

def src_ip_ranges
  @src_ip_ranges
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



46441
46442
46443
46444
46445
# File 'lib/google/apis/compute_alpha/classes.rb', line 46441

def update!(**args)
  @dest_ip_ranges = args[:dest_ip_ranges] if args.key?(:dest_ip_ranges)
  @layer4_configs = args[:layer4_configs] if args.key?(:layer4_configs)
  @src_ip_ranges = args[:src_ip_ranges] if args.key?(:src_ip_ranges)
end