Class: Google::Apis::ComputeAlpha::NetworkPolicyTrafficClassificationRuleMatcherLayer4Config
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::NetworkPolicyTrafficClassificationRuleMatcherLayer4Config
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#ip_protocol ⇒ String
The IP protocol to which this rule applies.
-
#ports ⇒ Array<String>
An optional list of ports to which this rule applies.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NetworkPolicyTrafficClassificationRuleMatcherLayer4Config
constructor
A new instance of NetworkPolicyTrafficClassificationRuleMatcherLayer4Config.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NetworkPolicyTrafficClassificationRuleMatcherLayer4Config
Returns a new instance of NetworkPolicyTrafficClassificationRuleMatcherLayer4Config.
46452 46453 46454 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 46452 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ip_protocol ⇒ String
The IP protocol to which this rule applies. The protocol type is
required when creating a traffic classification rule. This value can
either be one of the following well known protocol strings
(tcp, udp, icmp,esp, ah, ipip,sctp), or the IP protocol number.
Corresponds to the JSON property ipProtocol
46441 46442 46443 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 46441 def ip_protocol @ip_protocol end |
#ports ⇒ Array<String>
An optional list of ports to which this rule applies. This field is
only applicable for UDP, TCP or SCTP protocol. Each entry must be
either an integer or a range. If not specified, this rule applies to
connections through any port.
Example inputs include: ["22"],["80","443"], and ["12345-12349"].
Corresponds to the JSON property ports
46450 46451 46452 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 46450 def ports @ports end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
46457 46458 46459 46460 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 46457 def update!(**args) @ip_protocol = args[:ip_protocol] if args.key?(:ip_protocol) @ports = args[:ports] if args.key?(:ports) end |