Class: Google::Apis::ComputeAlpha::NetworkPolicyTrafficClassificationRuleMatcherLayer4Config
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::NetworkPolicyTrafficClassificationRuleMatcherLayer4Config
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#ip_protocol ⇒ String
The IP protocol to which this rule applies.
-
#ports ⇒ Array<String>
An optional list of ports to which this rule applies.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NetworkPolicyTrafficClassificationRuleMatcherLayer4Config
constructor
A new instance of NetworkPolicyTrafficClassificationRuleMatcherLayer4Config.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NetworkPolicyTrafficClassificationRuleMatcherLayer4Config
Returns a new instance of NetworkPolicyTrafficClassificationRuleMatcherLayer4Config.
46234 46235 46236 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 46234 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ip_protocol ⇒ String
The IP protocol to which this rule applies. The protocol type is
required when creating a traffic classification rule. This value can
either be one of the following well known protocol strings
(tcp, udp, icmp,esp, ah, ipip,sctp), or the IP protocol number.
Corresponds to the JSON property ipProtocol
46223 46224 46225 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 46223 def ip_protocol @ip_protocol end |
#ports ⇒ Array<String>
An optional list of ports to which this rule applies. This field is
only applicable for UDP, TCP or SCTP protocol. Each entry must be
either an integer or a range. If not specified, this rule applies to
connections through any port.
Example inputs include: ["22"],["80","443"], and ["12345-12349"].
Corresponds to the JSON property ports
46232 46233 46234 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 46232 def ports @ports end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
46239 46240 46241 46242 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 46239 def update!(**args) @ip_protocol = args[:ip_protocol] if args.key?(:ip_protocol) @ports = args[:ports] if args.key?(:ports) end |