Class: Google::Apis::ComputeAlpha::NetworkProfileNetworkFeatures
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::NetworkProfileNetworkFeatures
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#address_purposes ⇒ Array<String>
Specifies what address purposes are supported.
-
#allow_address_creation ⇒ String
Specifies whether address creation is allowed.
-
#allow_alias_ip_ranges ⇒ String
Specifies whether alias IP ranges (and secondary address ranges) are allowed.
-
#allow_auto_mode_subnet ⇒ String
Specifies whether auto mode subnet creation is allowed.
-
#allow_class_d_firewalls ⇒ String
Specifies whether firewalls for Class D address ranges are supported.
-
#allow_cloud_nat ⇒ String
Specifies whether cloud NAT creation is allowed.
-
#allow_cloud_router ⇒ String
Specifies whether cloud router creation is allowed.
-
#allow_default_nic_attachment ⇒ String
Specifies whether default NIC attachment is allowed.
-
#allow_external_ip_access ⇒ String
Specifies whether VMs are allowed to have external IP access on network interfaces connected to this VPC.
-
#allow_firewall_policy ⇒ String
Specifies whether firewall policy can be attached to the network.
-
#allow_interconnect ⇒ String
Specifies whether Cloud Interconnect creation is allowed.
-
#allow_ip_forwarding ⇒ String
Specifies whether IP forwarding is allowed.
-
#allow_load_balancing ⇒ String
Specifies whether cloud load balancing is allowed.
-
#allow_multi_nic_in_same_network ⇒ String
Specifies whether multi-nic in the same network is allowed.
-
#allow_multi_nic_in_same_subnetwork ⇒ String
Specifies whether multi-nic in the same subnetwork is allowed.
-
#allow_multicast ⇒ String
Specifies whether multicast is allowed.
-
#allow_ncc ⇒ String
Specifies whether NCC is allowed.
-
#allow_network_migration ⇒ String
Specifies whether VM network migration is allowed.
-
#allow_packet_mirroring ⇒ String
Specifies whether Packet Mirroring 1.0 is supported.
-
#allow_private_google_access ⇒ String
Specifies whether private Google access is allowed.
-
#allow_psc ⇒ String
Specifies whether PSC creation is allowed.
-
#allow_same_network_unicast ⇒ String
Specifies whether unicast within the same network is allowed.
-
#allow_static_routes ⇒ String
Specifies whether static route creation is allowed.
-
#allow_sub_interfaces ⇒ String
Specifies whether sub interfaces are allowed.
-
#allow_subnetwork_creation ⇒ String
Specifies whether subnetwork creation is allowed.
-
#allow_vpc_firewall_rules ⇒ String
Specifies whether VPC firewall rules can be created under the network.
-
#allow_vpc_peering ⇒ String
Specifies whether VPC peering is allowed.
-
#allow_vpn ⇒ String
Specifies whether VPN creation is allowed.
-
#firewall_policy_types ⇒ Array<String>
Corresponds to the JSON property
firewallPolicyTypes. -
#interface_types ⇒ Array<String>
If set, limits the interface types that the network supports.
-
#multicast ⇒ String
Specifies which type of multicast is supported.
-
#predefined_network_internal_ipv6_range ⇒ String
Specifies a predefined internal IPv6 range for the network.
-
#predefined_subnetwork_ranges ⇒ Array<Google::Apis::ComputeAlpha::NetworkProfileNetworkFeaturesPredefinedSubnetworkRange>
Predefined subnetwork ranges for the network.
-
#subnet_purposes ⇒ Array<String>
Specifies which subnetwork purposes are supported.
-
#subnet_stack_types ⇒ Array<String>
Specifies which subnetwork stack types are supported.
-
#subnetwork_purposes ⇒ Array<String>
Output only.
-
#subnetwork_stack_types ⇒ Array<String>
Output only.
-
#unicast ⇒ String
Specifies which type of unicast is supported.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NetworkProfileNetworkFeatures
constructor
A new instance of NetworkProfileNetworkFeatures.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NetworkProfileNetworkFeatures
Returns a new instance of NetworkProfileNetworkFeatures.
48135 48136 48137 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 48135 def initialize(**args) update!(**args) end |
Instance Attribute Details
#address_purposes ⇒ Array<String>
Specifies what address purposes are supported. If empty, all address
purposes are supported.
Corresponds to the JSON property addressPurposes
47945 47946 47947 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 47945 def address_purposes @address_purposes end |
#allow_address_creation ⇒ String
Specifies whether address creation is allowed.
Corresponds to the JSON property allowAddressCreation
47950 47951 47952 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 47950 def allow_address_creation @allow_address_creation end |
#allow_alias_ip_ranges ⇒ String
Specifies whether alias IP ranges (and secondary address ranges) are
allowed.
Corresponds to the JSON property allowAliasIpRanges
47956 47957 47958 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 47956 def allow_alias_ip_ranges @allow_alias_ip_ranges end |
#allow_auto_mode_subnet ⇒ String
Specifies whether auto mode subnet creation is allowed.
Corresponds to the JSON property allowAutoModeSubnet
47961 47962 47963 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 47961 def allow_auto_mode_subnet @allow_auto_mode_subnet end |
#allow_class_d_firewalls ⇒ String
Specifies whether firewalls for Class D address ranges are supported.
Corresponds to the JSON property allowClassDFirewalls
47966 47967 47968 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 47966 def allow_class_d_firewalls @allow_class_d_firewalls end |
#allow_cloud_nat ⇒ String
Specifies whether cloud NAT creation is allowed.
Corresponds to the JSON property allowCloudNat
47971 47972 47973 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 47971 def allow_cloud_nat @allow_cloud_nat end |
#allow_cloud_router ⇒ String
Specifies whether cloud router creation is allowed.
Corresponds to the JSON property allowCloudRouter
47976 47977 47978 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 47976 def allow_cloud_router @allow_cloud_router end |
#allow_default_nic_attachment ⇒ String
Specifies whether default NIC attachment is allowed.
Corresponds to the JSON property allowDefaultNicAttachment
47981 47982 47983 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 47981 def @allow_default_nic_attachment end |
#allow_external_ip_access ⇒ String
Specifies whether VMs are allowed to have external IP access on network
interfaces connected to this VPC.
Corresponds to the JSON property allowExternalIpAccess
47987 47988 47989 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 47987 def allow_external_ip_access @allow_external_ip_access end |
#allow_firewall_policy ⇒ String
Specifies whether firewall policy can be attached to the network.
Corresponds to the JSON property allowFirewallPolicy
47992 47993 47994 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 47992 def allow_firewall_policy @allow_firewall_policy end |
#allow_interconnect ⇒ String
Specifies whether Cloud Interconnect creation is allowed.
Corresponds to the JSON property allowInterconnect
47997 47998 47999 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 47997 def allow_interconnect @allow_interconnect end |
#allow_ip_forwarding ⇒ String
Specifies whether IP forwarding is allowed.
Corresponds to the JSON property allowIpForwarding
48002 48003 48004 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 48002 def allow_ip_forwarding @allow_ip_forwarding end |
#allow_load_balancing ⇒ String
Specifies whether cloud load balancing is allowed.
Corresponds to the JSON property allowLoadBalancing
48007 48008 48009 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 48007 def allow_load_balancing @allow_load_balancing end |
#allow_multi_nic_in_same_network ⇒ String
Specifies whether multi-nic in the same network is allowed.
Corresponds to the JSON property allowMultiNicInSameNetwork
48012 48013 48014 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 48012 def allow_multi_nic_in_same_network @allow_multi_nic_in_same_network end |
#allow_multi_nic_in_same_subnetwork ⇒ String
Specifies whether multi-nic in the same subnetwork is allowed.
Corresponds to the JSON property allowMultiNicInSameSubnetwork
48017 48018 48019 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 48017 def allow_multi_nic_in_same_subnetwork @allow_multi_nic_in_same_subnetwork end |
#allow_multicast ⇒ String
Specifies whether multicast is allowed.
Corresponds to the JSON property allowMulticast
48022 48023 48024 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 48022 def allow_multicast @allow_multicast end |
#allow_ncc ⇒ String
Specifies whether NCC is allowed.
Corresponds to the JSON property allowNcc
48027 48028 48029 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 48027 def allow_ncc @allow_ncc end |
#allow_network_migration ⇒ String
Specifies whether VM network migration is allowed.
Corresponds to the JSON property allowNetworkMigration
48032 48033 48034 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 48032 def allow_network_migration @allow_network_migration end |
#allow_packet_mirroring ⇒ String
Specifies whether Packet Mirroring 1.0 is supported.
Corresponds to the JSON property allowPacketMirroring
48037 48038 48039 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 48037 def allow_packet_mirroring @allow_packet_mirroring end |
#allow_private_google_access ⇒ String
Specifies whether private Google access is allowed.
Corresponds to the JSON property allowPrivateGoogleAccess
48042 48043 48044 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 48042 def allow_private_google_access @allow_private_google_access end |
#allow_psc ⇒ String
Specifies whether PSC creation is allowed.
Corresponds to the JSON property allowPsc
48047 48048 48049 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 48047 def allow_psc @allow_psc end |
#allow_same_network_unicast ⇒ String
Specifies whether unicast within the same network is allowed.
Corresponds to the JSON property allowSameNetworkUnicast
48052 48053 48054 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 48052 def allow_same_network_unicast @allow_same_network_unicast end |
#allow_static_routes ⇒ String
Specifies whether static route creation is allowed.
Corresponds to the JSON property allowStaticRoutes
48057 48058 48059 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 48057 def allow_static_routes @allow_static_routes end |
#allow_sub_interfaces ⇒ String
Specifies whether sub interfaces are allowed.
Corresponds to the JSON property allowSubInterfaces
48062 48063 48064 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 48062 def allow_sub_interfaces @allow_sub_interfaces end |
#allow_subnetwork_creation ⇒ String
Specifies whether subnetwork creation is allowed.
Corresponds to the JSON property allowSubnetworkCreation
48067 48068 48069 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 48067 def allow_subnetwork_creation @allow_subnetwork_creation end |
#allow_vpc_firewall_rules ⇒ String
Specifies whether VPC firewall rules can be created under the network.
Corresponds to the JSON property allowVpcFirewallRules
48072 48073 48074 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 48072 def allow_vpc_firewall_rules @allow_vpc_firewall_rules end |
#allow_vpc_peering ⇒ String
Specifies whether VPC peering is allowed.
Corresponds to the JSON property allowVpcPeering
48077 48078 48079 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 48077 def allow_vpc_peering @allow_vpc_peering end |
#allow_vpn ⇒ String
Specifies whether VPN creation is allowed.
Corresponds to the JSON property allowVpn
48082 48083 48084 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 48082 def allow_vpn @allow_vpn end |
#firewall_policy_types ⇒ Array<String>
Corresponds to the JSON property firewallPolicyTypes
48087 48088 48089 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 48087 def firewall_policy_types @firewall_policy_types end |
#interface_types ⇒ Array<String>
If set, limits the interface types that the network supports. If
empty, all interface types are supported.
Corresponds to the JSON property interfaceTypes
48093 48094 48095 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 48093 def interface_types @interface_types end |
#multicast ⇒ String
Specifies which type of multicast is supported.
Corresponds to the JSON property multicast
48098 48099 48100 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 48098 def multicast @multicast end |
#predefined_network_internal_ipv6_range ⇒ String
Specifies a predefined internal IPv6 range for the network.
Corresponds to the JSON property predefinedNetworkInternalIpv6Range
48103 48104 48105 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 48103 def predefined_network_internal_ipv6_range @predefined_network_internal_ipv6_range end |
#predefined_subnetwork_ranges ⇒ Array<Google::Apis::ComputeAlpha::NetworkProfileNetworkFeaturesPredefinedSubnetworkRange>
Predefined subnetwork ranges for the network.
Corresponds to the JSON property predefinedSubnetworkRanges
48108 48109 48110 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 48108 def predefined_subnetwork_ranges @predefined_subnetwork_ranges end |
#subnet_purposes ⇒ Array<String>
Specifies which subnetwork purposes are supported.
Corresponds to the JSON property subnetPurposes
48113 48114 48115 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 48113 def subnet_purposes @subnet_purposes end |
#subnet_stack_types ⇒ Array<String>
Specifies which subnetwork stack types are supported.
Corresponds to the JSON property subnetStackTypes
48118 48119 48120 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 48118 def subnet_stack_types @subnet_stack_types end |
#subnetwork_purposes ⇒ Array<String>
Output only. Specifies which subnetwork purposes are supported.
Corresponds to the JSON property subnetworkPurposes
48123 48124 48125 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 48123 def subnetwork_purposes @subnetwork_purposes end |
#subnetwork_stack_types ⇒ Array<String>
Output only. Specifies which subnetwork stack types are supported.
Corresponds to the JSON property subnetworkStackTypes
48128 48129 48130 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 48128 def subnetwork_stack_types @subnetwork_stack_types end |
#unicast ⇒ String
Specifies which type of unicast is supported.
Corresponds to the JSON property unicast
48133 48134 48135 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 48133 def unicast @unicast end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
48140 48141 48142 48143 48144 48145 48146 48147 48148 48149 48150 48151 48152 48153 48154 48155 48156 48157 48158 48159 48160 48161 48162 48163 48164 48165 48166 48167 48168 48169 48170 48171 48172 48173 48174 48175 48176 48177 48178 48179 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 48140 def update!(**args) @address_purposes = args[:address_purposes] if args.key?(:address_purposes) @allow_address_creation = args[:allow_address_creation] if args.key?(:allow_address_creation) @allow_alias_ip_ranges = args[:allow_alias_ip_ranges] if args.key?(:allow_alias_ip_ranges) @allow_auto_mode_subnet = args[:allow_auto_mode_subnet] if args.key?(:allow_auto_mode_subnet) @allow_class_d_firewalls = args[:allow_class_d_firewalls] if args.key?(:allow_class_d_firewalls) @allow_cloud_nat = args[:allow_cloud_nat] if args.key?(:allow_cloud_nat) @allow_cloud_router = args[:allow_cloud_router] if args.key?(:allow_cloud_router) @allow_default_nic_attachment = args[:allow_default_nic_attachment] if args.key?(:allow_default_nic_attachment) @allow_external_ip_access = args[:allow_external_ip_access] if args.key?(:allow_external_ip_access) @allow_firewall_policy = args[:allow_firewall_policy] if args.key?(:allow_firewall_policy) @allow_interconnect = args[:allow_interconnect] if args.key?(:allow_interconnect) @allow_ip_forwarding = args[:allow_ip_forwarding] if args.key?(:allow_ip_forwarding) @allow_load_balancing = args[:allow_load_balancing] if args.key?(:allow_load_balancing) @allow_multi_nic_in_same_network = args[:allow_multi_nic_in_same_network] if args.key?(:allow_multi_nic_in_same_network) @allow_multi_nic_in_same_subnetwork = args[:allow_multi_nic_in_same_subnetwork] if args.key?(:allow_multi_nic_in_same_subnetwork) @allow_multicast = args[:allow_multicast] if args.key?(:allow_multicast) @allow_ncc = args[:allow_ncc] if args.key?(:allow_ncc) @allow_network_migration = args[:allow_network_migration] if args.key?(:allow_network_migration) @allow_packet_mirroring = args[:allow_packet_mirroring] if args.key?(:allow_packet_mirroring) @allow_private_google_access = args[:allow_private_google_access] if args.key?(:allow_private_google_access) @allow_psc = args[:allow_psc] if args.key?(:allow_psc) @allow_same_network_unicast = args[:allow_same_network_unicast] if args.key?(:allow_same_network_unicast) @allow_static_routes = args[:allow_static_routes] if args.key?(:allow_static_routes) @allow_sub_interfaces = args[:allow_sub_interfaces] if args.key?(:allow_sub_interfaces) @allow_subnetwork_creation = args[:allow_subnetwork_creation] if args.key?(:allow_subnetwork_creation) @allow_vpc_firewall_rules = args[:allow_vpc_firewall_rules] if args.key?(:allow_vpc_firewall_rules) @allow_vpc_peering = args[:allow_vpc_peering] if args.key?(:allow_vpc_peering) @allow_vpn = args[:allow_vpn] if args.key?(:allow_vpn) @firewall_policy_types = args[:firewall_policy_types] if args.key?(:firewall_policy_types) @interface_types = args[:interface_types] if args.key?(:interface_types) @multicast = args[:multicast] if args.key?(:multicast) @predefined_network_internal_ipv6_range = args[:predefined_network_internal_ipv6_range] if args.key?(:predefined_network_internal_ipv6_range) @predefined_subnetwork_ranges = args[:predefined_subnetwork_ranges] if args.key?(:predefined_subnetwork_ranges) @subnet_purposes = args[:subnet_purposes] if args.key?(:subnet_purposes) @subnet_stack_types = args[:subnet_stack_types] if args.key?(:subnet_stack_types) @subnetwork_purposes = args[:subnetwork_purposes] if args.key?(:subnetwork_purposes) @subnetwork_stack_types = args[:subnetwork_stack_types] if args.key?(:subnetwork_stack_types) @unicast = args[:unicast] if args.key?(:unicast) end |