Class: Google::Apis::ComputeAlpha::NetworkProfileNetworkFeatures
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::NetworkProfileNetworkFeatures
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#address_purposes ⇒ Array<String>
Specifies what address purposes are supported.
-
#allow_address_creation ⇒ String
Specifies whether address creation is allowed.
-
#allow_alias_ip_ranges ⇒ String
Specifies whether alias IP ranges (and secondary address ranges) are allowed.
-
#allow_auto_mode_subnet ⇒ String
Specifies whether auto mode subnet creation is allowed.
-
#allow_class_d_firewalls ⇒ String
Specifies whether firewalls for Class D address ranges are supported.
-
#allow_cloud_nat ⇒ String
Specifies whether cloud NAT creation is allowed.
-
#allow_cloud_router ⇒ String
Specifies whether cloud router creation is allowed.
-
#allow_default_nic_attachment ⇒ String
Specifies whether default NIC attachment is allowed.
-
#allow_external_ip_access ⇒ String
Specifies whether VMs are allowed to have external IP access on network interfaces connected to this VPC.
-
#allow_firewall_policy ⇒ String
Specifies whether firewall policy can be attached to the network.
-
#allow_interconnect ⇒ String
Specifies whether Cloud Interconnect creation is allowed.
-
#allow_ip_forwarding ⇒ String
Specifies whether IP forwarding is allowed.
-
#allow_load_balancing ⇒ String
Specifies whether cloud load balancing is allowed.
-
#allow_multi_nic_in_same_network ⇒ String
Specifies whether multi-nic in the same network is allowed.
-
#allow_multi_nic_in_same_subnetwork ⇒ String
Specifies whether multi-nic in the same subnetwork is allowed.
-
#allow_multicast ⇒ String
Specifies whether multicast is allowed.
-
#allow_ncc ⇒ String
Specifies whether NCC is allowed.
-
#allow_network_migration ⇒ String
Specifies whether VM network migration is allowed.
-
#allow_packet_mirroring ⇒ String
Specifies whether Packet Mirroring 1.0 is supported.
-
#allow_private_google_access ⇒ String
Specifies whether private Google access is allowed.
-
#allow_psc ⇒ String
Specifies whether PSC creation is allowed.
-
#allow_same_network_unicast ⇒ String
Specifies whether unicast within the same network is allowed.
-
#allow_static_routes ⇒ String
Specifies whether static route creation is allowed.
-
#allow_sub_interfaces ⇒ String
Specifies whether sub interfaces are allowed.
-
#allow_subnetwork_creation ⇒ String
Specifies whether subnetwork creation is allowed.
-
#allow_vpc_firewall_rules ⇒ String
Specifies whether VPC firewall rules can be created under the network.
-
#allow_vpc_peering ⇒ String
Specifies whether VPC peering is allowed.
-
#allow_vpn ⇒ String
Specifies whether VPN creation is allowed.
-
#firewall_policy_types ⇒ Array<String>
Corresponds to the JSON property
firewallPolicyTypes. -
#interface_types ⇒ Array<String>
If set, limits the interface types that the network supports.
-
#multicast ⇒ String
Specifies which type of multicast is supported.
-
#predefined_network_internal_ipv6_range ⇒ String
Specifies a predefined internal IPv6 range for the network.
-
#predefined_subnetwork_ranges ⇒ Array<Google::Apis::ComputeAlpha::NetworkProfileNetworkFeaturesPredefinedSubnetworkRange>
Predefined subnetwork ranges for the network.
-
#subnet_purposes ⇒ Array<String>
Specifies which subnetwork purposes are supported.
-
#subnet_stack_types ⇒ Array<String>
Specifies which subnetwork stack types are supported.
-
#subnetwork_purposes ⇒ Array<String>
Output only.
-
#subnetwork_stack_types ⇒ Array<String>
Output only.
-
#unicast ⇒ String
Specifies which type of unicast is supported.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NetworkProfileNetworkFeatures
constructor
A new instance of NetworkProfileNetworkFeatures.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NetworkProfileNetworkFeatures
Returns a new instance of NetworkProfileNetworkFeatures.
46575 46576 46577 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 46575 def initialize(**args) update!(**args) end |
Instance Attribute Details
#address_purposes ⇒ Array<String>
Specifies what address purposes are supported. If empty, all address
purposes are supported.
Corresponds to the JSON property addressPurposes
46385 46386 46387 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 46385 def address_purposes @address_purposes end |
#allow_address_creation ⇒ String
Specifies whether address creation is allowed.
Corresponds to the JSON property allowAddressCreation
46390 46391 46392 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 46390 def allow_address_creation @allow_address_creation end |
#allow_alias_ip_ranges ⇒ String
Specifies whether alias IP ranges (and secondary address ranges) are
allowed.
Corresponds to the JSON property allowAliasIpRanges
46396 46397 46398 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 46396 def allow_alias_ip_ranges @allow_alias_ip_ranges end |
#allow_auto_mode_subnet ⇒ String
Specifies whether auto mode subnet creation is allowed.
Corresponds to the JSON property allowAutoModeSubnet
46401 46402 46403 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 46401 def allow_auto_mode_subnet @allow_auto_mode_subnet end |
#allow_class_d_firewalls ⇒ String
Specifies whether firewalls for Class D address ranges are supported.
Corresponds to the JSON property allowClassDFirewalls
46406 46407 46408 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 46406 def allow_class_d_firewalls @allow_class_d_firewalls end |
#allow_cloud_nat ⇒ String
Specifies whether cloud NAT creation is allowed.
Corresponds to the JSON property allowCloudNat
46411 46412 46413 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 46411 def allow_cloud_nat @allow_cloud_nat end |
#allow_cloud_router ⇒ String
Specifies whether cloud router creation is allowed.
Corresponds to the JSON property allowCloudRouter
46416 46417 46418 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 46416 def allow_cloud_router @allow_cloud_router end |
#allow_default_nic_attachment ⇒ String
Specifies whether default NIC attachment is allowed.
Corresponds to the JSON property allowDefaultNicAttachment
46421 46422 46423 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 46421 def @allow_default_nic_attachment end |
#allow_external_ip_access ⇒ String
Specifies whether VMs are allowed to have external IP access on network
interfaces connected to this VPC.
Corresponds to the JSON property allowExternalIpAccess
46427 46428 46429 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 46427 def allow_external_ip_access @allow_external_ip_access end |
#allow_firewall_policy ⇒ String
Specifies whether firewall policy can be attached to the network.
Corresponds to the JSON property allowFirewallPolicy
46432 46433 46434 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 46432 def allow_firewall_policy @allow_firewall_policy end |
#allow_interconnect ⇒ String
Specifies whether Cloud Interconnect creation is allowed.
Corresponds to the JSON property allowInterconnect
46437 46438 46439 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 46437 def allow_interconnect @allow_interconnect end |
#allow_ip_forwarding ⇒ String
Specifies whether IP forwarding is allowed.
Corresponds to the JSON property allowIpForwarding
46442 46443 46444 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 46442 def allow_ip_forwarding @allow_ip_forwarding end |
#allow_load_balancing ⇒ String
Specifies whether cloud load balancing is allowed.
Corresponds to the JSON property allowLoadBalancing
46447 46448 46449 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 46447 def allow_load_balancing @allow_load_balancing end |
#allow_multi_nic_in_same_network ⇒ String
Specifies whether multi-nic in the same network is allowed.
Corresponds to the JSON property allowMultiNicInSameNetwork
46452 46453 46454 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 46452 def allow_multi_nic_in_same_network @allow_multi_nic_in_same_network end |
#allow_multi_nic_in_same_subnetwork ⇒ String
Specifies whether multi-nic in the same subnetwork is allowed.
Corresponds to the JSON property allowMultiNicInSameSubnetwork
46457 46458 46459 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 46457 def allow_multi_nic_in_same_subnetwork @allow_multi_nic_in_same_subnetwork end |
#allow_multicast ⇒ String
Specifies whether multicast is allowed.
Corresponds to the JSON property allowMulticast
46462 46463 46464 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 46462 def allow_multicast @allow_multicast end |
#allow_ncc ⇒ String
Specifies whether NCC is allowed.
Corresponds to the JSON property allowNcc
46467 46468 46469 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 46467 def allow_ncc @allow_ncc end |
#allow_network_migration ⇒ String
Specifies whether VM network migration is allowed.
Corresponds to the JSON property allowNetworkMigration
46472 46473 46474 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 46472 def allow_network_migration @allow_network_migration end |
#allow_packet_mirroring ⇒ String
Specifies whether Packet Mirroring 1.0 is supported.
Corresponds to the JSON property allowPacketMirroring
46477 46478 46479 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 46477 def allow_packet_mirroring @allow_packet_mirroring end |
#allow_private_google_access ⇒ String
Specifies whether private Google access is allowed.
Corresponds to the JSON property allowPrivateGoogleAccess
46482 46483 46484 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 46482 def allow_private_google_access @allow_private_google_access end |
#allow_psc ⇒ String
Specifies whether PSC creation is allowed.
Corresponds to the JSON property allowPsc
46487 46488 46489 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 46487 def allow_psc @allow_psc end |
#allow_same_network_unicast ⇒ String
Specifies whether unicast within the same network is allowed.
Corresponds to the JSON property allowSameNetworkUnicast
46492 46493 46494 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 46492 def allow_same_network_unicast @allow_same_network_unicast end |
#allow_static_routes ⇒ String
Specifies whether static route creation is allowed.
Corresponds to the JSON property allowStaticRoutes
46497 46498 46499 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 46497 def allow_static_routes @allow_static_routes end |
#allow_sub_interfaces ⇒ String
Specifies whether sub interfaces are allowed.
Corresponds to the JSON property allowSubInterfaces
46502 46503 46504 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 46502 def allow_sub_interfaces @allow_sub_interfaces end |
#allow_subnetwork_creation ⇒ String
Specifies whether subnetwork creation is allowed.
Corresponds to the JSON property allowSubnetworkCreation
46507 46508 46509 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 46507 def allow_subnetwork_creation @allow_subnetwork_creation end |
#allow_vpc_firewall_rules ⇒ String
Specifies whether VPC firewall rules can be created under the network.
Corresponds to the JSON property allowVpcFirewallRules
46512 46513 46514 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 46512 def allow_vpc_firewall_rules @allow_vpc_firewall_rules end |
#allow_vpc_peering ⇒ String
Specifies whether VPC peering is allowed.
Corresponds to the JSON property allowVpcPeering
46517 46518 46519 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 46517 def allow_vpc_peering @allow_vpc_peering end |
#allow_vpn ⇒ String
Specifies whether VPN creation is allowed.
Corresponds to the JSON property allowVpn
46522 46523 46524 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 46522 def allow_vpn @allow_vpn end |
#firewall_policy_types ⇒ Array<String>
Corresponds to the JSON property firewallPolicyTypes
46527 46528 46529 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 46527 def firewall_policy_types @firewall_policy_types end |
#interface_types ⇒ Array<String>
If set, limits the interface types that the network supports. If
empty, all interface types are supported.
Corresponds to the JSON property interfaceTypes
46533 46534 46535 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 46533 def interface_types @interface_types end |
#multicast ⇒ String
Specifies which type of multicast is supported.
Corresponds to the JSON property multicast
46538 46539 46540 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 46538 def multicast @multicast end |
#predefined_network_internal_ipv6_range ⇒ String
Specifies a predefined internal IPv6 range for the network.
Corresponds to the JSON property predefinedNetworkInternalIpv6Range
46543 46544 46545 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 46543 def predefined_network_internal_ipv6_range @predefined_network_internal_ipv6_range end |
#predefined_subnetwork_ranges ⇒ Array<Google::Apis::ComputeAlpha::NetworkProfileNetworkFeaturesPredefinedSubnetworkRange>
Predefined subnetwork ranges for the network.
Corresponds to the JSON property predefinedSubnetworkRanges
46548 46549 46550 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 46548 def predefined_subnetwork_ranges @predefined_subnetwork_ranges end |
#subnet_purposes ⇒ Array<String>
Specifies which subnetwork purposes are supported.
Corresponds to the JSON property subnetPurposes
46553 46554 46555 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 46553 def subnet_purposes @subnet_purposes end |
#subnet_stack_types ⇒ Array<String>
Specifies which subnetwork stack types are supported.
Corresponds to the JSON property subnetStackTypes
46558 46559 46560 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 46558 def subnet_stack_types @subnet_stack_types end |
#subnetwork_purposes ⇒ Array<String>
Output only. Specifies which subnetwork purposes are supported.
Corresponds to the JSON property subnetworkPurposes
46563 46564 46565 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 46563 def subnetwork_purposes @subnetwork_purposes end |
#subnetwork_stack_types ⇒ Array<String>
Output only. Specifies which subnetwork stack types are supported.
Corresponds to the JSON property subnetworkStackTypes
46568 46569 46570 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 46568 def subnetwork_stack_types @subnetwork_stack_types end |
#unicast ⇒ String
Specifies which type of unicast is supported.
Corresponds to the JSON property unicast
46573 46574 46575 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 46573 def unicast @unicast end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
46580 46581 46582 46583 46584 46585 46586 46587 46588 46589 46590 46591 46592 46593 46594 46595 46596 46597 46598 46599 46600 46601 46602 46603 46604 46605 46606 46607 46608 46609 46610 46611 46612 46613 46614 46615 46616 46617 46618 46619 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 46580 def update!(**args) @address_purposes = args[:address_purposes] if args.key?(:address_purposes) @allow_address_creation = args[:allow_address_creation] if args.key?(:allow_address_creation) @allow_alias_ip_ranges = args[:allow_alias_ip_ranges] if args.key?(:allow_alias_ip_ranges) @allow_auto_mode_subnet = args[:allow_auto_mode_subnet] if args.key?(:allow_auto_mode_subnet) @allow_class_d_firewalls = args[:allow_class_d_firewalls] if args.key?(:allow_class_d_firewalls) @allow_cloud_nat = args[:allow_cloud_nat] if args.key?(:allow_cloud_nat) @allow_cloud_router = args[:allow_cloud_router] if args.key?(:allow_cloud_router) @allow_default_nic_attachment = args[:allow_default_nic_attachment] if args.key?(:allow_default_nic_attachment) @allow_external_ip_access = args[:allow_external_ip_access] if args.key?(:allow_external_ip_access) @allow_firewall_policy = args[:allow_firewall_policy] if args.key?(:allow_firewall_policy) @allow_interconnect = args[:allow_interconnect] if args.key?(:allow_interconnect) @allow_ip_forwarding = args[:allow_ip_forwarding] if args.key?(:allow_ip_forwarding) @allow_load_balancing = args[:allow_load_balancing] if args.key?(:allow_load_balancing) @allow_multi_nic_in_same_network = args[:allow_multi_nic_in_same_network] if args.key?(:allow_multi_nic_in_same_network) @allow_multi_nic_in_same_subnetwork = args[:allow_multi_nic_in_same_subnetwork] if args.key?(:allow_multi_nic_in_same_subnetwork) @allow_multicast = args[:allow_multicast] if args.key?(:allow_multicast) @allow_ncc = args[:allow_ncc] if args.key?(:allow_ncc) @allow_network_migration = args[:allow_network_migration] if args.key?(:allow_network_migration) @allow_packet_mirroring = args[:allow_packet_mirroring] if args.key?(:allow_packet_mirroring) @allow_private_google_access = args[:allow_private_google_access] if args.key?(:allow_private_google_access) @allow_psc = args[:allow_psc] if args.key?(:allow_psc) @allow_same_network_unicast = args[:allow_same_network_unicast] if args.key?(:allow_same_network_unicast) @allow_static_routes = args[:allow_static_routes] if args.key?(:allow_static_routes) @allow_sub_interfaces = args[:allow_sub_interfaces] if args.key?(:allow_sub_interfaces) @allow_subnetwork_creation = args[:allow_subnetwork_creation] if args.key?(:allow_subnetwork_creation) @allow_vpc_firewall_rules = args[:allow_vpc_firewall_rules] if args.key?(:allow_vpc_firewall_rules) @allow_vpc_peering = args[:allow_vpc_peering] if args.key?(:allow_vpc_peering) @allow_vpn = args[:allow_vpn] if args.key?(:allow_vpn) @firewall_policy_types = args[:firewall_policy_types] if args.key?(:firewall_policy_types) @interface_types = args[:interface_types] if args.key?(:interface_types) @multicast = args[:multicast] if args.key?(:multicast) @predefined_network_internal_ipv6_range = args[:predefined_network_internal_ipv6_range] if args.key?(:predefined_network_internal_ipv6_range) @predefined_subnetwork_ranges = args[:predefined_subnetwork_ranges] if args.key?(:predefined_subnetwork_ranges) @subnet_purposes = args[:subnet_purposes] if args.key?(:subnet_purposes) @subnet_stack_types = args[:subnet_stack_types] if args.key?(:subnet_stack_types) @subnetwork_purposes = args[:subnetwork_purposes] if args.key?(:subnetwork_purposes) @subnetwork_stack_types = args[:subnetwork_stack_types] if args.key?(:subnetwork_stack_types) @unicast = args[:unicast] if args.key?(:unicast) end |