Class: Google::Apis::ComputeAlpha::NetworkProfilesListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of network profiles.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkProfilesListResponse

Returns a new instance of NetworkProfilesListResponse.



46970
46971
46972
# File 'lib/google/apis/compute_alpha/classes.rb', line 46970

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


46924
46925
46926
# File 'lib/google/apis/compute_alpha/classes.rb', line 46924

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


46929
46930
46931
# File 'lib/google/apis/compute_alpha/classes.rb', line 46929

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::NetworkProfile>

A list of NetworkProfile resources. Corresponds to the JSON property items



46934
46935
46936
# File 'lib/google/apis/compute_alpha/classes.rb', line 46934

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute#networkProfileList for network profiles. Corresponds to the JSON property kind

Returns:

  • (String)


46940
46941
46942
# File 'lib/google/apis/compute_alpha/classes.rb', line 46940

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


46952
46953
46954
# File 'lib/google/apis/compute_alpha/classes.rb', line 46952

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


46957
46958
46959
# File 'lib/google/apis/compute_alpha/classes.rb', line 46957

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


46963
46964
46965
# File 'lib/google/apis/compute_alpha/classes.rb', line 46963

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::NetworkProfilesListResponse::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



46968
46969
46970
# File 'lib/google/apis/compute_alpha/classes.rb', line 46968

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



46975
46976
46977
46978
46979
46980
46981
46982
46983
46984
# File 'lib/google/apis/compute_alpha/classes.rb', line 46975

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end