Class: Google::Apis::ComputeAlpha::NetworkProfilesListResponse
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::NetworkProfilesListResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Contains a list of network profiles.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::NetworkProfile>
A list of NetworkProfile resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::NetworkProfilesListResponse::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NetworkProfilesListResponse
constructor
A new instance of NetworkProfilesListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NetworkProfilesListResponse
Returns a new instance of NetworkProfilesListResponse.
46953 46954 46955 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 46953 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
46907 46908 46909 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 46907 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
46912 46913 46914 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 46912 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::NetworkProfile>
A list of NetworkProfile resources.
Corresponds to the JSON property items
46917 46918 46919 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 46917 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#networkProfileList
for network profiles.
Corresponds to the JSON property kind
46923 46924 46925 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 46923 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value
for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken
to
continue paging through the results.
Corresponds to the JSON property nextPageToken
46935 46936 46937 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 46935 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
46940 46941 46942 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 46940 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
end_interface: MixerListResponseWithEtagBuilder
Corresponds to the JSON property unreachables
46946 46947 46948 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 46946 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::NetworkProfilesListResponse::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
46951 46952 46953 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 46951 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
46958 46959 46960 46961 46962 46963 46964 46965 46966 46967 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 46958 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |