Class: Google::Apis::ComputeAlpha::NetworkProfilesListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of network profiles.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkProfilesListResponse

Returns a new instance of NetworkProfilesListResponse.



46735
46736
46737
# File 'lib/google/apis/compute_alpha/classes.rb', line 46735

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


46689
46690
46691
# File 'lib/google/apis/compute_alpha/classes.rb', line 46689

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


46694
46695
46696
# File 'lib/google/apis/compute_alpha/classes.rb', line 46694

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::NetworkProfile>

A list of NetworkProfile resources. Corresponds to the JSON property items



46699
46700
46701
# File 'lib/google/apis/compute_alpha/classes.rb', line 46699

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute#networkProfileList for network profiles. Corresponds to the JSON property kind

Returns:

  • (String)


46705
46706
46707
# File 'lib/google/apis/compute_alpha/classes.rb', line 46705

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


46717
46718
46719
# File 'lib/google/apis/compute_alpha/classes.rb', line 46717

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


46722
46723
46724
# File 'lib/google/apis/compute_alpha/classes.rb', line 46722

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


46728
46729
46730
# File 'lib/google/apis/compute_alpha/classes.rb', line 46728

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::NetworkProfilesListResponse::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



46733
46734
46735
# File 'lib/google/apis/compute_alpha/classes.rb', line 46733

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



46740
46741
46742
46743
46744
46745
46746
46747
46748
46749
# File 'lib/google/apis/compute_alpha/classes.rb', line 46740

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end