Class: Google::Apis::ComputeAlpha::NetworkProfilesListResponse
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::NetworkProfilesListResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Contains a list of network profiles.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::NetworkProfile>
A list of NetworkProfile resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::NetworkProfilesListResponse::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NetworkProfilesListResponse
constructor
A new instance of NetworkProfilesListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NetworkProfilesListResponse
Returns a new instance of NetworkProfilesListResponse.
45777 45778 45779 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 45777 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
45731 45732 45733 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 45731 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
45736 45737 45738 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 45736 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::NetworkProfile>
A list of NetworkProfile resources.
Corresponds to the JSON property items
45741 45742 45743 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 45741 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#networkProfileList
for network profiles.
Corresponds to the JSON property kind
45747 45748 45749 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 45747 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value
for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken
to
continue paging through the results.
Corresponds to the JSON property nextPageToken
45759 45760 45761 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 45759 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
45764 45765 45766 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 45764 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
end_interface: MixerListResponseWithEtagBuilder
Corresponds to the JSON property unreachables
45770 45771 45772 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 45770 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::NetworkProfilesListResponse::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
45775 45776 45777 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 45775 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
45782 45783 45784 45785 45786 45787 45788 45789 45790 45791 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 45782 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |