Class: Google::Apis::ComputeAlpha::NetworkRoutingConfig
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::NetworkRoutingConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
A routing configuration attached to a network resource. The message includes the list of routers associated with the network, and a flag indicating the type of routing behavior to enforce network-wide.
Instance Attribute Summary collapse
-
#bgp_always_compare_med ⇒ Boolean
(also: #bgp_always_compare_med?)
Enable comparison of Multi-Exit Discriminators (MED) across routes with different neighbor ASNs when using the STANDARD BGP best path selection algorithm.
-
#bgp_best_path_selection_mode ⇒ String
The BGP best path selection algorithm to be employed within this network for dynamic routes learned by Cloud Routers.
-
#bgp_inter_region_cost ⇒ String
Allows to define a preferred approach for handling inter-region cost in the selection process when using the STANDARD BGP best path selection algorithm.
-
#effective_bgp_always_compare_med ⇒ Boolean
(also: #effective_bgp_always_compare_med?)
Output only.
-
#effective_bgp_inter_region_cost ⇒ String
Output only.
-
#routing_mode ⇒ String
The network-wide routing mode to use.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NetworkRoutingConfig
constructor
A new instance of NetworkRoutingConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NetworkRoutingConfig
Returns a new instance of NetworkRoutingConfig.
46872 46873 46874 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 46872 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bgp_always_compare_med ⇒ Boolean Also known as: bgp_always_compare_med?
Enable comparison of Multi-Exit Discriminators (MED) across routes with
different neighbor ASNs when using the STANDARD BGP best path selection
algorithm.
Corresponds to the JSON property bgpAlwaysCompareMed
46833 46834 46835 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 46833 def bgp_always_compare_med @bgp_always_compare_med end |
#bgp_best_path_selection_mode ⇒ String
The BGP best path selection algorithm to be employed within this network
for dynamic routes learned by Cloud Routers. Can be LEGACY
(default) or STANDARD.
Corresponds to the JSON property bgpBestPathSelectionMode
46841 46842 46843 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 46841 def bgp_best_path_selection_mode @bgp_best_path_selection_mode end |
#bgp_inter_region_cost ⇒ String
Allows to define a preferred approach for handling inter-region cost in
the selection process when using the STANDARD BGP best path
selection algorithm. Can be DEFAULT orADD_COST_TO_MED.
Corresponds to the JSON property bgpInterRegionCost
46848 46849 46850 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 46848 def bgp_inter_region_cost @bgp_inter_region_cost end |
#effective_bgp_always_compare_med ⇒ Boolean Also known as: effective_bgp_always_compare_med?
Output only. [Output Only] Effective value of the bgp_always_compare_med
field.
Corresponds to the JSON property effectiveBgpAlwaysCompareMed
46854 46855 46856 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 46854 def effective_bgp_always_compare_med @effective_bgp_always_compare_med end |
#effective_bgp_inter_region_cost ⇒ String
Output only. [Output Only] Effective value of the bgp_inter_region_cost
field.
Corresponds to the JSON property effectiveBgpInterRegionCost
46861 46862 46863 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 46861 def effective_bgp_inter_region_cost @effective_bgp_inter_region_cost end |
#routing_mode ⇒ String
The network-wide routing mode to use. If set to REGIONAL,
this network's Cloud Routers will only advertise routes with subnets
of this network in the same region as the router. If set toGLOBAL, this
network's Cloud Routers will advertise
routes with all subnets of this network, across regions.
Corresponds to the JSON property routingMode
46870 46871 46872 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 46870 def routing_mode @routing_mode end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
46877 46878 46879 46880 46881 46882 46883 46884 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 46877 def update!(**args) @bgp_always_compare_med = args[:bgp_always_compare_med] if args.key?(:bgp_always_compare_med) @bgp_best_path_selection_mode = args[:bgp_best_path_selection_mode] if args.key?(:bgp_best_path_selection_mode) @bgp_inter_region_cost = args[:bgp_inter_region_cost] if args.key?(:bgp_inter_region_cost) @effective_bgp_always_compare_med = args[:effective_bgp_always_compare_med] if args.key?(:effective_bgp_always_compare_med) @effective_bgp_inter_region_cost = args[:effective_bgp_inter_region_cost] if args.key?(:effective_bgp_inter_region_cost) @routing_mode = args[:routing_mode] if args.key?(:routing_mode) end |