Class: Google::Apis::ComputeAlpha::NetworkRoutingConfig
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::NetworkRoutingConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
A routing configuration attached to a network resource. The message includes the list of routers associated with the network, and a flag indicating the type of routing behavior to enforce network-wide.
Instance Attribute Summary collapse
-
#bgp_always_compare_med ⇒ Boolean
(also: #bgp_always_compare_med?)
Enable comparison of Multi-Exit Discriminators (MED) across routes with different neighbor ASNs when using the STANDARD BGP best path selection algorithm.
-
#bgp_best_path_selection_mode ⇒ String
The BGP best path selection algorithm to be employed within this network for dynamic routes learned by Cloud Routers.
-
#bgp_inter_region_cost ⇒ String
Allows to define a preferred approach for handling inter-region cost in the selection process when using the STANDARD BGP best path selection algorithm.
-
#effective_bgp_always_compare_med ⇒ Boolean
(also: #effective_bgp_always_compare_med?)
Output only.
-
#effective_bgp_inter_region_cost ⇒ String
Output only.
-
#routing_mode ⇒ String
The network-wide routing mode to use.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NetworkRoutingConfig
constructor
A new instance of NetworkRoutingConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NetworkRoutingConfig
Returns a new instance of NetworkRoutingConfig.
46671 46672 46673 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 46671 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bgp_always_compare_med ⇒ Boolean Also known as: bgp_always_compare_med?
Enable comparison of Multi-Exit Discriminators (MED) across routes with
different neighbor ASNs when using the STANDARD BGP best path selection
algorithm.
Corresponds to the JSON property bgpAlwaysCompareMed
46632 46633 46634 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 46632 def bgp_always_compare_med @bgp_always_compare_med end |
#bgp_best_path_selection_mode ⇒ String
The BGP best path selection algorithm to be employed within this network
for dynamic routes learned by Cloud Routers. Can be LEGACY
(default) or STANDARD.
Corresponds to the JSON property bgpBestPathSelectionMode
46640 46641 46642 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 46640 def bgp_best_path_selection_mode @bgp_best_path_selection_mode end |
#bgp_inter_region_cost ⇒ String
Allows to define a preferred approach for handling inter-region cost in
the selection process when using the STANDARD BGP best path
selection algorithm. Can be DEFAULT orADD_COST_TO_MED.
Corresponds to the JSON property bgpInterRegionCost
46647 46648 46649 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 46647 def bgp_inter_region_cost @bgp_inter_region_cost end |
#effective_bgp_always_compare_med ⇒ Boolean Also known as: effective_bgp_always_compare_med?
Output only. [Output Only] Effective value of the bgp_always_compare_med
field.
Corresponds to the JSON property effectiveBgpAlwaysCompareMed
46653 46654 46655 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 46653 def effective_bgp_always_compare_med @effective_bgp_always_compare_med end |
#effective_bgp_inter_region_cost ⇒ String
Output only. [Output Only] Effective value of the bgp_inter_region_cost
field.
Corresponds to the JSON property effectiveBgpInterRegionCost
46660 46661 46662 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 46660 def effective_bgp_inter_region_cost @effective_bgp_inter_region_cost end |
#routing_mode ⇒ String
The network-wide routing mode to use. If set to REGIONAL,
this network's Cloud Routers will only advertise routes with subnets
of this network in the same region as the router. If set toGLOBAL, this
network's Cloud Routers will advertise
routes with all subnets of this network, across regions.
Corresponds to the JSON property routingMode
46669 46670 46671 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 46669 def routing_mode @routing_mode end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
46676 46677 46678 46679 46680 46681 46682 46683 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 46676 def update!(**args) @bgp_always_compare_med = args[:bgp_always_compare_med] if args.key?(:bgp_always_compare_med) @bgp_best_path_selection_mode = args[:bgp_best_path_selection_mode] if args.key?(:bgp_best_path_selection_mode) @bgp_inter_region_cost = args[:bgp_inter_region_cost] if args.key?(:bgp_inter_region_cost) @effective_bgp_always_compare_med = args[:effective_bgp_always_compare_med] if args.key?(:effective_bgp_always_compare_med) @effective_bgp_inter_region_cost = args[:effective_bgp_inter_region_cost] if args.key?(:effective_bgp_inter_region_cost) @routing_mode = args[:routing_mode] if args.key?(:routing_mode) end |