Class: Google::Apis::ComputeAlpha::NetworkRoutingConfig
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::NetworkRoutingConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
A routing configuration attached to a network resource. The message includes the list of routers associated with the network, and a flag indicating the type of routing behavior to enforce network-wide.
Instance Attribute Summary collapse
-
#bgp_always_compare_med ⇒ Boolean
(also: #bgp_always_compare_med?)
Enable comparison of Multi-Exit Discriminators (MED) across routes with different neighbor ASNs when using the STANDARD BGP best path selection algorithm.
-
#bgp_best_path_selection_mode ⇒ String
The BGP best path selection algorithm to be employed within this network for dynamic routes learned by Cloud Routers.
-
#bgp_inter_region_cost ⇒ String
Allows to define a preferred approach for handling inter-region cost in the selection process when using the STANDARD BGP best path selection algorithm.
-
#effective_bgp_always_compare_med ⇒ Boolean
(also: #effective_bgp_always_compare_med?)
Output only.
-
#effective_bgp_inter_region_cost ⇒ String
Output only.
-
#routing_mode ⇒ String
The network-wide routing mode to use.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NetworkRoutingConfig
constructor
A new instance of NetworkRoutingConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NetworkRoutingConfig
Returns a new instance of NetworkRoutingConfig.
45914 45915 45916 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 45914 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bgp_always_compare_med ⇒ Boolean Also known as: bgp_always_compare_med?
Enable comparison of Multi-Exit Discriminators (MED) across routes with
different neighbor ASNs when using the STANDARD BGP best path selection
algorithm.
Corresponds to the JSON property bgpAlwaysCompareMed
45875 45876 45877 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 45875 def bgp_always_compare_med @bgp_always_compare_med end |
#bgp_best_path_selection_mode ⇒ String
The BGP best path selection algorithm to be employed within this network
for dynamic routes learned by Cloud Routers. Can be LEGACY
(default) or STANDARD.
Corresponds to the JSON property bgpBestPathSelectionMode
45883 45884 45885 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 45883 def bgp_best_path_selection_mode @bgp_best_path_selection_mode end |
#bgp_inter_region_cost ⇒ String
Allows to define a preferred approach for handling inter-region cost in
the selection process when using the STANDARD BGP best path
selection algorithm. Can be DEFAULT orADD_COST_TO_MED.
Corresponds to the JSON property bgpInterRegionCost
45890 45891 45892 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 45890 def bgp_inter_region_cost @bgp_inter_region_cost end |
#effective_bgp_always_compare_med ⇒ Boolean Also known as: effective_bgp_always_compare_med?
Output only. [Output Only] Effective value of the bgp_always_compare_med
field.
Corresponds to the JSON property effectiveBgpAlwaysCompareMed
45896 45897 45898 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 45896 def effective_bgp_always_compare_med @effective_bgp_always_compare_med end |
#effective_bgp_inter_region_cost ⇒ String
Output only. [Output Only] Effective value of the bgp_inter_region_cost
field.
Corresponds to the JSON property effectiveBgpInterRegionCost
45903 45904 45905 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 45903 def effective_bgp_inter_region_cost @effective_bgp_inter_region_cost end |
#routing_mode ⇒ String
The network-wide routing mode to use. If set to REGIONAL,
this network's Cloud Routers will only advertise routes with subnets
of this network in the same region as the router. If set toGLOBAL, this
network's Cloud Routers will advertise
routes with all subnets of this network, across regions.
Corresponds to the JSON property routingMode
45912 45913 45914 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 45912 def routing_mode @routing_mode end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
45919 45920 45921 45922 45923 45924 45925 45926 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 45919 def update!(**args) @bgp_always_compare_med = args[:bgp_always_compare_med] if args.key?(:bgp_always_compare_med) @bgp_best_path_selection_mode = args[:bgp_best_path_selection_mode] if args.key?(:bgp_best_path_selection_mode) @bgp_inter_region_cost = args[:bgp_inter_region_cost] if args.key?(:bgp_inter_region_cost) @effective_bgp_always_compare_med = args[:effective_bgp_always_compare_med] if args.key?(:effective_bgp_always_compare_med) @effective_bgp_inter_region_cost = args[:effective_bgp_inter_region_cost] if args.key?(:effective_bgp_inter_region_cost) @routing_mode = args[:routing_mode] if args.key?(:routing_mode) end |