Class: Google::Apis::ComputeAlpha::NetworksAddPeeringRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworksAddPeeringRequest

Returns a new instance of NetworksAddPeeringRequest.



48501
48502
48503
# File 'lib/google/apis/compute_alpha/classes.rb', line 48501

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#auto_create_routesBoolean Also known as: auto_create_routes?

This field will be deprecated soon. Useexchange_subnet_routes in network_peering instead. Indicates whether full mesh connectivity is created and managed automatically between peered networks. Currently this field should always be true since Google Compute Engine will automatically create and manage subnetwork routes between two networks when peering state isACTIVE. Corresponds to the JSON property autoCreateRoutes

Returns:

  • (Boolean)


48462
48463
48464
# File 'lib/google/apis/compute_alpha/classes.rb', line 48462

def auto_create_routes
  @auto_create_routes
end

#export_custom_routesBoolean Also known as: export_custom_routes?

This field will be deprecated soon. Useexport_custom_routes in network_peering instead. Whether to export the custom routes to peer network. Corresponds to the JSON property exportCustomRoutes

Returns:

  • (Boolean)


48470
48471
48472
# File 'lib/google/apis/compute_alpha/classes.rb', line 48470

def export_custom_routes
  @export_custom_routes
end

#import_custom_routesBoolean Also known as: import_custom_routes?

This field will be deprecated soon. Useimport_custom_routes in network_peering instead. Whether to import the custom routes from peer network. Corresponds to the JSON property importCustomRoutes

Returns:

  • (Boolean)


48478
48479
48480
# File 'lib/google/apis/compute_alpha/classes.rb', line 48478

def import_custom_routes
  @import_custom_routes
end

#nameString

Name of the peering, which should conform to RFC1035. Corresponds to the JSON property name

Returns:

  • (String)


48484
48485
48486
# File 'lib/google/apis/compute_alpha/classes.rb', line 48484

def name
  @name
end

#network_peeringGoogle::Apis::ComputeAlpha::NetworkPeering

A network peering attached to a network resource. The message includes the peering name, peer network, peering state, and a flag indicating whether Google Compute Engine should automatically create routes for the peering. Corresponds to the JSON property networkPeering



48491
48492
48493
# File 'lib/google/apis/compute_alpha/classes.rb', line 48491

def network_peering
  @network_peering
end

#peer_networkString

URL of the peer network. It can be either full URL or partial URL. The peer network may belong to a different project. If the partial URL does not contain project, it is assumed that the peer network is in the same project as the current network. Corresponds to the JSON property peerNetwork

Returns:

  • (String)


48499
48500
48501
# File 'lib/google/apis/compute_alpha/classes.rb', line 48499

def peer_network
  @peer_network
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



48506
48507
48508
48509
48510
48511
48512
48513
# File 'lib/google/apis/compute_alpha/classes.rb', line 48506

def update!(**args)
  @auto_create_routes = args[:auto_create_routes] if args.key?(:auto_create_routes)
  @export_custom_routes = args[:export_custom_routes] if args.key?(:export_custom_routes)
  @import_custom_routes = args[:import_custom_routes] if args.key?(:import_custom_routes)
  @name = args[:name] if args.key?(:name)
  @network_peering = args[:network_peering] if args.key?(:network_peering)
  @peer_network = args[:peer_network] if args.key?(:peer_network)
end