Class: Google::Apis::ComputeAlpha::NetworksAddPeeringRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworksAddPeeringRequest

Returns a new instance of NetworksAddPeeringRequest.



46941
46942
46943
# File 'lib/google/apis/compute_alpha/classes.rb', line 46941

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#auto_create_routesBoolean Also known as: auto_create_routes?

This field will be deprecated soon. Useexchange_subnet_routes in network_peering instead. Indicates whether full mesh connectivity is created and managed automatically between peered networks. Currently this field should always be true since Google Compute Engine will automatically create and manage subnetwork routes between two networks when peering state isACTIVE. Corresponds to the JSON property autoCreateRoutes

Returns:

  • (Boolean)


46902
46903
46904
# File 'lib/google/apis/compute_alpha/classes.rb', line 46902

def auto_create_routes
  @auto_create_routes
end

#export_custom_routesBoolean Also known as: export_custom_routes?

This field will be deprecated soon. Useexport_custom_routes in network_peering instead. Whether to export the custom routes to peer network. Corresponds to the JSON property exportCustomRoutes

Returns:

  • (Boolean)


46910
46911
46912
# File 'lib/google/apis/compute_alpha/classes.rb', line 46910

def export_custom_routes
  @export_custom_routes
end

#import_custom_routesBoolean Also known as: import_custom_routes?

This field will be deprecated soon. Useimport_custom_routes in network_peering instead. Whether to import the custom routes from peer network. Corresponds to the JSON property importCustomRoutes

Returns:

  • (Boolean)


46918
46919
46920
# File 'lib/google/apis/compute_alpha/classes.rb', line 46918

def import_custom_routes
  @import_custom_routes
end

#nameString

Name of the peering, which should conform to RFC1035. Corresponds to the JSON property name

Returns:

  • (String)


46924
46925
46926
# File 'lib/google/apis/compute_alpha/classes.rb', line 46924

def name
  @name
end

#network_peeringGoogle::Apis::ComputeAlpha::NetworkPeering

A network peering attached to a network resource. The message includes the peering name, peer network, peering state, and a flag indicating whether Google Compute Engine should automatically create routes for the peering. Corresponds to the JSON property networkPeering



46931
46932
46933
# File 'lib/google/apis/compute_alpha/classes.rb', line 46931

def network_peering
  @network_peering
end

#peer_networkString

URL of the peer network. It can be either full URL or partial URL. The peer network may belong to a different project. If the partial URL does not contain project, it is assumed that the peer network is in the same project as the current network. Corresponds to the JSON property peerNetwork

Returns:

  • (String)


46939
46940
46941
# File 'lib/google/apis/compute_alpha/classes.rb', line 46939

def peer_network
  @peer_network
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



46946
46947
46948
46949
46950
46951
46952
46953
# File 'lib/google/apis/compute_alpha/classes.rb', line 46946

def update!(**args)
  @auto_create_routes = args[:auto_create_routes] if args.key?(:auto_create_routes)
  @export_custom_routes = args[:export_custom_routes] if args.key?(:export_custom_routes)
  @import_custom_routes = args[:import_custom_routes] if args.key?(:import_custom_routes)
  @name = args[:name] if args.key?(:name)
  @network_peering = args[:network_peering] if args.key?(:network_peering)
  @peer_network = args[:peer_network] if args.key?(:peer_network)
end