Class: Google::Apis::ComputeAlpha::NetworksAddPeeringRequest
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::NetworksAddPeeringRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#auto_create_routes ⇒ Boolean
(also: #auto_create_routes?)
This field will be deprecated soon.
-
#export_custom_routes ⇒ Boolean
(also: #export_custom_routes?)
This field will be deprecated soon.
-
#import_custom_routes ⇒ Boolean
(also: #import_custom_routes?)
This field will be deprecated soon.
-
#name ⇒ String
Name of the peering, which should conform to RFC1035.
-
#network_peering ⇒ Google::Apis::ComputeAlpha::NetworkPeering
A network peering attached to a network resource.
-
#peer_network ⇒ String
URL of the peer network.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NetworksAddPeeringRequest
constructor
A new instance of NetworksAddPeeringRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NetworksAddPeeringRequest
Returns a new instance of NetworksAddPeeringRequest.
46738 46739 46740 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 46738 def initialize(**args) update!(**args) end |
Instance Attribute Details
#auto_create_routes ⇒ Boolean Also known as: auto_create_routes?
This field will be deprecated soon. Useexchange_subnet_routes in
network_peering
instead.
Indicates whether full mesh connectivity is created and managed
automatically between peered networks. Currently this field should always
be true since Google Compute Engine will automatically create and manage
subnetwork routes between two networks when peering state isACTIVE.
Corresponds to the JSON property autoCreateRoutes
46699 46700 46701 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 46699 def auto_create_routes @auto_create_routes end |
#export_custom_routes ⇒ Boolean Also known as: export_custom_routes?
This field will be deprecated soon. Useexport_custom_routes in network_peering
instead.
Whether to export the custom routes to peer network.
Corresponds to the JSON property exportCustomRoutes
46707 46708 46709 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 46707 def export_custom_routes @export_custom_routes end |
#import_custom_routes ⇒ Boolean Also known as: import_custom_routes?
This field will be deprecated soon. Useimport_custom_routes in network_peering
instead.
Whether to import the custom routes from peer network.
Corresponds to the JSON property importCustomRoutes
46715 46716 46717 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 46715 def import_custom_routes @import_custom_routes end |
#name ⇒ String
Name of the peering, which should conform to RFC1035.
Corresponds to the JSON property name
46721 46722 46723 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 46721 def name @name end |
#network_peering ⇒ Google::Apis::ComputeAlpha::NetworkPeering
A network peering attached to a network resource. The message includes the
peering name, peer network, peering state, and a flag indicating whether
Google Compute Engine should automatically create routes for the peering.
Corresponds to the JSON property networkPeering
46728 46729 46730 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 46728 def network_peering @network_peering end |
#peer_network ⇒ String
URL of the peer network. It can be either full URL or partial URL. The
peer network may belong to a different project. If the partial URL does not
contain project, it is assumed that the peer network is in the same project
as the current network.
Corresponds to the JSON property peerNetwork
46736 46737 46738 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 46736 def peer_network @peer_network end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
46743 46744 46745 46746 46747 46748 46749 46750 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 46743 def update!(**args) @auto_create_routes = args[:auto_create_routes] if args.key?(:auto_create_routes) @export_custom_routes = args[:export_custom_routes] if args.key?(:export_custom_routes) @import_custom_routes = args[:import_custom_routes] if args.key?(:import_custom_routes) @name = args[:name] if args.key?(:name) @network_peering = args[:network_peering] if args.key?(:network_peering) @peer_network = args[:peer_network] if args.key?(:peer_network) end |