Class: Google::Apis::ComputeAlpha::NodeGroup

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Represents a sole-tenant Node Group resource. A sole-tenant node is a physical server that is dedicated to hosting VM instances only for your specific project. Use sole-tenant nodes to keep your instances physically separated from instances in other projects, or to group your instances together on the same host hardware. For more information, readSole-tenant nodes.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NodeGroup

Returns a new instance of NodeGroup.



47075
47076
47077
# File 'lib/google/apis/compute_alpha/classes.rb', line 47075

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#autoscaling_policyGoogle::Apis::ComputeAlpha::NodeGroupAutoscalingPolicy

Specifies how autoscaling should behave. Corresponds to the JSON property autoscalingPolicy



46963
46964
46965
# File 'lib/google/apis/compute_alpha/classes.rb', line 46963

def autoscaling_policy
  @autoscaling_policy
end

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


46969
46970
46971
# File 'lib/google/apis/compute_alpha/classes.rb', line 46969

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


46975
46976
46977
# File 'lib/google/apis/compute_alpha/classes.rb', line 46975

def description
  @description
end

#fingerprintString

Corresponds to the JSON property fingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


46981
46982
46983
# File 'lib/google/apis/compute_alpha/classes.rb', line 46981

def fingerprint
  @fingerprint
end

#idFixnum

Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


46988
46989
46990
# File 'lib/google/apis/compute_alpha/classes.rb', line 46988

def id
  @id
end

#kindString

Output only. [Output Only] The type of the resource. Alwayscompute#nodeGroup for node group. Corresponds to the JSON property kind

Returns:

  • (String)


46994
46995
46996
# File 'lib/google/apis/compute_alpha/classes.rb', line 46994

def kind
  @kind
end

#location_hintString

An opaque location hint used to place the Node close to other resources. This field is for use by internal tools that use the public API. The location hint here on the NodeGroup overrides any location_hint present in the NodeTemplate. Corresponds to the JSON property locationHint

Returns:

  • (String)


47003
47004
47005
# File 'lib/google/apis/compute_alpha/classes.rb', line 47003

def location_hint
  @location_hint
end

#maintenance_intervalString

Specifies the frequency of planned maintenance events. The accepted values are: AS_NEEDED and RECURRENT. Corresponds to the JSON property maintenanceInterval

Returns:

  • (String)


47009
47010
47011
# File 'lib/google/apis/compute_alpha/classes.rb', line 47009

def maintenance_interval
  @maintenance_interval
end

#maintenance_policyString

Specifies how to handle instances when a node in the group undergoes maintenance. Set to one of: DEFAULT,RESTART_IN_PLACE, or MIGRATE_WITHIN_NODE_GROUP. The default value is DEFAULT. For more information, see Maintenance policies. Corresponds to the JSON property maintenancePolicy

Returns:

  • (String)


47018
47019
47020
# File 'lib/google/apis/compute_alpha/classes.rb', line 47018

def maintenance_policy
  @maintenance_policy
end

#maintenance_windowGoogle::Apis::ComputeAlpha::NodeGroupMaintenanceWindow

Time window specified for daily maintenance operations. GCE's internal maintenance will be performed within this window. Corresponds to the JSON property maintenanceWindow



47024
47025
47026
# File 'lib/google/apis/compute_alpha/classes.rb', line 47024

def maintenance_window
  @maintenance_window
end

#nameString

The name of the resource, provided by the client when initially creating the resource. The resource name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


47036
47037
47038
# File 'lib/google/apis/compute_alpha/classes.rb', line 47036

def name
  @name
end

#node_templateString

URL of the node template to create the node group from. Corresponds to the JSON property nodeTemplate

Returns:

  • (String)


47041
47042
47043
# File 'lib/google/apis/compute_alpha/classes.rb', line 47041

def node_template
  @node_template
end

Output only. [Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


47046
47047
47048
# File 'lib/google/apis/compute_alpha/classes.rb', line 47046

def self_link
  @self_link
end

Output only. [Output Only] Server-defined URL for this resource with the resource id. Corresponds to the JSON property selfLinkWithId

Returns:

  • (String)


47052
47053
47054
# File 'lib/google/apis/compute_alpha/classes.rb', line 47052

def self_link_with_id
  @self_link_with_id
end

#share_settingsGoogle::Apis::ComputeAlpha::ShareSettings

The share setting for reservations and sole tenancy node groups. Corresponds to the JSON property shareSettings



47057
47058
47059
# File 'lib/google/apis/compute_alpha/classes.rb', line 47057

def share_settings
  @share_settings
end

#sizeFixnum

Output only. [Output Only] The total number of nodes in the node group. Corresponds to the JSON property size

Returns:

  • (Fixnum)


47062
47063
47064
# File 'lib/google/apis/compute_alpha/classes.rb', line 47062

def size
  @size
end

#statusString

Corresponds to the JSON property status

Returns:

  • (String)


47067
47068
47069
# File 'lib/google/apis/compute_alpha/classes.rb', line 47067

def status
  @status
end

#zoneString

Output only. [Output Only] The name of the zone where the node group resides, such as us-central1-a. Corresponds to the JSON property zone

Returns:

  • (String)


47073
47074
47075
# File 'lib/google/apis/compute_alpha/classes.rb', line 47073

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



47080
47081
47082
47083
47084
47085
47086
47087
47088
47089
47090
47091
47092
47093
47094
47095
47096
47097
47098
47099
# File 'lib/google/apis/compute_alpha/classes.rb', line 47080

def update!(**args)
  @autoscaling_policy = args[:autoscaling_policy] if args.key?(:autoscaling_policy)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @fingerprint = args[:fingerprint] if args.key?(:fingerprint)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @location_hint = args[:location_hint] if args.key?(:location_hint)
  @maintenance_interval = args[:maintenance_interval] if args.key?(:maintenance_interval)
  @maintenance_policy = args[:maintenance_policy] if args.key?(:maintenance_policy)
  @maintenance_window = args[:maintenance_window] if args.key?(:maintenance_window)
  @name = args[:name] if args.key?(:name)
  @node_template = args[:node_template] if args.key?(:node_template)
  @self_link = args[:self_link] if args.key?(:self_link)
  @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id)
  @share_settings = args[:share_settings] if args.key?(:share_settings)
  @size = args[:size] if args.key?(:size)
  @status = args[:status] if args.key?(:status)
  @zone = args[:zone] if args.key?(:zone)
end