Class: Google::Apis::ComputeAlpha::NodeGroupAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::NodeGroupAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::NodeGroupsScopedList>
A list of NodeGroupsScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::NodeGroupAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NodeGroupAggregatedList
constructor
A new instance of NodeGroupAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NodeGroupAggregatedList
Returns a new instance of NodeGroupAggregatedList.
48911 48912 48913 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 48911 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
48872 48873 48874 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 48872 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::NodeGroupsScopedList>
A list of NodeGroupsScopedList resources.
Corresponds to the JSON property items
48877 48878 48879 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 48877 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource.Alwayscompute#
nodeGroupAggregatedList for aggregated lists of node
groups.
Corresponds to the JSON property kind
48884 48885 48886 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 48884 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
48894 48895 48896 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 48894 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
48899 48900 48901 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 48899 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
48904 48905 48906 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 48904 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::NodeGroupAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
48909 48910 48911 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 48909 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
48916 48917 48918 48919 48920 48921 48922 48923 48924 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 48916 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |