Class: Google::Apis::ComputeAlpha::NodeGroupAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NodeGroupAggregatedList

Returns a new instance of NodeGroupAggregatedList.



48632
48633
48634
# File 'lib/google/apis/compute_alpha/classes.rb', line 48632

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


48593
48594
48595
# File 'lib/google/apis/compute_alpha/classes.rb', line 48593

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::NodeGroupsScopedList>

A list of NodeGroupsScopedList resources. Corresponds to the JSON property items



48598
48599
48600
# File 'lib/google/apis/compute_alpha/classes.rb', line 48598

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource.Alwayscompute# nodeGroupAggregatedList for aggregated lists of node groups. Corresponds to the JSON property kind

Returns:

  • (String)


48605
48606
48607
# File 'lib/google/apis/compute_alpha/classes.rb', line 48605

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


48615
48616
48617
# File 'lib/google/apis/compute_alpha/classes.rb', line 48615

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


48620
48621
48622
# File 'lib/google/apis/compute_alpha/classes.rb', line 48620

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


48625
48626
48627
# File 'lib/google/apis/compute_alpha/classes.rb', line 48625

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::NodeGroupAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



48630
48631
48632
# File 'lib/google/apis/compute_alpha/classes.rb', line 48630

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



48637
48638
48639
48640
48641
48642
48643
48644
48645
# File 'lib/google/apis/compute_alpha/classes.rb', line 48637

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end