Class: Google::Apis::ComputeAlpha::NodeGroupAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::NodeGroupAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::NodeGroupsScopedList>
A list of NodeGroupsScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::NodeGroupAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NodeGroupAggregatedList
constructor
A new instance of NodeGroupAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NodeGroupAggregatedList
Returns a new instance of NodeGroupAggregatedList.
47584 47585 47586 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 47584 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
47545 47546 47547 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 47545 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::NodeGroupsScopedList>
A list of NodeGroupsScopedList resources.
Corresponds to the JSON property items
47550 47551 47552 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 47550 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource.Alwayscompute#
nodeGroupAggregatedList for aggregated lists of node
groups.
Corresponds to the JSON property kind
47557 47558 47559 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 47557 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
47567 47568 47569 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 47567 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
47572 47573 47574 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 47572 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
47577 47578 47579 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 47577 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::NodeGroupAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
47582 47583 47584 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 47582 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
47589 47590 47591 47592 47593 47594 47595 47596 47597 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 47589 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |