Class: Google::Apis::ComputeAlpha::NodeGroupAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NodeGroupAggregatedList

Returns a new instance of NodeGroupAggregatedList.



47567
47568
47569
# File 'lib/google/apis/compute_alpha/classes.rb', line 47567

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


47528
47529
47530
# File 'lib/google/apis/compute_alpha/classes.rb', line 47528

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::NodeGroupsScopedList>

A list of NodeGroupsScopedList resources. Corresponds to the JSON property items



47533
47534
47535
# File 'lib/google/apis/compute_alpha/classes.rb', line 47533

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource.Alwayscompute# nodeGroupAggregatedList for aggregated lists of node groups. Corresponds to the JSON property kind

Returns:

  • (String)


47540
47541
47542
# File 'lib/google/apis/compute_alpha/classes.rb', line 47540

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


47550
47551
47552
# File 'lib/google/apis/compute_alpha/classes.rb', line 47550

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


47555
47556
47557
# File 'lib/google/apis/compute_alpha/classes.rb', line 47555

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


47560
47561
47562
# File 'lib/google/apis/compute_alpha/classes.rb', line 47560

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::NodeGroupAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



47565
47566
47567
# File 'lib/google/apis/compute_alpha/classes.rb', line 47565

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



47572
47573
47574
47575
47576
47577
47578
47579
47580
# File 'lib/google/apis/compute_alpha/classes.rb', line 47572

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end