Class: Google::Apis::ComputeAlpha::NodeGroupAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NodeGroupAggregatedList

Returns a new instance of NodeGroupAggregatedList.



47351
47352
47353
# File 'lib/google/apis/compute_alpha/classes.rb', line 47351

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


47312
47313
47314
# File 'lib/google/apis/compute_alpha/classes.rb', line 47312

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::NodeGroupsScopedList>

A list of NodeGroupsScopedList resources. Corresponds to the JSON property items



47317
47318
47319
# File 'lib/google/apis/compute_alpha/classes.rb', line 47317

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource.Alwayscompute# nodeGroupAggregatedList for aggregated lists of node groups. Corresponds to the JSON property kind

Returns:

  • (String)


47324
47325
47326
# File 'lib/google/apis/compute_alpha/classes.rb', line 47324

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


47334
47335
47336
# File 'lib/google/apis/compute_alpha/classes.rb', line 47334

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


47339
47340
47341
# File 'lib/google/apis/compute_alpha/classes.rb', line 47339

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


47344
47345
47346
# File 'lib/google/apis/compute_alpha/classes.rb', line 47344

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::NodeGroupAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



47349
47350
47351
# File 'lib/google/apis/compute_alpha/classes.rb', line 47349

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



47356
47357
47358
47359
47360
47361
47362
47363
47364
# File 'lib/google/apis/compute_alpha/classes.rb', line 47356

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end