Class: Google::Apis::ComputeAlpha::NodeGroupAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NodeGroupAggregatedList

Returns a new instance of NodeGroupAggregatedList.



47349
47350
47351
# File 'lib/google/apis/compute_alpha/classes.rb', line 47349

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


47310
47311
47312
# File 'lib/google/apis/compute_alpha/classes.rb', line 47310

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::NodeGroupsScopedList>

A list of NodeGroupsScopedList resources. Corresponds to the JSON property items



47315
47316
47317
# File 'lib/google/apis/compute_alpha/classes.rb', line 47315

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource.Alwayscompute# nodeGroupAggregatedList for aggregated lists of node groups. Corresponds to the JSON property kind

Returns:

  • (String)


47322
47323
47324
# File 'lib/google/apis/compute_alpha/classes.rb', line 47322

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


47332
47333
47334
# File 'lib/google/apis/compute_alpha/classes.rb', line 47332

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


47337
47338
47339
# File 'lib/google/apis/compute_alpha/classes.rb', line 47337

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


47342
47343
47344
# File 'lib/google/apis/compute_alpha/classes.rb', line 47342

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::NodeGroupAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



47347
47348
47349
# File 'lib/google/apis/compute_alpha/classes.rb', line 47347

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



47354
47355
47356
47357
47358
47359
47360
47361
47362
# File 'lib/google/apis/compute_alpha/classes.rb', line 47354

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end