Class: Google::Apis::ComputeAlpha::NodeGroupAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NodeGroupAggregatedList

Returns a new instance of NodeGroupAggregatedList.



46391
46392
46393
# File 'lib/google/apis/compute_alpha/classes.rb', line 46391

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


46352
46353
46354
# File 'lib/google/apis/compute_alpha/classes.rb', line 46352

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::NodeGroupsScopedList>

A list of NodeGroupsScopedList resources. Corresponds to the JSON property items



46357
46358
46359
# File 'lib/google/apis/compute_alpha/classes.rb', line 46357

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource.Alwayscompute# nodeGroupAggregatedList for aggregated lists of node groups. Corresponds to the JSON property kind

Returns:

  • (String)


46364
46365
46366
# File 'lib/google/apis/compute_alpha/classes.rb', line 46364

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


46374
46375
46376
# File 'lib/google/apis/compute_alpha/classes.rb', line 46374

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


46379
46380
46381
# File 'lib/google/apis/compute_alpha/classes.rb', line 46379

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


46384
46385
46386
# File 'lib/google/apis/compute_alpha/classes.rb', line 46384

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::NodeGroupAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



46389
46390
46391
# File 'lib/google/apis/compute_alpha/classes.rb', line 46389

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



46396
46397
46398
46399
46400
46401
46402
46403
46404
# File 'lib/google/apis/compute_alpha/classes.rb', line 46396

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end