Class: Google::Apis::ComputeAlpha::NodeGroupAutoscalingPolicy
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::NodeGroupAutoscalingPolicy
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#max_nodes ⇒ Fixnum
The maximum number of nodes that the group should have.
-
#min_nodes ⇒ Fixnum
The minimum number of nodes that the group should have.
-
#mode ⇒ String
The autoscaling mode.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NodeGroupAutoscalingPolicy
constructor
A new instance of NodeGroupAutoscalingPolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NodeGroupAutoscalingPolicy
Returns a new instance of NodeGroupAutoscalingPolicy.
47675 47676 47677 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 47675 def initialize(**args) update!(**args) end |
Instance Attribute Details
#max_nodes ⇒ Fixnum
The maximum number of nodes that the group should have. Must be set if
autoscaling is enabled. Maximum value allowed is 100.
Corresponds to the JSON property maxNodes
47661 47662 47663 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 47661 def max_nodes @max_nodes end |
#min_nodes ⇒ Fixnum
The minimum number of nodes that the group should have.
Corresponds to the JSON property minNodes
47666 47667 47668 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 47666 def min_nodes @min_nodes end |
#mode ⇒ String
The autoscaling mode. Set to one of: ON, OFF,
or ONLY_SCALE_OUT. For more information, see
Autoscaler modes.
Corresponds to the JSON property mode
47673 47674 47675 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 47673 def mode @mode end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
47680 47681 47682 47683 47684 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 47680 def update!(**args) @max_nodes = args[:max_nodes] if args.key?(:max_nodes) @min_nodes = args[:min_nodes] if args.key?(:min_nodes) @mode = args[:mode] if args.key?(:mode) end |