Class: Google::Apis::ComputeAlpha::NodeGroupList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of nodeGroups.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NodeGroupList

Returns a new instance of NodeGroupList.



48792
48793
48794
# File 'lib/google/apis/compute_alpha/classes.rb', line 48792

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


48759
48760
48761
# File 'lib/google/apis/compute_alpha/classes.rb', line 48759

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::NodeGroup>

A list of NodeGroup resources. Corresponds to the JSON property items



48764
48765
48766
# File 'lib/google/apis/compute_alpha/classes.rb', line 48764

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource.Always compute#nodeGroupList for lists of node groups. Corresponds to the JSON property kind

Returns:

  • (String)


48770
48771
48772
# File 'lib/google/apis/compute_alpha/classes.rb', line 48770

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


48780
48781
48782
# File 'lib/google/apis/compute_alpha/classes.rb', line 48780

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


48785
48786
48787
# File 'lib/google/apis/compute_alpha/classes.rb', line 48785

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::NodeGroupList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



48790
48791
48792
# File 'lib/google/apis/compute_alpha/classes.rb', line 48790

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



48797
48798
48799
48800
48801
48802
48803
48804
# File 'lib/google/apis/compute_alpha/classes.rb', line 48797

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end