Class: Google::Apis::ComputeAlpha::NodeGroupList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of nodeGroups.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NodeGroupList

Returns a new instance of NodeGroupList.



47744
47745
47746
# File 'lib/google/apis/compute_alpha/classes.rb', line 47744

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


47711
47712
47713
# File 'lib/google/apis/compute_alpha/classes.rb', line 47711

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::NodeGroup>

A list of NodeGroup resources. Corresponds to the JSON property items



47716
47717
47718
# File 'lib/google/apis/compute_alpha/classes.rb', line 47716

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource.Always compute#nodeGroupList for lists of node groups. Corresponds to the JSON property kind

Returns:

  • (String)


47722
47723
47724
# File 'lib/google/apis/compute_alpha/classes.rb', line 47722

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


47732
47733
47734
# File 'lib/google/apis/compute_alpha/classes.rb', line 47732

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


47737
47738
47739
# File 'lib/google/apis/compute_alpha/classes.rb', line 47737

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::NodeGroupList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



47742
47743
47744
# File 'lib/google/apis/compute_alpha/classes.rb', line 47742

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



47749
47750
47751
47752
47753
47754
47755
47756
# File 'lib/google/apis/compute_alpha/classes.rb', line 47749

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end