Class: Google::Apis::ComputeAlpha::NodeGroupList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::NodeGroupList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Contains a list of nodeGroups.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::NodeGroup>
A list of NodeGroup resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::NodeGroupList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NodeGroupList
constructor
A new instance of NodeGroupList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NodeGroupList
Returns a new instance of NodeGroupList.
47727 47728 47729 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 47727 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
47694 47695 47696 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 47694 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::NodeGroup>
A list of NodeGroup resources.
Corresponds to the JSON property items
47699 47700 47701 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 47699 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource.Always compute#nodeGroupList
for lists of node groups.
Corresponds to the JSON property kind
47705 47706 47707 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 47705 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
47715 47716 47717 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 47715 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
47720 47721 47722 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 47720 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::NodeGroupList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
47725 47726 47727 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 47725 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
47732 47733 47734 47735 47736 47737 47738 47739 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 47732 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |