Class: Google::Apis::ComputeAlpha::NodeGroupList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::NodeGroupList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Contains a list of nodeGroups.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::NodeGroup>
A list of NodeGroup resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::NodeGroupList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NodeGroupList
constructor
A new instance of NodeGroupList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NodeGroupList
Returns a new instance of NodeGroupList.
47511 47512 47513 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 47511 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
47478 47479 47480 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 47478 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::NodeGroup>
A list of NodeGroup resources.
Corresponds to the JSON property items
47483 47484 47485 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 47483 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource.Always compute#nodeGroupList
for lists of node groups.
Corresponds to the JSON property kind
47489 47490 47491 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 47489 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
47499 47500 47501 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 47499 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
47504 47505 47506 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 47504 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::NodeGroupList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
47509 47510 47511 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 47509 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
47516 47517 47518 47519 47520 47521 47522 47523 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 47516 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |