Class: Google::Apis::ComputeAlpha::NodeGroupList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of nodeGroups.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NodeGroupList

Returns a new instance of NodeGroupList.



46551
46552
46553
# File 'lib/google/apis/compute_alpha/classes.rb', line 46551

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


46518
46519
46520
# File 'lib/google/apis/compute_alpha/classes.rb', line 46518

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::NodeGroup>

A list of NodeGroup resources. Corresponds to the JSON property items



46523
46524
46525
# File 'lib/google/apis/compute_alpha/classes.rb', line 46523

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource.Always compute#nodeGroupList for lists of node groups. Corresponds to the JSON property kind

Returns:

  • (String)


46529
46530
46531
# File 'lib/google/apis/compute_alpha/classes.rb', line 46529

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


46539
46540
46541
# File 'lib/google/apis/compute_alpha/classes.rb', line 46539

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


46544
46545
46546
# File 'lib/google/apis/compute_alpha/classes.rb', line 46544

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::NodeGroupList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



46549
46550
46551
# File 'lib/google/apis/compute_alpha/classes.rb', line 46549

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



46556
46557
46558
46559
46560
46561
46562
46563
# File 'lib/google/apis/compute_alpha/classes.rb', line 46556

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end