Class: Google::Apis::ComputeAlpha::NodeGroupMaintenanceWindow

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Time window specified for daily maintenance operations. GCE's internal maintenance will be performed within this window.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NodeGroupMaintenanceWindow

Returns a new instance of NodeGroupMaintenanceWindow.



47839
47840
47841
# File 'lib/google/apis/compute_alpha/classes.rb', line 47839

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#durationString

Output only. [Output only] A predetermined duration for the window, automatically chosen to be the smallest possible in the given scenario. Corresponds to the JSON property duration

Returns:

  • (String)


47822
47823
47824
# File 'lib/google/apis/compute_alpha/classes.rb', line 47822

def duration
  @duration
end

#maintenance_durationGoogle::Apis::ComputeAlpha::Duration

A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution. It is independent of any calendar and concepts like "day" or "month". Range is approximately 10,000 years. Corresponds to the JSON property maintenanceDuration



47830
47831
47832
# File 'lib/google/apis/compute_alpha/classes.rb', line 47830

def maintenance_duration
  @maintenance_duration
end

#start_timeString

Start time of the window. This must be in UTC format that resolves to one of 00:00, 04:00, 08:00,12:00, 16:00, or 20:00. For example, both 13:00-5 and 08:00 are valid. Corresponds to the JSON property startTime

Returns:

  • (String)


47837
47838
47839
# File 'lib/google/apis/compute_alpha/classes.rb', line 47837

def start_time
  @start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



47844
47845
47846
47847
47848
# File 'lib/google/apis/compute_alpha/classes.rb', line 47844

def update!(**args)
  @duration = args[:duration] if args.key?(:duration)
  @maintenance_duration = args[:maintenance_duration] if args.key?(:maintenance_duration)
  @start_time = args[:start_time] if args.key?(:start_time)
end