Class: Google::Apis::ComputeAlpha::NodeGroupsListNodes

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NodeGroupsListNodes

Returns a new instance of NodeGroupsListNodes.



49095
49096
49097
# File 'lib/google/apis/compute_alpha/classes.rb', line 49095

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Output only. [Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


49060
49061
49062
# File 'lib/google/apis/compute_alpha/classes.rb', line 49060

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::NodeGroupNode>

A list of Node resources. Corresponds to the JSON property items



49065
49066
49067
# File 'lib/google/apis/compute_alpha/classes.rb', line 49065

def items
  @items
end

#kindString

Output only. [Output Only] The resource type, which is alwayscompute. nodeGroupsListNodes for the list of nodes in the specified node group. Corresponds to the JSON property kind

Returns:

  • (String)


49072
49073
49074
# File 'lib/google/apis/compute_alpha/classes.rb', line 49072

def kind
  @kind
end

#next_page_tokenString

Output only. [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


49083
49084
49085
# File 'lib/google/apis/compute_alpha/classes.rb', line 49083

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


49088
49089
49090
# File 'lib/google/apis/compute_alpha/classes.rb', line 49088

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::NodeGroupsListNodes::Warning

Output only. [Output Only] Informational warning message. Corresponds to the JSON property warning



49093
49094
49095
# File 'lib/google/apis/compute_alpha/classes.rb', line 49093

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



49100
49101
49102
49103
49104
49105
49106
49107
# File 'lib/google/apis/compute_alpha/classes.rb', line 49100

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end