Class: Google::Apis::ComputeAlpha::NodeGroupsListNodes

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NodeGroupsListNodes

Returns a new instance of NodeGroupsListNodes.



47814
47815
47816
# File 'lib/google/apis/compute_alpha/classes.rb', line 47814

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Output only. [Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


47779
47780
47781
# File 'lib/google/apis/compute_alpha/classes.rb', line 47779

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::NodeGroupNode>

A list of Node resources. Corresponds to the JSON property items



47784
47785
47786
# File 'lib/google/apis/compute_alpha/classes.rb', line 47784

def items
  @items
end

#kindString

Output only. [Output Only] The resource type, which is alwayscompute. nodeGroupsListNodes for the list of nodes in the specified node group. Corresponds to the JSON property kind

Returns:

  • (String)


47791
47792
47793
# File 'lib/google/apis/compute_alpha/classes.rb', line 47791

def kind
  @kind
end

#next_page_tokenString

Output only. [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


47802
47803
47804
# File 'lib/google/apis/compute_alpha/classes.rb', line 47802

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


47807
47808
47809
# File 'lib/google/apis/compute_alpha/classes.rb', line 47807

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::NodeGroupsListNodes::Warning

Output only. [Output Only] Informational warning message. Corresponds to the JSON property warning



47812
47813
47814
# File 'lib/google/apis/compute_alpha/classes.rb', line 47812

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



47819
47820
47821
47822
47823
47824
47825
47826
# File 'lib/google/apis/compute_alpha/classes.rb', line 47819

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end