Class: Google::Apis::ComputeAlpha::NodeTemplate

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Represent a sole-tenant Node Template resource. You can use a template to define properties for nodes in a node group. For more information, readCreating node groups and instances.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NodeTemplate

Returns a new instance of NodeTemplate.



48410
48411
48412
# File 'lib/google/apis/compute_alpha/classes.rb', line 48410

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#acceleratorsArray<Google::Apis::ComputeAlpha::AcceleratorConfig>

Corresponds to the JSON property accelerators



48303
48304
48305
# File 'lib/google/apis/compute_alpha/classes.rb', line 48303

def accelerators
  @accelerators
end

#cpu_overcommit_typeString

CPU overcommit. Corresponds to the JSON property cpuOvercommitType

Returns:

  • (String)


48308
48309
48310
# File 'lib/google/apis/compute_alpha/classes.rb', line 48308

def cpu_overcommit_type
  @cpu_overcommit_type
end

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


48314
48315
48316
# File 'lib/google/apis/compute_alpha/classes.rb', line 48314

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


48320
48321
48322
# File 'lib/google/apis/compute_alpha/classes.rb', line 48320

def description
  @description
end

#disksArray<Google::Apis::ComputeAlpha::LocalDisk>

Corresponds to the JSON property disks



48325
48326
48327
# File 'lib/google/apis/compute_alpha/classes.rb', line 48325

def disks
  @disks
end

#idFixnum

Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


48332
48333
48334
# File 'lib/google/apis/compute_alpha/classes.rb', line 48332

def id
  @id
end

#kindString

Output only. [Output Only] The type of the resource. Alwayscompute# nodeTemplate for node templates. Corresponds to the JSON property kind

Returns:

  • (String)


48338
48339
48340
# File 'lib/google/apis/compute_alpha/classes.rb', line 48338

def kind
  @kind
end

#nameString

The name of the resource, provided by the client when initially creating the resource. The resource name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


48350
48351
48352
# File 'lib/google/apis/compute_alpha/classes.rb', line 48350

def name
  @name
end

#node_affinity_labelsHash<String,String>

Labels to use for node affinity, which will be used in instance scheduling. Corresponds to the JSON property nodeAffinityLabels

Returns:

  • (Hash<String,String>)


48355
48356
48357
# File 'lib/google/apis/compute_alpha/classes.rb', line 48355

def node_affinity_labels
  @node_affinity_labels
end

#node_typeString

The node type to use for nodes group that are created from this template. Corresponds to the JSON property nodeType

Returns:

  • (String)


48360
48361
48362
# File 'lib/google/apis/compute_alpha/classes.rb', line 48360

def node_type
  @node_type
end

#node_type_flexibilityGoogle::Apis::ComputeAlpha::NodeTemplateNodeTypeFlexibility

Do not use. Instead, use the node_type property. Corresponds to the JSON property nodeTypeFlexibility



48365
48366
48367
# File 'lib/google/apis/compute_alpha/classes.rb', line 48365

def node_type_flexibility
  @node_type_flexibility
end

#regionString

Output only. [Output Only] The name of the region where the node template resides, such as us-central1. Corresponds to the JSON property region

Returns:

  • (String)


48372
48373
48374
# File 'lib/google/apis/compute_alpha/classes.rb', line 48372

def region
  @region
end

Output only. [Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


48377
48378
48379
# File 'lib/google/apis/compute_alpha/classes.rb', line 48377

def self_link
  @self_link
end

Output only. [Output Only] Server-defined URL for this resource with the resource id. Corresponds to the JSON property selfLinkWithId

Returns:

  • (String)


48383
48384
48385
# File 'lib/google/apis/compute_alpha/classes.rb', line 48383

def self_link_with_id
  @self_link_with_id
end

#server_bindingGoogle::Apis::ComputeAlpha::ServerBinding

Sets the binding properties for the physical server. Valid values include:

  • [Default] RESTART_NODE_ON_ANY_SERVER: Restarts VMs on any available physical server
  • RESTART_NODE_ON_MINIMAL_SERVER: Restarts VMs on the same physical server whenever possible See Sole-tenant node options for more information. Corresponds to the JSON property serverBinding


48396
48397
48398
# File 'lib/google/apis/compute_alpha/classes.rb', line 48396

def server_binding
  @server_binding
end

#statusString

Output only. [Output Only] The status of the node template. One of the following values:CREATING, READY, and DELETING. Corresponds to the JSON property status

Returns:

  • (String)


48402
48403
48404
# File 'lib/google/apis/compute_alpha/classes.rb', line 48402

def status
  @status
end

#status_messageString

Output only. [Output Only] An optional, human-readable explanation of the status. Corresponds to the JSON property statusMessage

Returns:

  • (String)


48408
48409
48410
# File 'lib/google/apis/compute_alpha/classes.rb', line 48408

def status_message
  @status_message
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



48415
48416
48417
48418
48419
48420
48421
48422
48423
48424
48425
48426
48427
48428
48429
48430
48431
48432
48433
# File 'lib/google/apis/compute_alpha/classes.rb', line 48415

def update!(**args)
  @accelerators = args[:accelerators] if args.key?(:accelerators)
  @cpu_overcommit_type = args[:cpu_overcommit_type] if args.key?(:cpu_overcommit_type)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @disks = args[:disks] if args.key?(:disks)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @node_affinity_labels = args[:node_affinity_labels] if args.key?(:node_affinity_labels)
  @node_type = args[:node_type] if args.key?(:node_type)
  @node_type_flexibility = args[:node_type_flexibility] if args.key?(:node_type_flexibility)
  @region = args[:region] if args.key?(:region)
  @self_link = args[:self_link] if args.key?(:self_link)
  @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id)
  @server_binding = args[:server_binding] if args.key?(:server_binding)
  @status = args[:status] if args.key?(:status)
  @status_message = args[:status_message] if args.key?(:status_message)
end