Class: Google::Apis::ComputeAlpha::NodeTemplate
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::NodeTemplate
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Represent a sole-tenant Node Template resource. You can use a template to define properties for nodes in a node group. For more information, readCreating node groups and instances.
Instance Attribute Summary collapse
-
#accelerators ⇒ Array<Google::Apis::ComputeAlpha::AcceleratorConfig>
Corresponds to the JSON property
accelerators. -
#cpu_overcommit_type ⇒ String
CPU overcommit.
-
#creation_timestamp ⇒ String
Output only.
-
#description ⇒ String
An optional description of this resource.
-
#disks ⇒ Array<Google::Apis::ComputeAlpha::LocalDisk>
Corresponds to the JSON property
disks. -
#id ⇒ Fixnum
Output only.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
The name of the resource, provided by the client when initially creating the resource.
-
#node_affinity_labels ⇒ Hash<String,String>
Labels to use for node affinity, which will be used in instance scheduling.
-
#node_type ⇒ String
The node type to use for nodes group that are created from this template.
-
#node_type_flexibility ⇒ Google::Apis::ComputeAlpha::NodeTemplateNodeTypeFlexibility
Do not use.
-
#region ⇒ String
Output only.
-
#self_link ⇒ String
Output only.
-
#self_link_with_id ⇒ String
Output only.
-
#server_binding ⇒ Google::Apis::ComputeAlpha::ServerBinding
Sets the binding properties for the physical server.
-
#status ⇒ String
Output only.
-
#status_message ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NodeTemplate
constructor
A new instance of NodeTemplate.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NodeTemplate
Returns a new instance of NodeTemplate.
48177 48178 48179 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 48177 def initialize(**args) update!(**args) end |
Instance Attribute Details
#accelerators ⇒ Array<Google::Apis::ComputeAlpha::AcceleratorConfig>
Corresponds to the JSON property accelerators
48070 48071 48072 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 48070 def accelerators @accelerators end |
#cpu_overcommit_type ⇒ String
CPU overcommit.
Corresponds to the JSON property cpuOvercommitType
48075 48076 48077 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 48075 def cpu_overcommit_type @cpu_overcommit_type end |
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
48081 48082 48083 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 48081 def @creation_timestamp end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
48087 48088 48089 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 48087 def description @description end |
#disks ⇒ Array<Google::Apis::ComputeAlpha::LocalDisk>
Corresponds to the JSON property disks
48092 48093 48094 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 48092 def disks @disks end |
#id ⇒ Fixnum
Output only. [Output Only] The unique identifier for the resource. This
identifier is
defined by the server.
Corresponds to the JSON property id
48099 48100 48101 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 48099 def id @id end |
#kind ⇒ String
Output only. [Output Only] The type of the resource. Alwayscompute#
nodeTemplate for node templates.
Corresponds to the JSON property kind
48105 48106 48107 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 48105 def kind @kind end |
#name ⇒ String
The name of the resource, provided by the client when initially creating
the resource. The resource name must be 1-63 characters long, and comply
withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must be
a dash, lowercase letter, or digit, except the last character, which
cannot be a dash.
Corresponds to the JSON property name
48117 48118 48119 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 48117 def name @name end |
#node_affinity_labels ⇒ Hash<String,String>
Labels to use for node affinity, which will be used in instance scheduling.
Corresponds to the JSON property nodeAffinityLabels
48122 48123 48124 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 48122 def node_affinity_labels @node_affinity_labels end |
#node_type ⇒ String
The node type to use for nodes group that are created from this template.
Corresponds to the JSON property nodeType
48127 48128 48129 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 48127 def node_type @node_type end |
#node_type_flexibility ⇒ Google::Apis::ComputeAlpha::NodeTemplateNodeTypeFlexibility
Do not use. Instead, use the node_type property.
Corresponds to the JSON property nodeTypeFlexibility
48132 48133 48134 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 48132 def node_type_flexibility @node_type_flexibility end |
#region ⇒ String
Output only. [Output Only] The name of the region where the node template
resides,
such as us-central1.
Corresponds to the JSON property region
48139 48140 48141 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 48139 def region @region end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
48144 48145 48146 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 48144 def self_link @self_link end |
#self_link_with_id ⇒ String
Output only. [Output Only] Server-defined URL for this resource with the
resource id.
Corresponds to the JSON property selfLinkWithId
48150 48151 48152 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 48150 def self_link_with_id @self_link_with_id end |
#server_binding ⇒ Google::Apis::ComputeAlpha::ServerBinding
Sets the binding properties for the physical server. Valid values include:
- [Default] RESTART_NODE_ON_ANY_SERVER: Restarts VMs on any available physical server
- RESTART_NODE_ON_MINIMAL_SERVER: Restarts VMs on the same
physical server whenever possible
See Sole-tenant
node options for more information.
Corresponds to the JSON property
serverBinding
48163 48164 48165 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 48163 def server_binding @server_binding end |
#status ⇒ String
Output only. [Output Only] The status of the node template. One of the
following values:CREATING, READY, and DELETING.
Corresponds to the JSON property status
48169 48170 48171 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 48169 def status @status end |
#status_message ⇒ String
Output only. [Output Only] An optional, human-readable explanation of the
status.
Corresponds to the JSON property statusMessage
48175 48176 48177 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 48175 def @status_message end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
48182 48183 48184 48185 48186 48187 48188 48189 48190 48191 48192 48193 48194 48195 48196 48197 48198 48199 48200 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 48182 def update!(**args) @accelerators = args[:accelerators] if args.key?(:accelerators) @cpu_overcommit_type = args[:cpu_overcommit_type] if args.key?(:cpu_overcommit_type) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @disks = args[:disks] if args.key?(:disks) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @node_affinity_labels = args[:node_affinity_labels] if args.key?(:node_affinity_labels) @node_type = args[:node_type] if args.key?(:node_type) @node_type_flexibility = args[:node_type_flexibility] if args.key?(:node_type_flexibility) @region = args[:region] if args.key?(:region) @self_link = args[:self_link] if args.key?(:self_link) @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id) @server_binding = args[:server_binding] if args.key?(:server_binding) @status = args[:status] if args.key?(:status) @status_message = args[:status_message] if args.key?(:status_message) end |