Class: Google::Apis::ComputeAlpha::NodeTemplateAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::NodeTemplateAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::NodeTemplatesScopedList>
A list of NodeTemplatesScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::NodeTemplateAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NodeTemplateAggregatedList
constructor
A new instance of NodeTemplateAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NodeTemplateAggregatedList
Returns a new instance of NodeTemplateAggregatedList.
49530 49531 49532 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 49530 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
49491 49492 49493 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 49491 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::NodeTemplatesScopedList>
A list of NodeTemplatesScopedList resources.
Corresponds to the JSON property items
49496 49497 49498 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 49496 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource.Alwayscompute#
nodeTemplateAggregatedList for aggregated lists of
node templates.
Corresponds to the JSON property kind
49503 49504 49505 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 49503 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
49513 49514 49515 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 49513 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
49518 49519 49520 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 49518 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
49523 49524 49525 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 49523 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::NodeTemplateAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
49528 49529 49530 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 49528 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
49535 49536 49537 49538 49539 49540 49541 49542 49543 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 49535 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |