Class: Google::Apis::ComputeAlpha::NodeTemplateAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::NodeTemplateAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::NodeTemplatesScopedList>
A list of NodeTemplatesScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::NodeTemplateAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NodeTemplateAggregatedList
constructor
A new instance of NodeTemplateAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NodeTemplateAggregatedList
Returns a new instance of NodeTemplateAggregatedList.
48482 48483 48484 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 48482 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
48443 48444 48445 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 48443 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::NodeTemplatesScopedList>
A list of NodeTemplatesScopedList resources.
Corresponds to the JSON property items
48448 48449 48450 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 48448 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource.Alwayscompute#
nodeTemplateAggregatedList for aggregated lists of
node templates.
Corresponds to the JSON property kind
48455 48456 48457 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 48455 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
48465 48466 48467 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 48465 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
48470 48471 48472 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 48470 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
48475 48476 48477 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 48475 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::NodeTemplateAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
48480 48481 48482 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 48480 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
48487 48488 48489 48490 48491 48492 48493 48494 48495 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 48487 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |