Class: Google::Apis::ComputeAlpha::NodeTemplateAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NodeTemplateAggregatedList

Returns a new instance of NodeTemplateAggregatedList.



48249
48250
48251
# File 'lib/google/apis/compute_alpha/classes.rb', line 48249

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


48210
48211
48212
# File 'lib/google/apis/compute_alpha/classes.rb', line 48210

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::NodeTemplatesScopedList>

A list of NodeTemplatesScopedList resources. Corresponds to the JSON property items



48215
48216
48217
# File 'lib/google/apis/compute_alpha/classes.rb', line 48215

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource.Alwayscompute# nodeTemplateAggregatedList for aggregated lists of node templates. Corresponds to the JSON property kind

Returns:

  • (String)


48222
48223
48224
# File 'lib/google/apis/compute_alpha/classes.rb', line 48222

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


48232
48233
48234
# File 'lib/google/apis/compute_alpha/classes.rb', line 48232

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


48237
48238
48239
# File 'lib/google/apis/compute_alpha/classes.rb', line 48237

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


48242
48243
48244
# File 'lib/google/apis/compute_alpha/classes.rb', line 48242

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::NodeTemplateAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



48247
48248
48249
# File 'lib/google/apis/compute_alpha/classes.rb', line 48247

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



48254
48255
48256
48257
48258
48259
48260
48261
48262
# File 'lib/google/apis/compute_alpha/classes.rb', line 48254

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end