Class: Google::Apis::ComputeAlpha::NodeTemplateAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NodeTemplateAggregatedList

Returns a new instance of NodeTemplateAggregatedList.



48247
48248
48249
# File 'lib/google/apis/compute_alpha/classes.rb', line 48247

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


48208
48209
48210
# File 'lib/google/apis/compute_alpha/classes.rb', line 48208

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::NodeTemplatesScopedList>

A list of NodeTemplatesScopedList resources. Corresponds to the JSON property items



48213
48214
48215
# File 'lib/google/apis/compute_alpha/classes.rb', line 48213

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource.Alwayscompute# nodeTemplateAggregatedList for aggregated lists of node templates. Corresponds to the JSON property kind

Returns:

  • (String)


48220
48221
48222
# File 'lib/google/apis/compute_alpha/classes.rb', line 48220

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


48230
48231
48232
# File 'lib/google/apis/compute_alpha/classes.rb', line 48230

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


48235
48236
48237
# File 'lib/google/apis/compute_alpha/classes.rb', line 48235

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


48240
48241
48242
# File 'lib/google/apis/compute_alpha/classes.rb', line 48240

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::NodeTemplateAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



48245
48246
48247
# File 'lib/google/apis/compute_alpha/classes.rb', line 48245

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



48252
48253
48254
48255
48256
48257
48258
48259
48260
# File 'lib/google/apis/compute_alpha/classes.rb', line 48252

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end