Class: Google::Apis::ComputeAlpha::NodeTemplateAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NodeTemplateAggregatedList

Returns a new instance of NodeTemplateAggregatedList.



48046
48047
48048
# File 'lib/google/apis/compute_alpha/classes.rb', line 48046

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


48007
48008
48009
# File 'lib/google/apis/compute_alpha/classes.rb', line 48007

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::NodeTemplatesScopedList>

A list of NodeTemplatesScopedList resources. Corresponds to the JSON property items



48012
48013
48014
# File 'lib/google/apis/compute_alpha/classes.rb', line 48012

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource.Alwayscompute# nodeTemplateAggregatedList for aggregated lists of node templates. Corresponds to the JSON property kind

Returns:

  • (String)


48019
48020
48021
# File 'lib/google/apis/compute_alpha/classes.rb', line 48019

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


48029
48030
48031
# File 'lib/google/apis/compute_alpha/classes.rb', line 48029

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


48034
48035
48036
# File 'lib/google/apis/compute_alpha/classes.rb', line 48034

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


48039
48040
48041
# File 'lib/google/apis/compute_alpha/classes.rb', line 48039

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::NodeTemplateAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



48044
48045
48046
# File 'lib/google/apis/compute_alpha/classes.rb', line 48044

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



48051
48052
48053
48054
48055
48056
48057
48058
48059
# File 'lib/google/apis/compute_alpha/classes.rb', line 48051

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end