Class: Google::Apis::ComputeAlpha::NodeTemplateList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::NodeTemplateList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Contains a list of node templates.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::NodeTemplate>
A list of NodeTemplate resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::NodeTemplateList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NodeTemplateList
constructor
A new instance of NodeTemplateList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NodeTemplateList
Returns a new instance of NodeTemplateList.
49656 49657 49658 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 49656 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
49623 49624 49625 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 49623 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::NodeTemplate>
A list of NodeTemplate resources.
Corresponds to the JSON property items
49628 49629 49630 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 49628 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource.Always compute#nodeTemplateList
for lists of node templates.
Corresponds to the JSON property kind
49634 49635 49636 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 49634 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
49644 49645 49646 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 49644 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
49649 49650 49651 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 49649 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::NodeTemplateList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
49654 49655 49656 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 49654 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
49661 49662 49663 49664 49665 49666 49667 49668 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 49661 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |