Class: Google::Apis::ComputeAlpha::NodeTemplateList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of node templates.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NodeTemplateList

Returns a new instance of NodeTemplateList.



48375
48376
48377
# File 'lib/google/apis/compute_alpha/classes.rb', line 48375

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


48342
48343
48344
# File 'lib/google/apis/compute_alpha/classes.rb', line 48342

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::NodeTemplate>

A list of NodeTemplate resources. Corresponds to the JSON property items



48347
48348
48349
# File 'lib/google/apis/compute_alpha/classes.rb', line 48347

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource.Always compute#nodeTemplateList for lists of node templates. Corresponds to the JSON property kind

Returns:

  • (String)


48353
48354
48355
# File 'lib/google/apis/compute_alpha/classes.rb', line 48353

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


48363
48364
48365
# File 'lib/google/apis/compute_alpha/classes.rb', line 48363

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


48368
48369
48370
# File 'lib/google/apis/compute_alpha/classes.rb', line 48368

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::NodeTemplateList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



48373
48374
48375
# File 'lib/google/apis/compute_alpha/classes.rb', line 48373

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



48380
48381
48382
48383
48384
48385
48386
48387
# File 'lib/google/apis/compute_alpha/classes.rb', line 48380

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end