Class: Google::Apis::ComputeAlpha::NodeTemplateList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::NodeTemplateList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Contains a list of node templates.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::NodeTemplate>
A list of NodeTemplate resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::NodeTemplateList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NodeTemplateList
constructor
A new instance of NodeTemplateList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NodeTemplateList
Returns a new instance of NodeTemplateList.
48373 48374 48375 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 48373 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
48340 48341 48342 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 48340 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::NodeTemplate>
A list of NodeTemplate resources.
Corresponds to the JSON property items
48345 48346 48347 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 48345 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource.Always compute#nodeTemplateList
for lists of node templates.
Corresponds to the JSON property kind
48351 48352 48353 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 48351 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
48361 48362 48363 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 48361 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
48366 48367 48368 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 48366 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::NodeTemplateList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
48371 48372 48373 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 48371 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
48378 48379 48380 48381 48382 48383 48384 48385 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 48378 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |