Class: Google::Apis::ComputeAlpha::NodeTemplateList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of node templates.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NodeTemplateList

Returns a new instance of NodeTemplateList.



47415
47416
47417
# File 'lib/google/apis/compute_alpha/classes.rb', line 47415

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


47382
47383
47384
# File 'lib/google/apis/compute_alpha/classes.rb', line 47382

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::NodeTemplate>

A list of NodeTemplate resources. Corresponds to the JSON property items



47387
47388
47389
# File 'lib/google/apis/compute_alpha/classes.rb', line 47387

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource.Always compute#nodeTemplateList for lists of node templates. Corresponds to the JSON property kind

Returns:

  • (String)


47393
47394
47395
# File 'lib/google/apis/compute_alpha/classes.rb', line 47393

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


47403
47404
47405
# File 'lib/google/apis/compute_alpha/classes.rb', line 47403

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


47408
47409
47410
# File 'lib/google/apis/compute_alpha/classes.rb', line 47408

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::NodeTemplateList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



47413
47414
47415
# File 'lib/google/apis/compute_alpha/classes.rb', line 47413

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



47420
47421
47422
47423
47424
47425
47426
47427
# File 'lib/google/apis/compute_alpha/classes.rb', line 47420

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end