Class: Google::Apis::ComputeAlpha::NodeType
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::NodeType
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Represent a sole-tenant Node Type resource. Each node within a node group must have a node type. A node type specifies the total amount of cores and memory for that node. Currently, the only available node type is n1-node-96-624 node type that has 96 vCPUs and 624 GB of memory, available in multiple zones. For more information readNode types.
Instance Attribute Summary collapse
-
#cpu_platform ⇒ String
[Output Only] The CPU platform used by this node type.
-
#creation_timestamp ⇒ String
[Output Only] Creation timestamp inRFC3339 text format.
-
#deprecated ⇒ Google::Apis::ComputeAlpha::DeprecationStatus
Deprecation status for a public resource.
-
#description ⇒ String
[Output Only] An optional textual description of the resource.
-
#guest_cpus ⇒ Fixnum
[Output Only] The number of virtual CPUs that are available to the node type.
-
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource.
-
#kind ⇒ String
Output only.
-
#local_ssd_gb ⇒ Fixnum
[Output Only] Local SSD available to the node type, defined in GB.
-
#max_vms ⇒ Fixnum
Output only.
-
#memory_mb ⇒ Fixnum
[Output Only] The amount of physical memory available to the node type, defined in MB.
-
#name ⇒ String
[Output Only] Name of the resource.
-
#self_link ⇒ String
Output only.
-
#self_link_with_id ⇒ String
Output only.
-
#zone ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NodeType
constructor
A new instance of NodeType.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NodeType
Returns a new instance of NodeType.
48675 48676 48677 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 48675 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cpu_platform ⇒ String
[Output Only] The CPU platform used by this node type.
Corresponds to the JSON property cpuPlatform
48600 48601 48602 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 48600 def cpu_platform @cpu_platform end |
#creation_timestamp ⇒ String
[Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
48606 48607 48608 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 48606 def @creation_timestamp end |
#deprecated ⇒ Google::Apis::ComputeAlpha::DeprecationStatus
Deprecation status for a public resource.
Corresponds to the JSON property deprecated
48611 48612 48613 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 48611 def deprecated @deprecated end |
#description ⇒ String
[Output Only] An optional textual description of the resource.
Corresponds to the JSON property description
48616 48617 48618 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 48616 def description @description end |
#guest_cpus ⇒ Fixnum
[Output Only] The number of virtual CPUs that are available to the node
type.
Corresponds to the JSON property guestCpus
48622 48623 48624 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 48622 def guest_cpus @guest_cpus end |
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
48628 48629 48630 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 48628 def id @id end |
#kind ⇒ String
Output only. [Output Only] The type of the resource. Alwayscompute#nodeType
for node types.
Corresponds to the JSON property kind
48634 48635 48636 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 48634 def kind @kind end |
#local_ssd_gb ⇒ Fixnum
[Output Only] Local SSD available to the node type, defined in GB.
Corresponds to the JSON property localSsdGb
48639 48640 48641 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 48639 def local_ssd_gb @local_ssd_gb end |
#max_vms ⇒ Fixnum
Output only. [Output Only] Maximum number of VMs that can be created for this
node type.
Corresponds to the JSON property maxVms
48645 48646 48647 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 48645 def max_vms @max_vms end |
#memory_mb ⇒ Fixnum
[Output Only] The amount of physical memory available to the node type,
defined in MB.
Corresponds to the JSON property memoryMb
48651 48652 48653 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 48651 def memory_mb @memory_mb end |
#name ⇒ String
[Output Only] Name of the resource.
Corresponds to the JSON property name
48656 48657 48658 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 48656 def name @name end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
48661 48662 48663 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 48661 def self_link @self_link end |
#self_link_with_id ⇒ String
Output only. [Output Only] Server-defined URL for this resource with the
resource id.
Corresponds to the JSON property selfLinkWithId
48667 48668 48669 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 48667 def self_link_with_id @self_link_with_id end |
#zone ⇒ String
Output only. [Output Only] The name of the zone where the node type resides,
such as us-central1-a.
Corresponds to the JSON property zone
48673 48674 48675 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 48673 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
48680 48681 48682 48683 48684 48685 48686 48687 48688 48689 48690 48691 48692 48693 48694 48695 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 48680 def update!(**args) @cpu_platform = args[:cpu_platform] if args.key?(:cpu_platform) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @deprecated = args[:deprecated] if args.key?(:deprecated) @description = args[:description] if args.key?(:description) @guest_cpus = args[:guest_cpus] if args.key?(:guest_cpus) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @local_ssd_gb = args[:local_ssd_gb] if args.key?(:local_ssd_gb) @max_vms = args[:max_vms] if args.key?(:max_vms) @memory_mb = args[:memory_mb] if args.key?(:memory_mb) @name = args[:name] if args.key?(:name) @self_link = args[:self_link] if args.key?(:self_link) @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id) @zone = args[:zone] if args.key?(:zone) end |