Class: Google::Apis::ComputeAlpha::NotificationEndpoint

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Represents a notification endpoint. A notification endpoint resource defines an endpoint to receive notifications when there are status changes detected by the associated health check service. For more information, see Health checks overview.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NotificationEndpoint

Returns a new instance of NotificationEndpoint.



48914
48915
48916
# File 'lib/google/apis/compute_alpha/classes.rb', line 48914

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


48862
48863
48864
# File 'lib/google/apis/compute_alpha/classes.rb', line 48862

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


48868
48869
48870
# File 'lib/google/apis/compute_alpha/classes.rb', line 48868

def description
  @description
end

#grpc_settingsGoogle::Apis::ComputeAlpha::NotificationEndpointGrpcSettings

Represents a gRPC setting that describes one gRPC notification endpoint and the retry duration attempting to send notification to this endpoint. Corresponds to the JSON property grpcSettings



48874
48875
48876
# File 'lib/google/apis/compute_alpha/classes.rb', line 48874

def grpc_settings
  @grpc_settings
end

#idFixnum

Output only. [Output Only] A unique identifier for this resource type. The server generates this identifier. Corresponds to the JSON property id

Returns:

  • (Fixnum)


48881
48882
48883
# File 'lib/google/apis/compute_alpha/classes.rb', line 48881

def id
  @id
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# notificationEndpoint for notification endpoints. Corresponds to the JSON property kind

Returns:

  • (String)


48887
48888
48889
# File 'lib/google/apis/compute_alpha/classes.rb', line 48887

def kind
  @kind
end

#nameString

Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


48898
48899
48900
# File 'lib/google/apis/compute_alpha/classes.rb', line 48898

def name
  @name
end

#regionString

Output only. [Output Only] URL of the region where the notification endpoint resides. This field applies only to the regional resource. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body. Corresponds to the JSON property region

Returns:

  • (String)


48907
48908
48909
# File 'lib/google/apis/compute_alpha/classes.rb', line 48907

def region
  @region
end

Output only. [Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


48912
48913
48914
# File 'lib/google/apis/compute_alpha/classes.rb', line 48912

def self_link
  @self_link
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



48919
48920
48921
48922
48923
48924
48925
48926
48927
48928
# File 'lib/google/apis/compute_alpha/classes.rb', line 48919

def update!(**args)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @grpc_settings = args[:grpc_settings] if args.key?(:grpc_settings)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @region = args[:region] if args.key?(:region)
  @self_link = args[:self_link] if args.key?(:self_link)
end