Class: Google::Apis::ComputeAlpha::NotificationEndpointGrpcSettings
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::NotificationEndpointGrpcSettings
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Represents a gRPC setting that describes one gRPC notification endpoint and the retry duration attempting to send notification to this endpoint.
Instance Attribute Summary collapse
-
#authority ⇒ String
Optional.
-
#endpoint ⇒ String
Endpoint to which gRPC notifications are sent.
-
#payload_name ⇒ String
Optional.
-
#resend_interval ⇒ Google::Apis::ComputeAlpha::Duration
A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution.
-
#retry_duration_sec ⇒ Fixnum
How much time (in seconds) is spent attempting notification retries until a successful response is received.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NotificationEndpointGrpcSettings
constructor
A new instance of NotificationEndpointGrpcSettings.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NotificationEndpointGrpcSettings
Returns a new instance of NotificationEndpointGrpcSettings.
49303 49304 49305 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 49303 def initialize(**args) update!(**args) end |
Instance Attribute Details
#authority ⇒ String
Optional. If specified, this field is used to set the authority header by
the sender of notifications. See
https://tools.ietf.org/html/rfc7540#section-8.1.2.3
Corresponds to the JSON property authority
49274 49275 49276 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 49274 def @authority end |
#endpoint ⇒ String
Endpoint to which gRPC notifications are sent. This must be a valid
gRPCLB DNS name.
Corresponds to the JSON property endpoint
49280 49281 49282 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 49280 def endpoint @endpoint end |
#payload_name ⇒ String
Optional. If specified, this field is used to populate the "name" field
in gRPC requests.
Corresponds to the JSON property payloadName
49286 49287 49288 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 49286 def payload_name @payload_name end |
#resend_interval ⇒ Google::Apis::ComputeAlpha::Duration
A Duration represents a fixed-length span of time represented
as a count of seconds and fractions of seconds at nanosecond
resolution. It is independent of any calendar and concepts like "day"
or "month". Range is approximately 10,000 years.
Corresponds to the JSON property resendInterval
49294 49295 49296 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 49294 def resend_interval @resend_interval end |
#retry_duration_sec ⇒ Fixnum
How much time (in seconds) is spent attempting notification retries
until a successful response is received. Default is 30s. Limit is 20m
(1200s). Must be a positive number.
Corresponds to the JSON property retryDurationSec
49301 49302 49303 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 49301 def retry_duration_sec @retry_duration_sec end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
49308 49309 49310 49311 49312 49313 49314 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 49308 def update!(**args) @authority = args[:authority] if args.key?(:authority) @endpoint = args[:endpoint] if args.key?(:endpoint) @payload_name = args[:payload_name] if args.key?(:payload_name) @resend_interval = args[:resend_interval] if args.key?(:resend_interval) @retry_duration_sec = args[:retry_duration_sec] if args.key?(:retry_duration_sec) end |