Class: Google::Apis::ComputeAlpha::NotificationEndpointList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::NotificationEndpointList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::NotificationEndpoint>
A list of NotificationEndpoint resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
-
#warning ⇒ Google::Apis::ComputeAlpha::NotificationEndpointList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NotificationEndpointList
constructor
A new instance of NotificationEndpointList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NotificationEndpointList
Returns a new instance of NotificationEndpointList.
51158 51159 51160 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 51158 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
51125 51126 51127 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 51125 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::NotificationEndpoint>
A list of NotificationEndpoint resources.
Corresponds to the JSON property items
51130 51131 51132 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 51130 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#
notificationEndpoint for notification endpoints.
Corresponds to the JSON property kind
51136 51137 51138 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 51136 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
51146 51147 51148 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 51146 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
51151 51152 51153 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 51151 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::NotificationEndpointList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
51156 51157 51158 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 51156 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
51163 51164 51165 51166 51167 51168 51169 51170 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 51163 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |