Class: Google::Apis::ComputeAlpha::NotificationEndpointList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NotificationEndpointList

Returns a new instance of NotificationEndpointList.



50638
50639
50640
# File 'lib/google/apis/compute_alpha/classes.rb', line 50638

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


50605
50606
50607
# File 'lib/google/apis/compute_alpha/classes.rb', line 50605

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::NotificationEndpoint>

A list of NotificationEndpoint resources. Corresponds to the JSON property items



50610
50611
50612
# File 'lib/google/apis/compute_alpha/classes.rb', line 50610

def items
  @items
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# notificationEndpoint for notification endpoints. Corresponds to the JSON property kind

Returns:

  • (String)


50616
50617
50618
# File 'lib/google/apis/compute_alpha/classes.rb', line 50616

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


50626
50627
50628
# File 'lib/google/apis/compute_alpha/classes.rb', line 50626

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


50631
50632
50633
# File 'lib/google/apis/compute_alpha/classes.rb', line 50631

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::NotificationEndpointList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



50636
50637
50638
# File 'lib/google/apis/compute_alpha/classes.rb', line 50636

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



50643
50644
50645
50646
50647
50648
50649
50650
# File 'lib/google/apis/compute_alpha/classes.rb', line 50643

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end