Class: Google::Apis::ComputeAlpha::NotificationEndpointList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NotificationEndpointList

Returns a new instance of NotificationEndpointList.



49590
49591
49592
# File 'lib/google/apis/compute_alpha/classes.rb', line 49590

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


49557
49558
49559
# File 'lib/google/apis/compute_alpha/classes.rb', line 49557

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::NotificationEndpoint>

A list of NotificationEndpoint resources. Corresponds to the JSON property items



49562
49563
49564
# File 'lib/google/apis/compute_alpha/classes.rb', line 49562

def items
  @items
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# notificationEndpoint for notification endpoints. Corresponds to the JSON property kind

Returns:

  • (String)


49568
49569
49570
# File 'lib/google/apis/compute_alpha/classes.rb', line 49568

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


49578
49579
49580
# File 'lib/google/apis/compute_alpha/classes.rb', line 49578

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


49583
49584
49585
# File 'lib/google/apis/compute_alpha/classes.rb', line 49583

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::NotificationEndpointList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



49588
49589
49590
# File 'lib/google/apis/compute_alpha/classes.rb', line 49588

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



49595
49596
49597
49598
49599
49600
49601
49602
# File 'lib/google/apis/compute_alpha/classes.rb', line 49595

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end