Class: Google::Apis::ComputeAlpha::NotificationEndpointList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NotificationEndpointList

Returns a new instance of NotificationEndpointList.



49573
49574
49575
# File 'lib/google/apis/compute_alpha/classes.rb', line 49573

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


49540
49541
49542
# File 'lib/google/apis/compute_alpha/classes.rb', line 49540

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::NotificationEndpoint>

A list of NotificationEndpoint resources. Corresponds to the JSON property items



49545
49546
49547
# File 'lib/google/apis/compute_alpha/classes.rb', line 49545

def items
  @items
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# notificationEndpoint for notification endpoints. Corresponds to the JSON property kind

Returns:

  • (String)


49551
49552
49553
# File 'lib/google/apis/compute_alpha/classes.rb', line 49551

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


49561
49562
49563
# File 'lib/google/apis/compute_alpha/classes.rb', line 49561

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


49566
49567
49568
# File 'lib/google/apis/compute_alpha/classes.rb', line 49566

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::NotificationEndpointList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



49571
49572
49573
# File 'lib/google/apis/compute_alpha/classes.rb', line 49571

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



49578
49579
49580
49581
49582
49583
49584
49585
# File 'lib/google/apis/compute_alpha/classes.rb', line 49578

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end