Class: Google::Apis::ComputeAlpha::NotificationEndpointList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NotificationEndpointList

Returns a new instance of NotificationEndpointList.



49154
49155
49156
# File 'lib/google/apis/compute_alpha/classes.rb', line 49154

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


49121
49122
49123
# File 'lib/google/apis/compute_alpha/classes.rb', line 49121

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::NotificationEndpoint>

A list of NotificationEndpoint resources. Corresponds to the JSON property items



49126
49127
49128
# File 'lib/google/apis/compute_alpha/classes.rb', line 49126

def items
  @items
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# notificationEndpoint for notification endpoints. Corresponds to the JSON property kind

Returns:

  • (String)


49132
49133
49134
# File 'lib/google/apis/compute_alpha/classes.rb', line 49132

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


49142
49143
49144
# File 'lib/google/apis/compute_alpha/classes.rb', line 49142

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


49147
49148
49149
# File 'lib/google/apis/compute_alpha/classes.rb', line 49147

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::NotificationEndpointList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



49152
49153
49154
# File 'lib/google/apis/compute_alpha/classes.rb', line 49152

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



49159
49160
49161
49162
49163
49164
49165
49166
# File 'lib/google/apis/compute_alpha/classes.rb', line 49159

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end