Class: Google::Apis::ComputeAlpha::NotificationEndpointList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::NotificationEndpointList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::NotificationEndpoint>
A list of NotificationEndpoint resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
-
#warning ⇒ Google::Apis::ComputeAlpha::NotificationEndpointList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NotificationEndpointList
constructor
A new instance of NotificationEndpointList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NotificationEndpointList
Returns a new instance of NotificationEndpointList.
48397 48398 48399 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 48397 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
48364 48365 48366 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 48364 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::NotificationEndpoint>
A list of NotificationEndpoint resources.
Corresponds to the JSON property items
48369 48370 48371 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 48369 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#
notificationEndpoint for notification endpoints.
Corresponds to the JSON property kind
48375 48376 48377 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 48375 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
48385 48386 48387 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 48385 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
48390 48391 48392 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 48390 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::NotificationEndpointList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
48395 48396 48397 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 48395 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
48402 48403 48404 48405 48406 48407 48408 48409 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 48402 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |