Class: Google::Apis::ComputeAlpha::Operation

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Represents an Operation resource. Google Compute Engine has three Operation resources:

  • Global
  • Regional
  • Zonal You can use an operation resource to manage asynchronous API requests. For more information, readHandling API responses. Operations can be global, regional or zonal.

  • For global operations, use the globalOperations resource.

  • For regional operations, use the regionOperations resource.

  • For zonal operations, use the zoneOperations resource. For more information, read Global, Regional, and Zonal Resources. Note that completed Operation resources have a limited retention period.

Defined Under Namespace

Classes: Error, Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Operation

Returns a new instance of Operation.



51025
51026
51027
# File 'lib/google/apis/compute_alpha/classes.rb', line 51025

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#client_operation_idString

[Output Only] The value of requestId if you provided it in the request. Not present otherwise. Corresponds to the JSON property clientOperationId

Returns:

  • (String)


50847
50848
50849
# File 'lib/google/apis/compute_alpha/classes.rb', line 50847

def client_operation_id
  @client_operation_id
end

#creation_timestampString

[Deprecated] This field is deprecated. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


50852
50853
50854
# File 'lib/google/apis/compute_alpha/classes.rb', line 50852

def creation_timestamp
  @creation_timestamp
end

#descriptionString

[Output Only] A textual description of the operation, which is set when the operation is created. Corresponds to the JSON property description

Returns:

  • (String)


50858
50859
50860
# File 'lib/google/apis/compute_alpha/classes.rb', line 50858

def description
  @description
end

#end_timeString

[Output Only] The time that this operation was completed. This value is inRFC3339 text format. Corresponds to the JSON property endTime

Returns:

  • (String)


50865
50866
50867
# File 'lib/google/apis/compute_alpha/classes.rb', line 50865

def end_time
  @end_time
end

#errorGoogle::Apis::ComputeAlpha::Operation::Error

[Output Only] If errors are generated during processing of the operation, this field will be populated. Corresponds to the JSON property error



50871
50872
50873
# File 'lib/google/apis/compute_alpha/classes.rb', line 50871

def error
  @error
end

#firewall_policy_rule_operation_metadataGoogle::Apis::ComputeAlpha::FirewallPolicyRuleOperationMetadata

Metadata for FirewallPolicyRule operations. Corresponds to the JSON property firewallPolicyRuleOperationMetadata



50876
50877
50878
# File 'lib/google/apis/compute_alpha/classes.rb', line 50876

def 
  @firewall_policy_rule_operation_metadata
end

#get_version_operation_metadataGoogle::Apis::ComputeAlpha::GetVersionOperationMetadata

Corresponds to the JSON property getVersionOperationMetadata



50881
50882
50883
# File 'lib/google/apis/compute_alpha/classes.rb', line 50881

def 
  @get_version_operation_metadata
end

#http_error_messageString

[Output Only] If the operation fails, this field contains the HTTP error message that was returned, such as NOT FOUND. Corresponds to the JSON property httpErrorMessage

Returns:

  • (String)


50887
50888
50889
# File 'lib/google/apis/compute_alpha/classes.rb', line 50887

def http_error_message
  @http_error_message
end

#http_error_status_codeFixnum

[Output Only] If the operation fails, this field contains the HTTP error status code that was returned. For example, a 404 means the resource was not found. Corresponds to the JSON property httpErrorStatusCode

Returns:

  • (Fixnum)


50894
50895
50896
# File 'lib/google/apis/compute_alpha/classes.rb', line 50894

def http_error_status_code
  @http_error_status_code
end

#idFixnum

[Output Only] The unique identifier for the operation. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


50900
50901
50902
# File 'lib/google/apis/compute_alpha/classes.rb', line 50900

def id
  @id
end

#insert_timeString

[Output Only] The time that this operation was requested. This value is inRFC3339 text format. Corresponds to the JSON property insertTime

Returns:

  • (String)


50907
50908
50909
# File 'lib/google/apis/compute_alpha/classes.rb', line 50907

def insert_time
  @insert_time
end

#instances_bulk_insert_operation_metadataGoogle::Apis::ComputeAlpha::InstancesBulkInsertOperationMetadata

Corresponds to the JSON property instancesBulkInsertOperationMetadata



50912
50913
50914
# File 'lib/google/apis/compute_alpha/classes.rb', line 50912

def 
  @instances_bulk_insert_operation_metadata
end

#kindString

Output only. [Output Only] Type of the resource. Always compute#operation for Operation resources. Corresponds to the JSON property kind

Returns:

  • (String)


50919
50920
50921
# File 'lib/google/apis/compute_alpha/classes.rb', line 50919

def kind
  @kind
end

#nameString

[Output Only] Name of the operation. Corresponds to the JSON property name

Returns:

  • (String)


50924
50925
50926
# File 'lib/google/apis/compute_alpha/classes.rb', line 50924

def name
  @name
end

#operation_group_idString

Output only. [Output Only] An ID that represents a group of operations, such as when a group of operations results from a bulkInsert API request. Corresponds to the JSON property operationGroupId

Returns:

  • (String)


50931
50932
50933
# File 'lib/google/apis/compute_alpha/classes.rb', line 50931

def operation_group_id
  @operation_group_id
end

#operation_typeString

[Output Only] The type of operation, such as insert, update, or delete, and so on. Corresponds to the JSON property operationType

Returns:

  • (String)


50937
50938
50939
# File 'lib/google/apis/compute_alpha/classes.rb', line 50937

def operation_type
  @operation_type
end

#progressFixnum

[Output Only] An optional progress indicator that ranges from 0 to 100. There is no requirement that this be linear or support any granularity of operations. This should not be used to guess when the operation will be complete. This number should monotonically increase as the operation progresses. Corresponds to the JSON property progress

Returns:

  • (Fixnum)


50946
50947
50948
# File 'lib/google/apis/compute_alpha/classes.rb', line 50946

def progress
  @progress
end

#regionString

[Output Only] The URL of the region where the operation resides. Only applicable when performing regional operations. Corresponds to the JSON property region

Returns:

  • (String)


50952
50953
50954
# File 'lib/google/apis/compute_alpha/classes.rb', line 50952

def region
  @region
end

[Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


50957
50958
50959
# File 'lib/google/apis/compute_alpha/classes.rb', line 50957

def self_link
  @self_link
end

Output only. [Output Only] Server-defined URL for this resource with the resource id. Corresponds to the JSON property selfLinkWithId

Returns:

  • (String)


50963
50964
50965
# File 'lib/google/apis/compute_alpha/classes.rb', line 50963

def self_link_with_id
  @self_link_with_id
end

#set_common_instance_metadata_operation_metadataGoogle::Apis::ComputeAlpha::SetCommonInstanceMetadataOperationMetadata

Output only. [Output Only] If the operation is for projects. setCommonInstanceMetadata, this field will contain information on all underlying zonal actions and their state. Corresponds to the JSON property setCommonInstanceMetadataOperationMetadata



50971
50972
50973
# File 'lib/google/apis/compute_alpha/classes.rb', line 50971

def 
  @set_common_instance_metadata_operation_metadata
end

#start_timeString

[Output Only] The time that this operation was started by the server. This value is inRFC3339 text format. Corresponds to the JSON property startTime

Returns:

  • (String)


50978
50979
50980
# File 'lib/google/apis/compute_alpha/classes.rb', line 50978

def start_time
  @start_time
end

#statusString

[Output Only] The status of the operation, which can be one of the following: PENDING, RUNNING, or DONE. Corresponds to the JSON property status

Returns:

  • (String)


50985
50986
50987
# File 'lib/google/apis/compute_alpha/classes.rb', line 50985

def status
  @status
end

#status_messageString

[Output Only] An optional textual description of the current status of the operation. Corresponds to the JSON property statusMessage

Returns:

  • (String)


50991
50992
50993
# File 'lib/google/apis/compute_alpha/classes.rb', line 50991

def status_message
  @status_message
end

#target_idFixnum

[Output Only] The unique target ID, which identifies a specific incarnation of the target resource. Corresponds to the JSON property targetId

Returns:

  • (Fixnum)


50997
50998
50999
# File 'lib/google/apis/compute_alpha/classes.rb', line 50997

def target_id
  @target_id
end

[Output Only] The URL of the resource that the operation modifies. For operations related to creating a snapshot, this points to the disk that the snapshot was created from. Corresponds to the JSON property targetLink

Returns:

  • (String)


51004
51005
51006
# File 'lib/google/apis/compute_alpha/classes.rb', line 51004

def target_link
  @target_link
end

#userString

[Output Only] User who requested the operation, for example: user@example.com or alice_smith_identifier (global/workforcePools/example-com-us-employees). Corresponds to the JSON property user

Returns:

  • (String)


51011
51012
51013
# File 'lib/google/apis/compute_alpha/classes.rb', line 51011

def user
  @user
end

#warningsArray<Google::Apis::ComputeAlpha::Operation::Warning>

[Output Only] If warning messages are generated during processing of the operation, this field will be populated. Corresponds to the JSON property warnings



51017
51018
51019
# File 'lib/google/apis/compute_alpha/classes.rb', line 51017

def warnings
  @warnings
end

#zoneString

[Output Only] The URL of the zone where the operation resides. Only applicable when performing per-zone operations. Corresponds to the JSON property zone

Returns:

  • (String)


51023
51024
51025
# File 'lib/google/apis/compute_alpha/classes.rb', line 51023

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



51030
51031
51032
51033
51034
51035
51036
51037
51038
51039
51040
51041
51042
51043
51044
51045
51046
51047
51048
51049
51050
51051
51052
51053
51054
51055
51056
51057
51058
51059
51060
# File 'lib/google/apis/compute_alpha/classes.rb', line 51030

def update!(**args)
  @client_operation_id = args[:client_operation_id] if args.key?(:client_operation_id)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @end_time = args[:end_time] if args.key?(:end_time)
  @error = args[:error] if args.key?(:error)
  @firewall_policy_rule_operation_metadata = args[:firewall_policy_rule_operation_metadata] if args.key?(:firewall_policy_rule_operation_metadata)
  @get_version_operation_metadata = args[:get_version_operation_metadata] if args.key?(:get_version_operation_metadata)
  @http_error_message = args[:http_error_message] if args.key?(:http_error_message)
  @http_error_status_code = args[:http_error_status_code] if args.key?(:http_error_status_code)
  @id = args[:id] if args.key?(:id)
  @insert_time = args[:insert_time] if args.key?(:insert_time)
  @instances_bulk_insert_operation_metadata = args[:instances_bulk_insert_operation_metadata] if args.key?(:instances_bulk_insert_operation_metadata)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @operation_group_id = args[:operation_group_id] if args.key?(:operation_group_id)
  @operation_type = args[:operation_type] if args.key?(:operation_type)
  @progress = args[:progress] if args.key?(:progress)
  @region = args[:region] if args.key?(:region)
  @self_link = args[:self_link] if args.key?(:self_link)
  @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id)
  @set_common_instance_metadata_operation_metadata = args[:set_common_instance_metadata_operation_metadata] if args.key?(:set_common_instance_metadata_operation_metadata)
  @start_time = args[:start_time] if args.key?(:start_time)
  @status = args[:status] if args.key?(:status)
  @status_message = args[:status_message] if args.key?(:status_message)
  @target_id = args[:target_id] if args.key?(:target_id)
  @target_link = args[:target_link] if args.key?(:target_link)
  @user = args[:user] if args.key?(:user)
  @warnings = args[:warnings] if args.key?(:warnings)
  @zone = args[:zone] if args.key?(:zone)
end