Class: Google::Apis::ComputeAlpha::Operation
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::Operation
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Represents an Operation resource. Google Compute Engine has three Operation resources:
- Global
- Regional
Zonal You can use an operation resource to manage asynchronous API requests. For more information, readHandling API responses. Operations can be global, regional or zonal.
For global operations, use the
globalOperationsresource.For regional operations, use the
regionOperationsresource.For zonal operations, use the
zoneOperationsresource. For more information, read Global, Regional, and Zonal Resources. Note that completed Operation resources have a limited retention period.
Defined Under Namespace
Instance Attribute Summary collapse
-
#client_operation_id ⇒ String
[Output Only] The value of
requestIdif you provided it in the request. -
#creation_timestamp ⇒ String
[Deprecated] This field is deprecated.
-
#description ⇒ String
[Output Only] A textual description of the operation, which is set when the operation is created.
-
#end_time ⇒ String
[Output Only] The time that this operation was completed.
-
#error ⇒ Google::Apis::ComputeAlpha::Operation::Error
[Output Only] If errors are generated during processing of the operation, this field will be populated.
-
#get_version_operation_metadata ⇒ Google::Apis::ComputeAlpha::GetVersionOperationMetadata
Corresponds to the JSON property
getVersionOperationMetadata. -
#http_error_message ⇒ String
[Output Only] If the operation fails, this field contains the HTTP error message that was returned, such as
NOT FOUND. -
#http_error_status_code ⇒ Fixnum
[Output Only] If the operation fails, this field contains the HTTP error status code that was returned.
-
#id ⇒ Fixnum
[Output Only] The unique identifier for the operation.
-
#insert_time ⇒ String
[Output Only] The time that this operation was requested.
-
#instances_bulk_insert_operation_metadata ⇒ Google::Apis::ComputeAlpha::InstancesBulkInsertOperationMetadata
Corresponds to the JSON property
instancesBulkInsertOperationMetadata. -
#kind ⇒ String
Output only.
-
#name ⇒ String
[Output Only] Name of the operation.
-
#operation_group_id ⇒ String
Output only.
-
#operation_type ⇒ String
[Output Only] The type of operation, such as
insert,update, ordelete, and so on. -
#progress ⇒ Fixnum
[Output Only] An optional progress indicator that ranges from 0 to 100.
-
#region ⇒ String
[Output Only] The URL of the region where the operation resides.
-
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
-
#self_link_with_id ⇒ String
Output only.
-
#set_common_instance_metadata_operation_metadata ⇒ Google::Apis::ComputeAlpha::SetCommonInstanceMetadataOperationMetadata
Output only.
-
#start_time ⇒ String
[Output Only] The time that this operation was started by the server.
-
#status ⇒ String
[Output Only] The status of the operation, which can be one of the following:
PENDING,RUNNING, orDONE. -
#status_message ⇒ String
[Output Only] An optional textual description of the current status of the operation.
-
#target_id ⇒ Fixnum
[Output Only] The unique target ID, which identifies a specific incarnation of the target resource.
-
#target_link ⇒ String
[Output Only] The URL of the resource that the operation modifies.
-
#user ⇒ String
[Output Only] User who requested the operation, for example:
user@example.comoralice_smith_identifier (global/workforcePools/example-com-us-employees). -
#warnings ⇒ Array<Google::Apis::ComputeAlpha::Operation::Warning>
[Output Only] If warning messages are generated during processing of the operation, this field will be populated.
-
#zone ⇒ String
[Output Only] The URL of the zone where the operation resides.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Operation
constructor
A new instance of Operation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Operation
Returns a new instance of Operation.
49536 49537 49538 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 49536 def initialize(**args) update!(**args) end |
Instance Attribute Details
#client_operation_id ⇒ String
[Output Only] The value of requestId if you provided it in the request.
Not present otherwise.
Corresponds to the JSON property clientOperationId
49363 49364 49365 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 49363 def client_operation_id @client_operation_id end |
#creation_timestamp ⇒ String
[Deprecated] This field is deprecated.
Corresponds to the JSON property creationTimestamp
49368 49369 49370 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 49368 def @creation_timestamp end |
#description ⇒ String
[Output Only] A textual description of the operation, which is
set when the operation is created.
Corresponds to the JSON property description
49374 49375 49376 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 49374 def description @description end |
#end_time ⇒ String
[Output Only] The time that this operation was completed. This value is
inRFC3339
text format.
Corresponds to the JSON property endTime
49381 49382 49383 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 49381 def end_time @end_time end |
#error ⇒ Google::Apis::ComputeAlpha::Operation::Error
[Output Only] If errors are generated during processing of the operation,
this field will be populated.
Corresponds to the JSON property error
49387 49388 49389 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 49387 def error @error end |
#get_version_operation_metadata ⇒ Google::Apis::ComputeAlpha::GetVersionOperationMetadata
Corresponds to the JSON property getVersionOperationMetadata
49392 49393 49394 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 49392 def @get_version_operation_metadata end |
#http_error_message ⇒ String
[Output Only] If the operation fails, this field contains the HTTP error
message that was returned, such as NOT FOUND.
Corresponds to the JSON property httpErrorMessage
49398 49399 49400 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 49398 def @http_error_message end |
#http_error_status_code ⇒ Fixnum
[Output Only] If the operation fails, this field contains the HTTP error
status code that was returned. For example, a 404 means the
resource was not found.
Corresponds to the JSON property httpErrorStatusCode
49405 49406 49407 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 49405 def http_error_status_code @http_error_status_code end |
#id ⇒ Fixnum
[Output Only] The unique identifier for the operation. This identifier is
defined by the server.
Corresponds to the JSON property id
49411 49412 49413 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 49411 def id @id end |
#insert_time ⇒ String
[Output Only] The time that this operation was requested.
This value is inRFC3339
text format.
Corresponds to the JSON property insertTime
49418 49419 49420 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 49418 def insert_time @insert_time end |
#instances_bulk_insert_operation_metadata ⇒ Google::Apis::ComputeAlpha::InstancesBulkInsertOperationMetadata
Corresponds to the JSON property instancesBulkInsertOperationMetadata
49423 49424 49425 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 49423 def @instances_bulk_insert_operation_metadata end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Always compute#operation
for
Operation resources.
Corresponds to the JSON property kind
49430 49431 49432 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 49430 def kind @kind end |
#name ⇒ String
[Output Only] Name of the operation.
Corresponds to the JSON property name
49435 49436 49437 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 49435 def name @name end |
#operation_group_id ⇒ String
Output only. [Output Only] An ID that represents a group of operations, such
as when a
group of operations results from a bulkInsert API request.
Corresponds to the JSON property operationGroupId
49442 49443 49444 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 49442 def operation_group_id @operation_group_id end |
#operation_type ⇒ String
[Output Only] The type of operation, such as insert,
update, or delete, and so on.
Corresponds to the JSON property operationType
49448 49449 49450 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 49448 def operation_type @operation_type end |
#progress ⇒ Fixnum
[Output Only] An optional progress indicator that ranges from 0 to 100.
There is no requirement that this be linear or support any granularity of
operations. This should not be used to guess when the operation will be
complete. This number should monotonically increase as the operation
progresses.
Corresponds to the JSON property progress
49457 49458 49459 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 49457 def progress @progress end |
#region ⇒ String
[Output Only] The URL of the region where the operation resides. Only
applicable when performing regional operations.
Corresponds to the JSON property region
49463 49464 49465 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 49463 def region @region end |
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
49468 49469 49470 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 49468 def self_link @self_link end |
#self_link_with_id ⇒ String
Output only. [Output Only] Server-defined URL for this resource with the
resource id.
Corresponds to the JSON property selfLinkWithId
49474 49475 49476 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 49474 def self_link_with_id @self_link_with_id end |
#set_common_instance_metadata_operation_metadata ⇒ Google::Apis::ComputeAlpha::SetCommonInstanceMetadataOperationMetadata
Output only. [Output Only] If the operation is for projects.
setCommonInstanceMetadata,
this field will contain information on all underlying zonal actions and
their state.
Corresponds to the JSON property setCommonInstanceMetadataOperationMetadata
49482 49483 49484 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 49482 def @set_common_instance_metadata_operation_metadata end |
#start_time ⇒ String
[Output Only] The time that this operation was started by the server.
This value is inRFC3339
text format.
Corresponds to the JSON property startTime
49489 49490 49491 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 49489 def start_time @start_time end |
#status ⇒ String
[Output Only] The status of the operation, which can be one of the
following:
PENDING, RUNNING, or DONE.
Corresponds to the JSON property status
49496 49497 49498 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 49496 def status @status end |
#status_message ⇒ String
[Output Only] An optional textual description of the current status of the
operation.
Corresponds to the JSON property statusMessage
49502 49503 49504 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 49502 def @status_message end |
#target_id ⇒ Fixnum
[Output Only] The unique target ID, which identifies a specific incarnation
of the target resource.
Corresponds to the JSON property targetId
49508 49509 49510 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 49508 def target_id @target_id end |
#target_link ⇒ String
[Output Only] The URL of the resource that the operation modifies. For
operations related to creating a snapshot, this points to the disk
that the snapshot was created from.
Corresponds to the JSON property targetLink
49515 49516 49517 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 49515 def target_link @target_link end |
#user ⇒ String
[Output Only] User who requested the operation, for example:
user@example.com or
alice_smith_identifier (global/workforcePools/example-com-us-employees).
Corresponds to the JSON property user
49522 49523 49524 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 49522 def user @user end |
#warnings ⇒ Array<Google::Apis::ComputeAlpha::Operation::Warning>
[Output Only] If warning messages are generated during processing of the
operation, this field will be populated.
Corresponds to the JSON property warnings
49528 49529 49530 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 49528 def warnings @warnings end |
#zone ⇒ String
[Output Only] The URL of the zone where the operation resides. Only
applicable when performing per-zone operations.
Corresponds to the JSON property zone
49534 49535 49536 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 49534 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
49541 49542 49543 49544 49545 49546 49547 49548 49549 49550 49551 49552 49553 49554 49555 49556 49557 49558 49559 49560 49561 49562 49563 49564 49565 49566 49567 49568 49569 49570 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 49541 def update!(**args) @client_operation_id = args[:client_operation_id] if args.key?(:client_operation_id) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @end_time = args[:end_time] if args.key?(:end_time) @error = args[:error] if args.key?(:error) @get_version_operation_metadata = args[:get_version_operation_metadata] if args.key?(:get_version_operation_metadata) @http_error_message = args[:http_error_message] if args.key?(:http_error_message) @http_error_status_code = args[:http_error_status_code] if args.key?(:http_error_status_code) @id = args[:id] if args.key?(:id) @insert_time = args[:insert_time] if args.key?(:insert_time) @instances_bulk_insert_operation_metadata = args[:instances_bulk_insert_operation_metadata] if args.key?(:instances_bulk_insert_operation_metadata) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @operation_group_id = args[:operation_group_id] if args.key?(:operation_group_id) @operation_type = args[:operation_type] if args.key?(:operation_type) @progress = args[:progress] if args.key?(:progress) @region = args[:region] if args.key?(:region) @self_link = args[:self_link] if args.key?(:self_link) @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id) @set_common_instance_metadata_operation_metadata = args[:set_common_instance_metadata_operation_metadata] if args.key?(:set_common_instance_metadata_operation_metadata) @start_time = args[:start_time] if args.key?(:start_time) @status = args[:status] if args.key?(:status) @status_message = args[:status_message] if args.key?(:status_message) @target_id = args[:target_id] if args.key?(:target_id) @target_link = args[:target_link] if args.key?(:target_link) @user = args[:user] if args.key?(:user) @warnings = args[:warnings] if args.key?(:warnings) @zone = args[:zone] if args.key?(:zone) end |