Class: Google::Apis::ComputeAlpha::OperationAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::OperationAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] The unique identifier for the resource.
-
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::OperationsScopedList>
[Output Only] A map of scoped operation lists.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::OperationAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ OperationAggregatedList
constructor
A new instance of OperationAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ OperationAggregatedList
Returns a new instance of OperationAggregatedList.
51589 51590 51591 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 51589 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
51550 51551 51552 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 51550 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::OperationsScopedList>
[Output Only] A map of scoped operation lists.
Corresponds to the JSON property items
51555 51556 51557 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 51555 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#
operationAggregatedList
for aggregated lists of operations.
Corresponds to the JSON property kind
51562 51563 51564 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 51562 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger than
maxResults, use the nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
51572 51573 51574 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 51572 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
51577 51578 51579 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 51577 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
51582 51583 51584 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 51582 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::OperationAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
51587 51588 51589 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 51587 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
51594 51595 51596 51597 51598 51599 51600 51601 51602 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 51594 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |