Class: Google::Apis::ComputeAlpha::OperationAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::OperationAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] The unique identifier for the resource.
-
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::OperationsScopedList>
[Output Only] A map of scoped operation lists.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::OperationAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ OperationAggregatedList
constructor
A new instance of OperationAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ OperationAggregatedList
Returns a new instance of OperationAggregatedList.
50015 50016 50017 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 50015 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
49976 49977 49978 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 49976 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::OperationsScopedList>
[Output Only] A map of scoped operation lists.
Corresponds to the JSON property items
49981 49982 49983 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 49981 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#
operationAggregatedList
for aggregated lists of operations.
Corresponds to the JSON property kind
49988 49989 49990 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 49988 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger than
maxResults, use the nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
49998 49999 50000 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 49998 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
50003 50004 50005 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 50003 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
50008 50009 50010 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 50008 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::OperationAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
50013 50014 50015 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 50013 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
50020 50021 50022 50023 50024 50025 50026 50027 50028 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 50020 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |