Class: Google::Apis::ComputeAlpha::OperationAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OperationAggregatedList

Returns a new instance of OperationAggregatedList.



50013
50014
50015
# File 'lib/google/apis/compute_alpha/classes.rb', line 50013

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


49974
49975
49976
# File 'lib/google/apis/compute_alpha/classes.rb', line 49974

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::OperationsScopedList>

[Output Only] A map of scoped operation lists. Corresponds to the JSON property items



49979
49980
49981
# File 'lib/google/apis/compute_alpha/classes.rb', line 49979

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute# operationAggregatedList for aggregated lists of operations. Corresponds to the JSON property kind

Returns:

  • (String)


49986
49987
49988
# File 'lib/google/apis/compute_alpha/classes.rb', line 49986

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


49996
49997
49998
# File 'lib/google/apis/compute_alpha/classes.rb', line 49996

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


50001
50002
50003
# File 'lib/google/apis/compute_alpha/classes.rb', line 50001

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


50006
50007
50008
# File 'lib/google/apis/compute_alpha/classes.rb', line 50006

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::OperationAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



50011
50012
50013
# File 'lib/google/apis/compute_alpha/classes.rb', line 50011

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



50018
50019
50020
50021
50022
50023
50024
50025
50026
# File 'lib/google/apis/compute_alpha/classes.rb', line 50018

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end