Class: Google::Apis::ComputeAlpha::OperationList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of Operation resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OperationList

Returns a new instance of OperationList.



50376
50377
50378
# File 'lib/google/apis/compute_alpha/classes.rb', line 50376

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


50342
50343
50344
# File 'lib/google/apis/compute_alpha/classes.rb', line 50342

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::Operation>

[Output Only] A list of Operation resources. Corresponds to the JSON property items



50347
50348
50349
# File 'lib/google/apis/compute_alpha/classes.rb', line 50347

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#operations for Operations resource. Corresponds to the JSON property kind

Returns:

  • (String)


50354
50355
50356
# File 'lib/google/apis/compute_alpha/classes.rb', line 50354

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


50364
50365
50366
# File 'lib/google/apis/compute_alpha/classes.rb', line 50364

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


50369
50370
50371
# File 'lib/google/apis/compute_alpha/classes.rb', line 50369

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::OperationList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



50374
50375
50376
# File 'lib/google/apis/compute_alpha/classes.rb', line 50374

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



50381
50382
50383
50384
50385
50386
50387
50388
# File 'lib/google/apis/compute_alpha/classes.rb', line 50381

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end