Class: Google::Apis::ComputeAlpha::OperationList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::OperationList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Contains a list of Operation resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] The unique identifier for the resource.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::Operation>
[Output Only] A list of Operation resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
-
#warning ⇒ Google::Apis::ComputeAlpha::OperationList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ OperationList
constructor
A new instance of OperationList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ OperationList
Returns a new instance of OperationList.
50359 50360 50361 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 50359 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
50325 50326 50327 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 50325 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::Operation>
[Output Only] A list of Operation resources.
Corresponds to the JSON property items
50330 50331 50332 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 50330 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#operations for
Operations
resource.
Corresponds to the JSON property kind
50337 50338 50339 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 50337 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger than
maxResults, use the nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
50347 50348 50349 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 50347 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
50352 50353 50354 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 50352 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::OperationList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
50357 50358 50359 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 50357 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
50364 50365 50366 50367 50368 50369 50370 50371 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 50364 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |