Class: Google::Apis::ComputeAlpha::OrganizationRolloutsListResponse
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::OrganizationRolloutsListResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::Rollout>
A list of Rollout resources.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::OrganizationRolloutsListResponse::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ OrganizationRolloutsListResponse
constructor
A new instance of OrganizationRolloutsListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ OrganizationRolloutsListResponse
Returns a new instance of OrganizationRolloutsListResponse.
52185 52186 52187 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 52185 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
52147 52148 52149 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 52147 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
52152 52153 52154 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 52152 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::Rollout>
A list of Rollout resources.
Corresponds to the JSON property items
52157 52158 52159 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 52157 def items @items end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
52167 52168 52169 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 52167 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
52172 52173 52174 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 52172 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
end_interface: MixerListResponseWithEtagBuilder
Corresponds to the JSON property unreachables
52178 52179 52180 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 52178 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::OrganizationRolloutsListResponse::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
52183 52184 52185 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 52183 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
52190 52191 52192 52193 52194 52195 52196 52197 52198 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 52190 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |