Class: Google::Apis::ComputeAlpha::OrganizationRolloutsListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OrganizationRolloutsListResponse

Returns a new instance of OrganizationRolloutsListResponse.



51944
51945
51946
# File 'lib/google/apis/compute_alpha/classes.rb', line 51944

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


51906
51907
51908
# File 'lib/google/apis/compute_alpha/classes.rb', line 51906

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


51911
51912
51913
# File 'lib/google/apis/compute_alpha/classes.rb', line 51911

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::Rollout>

A list of Rollout resources. Corresponds to the JSON property items



51916
51917
51918
# File 'lib/google/apis/compute_alpha/classes.rb', line 51916

def items
  @items
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


51926
51927
51928
# File 'lib/google/apis/compute_alpha/classes.rb', line 51926

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


51931
51932
51933
# File 'lib/google/apis/compute_alpha/classes.rb', line 51931

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


51937
51938
51939
# File 'lib/google/apis/compute_alpha/classes.rb', line 51937

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::OrganizationRolloutsListResponse::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



51942
51943
51944
# File 'lib/google/apis/compute_alpha/classes.rb', line 51942

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



51949
51950
51951
51952
51953
51954
51955
51956
51957
# File 'lib/google/apis/compute_alpha/classes.rb', line 51949

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end