Class: Google::Apis::ComputeAlpha::OrganizationRolloutsListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OrganizationRolloutsListResponse

Returns a new instance of OrganizationRolloutsListResponse.



51659
51660
51661
# File 'lib/google/apis/compute_alpha/classes.rb', line 51659

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


51621
51622
51623
# File 'lib/google/apis/compute_alpha/classes.rb', line 51621

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


51626
51627
51628
# File 'lib/google/apis/compute_alpha/classes.rb', line 51626

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::Rollout>

A list of Rollout resources. Corresponds to the JSON property items



51631
51632
51633
# File 'lib/google/apis/compute_alpha/classes.rb', line 51631

def items
  @items
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


51641
51642
51643
# File 'lib/google/apis/compute_alpha/classes.rb', line 51641

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


51646
51647
51648
# File 'lib/google/apis/compute_alpha/classes.rb', line 51646

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


51652
51653
51654
# File 'lib/google/apis/compute_alpha/classes.rb', line 51652

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::OrganizationRolloutsListResponse::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



51657
51658
51659
# File 'lib/google/apis/compute_alpha/classes.rb', line 51657

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



51664
51665
51666
51667
51668
51669
51670
51671
51672
# File 'lib/google/apis/compute_alpha/classes.rb', line 51664

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end