Class: Google::Apis::ComputeAlpha::OrganizationRolloutsListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OrganizationRolloutsListResponse

Returns a new instance of OrganizationRolloutsListResponse.



50603
50604
50605
# File 'lib/google/apis/compute_alpha/classes.rb', line 50603

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


50565
50566
50567
# File 'lib/google/apis/compute_alpha/classes.rb', line 50565

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


50570
50571
50572
# File 'lib/google/apis/compute_alpha/classes.rb', line 50570

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::Rollout>

A list of Rollout resources. Corresponds to the JSON property items



50575
50576
50577
# File 'lib/google/apis/compute_alpha/classes.rb', line 50575

def items
  @items
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


50585
50586
50587
# File 'lib/google/apis/compute_alpha/classes.rb', line 50585

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


50590
50591
50592
# File 'lib/google/apis/compute_alpha/classes.rb', line 50590

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


50596
50597
50598
# File 'lib/google/apis/compute_alpha/classes.rb', line 50596

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::OrganizationRolloutsListResponse::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



50601
50602
50603
# File 'lib/google/apis/compute_alpha/classes.rb', line 50601

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



50608
50609
50610
50611
50612
50613
50614
50615
50616
# File 'lib/google/apis/compute_alpha/classes.rb', line 50608

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end