Class: Google::Apis::ComputeAlpha::OrganizationRolloutsListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OrganizationRolloutsListResponse

Returns a new instance of OrganizationRolloutsListResponse.



50586
50587
50588
# File 'lib/google/apis/compute_alpha/classes.rb', line 50586

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


50548
50549
50550
# File 'lib/google/apis/compute_alpha/classes.rb', line 50548

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


50553
50554
50555
# File 'lib/google/apis/compute_alpha/classes.rb', line 50553

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::Rollout>

A list of Rollout resources. Corresponds to the JSON property items



50558
50559
50560
# File 'lib/google/apis/compute_alpha/classes.rb', line 50558

def items
  @items
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


50568
50569
50570
# File 'lib/google/apis/compute_alpha/classes.rb', line 50568

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


50573
50574
50575
# File 'lib/google/apis/compute_alpha/classes.rb', line 50573

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


50579
50580
50581
# File 'lib/google/apis/compute_alpha/classes.rb', line 50579

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::OrganizationRolloutsListResponse::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



50584
50585
50586
# File 'lib/google/apis/compute_alpha/classes.rb', line 50584

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



50591
50592
50593
50594
50595
50596
50597
50598
50599
# File 'lib/google/apis/compute_alpha/classes.rb', line 50591

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end