Class: Google::Apis::ComputeAlpha::OrganizationVmExtensionPolicyAggregatedListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OrganizationVmExtensionPolicyAggregatedListResponse

Returns a new instance of OrganizationVmExtensionPolicyAggregatedListResponse.



52108
52109
52110
# File 'lib/google/apis/compute_alpha/classes.rb', line 52108

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


52064
52065
52066
# File 'lib/google/apis/compute_alpha/classes.rb', line 52064

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


52069
52070
52071
# File 'lib/google/apis/compute_alpha/classes.rb', line 52069

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::VmExtensionPoliciesScopedList>

A list of VmExtensionPoliciesScopedList resources. Corresponds to the JSON property items



52074
52075
52076
# File 'lib/google/apis/compute_alpha/classes.rb', line 52074

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# OrganizationVmExtensionPolicyAggregatedList for lists of VmExtensionPolicies. Corresponds to the JSON property kind

Returns:

  • (String)


52081
52082
52083
# File 'lib/google/apis/compute_alpha/classes.rb', line 52081

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


52091
52092
52093
# File 'lib/google/apis/compute_alpha/classes.rb', line 52091

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


52096
52097
52098
# File 'lib/google/apis/compute_alpha/classes.rb', line 52096

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


52101
52102
52103
# File 'lib/google/apis/compute_alpha/classes.rb', line 52101

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::OrganizationVmExtensionPolicyAggregatedListResponse::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



52106
52107
52108
# File 'lib/google/apis/compute_alpha/classes.rb', line 52106

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



52113
52114
52115
52116
52117
52118
52119
52120
52121
52122
# File 'lib/google/apis/compute_alpha/classes.rb', line 52113

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end