Class: Google::Apis::ComputeAlpha::OrganizationVmExtensionPolicyAggregatedListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OrganizationVmExtensionPolicyAggregatedListResponse

Returns a new instance of OrganizationVmExtensionPolicyAggregatedListResponse.



51823
51824
51825
# File 'lib/google/apis/compute_alpha/classes.rb', line 51823

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


51779
51780
51781
# File 'lib/google/apis/compute_alpha/classes.rb', line 51779

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


51784
51785
51786
# File 'lib/google/apis/compute_alpha/classes.rb', line 51784

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::VmExtensionPoliciesScopedList>

A list of VmExtensionPoliciesScopedList resources. Corresponds to the JSON property items



51789
51790
51791
# File 'lib/google/apis/compute_alpha/classes.rb', line 51789

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# OrganizationVmExtensionPolicyAggregatedList for lists of VmExtensionPolicies. Corresponds to the JSON property kind

Returns:

  • (String)


51796
51797
51798
# File 'lib/google/apis/compute_alpha/classes.rb', line 51796

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


51806
51807
51808
# File 'lib/google/apis/compute_alpha/classes.rb', line 51806

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


51811
51812
51813
# File 'lib/google/apis/compute_alpha/classes.rb', line 51811

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


51816
51817
51818
# File 'lib/google/apis/compute_alpha/classes.rb', line 51816

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::OrganizationVmExtensionPolicyAggregatedListResponse::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



51821
51822
51823
# File 'lib/google/apis/compute_alpha/classes.rb', line 51821

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



51828
51829
51830
51831
51832
51833
51834
51835
51836
51837
# File 'lib/google/apis/compute_alpha/classes.rb', line 51828

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end