Class: Google::Apis::ComputeAlpha::OrganizationVmExtensionPolicyAggregatedListResponse
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::OrganizationVmExtensionPolicyAggregatedListResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::VmExtensionPoliciesScopedList>
A list of VmExtensionPoliciesScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::OrganizationVmExtensionPolicyAggregatedListResponse::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ OrganizationVmExtensionPolicyAggregatedListResponse
constructor
A new instance of OrganizationVmExtensionPolicyAggregatedListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ OrganizationVmExtensionPolicyAggregatedListResponse
Returns a new instance of OrganizationVmExtensionPolicyAggregatedListResponse.
50767 50768 50769 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 50767 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
50723 50724 50725 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 50723 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
50728 50729 50730 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 50728 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::VmExtensionPoliciesScopedList>
A list of VmExtensionPoliciesScopedList resources.
Corresponds to the JSON property items
50733 50734 50735 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 50733 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
OrganizationVmExtensionPolicyAggregatedList for lists
of VmExtensionPolicies.
Corresponds to the JSON property kind
50740 50741 50742 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 50740 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
50750 50751 50752 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 50750 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
50755 50756 50757 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 50755 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
50760 50761 50762 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 50760 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::OrganizationVmExtensionPolicyAggregatedListResponse::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
50765 50766 50767 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 50765 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
50772 50773 50774 50775 50776 50777 50778 50779 50780 50781 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 50772 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |