Class: Google::Apis::ComputeAlpha::OrganizationVmExtensionPolicyAggregatedListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OrganizationVmExtensionPolicyAggregatedListResponse

Returns a new instance of OrganizationVmExtensionPolicyAggregatedListResponse.



50750
50751
50752
# File 'lib/google/apis/compute_alpha/classes.rb', line 50750

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


50706
50707
50708
# File 'lib/google/apis/compute_alpha/classes.rb', line 50706

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


50711
50712
50713
# File 'lib/google/apis/compute_alpha/classes.rb', line 50711

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::VmExtensionPoliciesScopedList>

A list of VmExtensionPoliciesScopedList resources. Corresponds to the JSON property items



50716
50717
50718
# File 'lib/google/apis/compute_alpha/classes.rb', line 50716

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# OrganizationVmExtensionPolicyAggregatedList for lists of VmExtensionPolicies. Corresponds to the JSON property kind

Returns:

  • (String)


50723
50724
50725
# File 'lib/google/apis/compute_alpha/classes.rb', line 50723

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


50733
50734
50735
# File 'lib/google/apis/compute_alpha/classes.rb', line 50733

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


50738
50739
50740
# File 'lib/google/apis/compute_alpha/classes.rb', line 50738

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


50743
50744
50745
# File 'lib/google/apis/compute_alpha/classes.rb', line 50743

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::OrganizationVmExtensionPolicyAggregatedListResponse::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



50748
50749
50750
# File 'lib/google/apis/compute_alpha/classes.rb', line 50748

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



50755
50756
50757
50758
50759
50760
50761
50762
50763
50764
# File 'lib/google/apis/compute_alpha/classes.rb', line 50755

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end