Class: Google::Apis::ComputeAlpha::PacketIntervals
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::PacketIntervals
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Next free: 7
Instance Attribute Summary collapse
-
#avg_ms ⇒ Fixnum
Average observed inter-packet interval in milliseconds.
-
#duration ⇒ String
From how long ago in the past these intervals were observed.
-
#max_ms ⇒ Fixnum
Maximum observed inter-packet interval in milliseconds.
-
#min_ms ⇒ Fixnum
Minimum observed inter-packet interval in milliseconds.
-
#num_intervals ⇒ Fixnum
Number of inter-packet intervals from which these statistics were derived.
-
#type ⇒ String
The type of packets for which inter-packet intervals were computed.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PacketIntervals
constructor
A new instance of PacketIntervals.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PacketIntervals
Returns a new instance of PacketIntervals.
50320 50321 50322 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 50320 def initialize(**args) update!(**args) end |
Instance Attribute Details
#avg_ms ⇒ Fixnum
Average observed inter-packet interval in milliseconds.
Corresponds to the JSON property avgMs
50293 50294 50295 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 50293 def avg_ms @avg_ms end |
#duration ⇒ String
From how long ago in the past these intervals were observed.
Corresponds to the JSON property duration
50298 50299 50300 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 50298 def duration @duration end |
#max_ms ⇒ Fixnum
Maximum observed inter-packet interval in milliseconds.
Corresponds to the JSON property maxMs
50303 50304 50305 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 50303 def max_ms @max_ms end |
#min_ms ⇒ Fixnum
Minimum observed inter-packet interval in milliseconds.
Corresponds to the JSON property minMs
50308 50309 50310 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 50308 def min_ms @min_ms end |
#num_intervals ⇒ Fixnum
Number of inter-packet intervals from which these statistics were derived.
Corresponds to the JSON property numIntervals
50313 50314 50315 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 50313 def num_intervals @num_intervals end |
#type ⇒ String
The type of packets for which inter-packet intervals were computed.
Corresponds to the JSON property type
50318 50319 50320 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 50318 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
50325 50326 50327 50328 50329 50330 50331 50332 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 50325 def update!(**args) @avg_ms = args[:avg_ms] if args.key?(:avg_ms) @duration = args[:duration] if args.key?(:duration) @max_ms = args[:max_ms] if args.key?(:max_ms) @min_ms = args[:min_ms] if args.key?(:min_ms) @num_intervals = args[:num_intervals] if args.key?(:num_intervals) @type = args[:type] if args.key?(:type) end |