Class: Google::Apis::ComputeAlpha::PacketMirroring

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Represents a Packet Mirroring resource. Packet Mirroring clones the traffic of specified instances in your Virtual Private Cloud (VPC) network and forwards it to a collector destination, such as an instance group of an internal TCP/UDP load balancer, for analysis or examination. For more information about setting up Packet Mirroring, seeUsing Packet Mirroring.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PacketMirroring

Returns a new instance of PacketMirroring.



51130
51131
51132
# File 'lib/google/apis/compute_alpha/classes.rb', line 51130

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#collector_ilbGoogle::Apis::ComputeAlpha::PacketMirroringForwardingRuleInfo

The Forwarding Rule resource of typeloadBalancingScheme=INTERNAL that will be used as collector for mirrored traffic. The specified forwarding rule must have isMirroringCollector set to true. Corresponds to the JSON property collectorIlb



51040
51041
51042
# File 'lib/google/apis/compute_alpha/classes.rb', line 51040

def collector_ilb
  @collector_ilb
end

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


51046
51047
51048
# File 'lib/google/apis/compute_alpha/classes.rb', line 51046

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


51052
51053
51054
# File 'lib/google/apis/compute_alpha/classes.rb', line 51052

def description
  @description
end

#enableString

Indicates whether or not this packet mirroring takes effect. If set to FALSE, this packet mirroring policy will not be enforced on the network. The default is TRUE. Corresponds to the JSON property enable

Returns:

  • (String)


51060
51061
51062
# File 'lib/google/apis/compute_alpha/classes.rb', line 51060

def enable
  @enable
end

#filterGoogle::Apis::ComputeAlpha::PacketMirroringFilter

Filter for mirrored traffic. If unspecified, all IPv4 traffic is mirrored. Corresponds to the JSON property filter



51065
51066
51067
# File 'lib/google/apis/compute_alpha/classes.rb', line 51065

def filter
  @filter
end

#idFixnum

Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


51072
51073
51074
# File 'lib/google/apis/compute_alpha/classes.rb', line 51072

def id
  @id
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute#packetMirroring for packet mirrorings. Corresponds to the JSON property kind

Returns:

  • (String)


51078
51079
51080
# File 'lib/google/apis/compute_alpha/classes.rb', line 51078

def kind
  @kind
end

#mirrored_resourcesGoogle::Apis::ComputeAlpha::PacketMirroringMirroredResourceInfo

PacketMirroring mirroredResourceInfos. MirroredResourceInfo specifies a set of mirrored VM instances, subnetworks and/or tags for which traffic from/to all VM instances will be mirrored. Corresponds to the JSON property mirroredResources



51085
51086
51087
# File 'lib/google/apis/compute_alpha/classes.rb', line 51085

def mirrored_resources
  @mirrored_resources
end

#nameString

Name of the resource; provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


51096
51097
51098
# File 'lib/google/apis/compute_alpha/classes.rb', line 51096

def name
  @name
end

#networkGoogle::Apis::ComputeAlpha::PacketMirroringNetworkInfo

Specifies the mirrored VPC network. Only packets in this network will be mirrored. All mirrored VMs should have a NIC in the given network. All mirrored subnetworks should belong to the given network. Corresponds to the JSON property network



51103
51104
51105
# File 'lib/google/apis/compute_alpha/classes.rb', line 51103

def network
  @network
end

#priorityFixnum

The priority of applying this configuration. Priority is used to break ties in cases where there is more than one matching rule. In the case of two rules that apply for a given Instance, the one with the lowest-numbered priority value wins. Default value is 1000. Valid range is 0 through 65535. Corresponds to the JSON property priority

Returns:

  • (Fixnum)


51112
51113
51114
# File 'lib/google/apis/compute_alpha/classes.rb', line 51112

def priority
  @priority
end

#regionString

[Output Only] URI of the region where the packetMirroring resides. Corresponds to the JSON property region

Returns:

  • (String)


51117
51118
51119
# File 'lib/google/apis/compute_alpha/classes.rb', line 51117

def region
  @region
end

Output only. [Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


51122
51123
51124
# File 'lib/google/apis/compute_alpha/classes.rb', line 51122

def self_link
  @self_link
end

Output only. [Output Only] Server-defined URL for this resource with the resource id. Corresponds to the JSON property selfLinkWithId

Returns:

  • (String)


51128
51129
51130
# File 'lib/google/apis/compute_alpha/classes.rb', line 51128

def self_link_with_id
  @self_link_with_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



51135
51136
51137
51138
51139
51140
51141
51142
51143
51144
51145
51146
51147
51148
51149
51150
# File 'lib/google/apis/compute_alpha/classes.rb', line 51135

def update!(**args)
  @collector_ilb = args[:collector_ilb] if args.key?(:collector_ilb)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @enable = args[:enable] if args.key?(:enable)
  @filter = args[:filter] if args.key?(:filter)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @mirrored_resources = args[:mirrored_resources] if args.key?(:mirrored_resources)
  @name = args[:name] if args.key?(:name)
  @network = args[:network] if args.key?(:network)
  @priority = args[:priority] if args.key?(:priority)
  @region = args[:region] if args.key?(:region)
  @self_link = args[:self_link] if args.key?(:self_link)
  @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id)
end