Class: Google::Apis::ComputeAlpha::PacketMirroringAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of packetMirrorings.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PacketMirroringAggregatedList

Returns a new instance of PacketMirroringAggregatedList.



52270
52271
52272
# File 'lib/google/apis/compute_alpha/classes.rb', line 52270

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


52233
52234
52235
# File 'lib/google/apis/compute_alpha/classes.rb', line 52233

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::PacketMirroringsScopedList>

A list of PacketMirroring resources. Corresponds to the JSON property items



52238
52239
52240
# File 'lib/google/apis/compute_alpha/classes.rb', line 52238

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


52243
52244
52245
# File 'lib/google/apis/compute_alpha/classes.rb', line 52243

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


52253
52254
52255
# File 'lib/google/apis/compute_alpha/classes.rb', line 52253

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


52258
52259
52260
# File 'lib/google/apis/compute_alpha/classes.rb', line 52258

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


52263
52264
52265
# File 'lib/google/apis/compute_alpha/classes.rb', line 52263

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::PacketMirroringAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



52268
52269
52270
# File 'lib/google/apis/compute_alpha/classes.rb', line 52268

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



52275
52276
52277
52278
52279
52280
52281
52282
52283
# File 'lib/google/apis/compute_alpha/classes.rb', line 52275

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end