Class: Google::Apis::ComputeAlpha::PacketMirroringAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::PacketMirroringAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Contains a list of packetMirrorings.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::PacketMirroringsScopedList>
A list of PacketMirroring resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::PacketMirroringAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PacketMirroringAggregatedList
constructor
A new instance of PacketMirroringAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PacketMirroringAggregatedList
Returns a new instance of PacketMirroringAggregatedList.
51214 51215 51216 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 51214 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
51177 51178 51179 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 51177 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::PacketMirroringsScopedList>
A list of PacketMirroring resources.
Corresponds to the JSON property items
51182 51183 51184 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 51182 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
51187 51188 51189 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 51187 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
51197 51198 51199 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 51197 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
51202 51203 51204 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 51202 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
51207 51208 51209 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 51207 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::PacketMirroringAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
51212 51213 51214 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 51212 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
51219 51220 51221 51222 51223 51224 51225 51226 51227 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 51219 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |