Class: Google::Apis::ComputeAlpha::PacketMirroringAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of packetMirrorings.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PacketMirroringAggregatedList

Returns a new instance of PacketMirroringAggregatedList.



51197
51198
51199
# File 'lib/google/apis/compute_alpha/classes.rb', line 51197

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


51160
51161
51162
# File 'lib/google/apis/compute_alpha/classes.rb', line 51160

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::PacketMirroringsScopedList>

A list of PacketMirroring resources. Corresponds to the JSON property items



51165
51166
51167
# File 'lib/google/apis/compute_alpha/classes.rb', line 51165

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


51170
51171
51172
# File 'lib/google/apis/compute_alpha/classes.rb', line 51170

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


51180
51181
51182
# File 'lib/google/apis/compute_alpha/classes.rb', line 51180

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


51185
51186
51187
# File 'lib/google/apis/compute_alpha/classes.rb', line 51185

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


51190
51191
51192
# File 'lib/google/apis/compute_alpha/classes.rb', line 51190

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::PacketMirroringAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



51195
51196
51197
# File 'lib/google/apis/compute_alpha/classes.rb', line 51195

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



51202
51203
51204
51205
51206
51207
51208
51209
51210
# File 'lib/google/apis/compute_alpha/classes.rb', line 51202

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end