Class: Google::Apis::ComputeAlpha::PacketMirroringAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of packetMirrorings.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PacketMirroringAggregatedList

Returns a new instance of PacketMirroringAggregatedList.



50710
50711
50712
# File 'lib/google/apis/compute_alpha/classes.rb', line 50710

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


50673
50674
50675
# File 'lib/google/apis/compute_alpha/classes.rb', line 50673

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::PacketMirroringsScopedList>

A list of PacketMirroring resources. Corresponds to the JSON property items



50678
50679
50680
# File 'lib/google/apis/compute_alpha/classes.rb', line 50678

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


50683
50684
50685
# File 'lib/google/apis/compute_alpha/classes.rb', line 50683

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


50693
50694
50695
# File 'lib/google/apis/compute_alpha/classes.rb', line 50693

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


50698
50699
50700
# File 'lib/google/apis/compute_alpha/classes.rb', line 50698

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


50703
50704
50705
# File 'lib/google/apis/compute_alpha/classes.rb', line 50703

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::PacketMirroringAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



50708
50709
50710
# File 'lib/google/apis/compute_alpha/classes.rb', line 50708

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



50715
50716
50717
50718
50719
50720
50721
50722
50723
# File 'lib/google/apis/compute_alpha/classes.rb', line 50715

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end