Class: Google::Apis::ComputeAlpha::PacketMirroringAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of packetMirrorings.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PacketMirroringAggregatedList

Returns a new instance of PacketMirroringAggregatedList.



49752
49753
49754
# File 'lib/google/apis/compute_alpha/classes.rb', line 49752

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


49715
49716
49717
# File 'lib/google/apis/compute_alpha/classes.rb', line 49715

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::PacketMirroringsScopedList>

A list of PacketMirroring resources. Corresponds to the JSON property items



49720
49721
49722
# File 'lib/google/apis/compute_alpha/classes.rb', line 49720

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


49725
49726
49727
# File 'lib/google/apis/compute_alpha/classes.rb', line 49725

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


49735
49736
49737
# File 'lib/google/apis/compute_alpha/classes.rb', line 49735

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


49740
49741
49742
# File 'lib/google/apis/compute_alpha/classes.rb', line 49740

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


49745
49746
49747
# File 'lib/google/apis/compute_alpha/classes.rb', line 49745

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::PacketMirroringAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



49750
49751
49752
# File 'lib/google/apis/compute_alpha/classes.rb', line 49750

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



49757
49758
49759
49760
49761
49762
49763
49764
49765
# File 'lib/google/apis/compute_alpha/classes.rb', line 49757

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end