Class: Google::Apis::ComputeAlpha::PacketMirroringList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::PacketMirroringList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Contains a list of PacketMirroring resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::PacketMirroring>
A list of PacketMirroring resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::PacketMirroringList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PacketMirroringList
constructor
A new instance of PacketMirroringList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PacketMirroringList
Returns a new instance of PacketMirroringList.
52991 52992 52993 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 52991 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
52958 52959 52960 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 52958 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::PacketMirroring>
A list of PacketMirroring resources.
Corresponds to the JSON property items
52963 52964 52965 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 52963 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#packetMirroring
for packetMirrorings.
Corresponds to the JSON property kind
52969 52970 52971 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 52969 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
52979 52980 52981 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 52979 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
52984 52985 52986 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 52984 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::PacketMirroringList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
52989 52990 52991 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 52989 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
52996 52997 52998 52999 53000 53001 53002 53003 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 52996 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |