Class: Google::Apis::ComputeAlpha::PacketMirroringList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::PacketMirroringList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Contains a list of PacketMirroring resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::PacketMirroring>
A list of PacketMirroring resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::PacketMirroringList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PacketMirroringList
constructor
A new instance of PacketMirroringList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PacketMirroringList
Returns a new instance of PacketMirroringList.
52750 52751 52752 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 52750 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
52717 52718 52719 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 52717 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::PacketMirroring>
A list of PacketMirroring resources.
Corresponds to the JSON property items
52722 52723 52724 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 52722 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#packetMirroring
for packetMirrorings.
Corresponds to the JSON property kind
52728 52729 52730 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 52728 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
52738 52739 52740 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 52738 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
52743 52744 52745 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 52743 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::PacketMirroringList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
52748 52749 52750 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 52748 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
52755 52756 52757 52758 52759 52760 52761 52762 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 52755 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |