Class: Google::Apis::ComputeAlpha::PacketMirroringList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::PacketMirroringList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Contains a list of PacketMirroring resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::PacketMirroring>
A list of PacketMirroring resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::PacketMirroringList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PacketMirroringList
constructor
A new instance of PacketMirroringList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PacketMirroringList
Returns a new instance of PacketMirroringList.
51409 51410 51411 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 51409 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
51376 51377 51378 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 51376 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::PacketMirroring>
A list of PacketMirroring resources.
Corresponds to the JSON property items
51381 51382 51383 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 51381 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#packetMirroring
for packetMirrorings.
Corresponds to the JSON property kind
51387 51388 51389 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 51387 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
51397 51398 51399 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 51397 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
51402 51403 51404 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 51402 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::PacketMirroringList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
51407 51408 51409 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 51407 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
51414 51415 51416 51417 51418 51419 51420 51421 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 51414 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |