Class: Google::Apis::ComputeAlpha::PacketMirroringList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of PacketMirroring resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PacketMirroringList

Returns a new instance of PacketMirroringList.



50704
50705
50706
# File 'lib/google/apis/compute_alpha/classes.rb', line 50704

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


50671
50672
50673
# File 'lib/google/apis/compute_alpha/classes.rb', line 50671

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::PacketMirroring>

A list of PacketMirroring resources. Corresponds to the JSON property items



50676
50677
50678
# File 'lib/google/apis/compute_alpha/classes.rb', line 50676

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#packetMirroring for packetMirrorings. Corresponds to the JSON property kind

Returns:

  • (String)


50682
50683
50684
# File 'lib/google/apis/compute_alpha/classes.rb', line 50682

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


50692
50693
50694
# File 'lib/google/apis/compute_alpha/classes.rb', line 50692

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


50697
50698
50699
# File 'lib/google/apis/compute_alpha/classes.rb', line 50697

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::PacketMirroringList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



50702
50703
50704
# File 'lib/google/apis/compute_alpha/classes.rb', line 50702

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



50709
50710
50711
50712
50713
50714
50715
50716
# File 'lib/google/apis/compute_alpha/classes.rb', line 50709

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end