Class: Google::Apis::ComputeAlpha::PacketMirroringList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::PacketMirroringList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Contains a list of PacketMirroring resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::PacketMirroring>
A list of PacketMirroring resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::PacketMirroringList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PacketMirroringList
constructor
A new instance of PacketMirroringList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PacketMirroringList
Returns a new instance of PacketMirroringList.
49947 49948 49949 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 49947 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
49914 49915 49916 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 49914 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::PacketMirroring>
A list of PacketMirroring resources.
Corresponds to the JSON property items
49919 49920 49921 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 49919 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#packetMirroring
for packetMirrorings.
Corresponds to the JSON property kind
49925 49926 49927 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 49925 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
49935 49936 49937 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 49935 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
49940 49941 49942 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 49940 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::PacketMirroringList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
49945 49946 49947 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 49945 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
49952 49953 49954 49955 49956 49957 49958 49959 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 49952 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |