Class: Google::Apis::ComputeAlpha::PacketMirroringMirroredResourceInfo
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::PacketMirroringMirroredResourceInfo
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#instances ⇒ Array<Google::Apis::ComputeAlpha::PacketMirroringMirroredResourceInfoInstanceInfo>
A set of virtual machine instances that are being mirrored.
-
#subnetworks ⇒ Array<Google::Apis::ComputeAlpha::PacketMirroringMirroredResourceInfoSubnetInfo>
A set of subnetworks for which traffic from/to all VM instances will be mirrored.
-
#tags ⇒ Array<String>
A set of mirrored tags.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PacketMirroringMirroredResourceInfo
constructor
A new instance of PacketMirroringMirroredResourceInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PacketMirroringMirroredResourceInfo
Returns a new instance of PacketMirroringMirroredResourceInfo.
51521 51522 51523 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 51521 def initialize(**args) update!(**args) end |
Instance Attribute Details
#instances ⇒ Array<Google::Apis::ComputeAlpha::PacketMirroringMirroredResourceInfoInstanceInfo>
A set of virtual machine instances that are being mirrored.
They must live in zones contained in the same region as this
packetMirroring.
Note that this config will apply only to those network interfaces of the
Instances that belong to the network specified in this packetMirroring.
You may specify a maximum of 50 Instances.
Corresponds to the JSON property instances
51506 51507 51508 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 51506 def instances @instances end |
#subnetworks ⇒ Array<Google::Apis::ComputeAlpha::PacketMirroringMirroredResourceInfoSubnetInfo>
A set of subnetworks for which traffic from/to all VM instances will be
mirrored. They must live in the same region as this packetMirroring.
You may specify a maximum of 5 subnetworks.
Corresponds to the JSON property subnetworks
51513 51514 51515 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 51513 def subnetworks @subnetworks end |
#tags ⇒ Array<String>
A set of mirrored tags. Traffic from/to all VM instances that have one or
more of these tags will be mirrored.
Corresponds to the JSON property tags
51519 51520 51521 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 51519 def @tags end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
51526 51527 51528 51529 51530 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 51526 def update!(**args) @instances = args[:instances] if args.key?(:instances) @subnetworks = args[:subnetworks] if args.key?(:subnetworks) @tags = args[:tags] if args.key?(:tags) end |