Class: Google::Apis::ComputeAlpha::PacketMirroringMirroredResourceInfo

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PacketMirroringMirroredResourceInfo

Returns a new instance of PacketMirroringMirroredResourceInfo.



51019
51020
51021
# File 'lib/google/apis/compute_alpha/classes.rb', line 51019

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#instancesArray<Google::Apis::ComputeAlpha::PacketMirroringMirroredResourceInfoInstanceInfo>

A set of virtual machine instances that are being mirrored. They must live in zones contained in the same region as this packetMirroring. Note that this config will apply only to those network interfaces of the Instances that belong to the network specified in this packetMirroring. You may specify a maximum of 50 Instances. Corresponds to the JSON property instances



51004
51005
51006
# File 'lib/google/apis/compute_alpha/classes.rb', line 51004

def instances
  @instances
end

#subnetworksArray<Google::Apis::ComputeAlpha::PacketMirroringMirroredResourceInfoSubnetInfo>

A set of subnetworks for which traffic from/to all VM instances will be mirrored. They must live in the same region as this packetMirroring. You may specify a maximum of 5 subnetworks. Corresponds to the JSON property subnetworks



51011
51012
51013
# File 'lib/google/apis/compute_alpha/classes.rb', line 51011

def subnetworks
  @subnetworks
end

#tagsArray<String>

A set of mirrored tags. Traffic from/to all VM instances that have one or more of these tags will be mirrored. Corresponds to the JSON property tags

Returns:

  • (Array<String>)


51017
51018
51019
# File 'lib/google/apis/compute_alpha/classes.rb', line 51017

def tags
  @tags
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



51024
51025
51026
51027
51028
# File 'lib/google/apis/compute_alpha/classes.rb', line 51024

def update!(**args)
  @instances = args[:instances] if args.key?(:instances)
  @subnetworks = args[:subnetworks] if args.key?(:subnetworks)
  @tags = args[:tags] if args.key?(:tags)
end