Class: Google::Apis::ComputeAlpha::PacketMirroringMirroredResourceInfo

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PacketMirroringMirroredResourceInfo

Returns a new instance of PacketMirroringMirroredResourceInfo.



50816
50817
50818
# File 'lib/google/apis/compute_alpha/classes.rb', line 50816

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#instancesArray<Google::Apis::ComputeAlpha::PacketMirroringMirroredResourceInfoInstanceInfo>

A set of virtual machine instances that are being mirrored. They must live in zones contained in the same region as this packetMirroring. Note that this config will apply only to those network interfaces of the Instances that belong to the network specified in this packetMirroring. You may specify a maximum of 50 Instances. Corresponds to the JSON property instances



50801
50802
50803
# File 'lib/google/apis/compute_alpha/classes.rb', line 50801

def instances
  @instances
end

#subnetworksArray<Google::Apis::ComputeAlpha::PacketMirroringMirroredResourceInfoSubnetInfo>

A set of subnetworks for which traffic from/to all VM instances will be mirrored. They must live in the same region as this packetMirroring. You may specify a maximum of 5 subnetworks. Corresponds to the JSON property subnetworks



50808
50809
50810
# File 'lib/google/apis/compute_alpha/classes.rb', line 50808

def subnetworks
  @subnetworks
end

#tagsArray<String>

A set of mirrored tags. Traffic from/to all VM instances that have one or more of these tags will be mirrored. Corresponds to the JSON property tags

Returns:

  • (Array<String>)


50814
50815
50816
# File 'lib/google/apis/compute_alpha/classes.rb', line 50814

def tags
  @tags
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



50821
50822
50823
50824
50825
# File 'lib/google/apis/compute_alpha/classes.rb', line 50821

def update!(**args)
  @instances = args[:instances] if args.key?(:instances)
  @subnetworks = args[:subnetworks] if args.key?(:subnetworks)
  @tags = args[:tags] if args.key?(:tags)
end