Class: Google::Apis::ComputeAlpha::PartnerMetadata

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Model definition of partner_metadata field. To be used in dedicated Partner Metadata methods and to be inlined in the Instance and InstanceTemplate resources.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PartnerMetadata

Returns a new instance of PartnerMetadata.



51230
51231
51232
# File 'lib/google/apis/compute_alpha/classes.rb', line 51230

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#fingerprintString

Instance-level hash to be used for optimistic locking. Corresponds to the JSON property fingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


51219
51220
51221
# File 'lib/google/apis/compute_alpha/classes.rb', line 51219

def fingerprint
  @fingerprint
end

#partner_metadataHash<String,Google::Apis::ComputeAlpha::StructuredEntries>

Partner Metadata assigned to the instance. A map from a subdomain to entries map. Subdomain name must be compliant withRFC1035 definition. The total size of all keys and values must be less than 2MB. Subdomain 'metadata.compute.googleapis.com' is reserverd for instance's metadata. Corresponds to the JSON property partnerMetadata



51228
51229
51230
# File 'lib/google/apis/compute_alpha/classes.rb', line 51228

def 
  @partner_metadata
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



51235
51236
51237
51238
# File 'lib/google/apis/compute_alpha/classes.rb', line 51235

def update!(**args)
  @fingerprint = args[:fingerprint] if args.key?(:fingerprint)
  @partner_metadata = args[:partner_metadata] if args.key?(:partner_metadata)
end