Class: Google::Apis::ComputeAlpha::PathMatcher

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

A matcher for the path portion of the URL. The BackendService from the longest-matched rule will serve the URL. If no rule was matched, the default service is used.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PathMatcher

Returns a new instance of PathMatcher.



51338
51339
51340
# File 'lib/google/apis/compute_alpha/classes.rb', line 51338

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#default_custom_error_response_policyGoogle::Apis::ComputeAlpha::CustomErrorResponsePolicy

Specifies the custom error response policy that must be applied when the backend service or backend bucket responds with an error. Corresponds to the JSON property defaultCustomErrorResponsePolicy



51251
51252
51253
# File 'lib/google/apis/compute_alpha/classes.rb', line 51251

def default_custom_error_response_policy
  @default_custom_error_response_policy
end

#default_route_actionGoogle::Apis::ComputeAlpha::HttpRouteAction

defaultRouteAction takes effect when none of the pathRules or routeRules match. The load balancer performs advanced routing actions, such as URL rewrites and header transformations, before forwarding the request to the selected backend. Only one of defaultUrlRedirect, defaultService or defaultRouteAction.weightedBackendService can be set. URL maps for classic Application Load Balancers only support the urlRewrite action within a path matcher'sdefaultRouteAction. Corresponds to the JSON property defaultRouteAction



51264
51265
51266
# File 'lib/google/apis/compute_alpha/classes.rb', line 51264

def default_route_action
  @default_route_action
end

#default_serviceString

The full or partial URL to the BackendService resource. This URL is used if none of the pathRules orrouteRules defined by this PathMatcher are matched. For example, the following are all valid URLs to a BackendService resource:

  • https://www.googleapis.com/compute/v1/projects/project/global/ backendServices/backendService
  • compute/v1/projects/project/global/backendServices/backendService
  • global/backendServices/backendService If defaultRouteAction is also specified, advanced routing actions, such as URL rewrites, take effect before sending the request to the backend. Only one of defaultUrlRedirect, defaultService or defaultRouteAction.weightedBackendService can be set. Authorization requires one or more of the following Google IAM permissions on the specified resource default_service:

  • compute.backendBuckets.use

  • compute.backendServices.use Corresponds to the JSON property defaultService

Returns:

  • (String)


51291
51292
51293
# File 'lib/google/apis/compute_alpha/classes.rb', line 51291

def default_service
  @default_service
end

#default_url_redirectGoogle::Apis::ComputeAlpha::HttpRedirectAction

Specifies settings for an HTTP redirect. Corresponds to the JSON property defaultUrlRedirect



51296
51297
51298
# File 'lib/google/apis/compute_alpha/classes.rb', line 51296

def default_url_redirect
  @default_url_redirect
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


51302
51303
51304
# File 'lib/google/apis/compute_alpha/classes.rb', line 51302

def description
  @description
end

#header_actionGoogle::Apis::ComputeAlpha::HttpHeaderAction

The request and response header transformations that take effect before the request is passed along to the selected backendService. Corresponds to the JSON property headerAction



51308
51309
51310
# File 'lib/google/apis/compute_alpha/classes.rb', line 51308

def header_action
  @header_action
end

#nameString

The name to which this PathMatcher is referred by theHostRule. Corresponds to the JSON property name

Returns:

  • (String)


51313
51314
51315
# File 'lib/google/apis/compute_alpha/classes.rb', line 51313

def name
  @name
end

#path_rulesArray<Google::Apis::ComputeAlpha::PathRule>

The list of path rules. Use this list instead of routeRules when routing based on simple path matching is all that's required. A path rule can only include a wildcard character () after a forward slash character ("/"). The order by which path rules are specified does not matter. Matches are always done on the longest-path-first basis. For example: a pathRule with a path /a/b/c/ will match before /a/b/* irrespective of the order in which those paths appear in this list. Within a given pathMatcher, only one ofpathRules or routeRules must be set. Corresponds to the JSON property pathRules



51327
51328
51329
# File 'lib/google/apis/compute_alpha/classes.rb', line 51327

def path_rules
  @path_rules
end

#route_rulesArray<Google::Apis::ComputeAlpha::HttpRouteRule>

The list of HTTP route rules. Use this list instead ofpathRules when advanced route matching and routing actions are desired. routeRules are evaluated in order of priority, from the lowest to highest number. Within a given pathMatcher, you can set only one ofpathRules or routeRules. Corresponds to the JSON property routeRules



51336
51337
51338
# File 'lib/google/apis/compute_alpha/classes.rb', line 51336

def route_rules
  @route_rules
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



51343
51344
51345
51346
51347
51348
51349
51350
51351
51352
51353
# File 'lib/google/apis/compute_alpha/classes.rb', line 51343

def update!(**args)
  @default_custom_error_response_policy = args[:default_custom_error_response_policy] if args.key?(:default_custom_error_response_policy)
  @default_route_action = args[:default_route_action] if args.key?(:default_route_action)
  @default_service = args[:default_service] if args.key?(:default_service)
  @default_url_redirect = args[:default_url_redirect] if args.key?(:default_url_redirect)
  @description = args[:description] if args.key?(:description)
  @header_action = args[:header_action] if args.key?(:header_action)
  @name = args[:name] if args.key?(:name)
  @path_rules = args[:path_rules] if args.key?(:path_rules)
  @route_rules = args[:route_rules] if args.key?(:route_rules)
end