Class: Google::Apis::ComputeAlpha::PeerAuthenticationMethod

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

[Deprecated] Configuration for the peer authentication method. Configuration for the peer authentication method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PeerAuthenticationMethod

Returns a new instance of PeerAuthenticationMethod.



50468
50469
50470
# File 'lib/google/apis/compute_alpha/classes.rb', line 50468

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#mtlsGoogle::Apis::ComputeAlpha::MutualTls

[Deprecated] Configuration for the mutual Tls mode for peer authentication. Configuration for the mutual Tls mode for peer authentication. Corresponds to the JSON property mtls



50466
50467
50468
# File 'lib/google/apis/compute_alpha/classes.rb', line 50466

def mtls
  @mtls
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



50473
50474
50475
# File 'lib/google/apis/compute_alpha/classes.rb', line 50473

def update!(**args)
  @mtls = args[:mtls] if args.key?(:mtls)
end