Class: Google::Apis::ComputeAlpha::PeriodicPartialMaintenanceSchedule

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

The periodic partial maintenance schedule includes 52 weeks worth of maintenance windows. LINT.IfChange(PeriodicPartialMaintenanceSchedule)

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PeriodicPartialMaintenanceSchedule

Returns a new instance of PeriodicPartialMaintenanceSchedule.



52037
52038
52039
# File 'lib/google/apis/compute_alpha/classes.rb', line 52037

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#sub_typeString

The maintenance type in which the zone is during the given window. Corresponds to the JSON property subType

Returns:

  • (String)


51980
51981
51982
# File 'lib/google/apis/compute_alpha/classes.rb', line 51980

def sub_type
  @sub_type
end

#target_resourceString

The target resource that the maintenance window is for. For example, "projects/my-project/zones/us-central1-a". Corresponds to the JSON property targetResource

Returns:

  • (String)


51986
51987
51988
# File 'lib/google/apis/compute_alpha/classes.rb', line 51986

def target_resource
  @target_resource
end

#typeString

Corresponds to the JSON property type

Returns:

  • (String)


51991
51992
51993
# File 'lib/google/apis/compute_alpha/classes.rb', line 51991

def type
  @type
end

#window_end_timeGoogle::Apis::ComputeAlpha::DateTime

Represents civil time (or occasionally physical time). This type can represent a civil time in one of a few possible ways:

  • When utc_offset is set and time_zone is unset: a civil time on a calendar day with a particular offset from UTC.
  • When time_zone is set and utc_offset is unset: a civil time on a calendar day in a particular time zone.
  • When neither time_zone nor utc_offset is set: a civil time on a calendar day in local time. The date is relative to the Proleptic Gregorian Calendar. If year, month, or day are 0, the DateTime is considered not to have a specific year, month, or day respectively. This type may also be used to represent a physical time if all the date and time fields are set and either case of the time_offset oneof is set. Consider using Timestamp message for physical time instead. If your use case also would like to store the user's timezone, that can be done in another field. This type is more flexible than some applications may want. Make sure to document and validate your application's limitations. Corresponds to the JSON property windowEndTime


52013
52014
52015
# File 'lib/google/apis/compute_alpha/classes.rb', line 52013

def window_end_time
  @window_end_time
end

#window_start_timeGoogle::Apis::ComputeAlpha::DateTime

Represents civil time (or occasionally physical time). This type can represent a civil time in one of a few possible ways:

  • When utc_offset is set and time_zone is unset: a civil time on a calendar day with a particular offset from UTC.
  • When time_zone is set and utc_offset is unset: a civil time on a calendar day in a particular time zone.
  • When neither time_zone nor utc_offset is set: a civil time on a calendar day in local time. The date is relative to the Proleptic Gregorian Calendar. If year, month, or day are 0, the DateTime is considered not to have a specific year, month, or day respectively. This type may also be used to represent a physical time if all the date and time fields are set and either case of the time_offset oneof is set. Consider using Timestamp message for physical time instead. If your use case also would like to store the user's timezone, that can be done in another field. This type is more flexible than some applications may want. Make sure to document and validate your application's limitations. Corresponds to the JSON property windowStartTime


52035
52036
52037
# File 'lib/google/apis/compute_alpha/classes.rb', line 52035

def window_start_time
  @window_start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



52042
52043
52044
52045
52046
52047
52048
# File 'lib/google/apis/compute_alpha/classes.rb', line 52042

def update!(**args)
  @sub_type = args[:sub_type] if args.key?(:sub_type)
  @target_resource = args[:target_resource] if args.key?(:target_resource)
  @type = args[:type] if args.key?(:type)
  @window_end_time = args[:window_end_time] if args.key?(:window_end_time)
  @window_start_time = args[:window_start_time] if args.key?(:window_start_time)
end