Class: Google::Apis::ComputeAlpha::PeriodicPartialMaintenanceSchedule
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::PeriodicPartialMaintenanceSchedule
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
The periodic partial maintenance schedule includes 52 weeks worth of maintenance windows. LINT.IfChange(PeriodicPartialMaintenanceSchedule)
Instance Attribute Summary collapse
-
#sub_type ⇒ String
The maintenance type in which the zone is during the given window.
-
#target_resource ⇒ String
The target resource that the maintenance window is for.
-
#type ⇒ String
Corresponds to the JSON property
type. -
#window_end_time ⇒ Google::Apis::ComputeAlpha::DateTime
Represents civil time (or occasionally physical time).
-
#window_start_time ⇒ Google::Apis::ComputeAlpha::DateTime
Represents civil time (or occasionally physical time).
Instance Method Summary collapse
-
#initialize(**args) ⇒ PeriodicPartialMaintenanceSchedule
constructor
A new instance of PeriodicPartialMaintenanceSchedule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PeriodicPartialMaintenanceSchedule
Returns a new instance of PeriodicPartialMaintenanceSchedule.
51550 51551 51552 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 51550 def initialize(**args) update!(**args) end |
Instance Attribute Details
#sub_type ⇒ String
The maintenance type in which the zone is during the given window.
Corresponds to the JSON property subType
51493 51494 51495 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 51493 def sub_type @sub_type end |
#target_resource ⇒ String
The target resource that the maintenance window is for.
For example, "projects/my-project/zones/us-central1-a".
Corresponds to the JSON property targetResource
51499 51500 51501 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 51499 def target_resource @target_resource end |
#type ⇒ String
Corresponds to the JSON property type
51504 51505 51506 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 51504 def type @type end |
#window_end_time ⇒ Google::Apis::ComputeAlpha::DateTime
Represents civil time (or occasionally physical time). This type can represent a civil time in one of a few possible ways:
- When utc_offset is set and time_zone is unset: a civil time on a calendar day with a particular offset from UTC.
- When time_zone is set and utc_offset is unset: a civil time on a calendar day in a particular time zone.
- When neither time_zone nor utc_offset is set: a civil time on a calendar
day in local time.
The date is relative to the Proleptic Gregorian Calendar.
If year, month, or day are 0, the DateTime is considered not to have a
specific year, month, or day respectively.
This type may also be used to represent a physical time if all the date and
time fields are set and either case of the
time_offsetoneof is set. Consider usingTimestampmessage for physical time instead. If your use case also would like to store the user's timezone, that can be done in another field. This type is more flexible than some applications may want. Make sure to document and validate your application's limitations. Corresponds to the JSON propertywindowEndTime
51526 51527 51528 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 51526 def window_end_time @window_end_time end |
#window_start_time ⇒ Google::Apis::ComputeAlpha::DateTime
Represents civil time (or occasionally physical time). This type can represent a civil time in one of a few possible ways:
- When utc_offset is set and time_zone is unset: a civil time on a calendar day with a particular offset from UTC.
- When time_zone is set and utc_offset is unset: a civil time on a calendar day in a particular time zone.
- When neither time_zone nor utc_offset is set: a civil time on a calendar
day in local time.
The date is relative to the Proleptic Gregorian Calendar.
If year, month, or day are 0, the DateTime is considered not to have a
specific year, month, or day respectively.
This type may also be used to represent a physical time if all the date and
time fields are set and either case of the
time_offsetoneof is set. Consider usingTimestampmessage for physical time instead. If your use case also would like to store the user's timezone, that can be done in another field. This type is more flexible than some applications may want. Make sure to document and validate your application's limitations. Corresponds to the JSON propertywindowStartTime
51548 51549 51550 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 51548 def window_start_time @window_start_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
51555 51556 51557 51558 51559 51560 51561 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 51555 def update!(**args) @sub_type = args[:sub_type] if args.key?(:sub_type) @target_resource = args[:target_resource] if args.key?(:target_resource) @type = args[:type] if args.key?(:type) @window_end_time = args[:window_end_time] if args.key?(:window_end_time) @window_start_time = args[:window_start_time] if args.key?(:window_start_time) end |