Class: Google::Apis::ComputeAlpha::PeriodicPartialMaintenanceSchedule
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::PeriodicPartialMaintenanceSchedule
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
The periodic partial maintenance schedule includes 52 weeks worth of maintenance windows. LINT.IfChange(PeriodicPartialMaintenanceSchedule)
Instance Attribute Summary collapse
-
#sub_type ⇒ String
The maintenance type in which the zone is during the given window.
-
#target_resource ⇒ String
The target resource that the maintenance window is for.
-
#type ⇒ String
Corresponds to the JSON property
type. -
#window_end_time ⇒ Google::Apis::ComputeAlpha::DateTime
Represents civil time (or occasionally physical time).
-
#window_start_time ⇒ Google::Apis::ComputeAlpha::DateTime
Represents civil time (or occasionally physical time).
Instance Method Summary collapse
-
#initialize(**args) ⇒ PeriodicPartialMaintenanceSchedule
constructor
A new instance of PeriodicPartialMaintenanceSchedule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PeriodicPartialMaintenanceSchedule
Returns a new instance of PeriodicPartialMaintenanceSchedule.
50592 50593 50594 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 50592 def initialize(**args) update!(**args) end |
Instance Attribute Details
#sub_type ⇒ String
The maintenance type in which the zone is during the given window.
Corresponds to the JSON property subType
50535 50536 50537 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 50535 def sub_type @sub_type end |
#target_resource ⇒ String
The target resource that the maintenance window is for.
For example, "projects/my-project/zones/us-central1-a".
Corresponds to the JSON property targetResource
50541 50542 50543 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 50541 def target_resource @target_resource end |
#type ⇒ String
Corresponds to the JSON property type
50546 50547 50548 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 50546 def type @type end |
#window_end_time ⇒ Google::Apis::ComputeAlpha::DateTime
Represents civil time (or occasionally physical time). This type can represent a civil time in one of a few possible ways:
- When utc_offset is set and time_zone is unset: a civil time on a calendar day with a particular offset from UTC.
- When time_zone is set and utc_offset is unset: a civil time on a calendar day in a particular time zone.
- When neither time_zone nor utc_offset is set: a civil time on a calendar
day in local time.
The date is relative to the Proleptic Gregorian Calendar.
If year, month, or day are 0, the DateTime is considered not to have a
specific year, month, or day respectively.
This type may also be used to represent a physical time if all the date and
time fields are set and either case of the
time_offsetoneof is set. Consider usingTimestampmessage for physical time instead. If your use case also would like to store the user's timezone, that can be done in another field. This type is more flexible than some applications may want. Make sure to document and validate your application's limitations. Corresponds to the JSON propertywindowEndTime
50568 50569 50570 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 50568 def window_end_time @window_end_time end |
#window_start_time ⇒ Google::Apis::ComputeAlpha::DateTime
Represents civil time (or occasionally physical time). This type can represent a civil time in one of a few possible ways:
- When utc_offset is set and time_zone is unset: a civil time on a calendar day with a particular offset from UTC.
- When time_zone is set and utc_offset is unset: a civil time on a calendar day in a particular time zone.
- When neither time_zone nor utc_offset is set: a civil time on a calendar
day in local time.
The date is relative to the Proleptic Gregorian Calendar.
If year, month, or day are 0, the DateTime is considered not to have a
specific year, month, or day respectively.
This type may also be used to represent a physical time if all the date and
time fields are set and either case of the
time_offsetoneof is set. Consider usingTimestampmessage for physical time instead. If your use case also would like to store the user's timezone, that can be done in another field. This type is more flexible than some applications may want. Make sure to document and validate your application's limitations. Corresponds to the JSON propertywindowStartTime
50590 50591 50592 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 50590 def window_start_time @window_start_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
50597 50598 50599 50600 50601 50602 50603 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 50597 def update!(**args) @sub_type = args[:sub_type] if args.key?(:sub_type) @target_resource = args[:target_resource] if args.key?(:target_resource) @type = args[:type] if args.key?(:type) @window_end_time = args[:window_end_time] if args.key?(:window_end_time) @window_start_time = args[:window_start_time] if args.key?(:window_start_time) end |