Class: Google::Apis::ComputeAlpha::Permission

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

[Deprecated] All fields defined in a permission are ANDed.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Permission

Returns a new instance of Permission.



53460
53461
53462
# File 'lib/google/apis/compute_alpha/classes.rb', line 53460

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#constraintsArray<Google::Apis::ComputeAlpha::PermissionConstraint>

Extra custom constraints. The constraints are ANDed together. Corresponds to the JSON property constraints



53416
53417
53418
# File 'lib/google/apis/compute_alpha/classes.rb', line 53416

def constraints
  @constraints
end

#hostsArray<String>

Used in Ingress or Egress Gateway cases to specify hosts that the policy applies to. Exact match, prefix match, and suffix match are supported. Corresponds to the JSON property hosts

Returns:

  • (Array<String>)


53422
53423
53424
# File 'lib/google/apis/compute_alpha/classes.rb', line 53422

def hosts
  @hosts
end

#methods_propArray<String>

HTTP method. Corresponds to the JSON property methods

Returns:

  • (Array<String>)


53427
53428
53429
# File 'lib/google/apis/compute_alpha/classes.rb', line 53427

def methods_prop
  @methods_prop
end

#not_hostsArray<String>

Negate of hosts. Specifies exclusions. Corresponds to the JSON property notHosts

Returns:

  • (Array<String>)


53432
53433
53434
# File 'lib/google/apis/compute_alpha/classes.rb', line 53432

def not_hosts
  @not_hosts
end

#not_methodsArray<String>

Negate of methods. Specifies exclusions. Corresponds to the JSON property notMethods

Returns:

  • (Array<String>)


53437
53438
53439
# File 'lib/google/apis/compute_alpha/classes.rb', line 53437

def not_methods
  @not_methods
end

#not_pathsArray<String>

Negate of paths. Specifies exclusions. Corresponds to the JSON property notPaths

Returns:

  • (Array<String>)


53442
53443
53444
# File 'lib/google/apis/compute_alpha/classes.rb', line 53442

def not_paths
  @not_paths
end

#not_portsArray<String>

Negate of ports. Specifies exclusions. Corresponds to the JSON property notPorts

Returns:

  • (Array<String>)


53447
53448
53449
# File 'lib/google/apis/compute_alpha/classes.rb', line 53447

def not_ports
  @not_ports
end

#pathsArray<String>

HTTP request paths or gRPC methods. Exact match, prefix match, and suffix match are supported. Corresponds to the JSON property paths

Returns:

  • (Array<String>)


53453
53454
53455
# File 'lib/google/apis/compute_alpha/classes.rb', line 53453

def paths
  @paths
end

#portsArray<String>

Port names or numbers. Corresponds to the JSON property ports

Returns:

  • (Array<String>)


53458
53459
53460
# File 'lib/google/apis/compute_alpha/classes.rb', line 53458

def ports
  @ports
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



53465
53466
53467
53468
53469
53470
53471
53472
53473
53474
53475
# File 'lib/google/apis/compute_alpha/classes.rb', line 53465

def update!(**args)
  @constraints = args[:constraints] if args.key?(:constraints)
  @hosts = args[:hosts] if args.key?(:hosts)
  @methods_prop = args[:methods_prop] if args.key?(:methods_prop)
  @not_hosts = args[:not_hosts] if args.key?(:not_hosts)
  @not_methods = args[:not_methods] if args.key?(:not_methods)
  @not_paths = args[:not_paths] if args.key?(:not_paths)
  @not_ports = args[:not_ports] if args.key?(:not_ports)
  @paths = args[:paths] if args.key?(:paths)
  @ports = args[:ports] if args.key?(:ports)
end