Class: Google::Apis::ComputeAlpha::Permission
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::Permission
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
[Deprecated] All fields defined in a permission are ANDed.
Instance Attribute Summary collapse
-
#constraints ⇒ Array<Google::Apis::ComputeAlpha::PermissionConstraint>
Extra custom constraints.
-
#hosts ⇒ Array<String>
Used in Ingress or Egress Gateway cases to specify hosts that the policy applies to.
-
#methods_prop ⇒ Array<String>
HTTP method.
-
#not_hosts ⇒ Array<String>
Negate of hosts.
-
#not_methods ⇒ Array<String>
Negate of methods.
-
#not_paths ⇒ Array<String>
Negate of paths.
-
#not_ports ⇒ Array<String>
Negate of ports.
-
#paths ⇒ Array<String>
HTTP request paths or gRPC methods.
-
#ports ⇒ Array<String>
Port names or numbers.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Permission
constructor
A new instance of Permission.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Permission
Returns a new instance of Permission.
53175 53176 53177 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53175 def initialize(**args) update!(**args) end |
Instance Attribute Details
#constraints ⇒ Array<Google::Apis::ComputeAlpha::PermissionConstraint>
Extra custom constraints. The constraints are ANDed together.
Corresponds to the JSON property constraints
53131 53132 53133 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53131 def constraints @constraints end |
#hosts ⇒ Array<String>
Used in Ingress or Egress Gateway cases to specify hosts that the policy
applies to. Exact match, prefix match, and suffix match are supported.
Corresponds to the JSON property hosts
53137 53138 53139 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53137 def hosts @hosts end |
#methods_prop ⇒ Array<String>
HTTP method.
Corresponds to the JSON property methods
53142 53143 53144 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53142 def methods_prop @methods_prop end |
#not_hosts ⇒ Array<String>
Negate of hosts. Specifies exclusions.
Corresponds to the JSON property notHosts
53147 53148 53149 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53147 def not_hosts @not_hosts end |
#not_methods ⇒ Array<String>
Negate of methods. Specifies exclusions.
Corresponds to the JSON property notMethods
53152 53153 53154 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53152 def not_methods @not_methods end |
#not_paths ⇒ Array<String>
Negate of paths. Specifies exclusions.
Corresponds to the JSON property notPaths
53157 53158 53159 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53157 def not_paths @not_paths end |
#not_ports ⇒ Array<String>
Negate of ports. Specifies exclusions.
Corresponds to the JSON property notPorts
53162 53163 53164 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53162 def not_ports @not_ports end |
#paths ⇒ Array<String>
HTTP request paths or gRPC methods.
Exact match, prefix match, and suffix match are supported.
Corresponds to the JSON property paths
53168 53169 53170 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53168 def paths @paths end |
#ports ⇒ Array<String>
Port names or numbers.
Corresponds to the JSON property ports
53173 53174 53175 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53173 def ports @ports end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
53180 53181 53182 53183 53184 53185 53186 53187 53188 53189 53190 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53180 def update!(**args) @constraints = args[:constraints] if args.key?(:constraints) @hosts = args[:hosts] if args.key?(:hosts) @methods_prop = args[:methods_prop] if args.key?(:methods_prop) @not_hosts = args[:not_hosts] if args.key?(:not_hosts) @not_methods = args[:not_methods] if args.key?(:not_methods) @not_paths = args[:not_paths] if args.key?(:not_paths) @not_ports = args[:not_ports] if args.key?(:not_ports) @paths = args[:paths] if args.key?(:paths) @ports = args[:ports] if args.key?(:ports) end |