Class: Google::Apis::ComputeAlpha::Permission
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::Permission
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
[Deprecated] All fields defined in a permission are ANDed.
Instance Attribute Summary collapse
-
#constraints ⇒ Array<Google::Apis::ComputeAlpha::PermissionConstraint>
Extra custom constraints.
-
#hosts ⇒ Array<String>
Used in Ingress or Egress Gateway cases to specify hosts that the policy applies to.
-
#methods_prop ⇒ Array<String>
HTTP method.
-
#not_hosts ⇒ Array<String>
Negate of hosts.
-
#not_methods ⇒ Array<String>
Negate of methods.
-
#not_paths ⇒ Array<String>
Negate of paths.
-
#not_ports ⇒ Array<String>
Negate of ports.
-
#paths ⇒ Array<String>
HTTP request paths or gRPC methods.
-
#ports ⇒ Array<String>
Port names or numbers.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Permission
constructor
A new instance of Permission.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Permission
Returns a new instance of Permission.
52119 52120 52121 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 52119 def initialize(**args) update!(**args) end |
Instance Attribute Details
#constraints ⇒ Array<Google::Apis::ComputeAlpha::PermissionConstraint>
Extra custom constraints. The constraints are ANDed together.
Corresponds to the JSON property constraints
52075 52076 52077 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 52075 def constraints @constraints end |
#hosts ⇒ Array<String>
Used in Ingress or Egress Gateway cases to specify hosts that the policy
applies to. Exact match, prefix match, and suffix match are supported.
Corresponds to the JSON property hosts
52081 52082 52083 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 52081 def hosts @hosts end |
#methods_prop ⇒ Array<String>
HTTP method.
Corresponds to the JSON property methods
52086 52087 52088 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 52086 def methods_prop @methods_prop end |
#not_hosts ⇒ Array<String>
Negate of hosts. Specifies exclusions.
Corresponds to the JSON property notHosts
52091 52092 52093 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 52091 def not_hosts @not_hosts end |
#not_methods ⇒ Array<String>
Negate of methods. Specifies exclusions.
Corresponds to the JSON property notMethods
52096 52097 52098 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 52096 def not_methods @not_methods end |
#not_paths ⇒ Array<String>
Negate of paths. Specifies exclusions.
Corresponds to the JSON property notPaths
52101 52102 52103 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 52101 def not_paths @not_paths end |
#not_ports ⇒ Array<String>
Negate of ports. Specifies exclusions.
Corresponds to the JSON property notPorts
52106 52107 52108 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 52106 def not_ports @not_ports end |
#paths ⇒ Array<String>
HTTP request paths or gRPC methods.
Exact match, prefix match, and suffix match are supported.
Corresponds to the JSON property paths
52112 52113 52114 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 52112 def paths @paths end |
#ports ⇒ Array<String>
Port names or numbers.
Corresponds to the JSON property ports
52117 52118 52119 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 52117 def ports @ports end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
52124 52125 52126 52127 52128 52129 52130 52131 52132 52133 52134 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 52124 def update!(**args) @constraints = args[:constraints] if args.key?(:constraints) @hosts = args[:hosts] if args.key?(:hosts) @methods_prop = args[:methods_prop] if args.key?(:methods_prop) @not_hosts = args[:not_hosts] if args.key?(:not_hosts) @not_methods = args[:not_methods] if args.key?(:not_methods) @not_paths = args[:not_paths] if args.key?(:not_paths) @not_ports = args[:not_ports] if args.key?(:not_ports) @paths = args[:paths] if args.key?(:paths) @ports = args[:ports] if args.key?(:ports) end |