Class: Google::Apis::ComputeAlpha::Permission

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

[Deprecated] All fields defined in a permission are ANDed.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Permission

Returns a new instance of Permission.



52102
52103
52104
# File 'lib/google/apis/compute_alpha/classes.rb', line 52102

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#constraintsArray<Google::Apis::ComputeAlpha::PermissionConstraint>

Extra custom constraints. The constraints are ANDed together. Corresponds to the JSON property constraints



52058
52059
52060
# File 'lib/google/apis/compute_alpha/classes.rb', line 52058

def constraints
  @constraints
end

#hostsArray<String>

Used in Ingress or Egress Gateway cases to specify hosts that the policy applies to. Exact match, prefix match, and suffix match are supported. Corresponds to the JSON property hosts

Returns:

  • (Array<String>)


52064
52065
52066
# File 'lib/google/apis/compute_alpha/classes.rb', line 52064

def hosts
  @hosts
end

#methods_propArray<String>

HTTP method. Corresponds to the JSON property methods

Returns:

  • (Array<String>)


52069
52070
52071
# File 'lib/google/apis/compute_alpha/classes.rb', line 52069

def methods_prop
  @methods_prop
end

#not_hostsArray<String>

Negate of hosts. Specifies exclusions. Corresponds to the JSON property notHosts

Returns:

  • (Array<String>)


52074
52075
52076
# File 'lib/google/apis/compute_alpha/classes.rb', line 52074

def not_hosts
  @not_hosts
end

#not_methodsArray<String>

Negate of methods. Specifies exclusions. Corresponds to the JSON property notMethods

Returns:

  • (Array<String>)


52079
52080
52081
# File 'lib/google/apis/compute_alpha/classes.rb', line 52079

def not_methods
  @not_methods
end

#not_pathsArray<String>

Negate of paths. Specifies exclusions. Corresponds to the JSON property notPaths

Returns:

  • (Array<String>)


52084
52085
52086
# File 'lib/google/apis/compute_alpha/classes.rb', line 52084

def not_paths
  @not_paths
end

#not_portsArray<String>

Negate of ports. Specifies exclusions. Corresponds to the JSON property notPorts

Returns:

  • (Array<String>)


52089
52090
52091
# File 'lib/google/apis/compute_alpha/classes.rb', line 52089

def not_ports
  @not_ports
end

#pathsArray<String>

HTTP request paths or gRPC methods. Exact match, prefix match, and suffix match are supported. Corresponds to the JSON property paths

Returns:

  • (Array<String>)


52095
52096
52097
# File 'lib/google/apis/compute_alpha/classes.rb', line 52095

def paths
  @paths
end

#portsArray<String>

Port names or numbers. Corresponds to the JSON property ports

Returns:

  • (Array<String>)


52100
52101
52102
# File 'lib/google/apis/compute_alpha/classes.rb', line 52100

def ports
  @ports
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



52107
52108
52109
52110
52111
52112
52113
52114
52115
52116
52117
# File 'lib/google/apis/compute_alpha/classes.rb', line 52107

def update!(**args)
  @constraints = args[:constraints] if args.key?(:constraints)
  @hosts = args[:hosts] if args.key?(:hosts)
  @methods_prop = args[:methods_prop] if args.key?(:methods_prop)
  @not_hosts = args[:not_hosts] if args.key?(:not_hosts)
  @not_methods = args[:not_methods] if args.key?(:not_methods)
  @not_paths = args[:not_paths] if args.key?(:not_paths)
  @not_ports = args[:not_ports] if args.key?(:not_ports)
  @paths = args[:paths] if args.key?(:paths)
  @ports = args[:ports] if args.key?(:ports)
end