Class: Google::Apis::ComputeAlpha::Permission
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::Permission
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
[Deprecated] All fields defined in a permission are ANDed.
Instance Attribute Summary collapse
-
#constraints ⇒ Array<Google::Apis::ComputeAlpha::PermissionConstraint>
Extra custom constraints.
-
#hosts ⇒ Array<String>
Used in Ingress or Egress Gateway cases to specify hosts that the policy applies to.
-
#methods_prop ⇒ Array<String>
HTTP method.
-
#not_hosts ⇒ Array<String>
Negate of hosts.
-
#not_methods ⇒ Array<String>
Negate of methods.
-
#not_paths ⇒ Array<String>
Negate of paths.
-
#not_ports ⇒ Array<String>
Negate of ports.
-
#paths ⇒ Array<String>
HTTP request paths or gRPC methods.
-
#ports ⇒ Array<String>
Port names or numbers.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Permission
constructor
A new instance of Permission.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Permission
Returns a new instance of Permission.
51617 51618 51619 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 51617 def initialize(**args) update!(**args) end |
Instance Attribute Details
#constraints ⇒ Array<Google::Apis::ComputeAlpha::PermissionConstraint>
Extra custom constraints. The constraints are ANDed together.
Corresponds to the JSON property constraints
51573 51574 51575 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 51573 def constraints @constraints end |
#hosts ⇒ Array<String>
Used in Ingress or Egress Gateway cases to specify hosts that the policy
applies to. Exact match, prefix match, and suffix match are supported.
Corresponds to the JSON property hosts
51579 51580 51581 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 51579 def hosts @hosts end |
#methods_prop ⇒ Array<String>
HTTP method.
Corresponds to the JSON property methods
51584 51585 51586 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 51584 def methods_prop @methods_prop end |
#not_hosts ⇒ Array<String>
Negate of hosts. Specifies exclusions.
Corresponds to the JSON property notHosts
51589 51590 51591 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 51589 def not_hosts @not_hosts end |
#not_methods ⇒ Array<String>
Negate of methods. Specifies exclusions.
Corresponds to the JSON property notMethods
51594 51595 51596 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 51594 def not_methods @not_methods end |
#not_paths ⇒ Array<String>
Negate of paths. Specifies exclusions.
Corresponds to the JSON property notPaths
51599 51600 51601 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 51599 def not_paths @not_paths end |
#not_ports ⇒ Array<String>
Negate of ports. Specifies exclusions.
Corresponds to the JSON property notPorts
51604 51605 51606 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 51604 def not_ports @not_ports end |
#paths ⇒ Array<String>
HTTP request paths or gRPC methods.
Exact match, prefix match, and suffix match are supported.
Corresponds to the JSON property paths
51610 51611 51612 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 51610 def paths @paths end |
#ports ⇒ Array<String>
Port names or numbers.
Corresponds to the JSON property ports
51615 51616 51617 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 51615 def ports @ports end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
51622 51623 51624 51625 51626 51627 51628 51629 51630 51631 51632 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 51622 def update!(**args) @constraints = args[:constraints] if args.key?(:constraints) @hosts = args[:hosts] if args.key?(:hosts) @methods_prop = args[:methods_prop] if args.key?(:methods_prop) @not_hosts = args[:not_hosts] if args.key?(:not_hosts) @not_methods = args[:not_methods] if args.key?(:not_methods) @not_paths = args[:not_paths] if args.key?(:not_paths) @not_ports = args[:not_ports] if args.key?(:not_ports) @paths = args[:paths] if args.key?(:paths) @ports = args[:ports] if args.key?(:ports) end |