Class: Google::Apis::ComputeAlpha::Permission
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::Permission
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
[Deprecated] All fields defined in a permission are ANDed.
Instance Attribute Summary collapse
-
#constraints ⇒ Array<Google::Apis::ComputeAlpha::PermissionConstraint>
Extra custom constraints.
-
#hosts ⇒ Array<String>
Used in Ingress or Egress Gateway cases to specify hosts that the policy applies to.
-
#methods_prop ⇒ Array<String>
HTTP method.
-
#not_hosts ⇒ Array<String>
Negate of hosts.
-
#not_methods ⇒ Array<String>
Negate of methods.
-
#not_paths ⇒ Array<String>
Negate of paths.
-
#not_ports ⇒ Array<String>
Negate of ports.
-
#paths ⇒ Array<String>
HTTP request paths or gRPC methods.
-
#ports ⇒ Array<String>
Port names or numbers.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Permission
constructor
A new instance of Permission.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Permission
Returns a new instance of Permission.
51414 51415 51416 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 51414 def initialize(**args) update!(**args) end |
Instance Attribute Details
#constraints ⇒ Array<Google::Apis::ComputeAlpha::PermissionConstraint>
Extra custom constraints. The constraints are ANDed together.
Corresponds to the JSON property constraints
51370 51371 51372 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 51370 def constraints @constraints end |
#hosts ⇒ Array<String>
Used in Ingress or Egress Gateway cases to specify hosts that the policy
applies to. Exact match, prefix match, and suffix match are supported.
Corresponds to the JSON property hosts
51376 51377 51378 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 51376 def hosts @hosts end |
#methods_prop ⇒ Array<String>
HTTP method.
Corresponds to the JSON property methods
51381 51382 51383 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 51381 def methods_prop @methods_prop end |
#not_hosts ⇒ Array<String>
Negate of hosts. Specifies exclusions.
Corresponds to the JSON property notHosts
51386 51387 51388 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 51386 def not_hosts @not_hosts end |
#not_methods ⇒ Array<String>
Negate of methods. Specifies exclusions.
Corresponds to the JSON property notMethods
51391 51392 51393 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 51391 def not_methods @not_methods end |
#not_paths ⇒ Array<String>
Negate of paths. Specifies exclusions.
Corresponds to the JSON property notPaths
51396 51397 51398 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 51396 def not_paths @not_paths end |
#not_ports ⇒ Array<String>
Negate of ports. Specifies exclusions.
Corresponds to the JSON property notPorts
51401 51402 51403 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 51401 def not_ports @not_ports end |
#paths ⇒ Array<String>
HTTP request paths or gRPC methods.
Exact match, prefix match, and suffix match are supported.
Corresponds to the JSON property paths
51407 51408 51409 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 51407 def paths @paths end |
#ports ⇒ Array<String>
Port names or numbers.
Corresponds to the JSON property ports
51412 51413 51414 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 51412 def ports @ports end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
51419 51420 51421 51422 51423 51424 51425 51426 51427 51428 51429 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 51419 def update!(**args) @constraints = args[:constraints] if args.key?(:constraints) @hosts = args[:hosts] if args.key?(:hosts) @methods_prop = args[:methods_prop] if args.key?(:methods_prop) @not_hosts = args[:not_hosts] if args.key?(:not_hosts) @not_methods = args[:not_methods] if args.key?(:not_methods) @not_paths = args[:not_paths] if args.key?(:not_paths) @not_ports = args[:not_ports] if args.key?(:not_ports) @paths = args[:paths] if args.key?(:paths) @ports = args[:ports] if args.key?(:ports) end |