Class: Google::Apis::ComputeAlpha::Permission

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

[Deprecated] All fields defined in a permission are ANDed.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Permission

Returns a new instance of Permission.



50657
50658
50659
# File 'lib/google/apis/compute_alpha/classes.rb', line 50657

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#constraintsArray<Google::Apis::ComputeAlpha::PermissionConstraint>

Extra custom constraints. The constraints are ANDed together. Corresponds to the JSON property constraints



50613
50614
50615
# File 'lib/google/apis/compute_alpha/classes.rb', line 50613

def constraints
  @constraints
end

#hostsArray<String>

Used in Ingress or Egress Gateway cases to specify hosts that the policy applies to. Exact match, prefix match, and suffix match are supported. Corresponds to the JSON property hosts

Returns:

  • (Array<String>)


50619
50620
50621
# File 'lib/google/apis/compute_alpha/classes.rb', line 50619

def hosts
  @hosts
end

#methods_propArray<String>

HTTP method. Corresponds to the JSON property methods

Returns:

  • (Array<String>)


50624
50625
50626
# File 'lib/google/apis/compute_alpha/classes.rb', line 50624

def methods_prop
  @methods_prop
end

#not_hostsArray<String>

Negate of hosts. Specifies exclusions. Corresponds to the JSON property notHosts

Returns:

  • (Array<String>)


50629
50630
50631
# File 'lib/google/apis/compute_alpha/classes.rb', line 50629

def not_hosts
  @not_hosts
end

#not_methodsArray<String>

Negate of methods. Specifies exclusions. Corresponds to the JSON property notMethods

Returns:

  • (Array<String>)


50634
50635
50636
# File 'lib/google/apis/compute_alpha/classes.rb', line 50634

def not_methods
  @not_methods
end

#not_pathsArray<String>

Negate of paths. Specifies exclusions. Corresponds to the JSON property notPaths

Returns:

  • (Array<String>)


50639
50640
50641
# File 'lib/google/apis/compute_alpha/classes.rb', line 50639

def not_paths
  @not_paths
end

#not_portsArray<String>

Negate of ports. Specifies exclusions. Corresponds to the JSON property notPorts

Returns:

  • (Array<String>)


50644
50645
50646
# File 'lib/google/apis/compute_alpha/classes.rb', line 50644

def not_ports
  @not_ports
end

#pathsArray<String>

HTTP request paths or gRPC methods. Exact match, prefix match, and suffix match are supported. Corresponds to the JSON property paths

Returns:

  • (Array<String>)


50650
50651
50652
# File 'lib/google/apis/compute_alpha/classes.rb', line 50650

def paths
  @paths
end

#portsArray<String>

Port names or numbers. Corresponds to the JSON property ports

Returns:

  • (Array<String>)


50655
50656
50657
# File 'lib/google/apis/compute_alpha/classes.rb', line 50655

def ports
  @ports
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



50662
50663
50664
50665
50666
50667
50668
50669
50670
50671
50672
# File 'lib/google/apis/compute_alpha/classes.rb', line 50662

def update!(**args)
  @constraints = args[:constraints] if args.key?(:constraints)
  @hosts = args[:hosts] if args.key?(:hosts)
  @methods_prop = args[:methods_prop] if args.key?(:methods_prop)
  @not_hosts = args[:not_hosts] if args.key?(:not_hosts)
  @not_methods = args[:not_methods] if args.key?(:not_methods)
  @not_paths = args[:not_paths] if args.key?(:not_paths)
  @not_ports = args[:not_ports] if args.key?(:not_ports)
  @paths = args[:paths] if args.key?(:paths)
  @ports = args[:ports] if args.key?(:ports)
end