Class: Google::Apis::ComputeAlpha::PersistentDiskResourceCommitment
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::PersistentDiskResourceCommitment
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Commitment for a particular persistent disk resource.
Instance Attribute Summary collapse
-
#amount ⇒ Fixnum
Required.
-
#dimension_type ⇒ String
The specific dimension of the product for this amount.
-
#product_type ⇒ String
The PD product being committed to.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PersistentDiskResourceCommitment
constructor
A new instance of PersistentDiskResourceCommitment.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PersistentDiskResourceCommitment
Returns a new instance of PersistentDiskResourceCommitment.
52183 52184 52185 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 52183 def initialize(**args) update!(**args) end |
Instance Attribute Details
#amount ⇒ Fixnum
Required. The amount of the resource to commit to, in GiB.
Corresponds to the JSON property amount
52170 52171 52172 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 52170 def amount @amount end |
#dimension_type ⇒ String
The specific dimension of the product for this amount.
Corresponds to the JSON property dimensionType
52175 52176 52177 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 52175 def dimension_type @dimension_type end |
#product_type ⇒ String
The PD product being committed to. All entries in a
Commitment.persistent_disk_resources list must have the same product_type.
Corresponds to the JSON property productType
52181 52182 52183 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 52181 def product_type @product_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
52188 52189 52190 52191 52192 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 52188 def update!(**args) @amount = args[:amount] if args.key?(:amount) @dimension_type = args[:dimension_type] if args.key?(:dimension_type) @product_type = args[:product_type] if args.key?(:product_type) end |