Class: Google::Apis::ComputeAlpha::PersistentDiskResourceCommitment

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Commitment for a particular persistent disk resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PersistentDiskResourceCommitment

Returns a new instance of PersistentDiskResourceCommitment.



52166
52167
52168
# File 'lib/google/apis/compute_alpha/classes.rb', line 52166

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#amountFixnum

Required. The amount of the resource to commit to, in GiB. Corresponds to the JSON property amount

Returns:

  • (Fixnum)


52153
52154
52155
# File 'lib/google/apis/compute_alpha/classes.rb', line 52153

def amount
  @amount
end

#dimension_typeString

The specific dimension of the product for this amount. Corresponds to the JSON property dimensionType

Returns:

  • (String)


52158
52159
52160
# File 'lib/google/apis/compute_alpha/classes.rb', line 52158

def dimension_type
  @dimension_type
end

#product_typeString

The PD product being committed to. All entries in a Commitment.persistent_disk_resources list must have the same product_type. Corresponds to the JSON property productType

Returns:

  • (String)


52164
52165
52166
# File 'lib/google/apis/compute_alpha/classes.rb', line 52164

def product_type
  @product_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



52171
52172
52173
52174
52175
# File 'lib/google/apis/compute_alpha/classes.rb', line 52171

def update!(**args)
  @amount = args[:amount] if args.key?(:amount)
  @dimension_type = args[:dimension_type] if args.key?(:dimension_type)
  @product_type = args[:product_type] if args.key?(:product_type)
end