Class: Google::Apis::ComputeAlpha::PreservedStatePreservedNetworkIp

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PreservedStatePreservedNetworkIp

Returns a new instance of PreservedStatePreservedNetworkIp.



51712
51713
51714
# File 'lib/google/apis/compute_alpha/classes.rb', line 51712

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#auto_deleteString

These stateful IPs will never be released during autohealing, update or VM instance recreate operations. This flag is used to configure if the IP reservation should be deleted after it is no longer used by the group, e.g. when the given instance or the whole group is deleted. Corresponds to the JSON property autoDelete

Returns:

  • (String)


51705
51706
51707
# File 'lib/google/apis/compute_alpha/classes.rb', line 51705

def auto_delete
  @auto_delete
end

#ip_addressGoogle::Apis::ComputeAlpha::PreservedStatePreservedNetworkIpIpAddress

Ip address representation Corresponds to the JSON property ipAddress



51710
51711
51712
# File 'lib/google/apis/compute_alpha/classes.rb', line 51710

def ip_address
  @ip_address
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



51717
51718
51719
51720
# File 'lib/google/apis/compute_alpha/classes.rb', line 51717

def update!(**args)
  @auto_delete = args[:auto_delete] if args.key?(:auto_delete)
  @ip_address = args[:ip_address] if args.key?(:ip_address)
end