Class: Google::Apis::ComputeAlpha::PreservedStatePreservedNetworkIp
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::PreservedStatePreservedNetworkIp
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#auto_delete ⇒ String
These stateful IPs will never be released during autohealing, update or VM instance recreate operations.
-
#ip_address ⇒ Google::Apis::ComputeAlpha::PreservedStatePreservedNetworkIpIpAddress
Ip address representation Corresponds to the JSON property
ipAddress.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PreservedStatePreservedNetworkIp
constructor
A new instance of PreservedStatePreservedNetworkIp.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PreservedStatePreservedNetworkIp
Returns a new instance of PreservedStatePreservedNetworkIp.
50955 50956 50957 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 50955 def initialize(**args) update!(**args) end |
Instance Attribute Details
#auto_delete ⇒ String
These stateful IPs will never be released during autohealing,
update or VM instance recreate operations.
This flag is used to configure if the IP reservation should be deleted
after it is no longer used by the group, e.g. when the given instance
or the whole group is deleted.
Corresponds to the JSON property autoDelete
50948 50949 50950 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 50948 def auto_delete @auto_delete end |
#ip_address ⇒ Google::Apis::ComputeAlpha::PreservedStatePreservedNetworkIpIpAddress
Ip address representation
Corresponds to the JSON property ipAddress
50953 50954 50955 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 50953 def ip_address @ip_address end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
50960 50961 50962 50963 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 50960 def update!(**args) @auto_delete = args[:auto_delete] if args.key?(:auto_delete) @ip_address = args[:ip_address] if args.key?(:ip_address) end |