Class: Google::Apis::ComputeAlpha::PreviewFeatureList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::PreviewFeatureList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::PreviewFeature>
A list of PreviewFeature resources.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::PreviewFeatureList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PreviewFeatureList
constructor
A new instance of PreviewFeatureList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PreviewFeatureList
Returns a new instance of PreviewFeatureList.
53944 53945 53946 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53944 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
53906 53907 53908 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53906 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
53911 53912 53913 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53911 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::PreviewFeature>
A list of PreviewFeature resources.
Corresponds to the JSON property items
53916 53917 53918 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53916 def items @items end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
53926 53927 53928 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53926 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
53931 53932 53933 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53931 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
end_interface: MixerListResponseWithEtagBuilder
Corresponds to the JSON property unreachables
53937 53938 53939 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53937 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::PreviewFeatureList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
53942 53943 53944 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53942 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
53949 53950 53951 53952 53953 53954 53955 53956 53957 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53949 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |