Class: Google::Apis::ComputeAlpha::PreviewFeatureList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PreviewFeatureList

Returns a new instance of PreviewFeatureList.



53659
53660
53661
# File 'lib/google/apis/compute_alpha/classes.rb', line 53659

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


53621
53622
53623
# File 'lib/google/apis/compute_alpha/classes.rb', line 53621

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


53626
53627
53628
# File 'lib/google/apis/compute_alpha/classes.rb', line 53626

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::PreviewFeature>

A list of PreviewFeature resources. Corresponds to the JSON property items



53631
53632
53633
# File 'lib/google/apis/compute_alpha/classes.rb', line 53631

def items
  @items
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


53641
53642
53643
# File 'lib/google/apis/compute_alpha/classes.rb', line 53641

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


53646
53647
53648
# File 'lib/google/apis/compute_alpha/classes.rb', line 53646

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


53652
53653
53654
# File 'lib/google/apis/compute_alpha/classes.rb', line 53652

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::PreviewFeatureList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



53657
53658
53659
# File 'lib/google/apis/compute_alpha/classes.rb', line 53657

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



53664
53665
53666
53667
53668
53669
53670
53671
53672
# File 'lib/google/apis/compute_alpha/classes.rb', line 53664

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end