Class: Google::Apis::ComputeAlpha::PreviewFeatureList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PreviewFeatureList

Returns a new instance of PreviewFeatureList.



52069
52070
52071
# File 'lib/google/apis/compute_alpha/classes.rb', line 52069

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


52031
52032
52033
# File 'lib/google/apis/compute_alpha/classes.rb', line 52031

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


52036
52037
52038
# File 'lib/google/apis/compute_alpha/classes.rb', line 52036

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::PreviewFeature>

A list of PreviewFeature resources. Corresponds to the JSON property items



52041
52042
52043
# File 'lib/google/apis/compute_alpha/classes.rb', line 52041

def items
  @items
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


52051
52052
52053
# File 'lib/google/apis/compute_alpha/classes.rb', line 52051

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


52056
52057
52058
# File 'lib/google/apis/compute_alpha/classes.rb', line 52056

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


52062
52063
52064
# File 'lib/google/apis/compute_alpha/classes.rb', line 52062

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::PreviewFeatureList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



52067
52068
52069
# File 'lib/google/apis/compute_alpha/classes.rb', line 52067

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



52074
52075
52076
52077
52078
52079
52080
52081
52082
# File 'lib/google/apis/compute_alpha/classes.rb', line 52074

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end