Class: Google::Apis::ComputeAlpha::PreviewFeatureList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::PreviewFeatureList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::PreviewFeature>
A list of PreviewFeature resources.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::PreviewFeatureList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PreviewFeatureList
constructor
A new instance of PreviewFeatureList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PreviewFeatureList
Returns a new instance of PreviewFeatureList.
51109 51110 51111 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 51109 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
51071 51072 51073 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 51071 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
51076 51077 51078 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 51076 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::PreviewFeature>
A list of PreviewFeature resources.
Corresponds to the JSON property items
51081 51082 51083 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 51081 def items @items end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
51091 51092 51093 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 51091 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
51096 51097 51098 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 51096 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
end_interface: MixerListResponseWithEtagBuilder
Corresponds to the JSON property unreachables
51102 51103 51104 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 51102 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::PreviewFeatureList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
51107 51108 51109 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 51107 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
51114 51115 51116 51117 51118 51119 51120 51121 51122 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 51114 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |