Class: Google::Apis::ComputeAlpha::Principal
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::Principal
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
[Deprecated] All fields defined in a principal are ANDed.
Instance Attribute Summary collapse
-
#condition ⇒ String
An expression to specify custom condition.
-
#groups ⇒ Array<String>
The groups the principal belongs to.
-
#ips ⇒ Array<String>
IPv4 or IPv6 address or range (In CIDR format) Corresponds to the JSON property
ips. -
#namespaces ⇒ Array<String>
The namespaces.
-
#not_groups ⇒ Array<String>
Negate of groups.
-
#not_ips ⇒ Array<String>
Negate of IPs.
-
#not_namespaces ⇒ Array<String>
Negate of namespaces.
-
#not_users ⇒ Array<String>
Negate of users.
-
#properties ⇒ Hash<String,String>
A map of Istio attribute to expected values.
-
#users ⇒ Array<String>
The user names/IDs or service accounts.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Principal
constructor
A new instance of Principal.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Principal
Returns a new instance of Principal.
53921 53922 53923 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53921 def initialize(**args) update!(**args) end |
Instance Attribute Details
#condition ⇒ String
An expression to specify custom condition.
Corresponds to the JSON property condition
53870 53871 53872 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53870 def condition @condition end |
#groups ⇒ Array<String>
The groups the principal belongs to.
Exact match, prefix match, and suffix match are supported.
Corresponds to the JSON property groups
53876 53877 53878 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53876 def groups @groups end |
#ips ⇒ Array<String>
IPv4 or IPv6 address or range (In CIDR format)
Corresponds to the JSON property ips
53881 53882 53883 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53881 def ips @ips end |
#namespaces ⇒ Array<String>
The namespaces. Exact match, prefix match, and suffix match are supported.
Corresponds to the JSON property namespaces
53886 53887 53888 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53886 def namespaces @namespaces end |
#not_groups ⇒ Array<String>
Negate of groups. Specifies exclusions.
Corresponds to the JSON property notGroups
53891 53892 53893 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53891 def not_groups @not_groups end |
#not_ips ⇒ Array<String>
Negate of IPs. Specifies exclusions.
Corresponds to the JSON property notIps
53896 53897 53898 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53896 def not_ips @not_ips end |
#not_namespaces ⇒ Array<String>
Negate of namespaces. Specifies exclusions.
Corresponds to the JSON property notNamespaces
53901 53902 53903 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53901 def not_namespaces @not_namespaces end |
#not_users ⇒ Array<String>
Negate of users. Specifies exclusions.
Corresponds to the JSON property notUsers
53906 53907 53908 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53906 def not_users @not_users end |
#properties ⇒ Hash<String,String>
A map of Istio attribute to expected values. Exact match, prefix match, and
suffix match are supported for values. For example,
request.headers[version]: "v1". The properties are ANDed together.
Corresponds to the JSON property properties
53913 53914 53915 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53913 def properties @properties end |
#users ⇒ Array<String>
The user names/IDs or service accounts.
Exact match, prefix match, and suffix match are supported.
Corresponds to the JSON property users
53919 53920 53921 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53919 def users @users end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
53926 53927 53928 53929 53930 53931 53932 53933 53934 53935 53936 53937 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53926 def update!(**args) @condition = args[:condition] if args.key?(:condition) @groups = args[:groups] if args.key?(:groups) @ips = args[:ips] if args.key?(:ips) @namespaces = args[:namespaces] if args.key?(:namespaces) @not_groups = args[:not_groups] if args.key?(:not_groups) @not_ips = args[:not_ips] if args.key?(:not_ips) @not_namespaces = args[:not_namespaces] if args.key?(:not_namespaces) @not_users = args[:not_users] if args.key?(:not_users) @properties = args[:properties] if args.key?(:properties) @users = args[:users] if args.key?(:users) end |