Class: Google::Apis::ComputeAlpha::Principal

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

[Deprecated] All fields defined in a principal are ANDed.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Principal

Returns a new instance of Principal.



52865
52866
52867
# File 'lib/google/apis/compute_alpha/classes.rb', line 52865

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#conditionString

An expression to specify custom condition. Corresponds to the JSON property condition

Returns:

  • (String)


52814
52815
52816
# File 'lib/google/apis/compute_alpha/classes.rb', line 52814

def condition
  @condition
end

#groupsArray<String>

The groups the principal belongs to. Exact match, prefix match, and suffix match are supported. Corresponds to the JSON property groups

Returns:

  • (Array<String>)


52820
52821
52822
# File 'lib/google/apis/compute_alpha/classes.rb', line 52820

def groups
  @groups
end

#ipsArray<String>

IPv4 or IPv6 address or range (In CIDR format) Corresponds to the JSON property ips

Returns:

  • (Array<String>)


52825
52826
52827
# File 'lib/google/apis/compute_alpha/classes.rb', line 52825

def ips
  @ips
end

#namespacesArray<String>

The namespaces. Exact match, prefix match, and suffix match are supported. Corresponds to the JSON property namespaces

Returns:

  • (Array<String>)


52830
52831
52832
# File 'lib/google/apis/compute_alpha/classes.rb', line 52830

def namespaces
  @namespaces
end

#not_groupsArray<String>

Negate of groups. Specifies exclusions. Corresponds to the JSON property notGroups

Returns:

  • (Array<String>)


52835
52836
52837
# File 'lib/google/apis/compute_alpha/classes.rb', line 52835

def not_groups
  @not_groups
end

#not_ipsArray<String>

Negate of IPs. Specifies exclusions. Corresponds to the JSON property notIps

Returns:

  • (Array<String>)


52840
52841
52842
# File 'lib/google/apis/compute_alpha/classes.rb', line 52840

def not_ips
  @not_ips
end

#not_namespacesArray<String>

Negate of namespaces. Specifies exclusions. Corresponds to the JSON property notNamespaces

Returns:

  • (Array<String>)


52845
52846
52847
# File 'lib/google/apis/compute_alpha/classes.rb', line 52845

def not_namespaces
  @not_namespaces
end

#not_usersArray<String>

Negate of users. Specifies exclusions. Corresponds to the JSON property notUsers

Returns:

  • (Array<String>)


52850
52851
52852
# File 'lib/google/apis/compute_alpha/classes.rb', line 52850

def not_users
  @not_users
end

#propertiesHash<String,String>

A map of Istio attribute to expected values. Exact match, prefix match, and suffix match are supported for values. For example, request.headers[version]: "v1". The properties are ANDed together. Corresponds to the JSON property properties

Returns:

  • (Hash<String,String>)


52857
52858
52859
# File 'lib/google/apis/compute_alpha/classes.rb', line 52857

def properties
  @properties
end

#usersArray<String>

The user names/IDs or service accounts. Exact match, prefix match, and suffix match are supported. Corresponds to the JSON property users

Returns:

  • (Array<String>)


52863
52864
52865
# File 'lib/google/apis/compute_alpha/classes.rb', line 52863

def users
  @users
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



52870
52871
52872
52873
52874
52875
52876
52877
52878
52879
52880
52881
# File 'lib/google/apis/compute_alpha/classes.rb', line 52870

def update!(**args)
  @condition = args[:condition] if args.key?(:condition)
  @groups = args[:groups] if args.key?(:groups)
  @ips = args[:ips] if args.key?(:ips)
  @namespaces = args[:namespaces] if args.key?(:namespaces)
  @not_groups = args[:not_groups] if args.key?(:not_groups)
  @not_ips = args[:not_ips] if args.key?(:not_ips)
  @not_namespaces = args[:not_namespaces] if args.key?(:not_namespaces)
  @not_users = args[:not_users] if args.key?(:not_users)
  @properties = args[:properties] if args.key?(:properties)
  @users = args[:users] if args.key?(:users)
end