Class: Google::Apis::ComputeAlpha::Principal

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

[Deprecated] All fields defined in a principal are ANDed.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Principal

Returns a new instance of Principal.



52848
52849
52850
# File 'lib/google/apis/compute_alpha/classes.rb', line 52848

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#conditionString

An expression to specify custom condition. Corresponds to the JSON property condition

Returns:

  • (String)


52797
52798
52799
# File 'lib/google/apis/compute_alpha/classes.rb', line 52797

def condition
  @condition
end

#groupsArray<String>

The groups the principal belongs to. Exact match, prefix match, and suffix match are supported. Corresponds to the JSON property groups

Returns:

  • (Array<String>)


52803
52804
52805
# File 'lib/google/apis/compute_alpha/classes.rb', line 52803

def groups
  @groups
end

#ipsArray<String>

IPv4 or IPv6 address or range (In CIDR format) Corresponds to the JSON property ips

Returns:

  • (Array<String>)


52808
52809
52810
# File 'lib/google/apis/compute_alpha/classes.rb', line 52808

def ips
  @ips
end

#namespacesArray<String>

The namespaces. Exact match, prefix match, and suffix match are supported. Corresponds to the JSON property namespaces

Returns:

  • (Array<String>)


52813
52814
52815
# File 'lib/google/apis/compute_alpha/classes.rb', line 52813

def namespaces
  @namespaces
end

#not_groupsArray<String>

Negate of groups. Specifies exclusions. Corresponds to the JSON property notGroups

Returns:

  • (Array<String>)


52818
52819
52820
# File 'lib/google/apis/compute_alpha/classes.rb', line 52818

def not_groups
  @not_groups
end

#not_ipsArray<String>

Negate of IPs. Specifies exclusions. Corresponds to the JSON property notIps

Returns:

  • (Array<String>)


52823
52824
52825
# File 'lib/google/apis/compute_alpha/classes.rb', line 52823

def not_ips
  @not_ips
end

#not_namespacesArray<String>

Negate of namespaces. Specifies exclusions. Corresponds to the JSON property notNamespaces

Returns:

  • (Array<String>)


52828
52829
52830
# File 'lib/google/apis/compute_alpha/classes.rb', line 52828

def not_namespaces
  @not_namespaces
end

#not_usersArray<String>

Negate of users. Specifies exclusions. Corresponds to the JSON property notUsers

Returns:

  • (Array<String>)


52833
52834
52835
# File 'lib/google/apis/compute_alpha/classes.rb', line 52833

def not_users
  @not_users
end

#propertiesHash<String,String>

A map of Istio attribute to expected values. Exact match, prefix match, and suffix match are supported for values. For example, request.headers[version]: "v1". The properties are ANDed together. Corresponds to the JSON property properties

Returns:

  • (Hash<String,String>)


52840
52841
52842
# File 'lib/google/apis/compute_alpha/classes.rb', line 52840

def properties
  @properties
end

#usersArray<String>

The user names/IDs or service accounts. Exact match, prefix match, and suffix match are supported. Corresponds to the JSON property users

Returns:

  • (Array<String>)


52846
52847
52848
# File 'lib/google/apis/compute_alpha/classes.rb', line 52846

def users
  @users
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



52853
52854
52855
52856
52857
52858
52859
52860
52861
52862
52863
52864
# File 'lib/google/apis/compute_alpha/classes.rb', line 52853

def update!(**args)
  @condition = args[:condition] if args.key?(:condition)
  @groups = args[:groups] if args.key?(:groups)
  @ips = args[:ips] if args.key?(:ips)
  @namespaces = args[:namespaces] if args.key?(:namespaces)
  @not_groups = args[:not_groups] if args.key?(:not_groups)
  @not_ips = args[:not_ips] if args.key?(:not_ips)
  @not_namespaces = args[:not_namespaces] if args.key?(:not_namespaces)
  @not_users = args[:not_users] if args.key?(:not_users)
  @properties = args[:properties] if args.key?(:properties)
  @users = args[:users] if args.key?(:users)
end