Class: Google::Apis::ComputeAlpha::Principal

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

[Deprecated] All fields defined in a principal are ANDed.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Principal

Returns a new instance of Principal.



52331
52332
52333
# File 'lib/google/apis/compute_alpha/classes.rb', line 52331

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#conditionString

An expression to specify custom condition. Corresponds to the JSON property condition

Returns:

  • (String)


52280
52281
52282
# File 'lib/google/apis/compute_alpha/classes.rb', line 52280

def condition
  @condition
end

#groupsArray<String>

The groups the principal belongs to. Exact match, prefix match, and suffix match are supported. Corresponds to the JSON property groups

Returns:

  • (Array<String>)


52286
52287
52288
# File 'lib/google/apis/compute_alpha/classes.rb', line 52286

def groups
  @groups
end

#ipsArray<String>

IPv4 or IPv6 address or range (In CIDR format) Corresponds to the JSON property ips

Returns:

  • (Array<String>)


52291
52292
52293
# File 'lib/google/apis/compute_alpha/classes.rb', line 52291

def ips
  @ips
end

#namespacesArray<String>

The namespaces. Exact match, prefix match, and suffix match are supported. Corresponds to the JSON property namespaces

Returns:

  • (Array<String>)


52296
52297
52298
# File 'lib/google/apis/compute_alpha/classes.rb', line 52296

def namespaces
  @namespaces
end

#not_groupsArray<String>

Negate of groups. Specifies exclusions. Corresponds to the JSON property notGroups

Returns:

  • (Array<String>)


52301
52302
52303
# File 'lib/google/apis/compute_alpha/classes.rb', line 52301

def not_groups
  @not_groups
end

#not_ipsArray<String>

Negate of IPs. Specifies exclusions. Corresponds to the JSON property notIps

Returns:

  • (Array<String>)


52306
52307
52308
# File 'lib/google/apis/compute_alpha/classes.rb', line 52306

def not_ips
  @not_ips
end

#not_namespacesArray<String>

Negate of namespaces. Specifies exclusions. Corresponds to the JSON property notNamespaces

Returns:

  • (Array<String>)


52311
52312
52313
# File 'lib/google/apis/compute_alpha/classes.rb', line 52311

def not_namespaces
  @not_namespaces
end

#not_usersArray<String>

Negate of users. Specifies exclusions. Corresponds to the JSON property notUsers

Returns:

  • (Array<String>)


52316
52317
52318
# File 'lib/google/apis/compute_alpha/classes.rb', line 52316

def not_users
  @not_users
end

#propertiesHash<String,String>

A map of Istio attribute to expected values. Exact match, prefix match, and suffix match are supported for values. For example, request.headers[version]: "v1". The properties are ANDed together. Corresponds to the JSON property properties

Returns:

  • (Hash<String,String>)


52323
52324
52325
# File 'lib/google/apis/compute_alpha/classes.rb', line 52323

def properties
  @properties
end

#usersArray<String>

The user names/IDs or service accounts. Exact match, prefix match, and suffix match are supported. Corresponds to the JSON property users

Returns:

  • (Array<String>)


52329
52330
52331
# File 'lib/google/apis/compute_alpha/classes.rb', line 52329

def users
  @users
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



52336
52337
52338
52339
52340
52341
52342
52343
52344
52345
52346
52347
# File 'lib/google/apis/compute_alpha/classes.rb', line 52336

def update!(**args)
  @condition = args[:condition] if args.key?(:condition)
  @groups = args[:groups] if args.key?(:groups)
  @ips = args[:ips] if args.key?(:ips)
  @namespaces = args[:namespaces] if args.key?(:namespaces)
  @not_groups = args[:not_groups] if args.key?(:not_groups)
  @not_ips = args[:not_ips] if args.key?(:not_ips)
  @not_namespaces = args[:not_namespaces] if args.key?(:not_namespaces)
  @not_users = args[:not_users] if args.key?(:not_users)
  @properties = args[:properties] if args.key?(:properties)
  @users = args[:users] if args.key?(:users)
end