Class: Google::Apis::ComputeAlpha::Principal

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

[Deprecated] All fields defined in a principal are ANDed.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Principal

Returns a new instance of Principal.



52128
52129
52130
# File 'lib/google/apis/compute_alpha/classes.rb', line 52128

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#conditionString

An expression to specify custom condition. Corresponds to the JSON property condition

Returns:

  • (String)


52077
52078
52079
# File 'lib/google/apis/compute_alpha/classes.rb', line 52077

def condition
  @condition
end

#groupsArray<String>

The groups the principal belongs to. Exact match, prefix match, and suffix match are supported. Corresponds to the JSON property groups

Returns:

  • (Array<String>)


52083
52084
52085
# File 'lib/google/apis/compute_alpha/classes.rb', line 52083

def groups
  @groups
end

#ipsArray<String>

IPv4 or IPv6 address or range (In CIDR format) Corresponds to the JSON property ips

Returns:

  • (Array<String>)


52088
52089
52090
# File 'lib/google/apis/compute_alpha/classes.rb', line 52088

def ips
  @ips
end

#namespacesArray<String>

The namespaces. Exact match, prefix match, and suffix match are supported. Corresponds to the JSON property namespaces

Returns:

  • (Array<String>)


52093
52094
52095
# File 'lib/google/apis/compute_alpha/classes.rb', line 52093

def namespaces
  @namespaces
end

#not_groupsArray<String>

Negate of groups. Specifies exclusions. Corresponds to the JSON property notGroups

Returns:

  • (Array<String>)


52098
52099
52100
# File 'lib/google/apis/compute_alpha/classes.rb', line 52098

def not_groups
  @not_groups
end

#not_ipsArray<String>

Negate of IPs. Specifies exclusions. Corresponds to the JSON property notIps

Returns:

  • (Array<String>)


52103
52104
52105
# File 'lib/google/apis/compute_alpha/classes.rb', line 52103

def not_ips
  @not_ips
end

#not_namespacesArray<String>

Negate of namespaces. Specifies exclusions. Corresponds to the JSON property notNamespaces

Returns:

  • (Array<String>)


52108
52109
52110
# File 'lib/google/apis/compute_alpha/classes.rb', line 52108

def not_namespaces
  @not_namespaces
end

#not_usersArray<String>

Negate of users. Specifies exclusions. Corresponds to the JSON property notUsers

Returns:

  • (Array<String>)


52113
52114
52115
# File 'lib/google/apis/compute_alpha/classes.rb', line 52113

def not_users
  @not_users
end

#propertiesHash<String,String>

A map of Istio attribute to expected values. Exact match, prefix match, and suffix match are supported for values. For example, request.headers[version]: "v1". The properties are ANDed together. Corresponds to the JSON property properties

Returns:

  • (Hash<String,String>)


52120
52121
52122
# File 'lib/google/apis/compute_alpha/classes.rb', line 52120

def properties
  @properties
end

#usersArray<String>

The user names/IDs or service accounts. Exact match, prefix match, and suffix match are supported. Corresponds to the JSON property users

Returns:

  • (Array<String>)


52126
52127
52128
# File 'lib/google/apis/compute_alpha/classes.rb', line 52126

def users
  @users
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



52133
52134
52135
52136
52137
52138
52139
52140
52141
52142
52143
52144
# File 'lib/google/apis/compute_alpha/classes.rb', line 52133

def update!(**args)
  @condition = args[:condition] if args.key?(:condition)
  @groups = args[:groups] if args.key?(:groups)
  @ips = args[:ips] if args.key?(:ips)
  @namespaces = args[:namespaces] if args.key?(:namespaces)
  @not_groups = args[:not_groups] if args.key?(:not_groups)
  @not_ips = args[:not_ips] if args.key?(:not_ips)
  @not_namespaces = args[:not_namespaces] if args.key?(:not_namespaces)
  @not_users = args[:not_users] if args.key?(:not_users)
  @properties = args[:properties] if args.key?(:properties)
  @users = args[:users] if args.key?(:users)
end