Class: Google::Apis::ComputeAlpha::Principal
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::Principal
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
[Deprecated] All fields defined in a principal are ANDed.
Instance Attribute Summary collapse
-
#condition ⇒ String
An expression to specify custom condition.
-
#groups ⇒ Array<String>
The groups the principal belongs to.
-
#ips ⇒ Array<String>
IPv4 or IPv6 address or range (In CIDR format) Corresponds to the JSON property
ips. -
#namespaces ⇒ Array<String>
The namespaces.
-
#not_groups ⇒ Array<String>
Negate of groups.
-
#not_ips ⇒ Array<String>
Negate of IPs.
-
#not_namespaces ⇒ Array<String>
Negate of namespaces.
-
#not_users ⇒ Array<String>
Negate of users.
-
#properties ⇒ Hash<String,String>
A map of Istio attribute to expected values.
-
#users ⇒ Array<String>
The user names/IDs or service accounts.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Principal
constructor
A new instance of Principal.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Principal
Returns a new instance of Principal.
52128 52129 52130 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 52128 def initialize(**args) update!(**args) end |
Instance Attribute Details
#condition ⇒ String
An expression to specify custom condition.
Corresponds to the JSON property condition
52077 52078 52079 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 52077 def condition @condition end |
#groups ⇒ Array<String>
The groups the principal belongs to.
Exact match, prefix match, and suffix match are supported.
Corresponds to the JSON property groups
52083 52084 52085 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 52083 def groups @groups end |
#ips ⇒ Array<String>
IPv4 or IPv6 address or range (In CIDR format)
Corresponds to the JSON property ips
52088 52089 52090 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 52088 def ips @ips end |
#namespaces ⇒ Array<String>
The namespaces. Exact match, prefix match, and suffix match are supported.
Corresponds to the JSON property namespaces
52093 52094 52095 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 52093 def namespaces @namespaces end |
#not_groups ⇒ Array<String>
Negate of groups. Specifies exclusions.
Corresponds to the JSON property notGroups
52098 52099 52100 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 52098 def not_groups @not_groups end |
#not_ips ⇒ Array<String>
Negate of IPs. Specifies exclusions.
Corresponds to the JSON property notIps
52103 52104 52105 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 52103 def not_ips @not_ips end |
#not_namespaces ⇒ Array<String>
Negate of namespaces. Specifies exclusions.
Corresponds to the JSON property notNamespaces
52108 52109 52110 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 52108 def not_namespaces @not_namespaces end |
#not_users ⇒ Array<String>
Negate of users. Specifies exclusions.
Corresponds to the JSON property notUsers
52113 52114 52115 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 52113 def not_users @not_users end |
#properties ⇒ Hash<String,String>
A map of Istio attribute to expected values. Exact match, prefix match, and
suffix match are supported for values. For example,
request.headers[version]: "v1". The properties are ANDed together.
Corresponds to the JSON property properties
52120 52121 52122 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 52120 def properties @properties end |
#users ⇒ Array<String>
The user names/IDs or service accounts.
Exact match, prefix match, and suffix match are supported.
Corresponds to the JSON property users
52126 52127 52128 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 52126 def users @users end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
52133 52134 52135 52136 52137 52138 52139 52140 52141 52142 52143 52144 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 52133 def update!(**args) @condition = args[:condition] if args.key?(:condition) @groups = args[:groups] if args.key?(:groups) @ips = args[:ips] if args.key?(:ips) @namespaces = args[:namespaces] if args.key?(:namespaces) @not_groups = args[:not_groups] if args.key?(:not_groups) @not_ips = args[:not_ips] if args.key?(:not_ips) @not_namespaces = args[:not_namespaces] if args.key?(:not_namespaces) @not_users = args[:not_users] if args.key?(:not_users) @properties = args[:properties] if args.key?(:properties) @users = args[:users] if args.key?(:users) end |