Class: Google::Apis::ComputeAlpha::Project

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Represents a Project resource. A project is used to organize resources in a Google Cloud Platform environment. For more information, read about the Resource Hierarchy.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Project

Returns a new instance of Project.



52972
52973
52974
# File 'lib/google/apis/compute_alpha/classes.rb', line 52972

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cloud_armor_tierString

Output only. [Output Only] The Cloud Armor tier for this project. It can be one of the following values: CA_STANDARD,CA_ENTERPRISE_PAYGO. If this field is not specified, it is assumed to beCA_STANDARD. Corresponds to the JSON property cloudArmorTier

Returns:

  • (String)


52880
52881
52882
# File 'lib/google/apis/compute_alpha/classes.rb', line 52880

def cloud_armor_tier
  @cloud_armor_tier
end

#common_instance_metadataGoogle::Apis::ComputeAlpha::Metadata

A metadata key/value entry. Corresponds to the JSON property commonInstanceMetadata



52885
52886
52887
# File 'lib/google/apis/compute_alpha/classes.rb', line 52885

def 
  @common_instance_metadata
end

#creation_timestampString

[Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


52891
52892
52893
# File 'lib/google/apis/compute_alpha/classes.rb', line 52891

def creation_timestamp
  @creation_timestamp
end

#default_network_tierString

This signifies the default network tier used for configuring resources of the project and can only take the following values:PREMIUM, STANDARD. Initially the default network tier is PREMIUM. Corresponds to the JSON property defaultNetworkTier

Returns:

  • (String)


52899
52900
52901
# File 'lib/google/apis/compute_alpha/classes.rb', line 52899

def default_network_tier
  @default_network_tier
end

#default_service_accountString

[Output Only] Default service account used by VMs running in this project. Corresponds to the JSON property defaultServiceAccount

Returns:

  • (String)


52904
52905
52906
# File 'lib/google/apis/compute_alpha/classes.rb', line 52904

def 
  @default_service_account
end

#descriptionString

An optional textual description of the resource. Corresponds to the JSON property description

Returns:

  • (String)


52909
52910
52911
# File 'lib/google/apis/compute_alpha/classes.rb', line 52909

def description
  @description
end

#enabled_featuresArray<String>

An optional list of restricted features enabled for use on this project. Corresponds to the JSON property enabledFeatures

Returns:

  • (Array<String>)


52914
52915
52916
# File 'lib/google/apis/compute_alpha/classes.rb', line 52914

def enabled_features
  @enabled_features
end

#idFixnum

[Output Only] The unique identifier for the resource. This identifier is defined by the server. This is not the project ID, and is just a unique ID used by Compute Engine to identify resources. Corresponds to the JSON property id

Returns:

  • (Fixnum)


52921
52922
52923
# File 'lib/google/apis/compute_alpha/classes.rb', line 52921

def id
  @id
end

#kindString

Output only. [Output Only] Type of the resource. Always compute#project for projects. Corresponds to the JSON property kind

Returns:

  • (String)


52927
52928
52929
# File 'lib/google/apis/compute_alpha/classes.rb', line 52927

def kind
  @kind
end

#managed_protection_tierString

Output only. [Output Only] The Cloud Armor Managed Protection (CAMP) tier for this project. It can be one of the following values:CA_STANDARD, CAMP_PLUS_PAYGO. If this field is not specified, it is assumed to beCA_STANDARD. Corresponds to the JSON property managedProtectionTier

Returns:

  • (String)


52935
52936
52937
# File 'lib/google/apis/compute_alpha/classes.rb', line 52935

def managed_protection_tier
  @managed_protection_tier
end

#nameString

The project ID. For example: my-example-project. Use the project ID to make requests to Compute Engine. Corresponds to the JSON property name

Returns:

  • (String)


52941
52942
52943
# File 'lib/google/apis/compute_alpha/classes.rb', line 52941

def name
  @name
end

#quotasArray<Google::Apis::ComputeAlpha::Quota>

[Output Only] Quotas assigned to this project. Corresponds to the JSON property quotas



52946
52947
52948
# File 'lib/google/apis/compute_alpha/classes.rb', line 52946

def quotas
  @quotas
end

[Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


52951
52952
52953
# File 'lib/google/apis/compute_alpha/classes.rb', line 52951

def self_link
  @self_link
end

#usage_export_locationGoogle::Apis::ComputeAlpha::UsageExportLocation

The location in Cloud Storage and naming method of the daily usage report. Contains bucket_name and report_name prefix. Corresponds to the JSON property usageExportLocation



52957
52958
52959
# File 'lib/google/apis/compute_alpha/classes.rb', line 52957

def usage_export_location
  @usage_export_location
end

#vm_dns_settingString

Output only. [Output Only] Default internal DNS setting used by VMs running in this project. Corresponds to the JSON property vmDnsSetting

Returns:

  • (String)


52963
52964
52965
# File 'lib/google/apis/compute_alpha/classes.rb', line 52963

def vm_dns_setting
  @vm_dns_setting
end

#xpn_project_statusString

[Output Only] The role this project has in a shared VPC configuration. Currently, only projects with the host role, which is specified by the value HOST, are differentiated. Corresponds to the JSON property xpnProjectStatus

Returns:

  • (String)


52970
52971
52972
# File 'lib/google/apis/compute_alpha/classes.rb', line 52970

def xpn_project_status
  @xpn_project_status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



52977
52978
52979
52980
52981
52982
52983
52984
52985
52986
52987
52988
52989
52990
52991
52992
52993
52994
# File 'lib/google/apis/compute_alpha/classes.rb', line 52977

def update!(**args)
  @cloud_armor_tier = args[:cloud_armor_tier] if args.key?(:cloud_armor_tier)
  @common_instance_metadata = args[:common_instance_metadata] if args.key?(:common_instance_metadata)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @default_network_tier = args[:default_network_tier] if args.key?(:default_network_tier)
  @default_service_account = args[:default_service_account] if args.key?(:default_service_account)
  @description = args[:description] if args.key?(:description)
  @enabled_features = args[:enabled_features] if args.key?(:enabled_features)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @managed_protection_tier = args[:managed_protection_tier] if args.key?(:managed_protection_tier)
  @name = args[:name] if args.key?(:name)
  @quotas = args[:quotas] if args.key?(:quotas)
  @self_link = args[:self_link] if args.key?(:self_link)
  @usage_export_location = args[:usage_export_location] if args.key?(:usage_export_location)
  @vm_dns_setting = args[:vm_dns_setting] if args.key?(:vm_dns_setting)
  @xpn_project_status = args[:xpn_project_status] if args.key?(:xpn_project_status)
end