Class: Google::Apis::ComputeAlpha::Project

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Represents a Project resource. A project is used to organize resources in a Google Cloud Platform environment. For more information, read about the Resource Hierarchy.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Project

Returns a new instance of Project.



52455
52456
52457
# File 'lib/google/apis/compute_alpha/classes.rb', line 52455

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cloud_armor_tierString

Output only. [Output Only] The Cloud Armor tier for this project. It can be one of the following values: CA_STANDARD,CA_ENTERPRISE_PAYGO. If this field is not specified, it is assumed to beCA_STANDARD. Corresponds to the JSON property cloudArmorTier

Returns:

  • (String)


52363
52364
52365
# File 'lib/google/apis/compute_alpha/classes.rb', line 52363

def cloud_armor_tier
  @cloud_armor_tier
end

#common_instance_metadataGoogle::Apis::ComputeAlpha::Metadata

A metadata key/value entry. Corresponds to the JSON property commonInstanceMetadata



52368
52369
52370
# File 'lib/google/apis/compute_alpha/classes.rb', line 52368

def 
  @common_instance_metadata
end

#creation_timestampString

[Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


52374
52375
52376
# File 'lib/google/apis/compute_alpha/classes.rb', line 52374

def creation_timestamp
  @creation_timestamp
end

#default_network_tierString

This signifies the default network tier used for configuring resources of the project and can only take the following values:PREMIUM, STANDARD. Initially the default network tier is PREMIUM. Corresponds to the JSON property defaultNetworkTier

Returns:

  • (String)


52382
52383
52384
# File 'lib/google/apis/compute_alpha/classes.rb', line 52382

def default_network_tier
  @default_network_tier
end

#default_service_accountString

[Output Only] Default service account used by VMs running in this project. Corresponds to the JSON property defaultServiceAccount

Returns:

  • (String)


52387
52388
52389
# File 'lib/google/apis/compute_alpha/classes.rb', line 52387

def 
  @default_service_account
end

#descriptionString

An optional textual description of the resource. Corresponds to the JSON property description

Returns:

  • (String)


52392
52393
52394
# File 'lib/google/apis/compute_alpha/classes.rb', line 52392

def description
  @description
end

#enabled_featuresArray<String>

An optional list of restricted features enabled for use on this project. Corresponds to the JSON property enabledFeatures

Returns:

  • (Array<String>)


52397
52398
52399
# File 'lib/google/apis/compute_alpha/classes.rb', line 52397

def enabled_features
  @enabled_features
end

#idFixnum

[Output Only] The unique identifier for the resource. This identifier is defined by the server. This is not the project ID, and is just a unique ID used by Compute Engine to identify resources. Corresponds to the JSON property id

Returns:

  • (Fixnum)


52404
52405
52406
# File 'lib/google/apis/compute_alpha/classes.rb', line 52404

def id
  @id
end

#kindString

Output only. [Output Only] Type of the resource. Always compute#project for projects. Corresponds to the JSON property kind

Returns:

  • (String)


52410
52411
52412
# File 'lib/google/apis/compute_alpha/classes.rb', line 52410

def kind
  @kind
end

#managed_protection_tierString

Output only. [Output Only] The Cloud Armor Managed Protection (CAMP) tier for this project. It can be one of the following values:CA_STANDARD, CAMP_PLUS_PAYGO. If this field is not specified, it is assumed to beCA_STANDARD. Corresponds to the JSON property managedProtectionTier

Returns:

  • (String)


52418
52419
52420
# File 'lib/google/apis/compute_alpha/classes.rb', line 52418

def managed_protection_tier
  @managed_protection_tier
end

#nameString

The project ID. For example: my-example-project. Use the project ID to make requests to Compute Engine. Corresponds to the JSON property name

Returns:

  • (String)


52424
52425
52426
# File 'lib/google/apis/compute_alpha/classes.rb', line 52424

def name
  @name
end

#quotasArray<Google::Apis::ComputeAlpha::Quota>

[Output Only] Quotas assigned to this project. Corresponds to the JSON property quotas



52429
52430
52431
# File 'lib/google/apis/compute_alpha/classes.rb', line 52429

def quotas
  @quotas
end

[Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


52434
52435
52436
# File 'lib/google/apis/compute_alpha/classes.rb', line 52434

def self_link
  @self_link
end

#usage_export_locationGoogle::Apis::ComputeAlpha::UsageExportLocation

The location in Cloud Storage and naming method of the daily usage report. Contains bucket_name and report_name prefix. Corresponds to the JSON property usageExportLocation



52440
52441
52442
# File 'lib/google/apis/compute_alpha/classes.rb', line 52440

def usage_export_location
  @usage_export_location
end

#vm_dns_settingString

Output only. [Output Only] Default internal DNS setting used by VMs running in this project. Corresponds to the JSON property vmDnsSetting

Returns:

  • (String)


52446
52447
52448
# File 'lib/google/apis/compute_alpha/classes.rb', line 52446

def vm_dns_setting
  @vm_dns_setting
end

#xpn_project_statusString

[Output Only] The role this project has in a shared VPC configuration. Currently, only projects with the host role, which is specified by the value HOST, are differentiated. Corresponds to the JSON property xpnProjectStatus

Returns:

  • (String)


52453
52454
52455
# File 'lib/google/apis/compute_alpha/classes.rb', line 52453

def xpn_project_status
  @xpn_project_status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



52460
52461
52462
52463
52464
52465
52466
52467
52468
52469
52470
52471
52472
52473
52474
52475
52476
52477
# File 'lib/google/apis/compute_alpha/classes.rb', line 52460

def update!(**args)
  @cloud_armor_tier = args[:cloud_armor_tier] if args.key?(:cloud_armor_tier)
  @common_instance_metadata = args[:common_instance_metadata] if args.key?(:common_instance_metadata)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @default_network_tier = args[:default_network_tier] if args.key?(:default_network_tier)
  @default_service_account = args[:default_service_account] if args.key?(:default_service_account)
  @description = args[:description] if args.key?(:description)
  @enabled_features = args[:enabled_features] if args.key?(:enabled_features)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @managed_protection_tier = args[:managed_protection_tier] if args.key?(:managed_protection_tier)
  @name = args[:name] if args.key?(:name)
  @quotas = args[:quotas] if args.key?(:quotas)
  @self_link = args[:self_link] if args.key?(:self_link)
  @usage_export_location = args[:usage_export_location] if args.key?(:usage_export_location)
  @vm_dns_setting = args[:vm_dns_setting] if args.key?(:vm_dns_setting)
  @xpn_project_status = args[:xpn_project_status] if args.key?(:xpn_project_status)
end