Class: Google::Apis::ComputeAlpha::Project
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::Project
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Represents a Project resource. A project is used to organize resources in a Google Cloud Platform environment. For more information, read about the Resource Hierarchy.
Instance Attribute Summary collapse
-
#cloud_armor_tier ⇒ String
Output only.
-
#common_instance_metadata ⇒ Google::Apis::ComputeAlpha::Metadata
A metadata key/value entry.
-
#creation_timestamp ⇒ String
[Output Only] Creation timestamp inRFC3339 text format.
-
#default_network_tier ⇒ String
This signifies the default network tier used for configuring resources of the project and can only take the following values:PREMIUM, STANDARD.
-
#default_service_account ⇒ String
[Output Only] Default service account used by VMs running in this project.
-
#description ⇒ String
An optional textual description of the resource.
-
#enabled_features ⇒ Array<String>
An optional list of restricted features enabled for use on this project.
-
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource.
-
#kind ⇒ String
Output only.
-
#managed_protection_tier ⇒ String
Output only.
-
#name ⇒ String
The project ID.
-
#quotas ⇒ Array<Google::Apis::ComputeAlpha::Quota>
[Output Only] Quotas assigned to this project.
-
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
-
#usage_export_location ⇒ Google::Apis::ComputeAlpha::UsageExportLocation
The location in Cloud Storage and naming method of the daily usage report.
-
#vm_dns_setting ⇒ String
Output only.
-
#xpn_project_status ⇒ String
[Output Only] The role this project has in a shared VPC configuration.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Project
constructor
A new instance of Project.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Project
Returns a new instance of Project.
51495 51496 51497 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 51495 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cloud_armor_tier ⇒ String
Output only. [Output Only] The Cloud Armor tier for this project. It can be
one of the
following values: CA_STANDARD,CA_ENTERPRISE_PAYGO.
If this field is not specified, it is assumed to beCA_STANDARD.
Corresponds to the JSON property cloudArmorTier
51403 51404 51405 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 51403 def cloud_armor_tier @cloud_armor_tier end |
#common_instance_metadata ⇒ Google::Apis::ComputeAlpha::Metadata
A metadata key/value entry.
Corresponds to the JSON property commonInstanceMetadata
51408 51409 51410 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 51408 def @common_instance_metadata end |
#creation_timestamp ⇒ String
[Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
51414 51415 51416 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 51414 def @creation_timestamp end |
#default_network_tier ⇒ String
This signifies the default network tier used for configuring resources of
the project and can only take the following values:PREMIUM, STANDARD.
Initially the default network
tier is PREMIUM.
Corresponds to the JSON property defaultNetworkTier
51422 51423 51424 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 51422 def default_network_tier @default_network_tier end |
#default_service_account ⇒ String
[Output Only] Default service account used by VMs running in this project.
Corresponds to the JSON property defaultServiceAccount
51427 51428 51429 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 51427 def default_service_account @default_service_account end |
#description ⇒ String
An optional textual description of the resource.
Corresponds to the JSON property description
51432 51433 51434 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 51432 def description @description end |
#enabled_features ⇒ Array<String>
An optional list of restricted features enabled for use on this project.
Corresponds to the JSON property enabledFeatures
51437 51438 51439 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 51437 def enabled_features @enabled_features end |
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource. This identifier is
defined by the server. This is not the project ID, and is
just a unique ID used by Compute Engine to identify resources.
Corresponds to the JSON property id
51444 51445 51446 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 51444 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Always compute#project for
projects.
Corresponds to the JSON property kind
51450 51451 51452 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 51450 def kind @kind end |
#managed_protection_tier ⇒ String
Output only. [Output Only] The Cloud Armor Managed Protection (CAMP) tier for
this project. It can be one of the following values:CA_STANDARD,
CAMP_PLUS_PAYGO.
If this field is not specified, it is assumed to beCA_STANDARD.
Corresponds to the JSON property managedProtectionTier
51458 51459 51460 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 51458 def managed_protection_tier @managed_protection_tier end |
#name ⇒ String
The project ID. For example: my-example-project. Use the
project ID to make requests to Compute Engine.
Corresponds to the JSON property name
51464 51465 51466 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 51464 def name @name end |
#quotas ⇒ Array<Google::Apis::ComputeAlpha::Quota>
[Output Only] Quotas assigned to this project.
Corresponds to the JSON property quotas
51469 51470 51471 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 51469 def quotas @quotas end |
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
51474 51475 51476 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 51474 def self_link @self_link end |
#usage_export_location ⇒ Google::Apis::ComputeAlpha::UsageExportLocation
The location in Cloud Storage and naming method of the daily usage
report. Contains bucket_name and report_name prefix.
Corresponds to the JSON property usageExportLocation
51480 51481 51482 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 51480 def usage_export_location @usage_export_location end |
#vm_dns_setting ⇒ String
Output only. [Output Only] Default internal DNS setting used by VMs running in
this project.
Corresponds to the JSON property vmDnsSetting
51486 51487 51488 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 51486 def vm_dns_setting @vm_dns_setting end |
#xpn_project_status ⇒ String
[Output Only] The role this project has in a shared VPC configuration.
Currently, only projects with the host role, which is specified by the
value HOST, are differentiated.
Corresponds to the JSON property xpnProjectStatus
51493 51494 51495 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 51493 def xpn_project_status @xpn_project_status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
51500 51501 51502 51503 51504 51505 51506 51507 51508 51509 51510 51511 51512 51513 51514 51515 51516 51517 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 51500 def update!(**args) @cloud_armor_tier = args[:cloud_armor_tier] if args.key?(:cloud_armor_tier) @common_instance_metadata = args[:common_instance_metadata] if args.key?(:common_instance_metadata) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @default_network_tier = args[:default_network_tier] if args.key?(:default_network_tier) @default_service_account = args[:default_service_account] if args.key?(:default_service_account) @description = args[:description] if args.key?(:description) @enabled_features = args[:enabled_features] if args.key?(:enabled_features) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @managed_protection_tier = args[:managed_protection_tier] if args.key?(:managed_protection_tier) @name = args[:name] if args.key?(:name) @quotas = args[:quotas] if args.key?(:quotas) @self_link = args[:self_link] if args.key?(:self_link) @usage_export_location = args[:usage_export_location] if args.key?(:usage_export_location) @vm_dns_setting = args[:vm_dns_setting] if args.key?(:vm_dns_setting) @xpn_project_status = args[:xpn_project_status] if args.key?(:xpn_project_status) end |