Class: Google::Apis::ComputeAlpha::ProjectsGetXpnResources

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ProjectsGetXpnResources

Returns a new instance of ProjectsGetXpnResources.



52568
52569
52570
# File 'lib/google/apis/compute_alpha/classes.rb', line 52568

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# projectsGetXpnResources for lists of service resources (a.k.a service projects) Corresponds to the JSON property kind

Returns:

  • (String)


52549
52550
52551
# File 'lib/google/apis/compute_alpha/classes.rb', line 52549

def kind
  @kind
end

#next_page_tokenString

Output only. [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


52560
52561
52562
# File 'lib/google/apis/compute_alpha/classes.rb', line 52560

def next_page_token
  @next_page_token
end

#resourcesArray<Google::Apis::ComputeAlpha::XpnResourceId>

Service resources (a.k.a service projects) attached to this project as their shared VPC host. Corresponds to the JSON property resources



52566
52567
52568
# File 'lib/google/apis/compute_alpha/classes.rb', line 52566

def resources
  @resources
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



52573
52574
52575
52576
52577
# File 'lib/google/apis/compute_alpha/classes.rb', line 52573

def update!(**args)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @resources = args[:resources] if args.key?(:resources)
end