Class: Google::Apis::ComputeAlpha::ProjectsListXpnHostsRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ProjectsListXpnHostsRequest

Returns a new instance of ProjectsListXpnHostsRequest.



54193
54194
54195
# File 'lib/google/apis/compute_alpha/classes.rb', line 54193

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#organizationString

Optional organization ID managed by Cloud Resource Manager, for which to list shared VPC host projects. If not specified, the organization will be inferred from the project. Corresponds to the JSON property organization

Returns:

  • (String)


54181
54182
54183
# File 'lib/google/apis/compute_alpha/classes.rb', line 54181

def organization
  @organization
end

#return_partial_pageBoolean Also known as: return_partial_page?

Opt-in for partial page behavior which provides a partial filled page (number of items on which may be smaller than maxResults) within the API deadline. If opt-in, then the user should rely on if nextPageToken is empty in the response to determine if there is a next page. Empty page is also valid and possible. The default value is false. Corresponds to the JSON property returnPartialPage

Returns:

  • (Boolean)


54190
54191
54192
# File 'lib/google/apis/compute_alpha/classes.rb', line 54190

def return_partial_page
  @return_partial_page
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



54198
54199
54200
54201
# File 'lib/google/apis/compute_alpha/classes.rb', line 54198

def update!(**args)
  @organization = args[:organization] if args.key?(:organization)
  @return_partial_page = args[:return_partial_page] if args.key?(:return_partial_page)
end