Class: Google::Apis::ComputeAlpha::ProjectsListXpnHostsRequest
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::ProjectsListXpnHostsRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#organization ⇒ String
Optional organization ID managed by Cloud Resource Manager, for which to list shared VPC host projects.
-
#return_partial_page ⇒ Boolean
(also: #return_partial_page?)
Opt-in for partial page behavior which provides a partial filled page (number of items on which may be smaller than maxResults) within the API deadline.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ProjectsListXpnHostsRequest
constructor
A new instance of ProjectsListXpnHostsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ProjectsListXpnHostsRequest
Returns a new instance of ProjectsListXpnHostsRequest.
53137 53138 53139 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53137 def initialize(**args) update!(**args) end |
Instance Attribute Details
#organization ⇒ String
Optional organization ID managed by Cloud Resource Manager, for which to
list shared VPC host projects. If not specified, the organization will be
inferred from the project.
Corresponds to the JSON property organization
53125 53126 53127 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53125 def organization @organization end |
#return_partial_page ⇒ Boolean Also known as: return_partial_page?
Opt-in for partial page behavior which provides a partial filled page
(number of items on which may be smaller than maxResults) within the API
deadline. If opt-in, then the user should rely on if nextPageToken is empty
in the response to determine if there is a next page. Empty page is also
valid and possible. The default value is false.
Corresponds to the JSON property returnPartialPage
53134 53135 53136 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53134 def return_partial_page @return_partial_page end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
53142 53143 53144 53145 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53142 def update!(**args) @organization = args[:organization] if args.key?(:organization) @return_partial_page = args[:return_partial_page] if args.key?(:return_partial_page) end |