Class: Google::Apis::ComputeAlpha::PublicAdvertisedPrefix
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::PublicAdvertisedPrefix
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
A public advertised prefix represents an aggregated IP prefix or netblock which customers bring to cloud. The IP prefix is a single unit of route advertisement and is announced globally to the internet.
Instance Attribute Summary collapse
-
#byoip_api_version ⇒ String
Output only.
-
#creation_timestamp ⇒ String
Output only.
-
#description ⇒ String
An optional description of this resource.
-
#dns_verification_ip ⇒ String
The address to be used for reverse DNS verification.
-
#fingerprint ⇒ String
Fingerprint of this resource.
-
#id ⇒ Fixnum
Output only.
-
#ip_cidr_range ⇒ String
The address range, in CIDR format, represented by this public advertised prefix.
-
#ipv6_access_type ⇒ String
The internet access type for IPv6 Public Advertised Prefixes.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
Name of the resource.
-
#network_tier ⇒ String
Network tier to be used for this prefix.
-
#pdp_scope ⇒ String
Specifies how child public delegated prefix will be scoped.
-
#public_delegated_prefixs ⇒ Array<Google::Apis::ComputeAlpha::PublicAdvertisedPrefixPublicDelegatedPrefix>
Output only.
-
#self_link ⇒ String
Output only.
-
#self_link_with_id ⇒ String
Output only.
-
#shared_secret ⇒ String
[Output Only] The shared secret to be used for reverse DNS verification.
-
#status ⇒ String
The status of the public advertised prefix.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PublicAdvertisedPrefix
constructor
A new instance of PublicAdvertisedPrefix.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PublicAdvertisedPrefix
Returns a new instance of PublicAdvertisedPrefix.
54415 54416 54417 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54415 def initialize(**args) update!(**args) end |
Instance Attribute Details
#byoip_api_version ⇒ String
Output only. [Output Only] The version of BYOIP API.
Corresponds to the JSON property byoipApiVersion
54289 54290 54291 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54289 def byoip_api_version @byoip_api_version end |
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
54295 54296 54297 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54295 def @creation_timestamp end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
54301 54302 54303 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54301 def description @description end |
#dns_verification_ip ⇒ String
The address to be used for reverse DNS verification.
Corresponds to the JSON property dnsVerificationIp
54306 54307 54308 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54306 def dns_verification_ip @dns_verification_ip end |
#fingerprint ⇒ String
Fingerprint of this resource. A hash of the contents stored in this object.
This field is used in optimistic locking. This field will be ignored when
inserting a new PublicAdvertisedPrefix. An up-to-date
fingerprint must be provided in order to update thePublicAdvertisedPrefix,
otherwise the request will fail with
error 412 conditionNotMet.
To see the latest fingerprint, make a get() request to
retrieve a PublicAdvertisedPrefix.
Corresponds to the JSON property fingerprint
NOTE: Values are automatically base64 encoded/decoded in the client library.
54319 54320 54321 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54319 def fingerprint @fingerprint end |
#id ⇒ Fixnum
Output only. [Output Only] The unique identifier for the resource type. The
server
generates this identifier.
Corresponds to the JSON property id
54326 54327 54328 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54326 def id @id end |
#ip_cidr_range ⇒ String
The address range, in CIDR format, represented by this public advertised
prefix.
Corresponds to the JSON property ipCidrRange
54332 54333 54334 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54332 def ip_cidr_range @ip_cidr_range end |
#ipv6_access_type ⇒ String
The internet access type for IPv6 Public Advertised Prefixes.
Corresponds to the JSON property ipv6AccessType
54337 54338 54339 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54337 def ipv6_access_type @ipv6_access_type end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#
publicAdvertisedPrefix for public advertised prefixes.
Corresponds to the JSON property kind
54343 54344 54345 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54343 def kind @kind end |
#name ⇒ String
Name of the resource. Provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must
be a dash, lowercase letter, or digit, except the last character, which
cannot be a dash.
Corresponds to the JSON property name
54354 54355 54356 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54354 def name @name end |
#network_tier ⇒ String
Network tier to be used for this prefix. All child delegated prefixes will
inherit this field. If this field is not specified, it defaults to the
network tier of the project that the PublicAdvertisedPrefix belongs to.
Corresponds to the JSON property networkTier
54361 54362 54363 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54361 def network_tier @network_tier end |
#pdp_scope ⇒ String
Specifies how child public delegated prefix will be scoped. It could be one of following values:
REGIONAL: The public delegated prefix is regional only. The provisioning will take a few minutes.GLOBAL: The public delegated prefix is global only. The provisioning will take ~4 weeks.GLOBAL_AND_REGIONAL[output only]: The public delegated prefixes is BYOIP V1 legacy prefix. This is output only value and no longer supported in BYOIP V2. Corresponds to the JSON propertypdpScope
54376 54377 54378 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54376 def pdp_scope @pdp_scope end |
#public_delegated_prefixs ⇒ Array<Google::Apis::ComputeAlpha::PublicAdvertisedPrefixPublicDelegatedPrefix>
Output only. [Output Only] The list of public delegated prefixes that exist
for this
public advertised prefix.
Corresponds to the JSON property publicDelegatedPrefixs
54383 54384 54385 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54383 def public_delegated_prefixs @public_delegated_prefixs end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
54388 54389 54390 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54388 def self_link @self_link end |
#self_link_with_id ⇒ String
Output only. [Output Only] Server-defined URL with id for the resource.
Corresponds to the JSON property selfLinkWithId
54393 54394 54395 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54393 def self_link_with_id @self_link_with_id end |
#shared_secret ⇒ String
[Output Only] The shared secret to be used for reverse DNS verification.
Corresponds to the JSON property sharedSecret
54398 54399 54400 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54398 def shared_secret @shared_secret end |
#status ⇒ String
The status of the public advertised prefix. Possible values include:
INITIAL: RPKI validation is complete.PTR_CONFIGURED: User has configured the PTR.VALIDATED: Reverse DNS lookup is successful.REVERSE_DNS_LOOKUP_FAILED: Reverse DNS lookup failed.PREFIX_CONFIGURATION_IN_PROGRESS: The prefix is being configured.PREFIX_CONFIGURATION_COMPLETE: The prefix is fully configured.PREFIX_REMOVAL_IN_PROGRESS: The prefix is being removed. Corresponds to the JSON propertystatus
54413 54414 54415 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54413 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
54420 54421 54422 54423 54424 54425 54426 54427 54428 54429 54430 54431 54432 54433 54434 54435 54436 54437 54438 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54420 def update!(**args) @byoip_api_version = args[:byoip_api_version] if args.key?(:byoip_api_version) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @dns_verification_ip = args[:dns_verification_ip] if args.key?(:dns_verification_ip) @fingerprint = args[:fingerprint] if args.key?(:fingerprint) @id = args[:id] if args.key?(:id) @ip_cidr_range = args[:ip_cidr_range] if args.key?(:ip_cidr_range) @ipv6_access_type = args[:ipv6_access_type] if args.key?(:ipv6_access_type) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @network_tier = args[:network_tier] if args.key?(:network_tier) @pdp_scope = args[:pdp_scope] if args.key?(:pdp_scope) @public_delegated_prefixs = args[:public_delegated_prefixs] if args.key?(:public_delegated_prefixs) @self_link = args[:self_link] if args.key?(:self_link) @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id) @shared_secret = args[:shared_secret] if args.key?(:shared_secret) @status = args[:status] if args.key?(:status) end |