Class: Google::Apis::ComputeAlpha::PublicAdvertisedPrefix

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

A public advertised prefix represents an aggregated IP prefix or netblock which customers bring to cloud. The IP prefix is a single unit of route advertisement and is announced globally to the internet.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PublicAdvertisedPrefix

Returns a new instance of PublicAdvertisedPrefix.



53342
53343
53344
# File 'lib/google/apis/compute_alpha/classes.rb', line 53342

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#byoip_api_versionString

Output only. [Output Only] The version of BYOIP API. Corresponds to the JSON property byoipApiVersion

Returns:

  • (String)


53216
53217
53218
# File 'lib/google/apis/compute_alpha/classes.rb', line 53216

def byoip_api_version
  @byoip_api_version
end

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


53222
53223
53224
# File 'lib/google/apis/compute_alpha/classes.rb', line 53222

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


53228
53229
53230
# File 'lib/google/apis/compute_alpha/classes.rb', line 53228

def description
  @description
end

#dns_verification_ipString

The address to be used for reverse DNS verification. Corresponds to the JSON property dnsVerificationIp

Returns:

  • (String)


53233
53234
53235
# File 'lib/google/apis/compute_alpha/classes.rb', line 53233

def dns_verification_ip
  @dns_verification_ip
end

#fingerprintString

Fingerprint of this resource. A hash of the contents stored in this object. This field is used in optimistic locking. This field will be ignored when inserting a new PublicAdvertisedPrefix. An up-to-date fingerprint must be provided in order to update thePublicAdvertisedPrefix, otherwise the request will fail with error 412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve a PublicAdvertisedPrefix. Corresponds to the JSON property fingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


53246
53247
53248
# File 'lib/google/apis/compute_alpha/classes.rb', line 53246

def fingerprint
  @fingerprint
end

#idFixnum

Output only. [Output Only] The unique identifier for the resource type. The server generates this identifier. Corresponds to the JSON property id

Returns:

  • (Fixnum)


53253
53254
53255
# File 'lib/google/apis/compute_alpha/classes.rb', line 53253

def id
  @id
end

#ip_cidr_rangeString

The address range, in CIDR format, represented by this public advertised prefix. Corresponds to the JSON property ipCidrRange

Returns:

  • (String)


53259
53260
53261
# File 'lib/google/apis/compute_alpha/classes.rb', line 53259

def ip_cidr_range
  @ip_cidr_range
end

#ipv6_access_typeString

The internet access type for IPv6 Public Advertised Prefixes. Corresponds to the JSON property ipv6AccessType

Returns:

  • (String)


53264
53265
53266
# File 'lib/google/apis/compute_alpha/classes.rb', line 53264

def ipv6_access_type
  @ipv6_access_type
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# publicAdvertisedPrefix for public advertised prefixes. Corresponds to the JSON property kind

Returns:

  • (String)


53270
53271
53272
# File 'lib/google/apis/compute_alpha/classes.rb', line 53270

def kind
  @kind
end

#nameString

Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


53281
53282
53283
# File 'lib/google/apis/compute_alpha/classes.rb', line 53281

def name
  @name
end

#network_tierString

Network tier to be used for this prefix. All child delegated prefixes will inherit this field. If this field is not specified, it defaults to the network tier of the project that the PublicAdvertisedPrefix belongs to. Corresponds to the JSON property networkTier

Returns:

  • (String)


53288
53289
53290
# File 'lib/google/apis/compute_alpha/classes.rb', line 53288

def network_tier
  @network_tier
end

#pdp_scopeString

Specifies how child public delegated prefix will be scoped. It could be one of following values:

  • REGIONAL: The public delegated prefix is regional only. The provisioning will take a few minutes.
  • GLOBAL: The public delegated prefix is global only. The provisioning will take ~4 weeks.
  • GLOBAL_AND_REGIONAL [output only]: The public delegated prefixes is BYOIP V1 legacy prefix. This is output only value and no longer supported in BYOIP V2. Corresponds to the JSON property pdpScope

Returns:

  • (String)


53303
53304
53305
# File 'lib/google/apis/compute_alpha/classes.rb', line 53303

def pdp_scope
  @pdp_scope
end

#public_delegated_prefixsArray<Google::Apis::ComputeAlpha::PublicAdvertisedPrefixPublicDelegatedPrefix>

Output only. [Output Only] The list of public delegated prefixes that exist for this public advertised prefix. Corresponds to the JSON property publicDelegatedPrefixs



53310
53311
53312
# File 'lib/google/apis/compute_alpha/classes.rb', line 53310

def public_delegated_prefixs
  @public_delegated_prefixs
end

Output only. [Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


53315
53316
53317
# File 'lib/google/apis/compute_alpha/classes.rb', line 53315

def self_link
  @self_link
end

Output only. [Output Only] Server-defined URL with id for the resource. Corresponds to the JSON property selfLinkWithId

Returns:

  • (String)


53320
53321
53322
# File 'lib/google/apis/compute_alpha/classes.rb', line 53320

def self_link_with_id
  @self_link_with_id
end

#shared_secretString

[Output Only] The shared secret to be used for reverse DNS verification. Corresponds to the JSON property sharedSecret

Returns:

  • (String)


53325
53326
53327
# File 'lib/google/apis/compute_alpha/classes.rb', line 53325

def shared_secret
  @shared_secret
end

#statusString

The status of the public advertised prefix. Possible values include:

  • INITIAL: RPKI validation is complete.
  • PTR_CONFIGURED: User has configured the PTR.
  • VALIDATED: Reverse DNS lookup is successful.
  • REVERSE_DNS_LOOKUP_FAILED: Reverse DNS lookup failed.
  • PREFIX_CONFIGURATION_IN_PROGRESS: The prefix is being configured.
  • PREFIX_CONFIGURATION_COMPLETE: The prefix is fully configured.
  • PREFIX_REMOVAL_IN_PROGRESS: The prefix is being removed. Corresponds to the JSON property status

Returns:

  • (String)


53340
53341
53342
# File 'lib/google/apis/compute_alpha/classes.rb', line 53340

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



53347
53348
53349
53350
53351
53352
53353
53354
53355
53356
53357
53358
53359
53360
53361
53362
53363
53364
53365
# File 'lib/google/apis/compute_alpha/classes.rb', line 53347

def update!(**args)
  @byoip_api_version = args[:byoip_api_version] if args.key?(:byoip_api_version)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @dns_verification_ip = args[:dns_verification_ip] if args.key?(:dns_verification_ip)
  @fingerprint = args[:fingerprint] if args.key?(:fingerprint)
  @id = args[:id] if args.key?(:id)
  @ip_cidr_range = args[:ip_cidr_range] if args.key?(:ip_cidr_range)
  @ipv6_access_type = args[:ipv6_access_type] if args.key?(:ipv6_access_type)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @network_tier = args[:network_tier] if args.key?(:network_tier)
  @pdp_scope = args[:pdp_scope] if args.key?(:pdp_scope)
  @public_delegated_prefixs = args[:public_delegated_prefixs] if args.key?(:public_delegated_prefixs)
  @self_link = args[:self_link] if args.key?(:self_link)
  @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id)
  @shared_secret = args[:shared_secret] if args.key?(:shared_secret)
  @status = args[:status] if args.key?(:status)
end