Class: Google::Apis::ComputeAlpha::PublicAdvertisedPrefix
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::PublicAdvertisedPrefix
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
A public advertised prefix represents an aggregated IP prefix or netblock which customers bring to cloud. The IP prefix is a single unit of route advertisement and is announced globally to the internet.
Instance Attribute Summary collapse
-
#byoip_api_version ⇒ String
Output only.
-
#creation_timestamp ⇒ String
Output only.
-
#description ⇒ String
An optional description of this resource.
-
#dns_verification_ip ⇒ String
The address to be used for reverse DNS verification.
-
#fingerprint ⇒ String
Fingerprint of this resource.
-
#id ⇒ Fixnum
Output only.
-
#ip_cidr_range ⇒ String
The address range, in CIDR format, represented by this public advertised prefix.
-
#ipv6_access_type ⇒ String
The internet access type for IPv6 Public Advertised Prefixes.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
Name of the resource.
-
#network_tier ⇒ String
Network tier to be used for this prefix.
-
#pdp_scope ⇒ String
Specifies how child public delegated prefix will be scoped.
-
#public_delegated_prefixs ⇒ Array<Google::Apis::ComputeAlpha::PublicAdvertisedPrefixPublicDelegatedPrefix>
Output only.
-
#self_link ⇒ String
Output only.
-
#self_link_with_id ⇒ String
Output only.
-
#shared_secret ⇒ String
[Output Only] The shared secret to be used for reverse DNS verification.
-
#status ⇒ String
The status of the public advertised prefix.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PublicAdvertisedPrefix
constructor
A new instance of PublicAdvertisedPrefix.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PublicAdvertisedPrefix
Returns a new instance of PublicAdvertisedPrefix.
52823 52824 52825 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 52823 def initialize(**args) update!(**args) end |
Instance Attribute Details
#byoip_api_version ⇒ String
Output only. [Output Only] The version of BYOIP API.
Corresponds to the JSON property byoipApiVersion
52697 52698 52699 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 52697 def byoip_api_version @byoip_api_version end |
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
52703 52704 52705 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 52703 def @creation_timestamp end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
52709 52710 52711 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 52709 def description @description end |
#dns_verification_ip ⇒ String
The address to be used for reverse DNS verification.
Corresponds to the JSON property dnsVerificationIp
52714 52715 52716 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 52714 def dns_verification_ip @dns_verification_ip end |
#fingerprint ⇒ String
Fingerprint of this resource. A hash of the contents stored in this object.
This field is used in optimistic locking. This field will be ignored when
inserting a new PublicAdvertisedPrefix. An up-to-date
fingerprint must be provided in order to update thePublicAdvertisedPrefix,
otherwise the request will fail with
error 412 conditionNotMet.
To see the latest fingerprint, make a get() request to
retrieve a PublicAdvertisedPrefix.
Corresponds to the JSON property fingerprint
NOTE: Values are automatically base64 encoded/decoded in the client library.
52727 52728 52729 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 52727 def fingerprint @fingerprint end |
#id ⇒ Fixnum
Output only. [Output Only] The unique identifier for the resource type. The
server
generates this identifier.
Corresponds to the JSON property id
52734 52735 52736 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 52734 def id @id end |
#ip_cidr_range ⇒ String
The address range, in CIDR format, represented by this public advertised
prefix.
Corresponds to the JSON property ipCidrRange
52740 52741 52742 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 52740 def ip_cidr_range @ip_cidr_range end |
#ipv6_access_type ⇒ String
The internet access type for IPv6 Public Advertised Prefixes.
Corresponds to the JSON property ipv6AccessType
52745 52746 52747 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 52745 def ipv6_access_type @ipv6_access_type end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#
publicAdvertisedPrefix for public advertised prefixes.
Corresponds to the JSON property kind
52751 52752 52753 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 52751 def kind @kind end |
#name ⇒ String
Name of the resource. Provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must
be a dash, lowercase letter, or digit, except the last character, which
cannot be a dash.
Corresponds to the JSON property name
52762 52763 52764 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 52762 def name @name end |
#network_tier ⇒ String
Network tier to be used for this prefix. All child delegated prefixes will
inherit this field. If this field is not specified, it defaults to the
network tier of the project that the PublicAdvertisedPrefix belongs to.
Corresponds to the JSON property networkTier
52769 52770 52771 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 52769 def network_tier @network_tier end |
#pdp_scope ⇒ String
Specifies how child public delegated prefix will be scoped. It could be one of following values:
REGIONAL: The public delegated prefix is regional only. The provisioning will take a few minutes.GLOBAL: The public delegated prefix is global only. The provisioning will take ~4 weeks.GLOBAL_AND_REGIONAL[output only]: The public delegated prefixes is BYOIP V1 legacy prefix. This is output only value and no longer supported in BYOIP V2. Corresponds to the JSON propertypdpScope
52784 52785 52786 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 52784 def pdp_scope @pdp_scope end |
#public_delegated_prefixs ⇒ Array<Google::Apis::ComputeAlpha::PublicAdvertisedPrefixPublicDelegatedPrefix>
Output only. [Output Only] The list of public delegated prefixes that exist
for this
public advertised prefix.
Corresponds to the JSON property publicDelegatedPrefixs
52791 52792 52793 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 52791 def public_delegated_prefixs @public_delegated_prefixs end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
52796 52797 52798 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 52796 def self_link @self_link end |
#self_link_with_id ⇒ String
Output only. [Output Only] Server-defined URL with id for the resource.
Corresponds to the JSON property selfLinkWithId
52801 52802 52803 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 52801 def self_link_with_id @self_link_with_id end |
#shared_secret ⇒ String
[Output Only] The shared secret to be used for reverse DNS verification.
Corresponds to the JSON property sharedSecret
52806 52807 52808 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 52806 def shared_secret @shared_secret end |
#status ⇒ String
The status of the public advertised prefix. Possible values include:
INITIAL: RPKI validation is complete.PTR_CONFIGURED: User has configured the PTR.VALIDATED: Reverse DNS lookup is successful.REVERSE_DNS_LOOKUP_FAILED: Reverse DNS lookup failed.PREFIX_CONFIGURATION_IN_PROGRESS: The prefix is being configured.PREFIX_CONFIGURATION_COMPLETE: The prefix is fully configured.PREFIX_REMOVAL_IN_PROGRESS: The prefix is being removed. Corresponds to the JSON propertystatus
52821 52822 52823 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 52821 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
52828 52829 52830 52831 52832 52833 52834 52835 52836 52837 52838 52839 52840 52841 52842 52843 52844 52845 52846 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 52828 def update!(**args) @byoip_api_version = args[:byoip_api_version] if args.key?(:byoip_api_version) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @dns_verification_ip = args[:dns_verification_ip] if args.key?(:dns_verification_ip) @fingerprint = args[:fingerprint] if args.key?(:fingerprint) @id = args[:id] if args.key?(:id) @ip_cidr_range = args[:ip_cidr_range] if args.key?(:ip_cidr_range) @ipv6_access_type = args[:ipv6_access_type] if args.key?(:ipv6_access_type) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @network_tier = args[:network_tier] if args.key?(:network_tier) @pdp_scope = args[:pdp_scope] if args.key?(:pdp_scope) @public_delegated_prefixs = args[:public_delegated_prefixs] if args.key?(:public_delegated_prefixs) @self_link = args[:self_link] if args.key?(:self_link) @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id) @shared_secret = args[:shared_secret] if args.key?(:shared_secret) @status = args[:status] if args.key?(:status) end |