Class: Google::Apis::ComputeAlpha::PublicAdvertisedPrefixList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PublicAdvertisedPrefixList

Returns a new instance of PublicAdvertisedPrefixList.



54766
54767
54768
# File 'lib/google/apis/compute_alpha/classes.rb', line 54766

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


54733
54734
54735
# File 'lib/google/apis/compute_alpha/classes.rb', line 54733

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::PublicAdvertisedPrefix>

A list of PublicAdvertisedPrefix resources. Corresponds to the JSON property items



54738
54739
54740
# File 'lib/google/apis/compute_alpha/classes.rb', line 54738

def items
  @items
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# publicAdvertisedPrefix for public advertised prefixes. Corresponds to the JSON property kind

Returns:

  • (String)


54744
54745
54746
# File 'lib/google/apis/compute_alpha/classes.rb', line 54744

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


54754
54755
54756
# File 'lib/google/apis/compute_alpha/classes.rb', line 54754

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


54759
54760
54761
# File 'lib/google/apis/compute_alpha/classes.rb', line 54759

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::PublicAdvertisedPrefixList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



54764
54765
54766
# File 'lib/google/apis/compute_alpha/classes.rb', line 54764

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



54771
54772
54773
54774
54775
54776
54777
54778
# File 'lib/google/apis/compute_alpha/classes.rb', line 54771

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end