Class: Google::Apis::ComputeAlpha::PublicAdvertisedPrefixList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::PublicAdvertisedPrefixList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::PublicAdvertisedPrefix>
A list of PublicAdvertisedPrefix resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
-
#warning ⇒ Google::Apis::ComputeAlpha::PublicAdvertisedPrefixList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PublicAdvertisedPrefixList
constructor
A new instance of PublicAdvertisedPrefixList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PublicAdvertisedPrefixList
Returns a new instance of PublicAdvertisedPrefixList.
52664 52665 52666 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 52664 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
52631 52632 52633 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 52631 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::PublicAdvertisedPrefix>
A list of PublicAdvertisedPrefix resources.
Corresponds to the JSON property items
52636 52637 52638 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 52636 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#
publicAdvertisedPrefix for public advertised prefixes.
Corresponds to the JSON property kind
52642 52643 52644 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 52642 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
52652 52653 52654 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 52652 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
52657 52658 52659 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 52657 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::PublicAdvertisedPrefixList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
52662 52663 52664 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 52662 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
52669 52670 52671 52672 52673 52674 52675 52676 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 52669 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |