Class: Google::Apis::ComputeAlpha::PublicAdvertisedPrefixList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PublicAdvertisedPrefixList

Returns a new instance of PublicAdvertisedPrefixList.



51899
51900
51901
# File 'lib/google/apis/compute_alpha/classes.rb', line 51899

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


51866
51867
51868
# File 'lib/google/apis/compute_alpha/classes.rb', line 51866

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::PublicAdvertisedPrefix>

A list of PublicAdvertisedPrefix resources. Corresponds to the JSON property items



51871
51872
51873
# File 'lib/google/apis/compute_alpha/classes.rb', line 51871

def items
  @items
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# publicAdvertisedPrefix for public advertised prefixes. Corresponds to the JSON property kind

Returns:

  • (String)


51877
51878
51879
# File 'lib/google/apis/compute_alpha/classes.rb', line 51877

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


51887
51888
51889
# File 'lib/google/apis/compute_alpha/classes.rb', line 51887

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


51892
51893
51894
# File 'lib/google/apis/compute_alpha/classes.rb', line 51892

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::PublicAdvertisedPrefixList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



51897
51898
51899
# File 'lib/google/apis/compute_alpha/classes.rb', line 51897

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



51904
51905
51906
51907
51908
51909
51910
51911
# File 'lib/google/apis/compute_alpha/classes.rb', line 51904

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end