Class: Google::Apis::ComputeAlpha::PublicAdvertisedPrefixPublicDelegatedPrefix

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Represents a CIDR range which can be used to assign addresses.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PublicAdvertisedPrefixPublicDelegatedPrefix

Returns a new instance of PublicAdvertisedPrefixPublicDelegatedPrefix.



53543
53544
53545
# File 'lib/google/apis/compute_alpha/classes.rb', line 53543

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ip_rangeString

The IP address range of the public delegated prefix Corresponds to the JSON property ipRange

Returns:

  • (String)


53517
53518
53519
# File 'lib/google/apis/compute_alpha/classes.rb', line 53517

def ip_range
  @ip_range
end

#nameString

The name of the public delegated prefix Corresponds to the JSON property name

Returns:

  • (String)


53522
53523
53524
# File 'lib/google/apis/compute_alpha/classes.rb', line 53522

def name
  @name
end

#projectString

The project number of the public delegated prefix Corresponds to the JSON property project

Returns:

  • (String)


53527
53528
53529
# File 'lib/google/apis/compute_alpha/classes.rb', line 53527

def project
  @project
end

#regionString

The region of the public delegated prefix if it is regional. If absent, the prefix is global. Corresponds to the JSON property region

Returns:

  • (String)


53533
53534
53535
# File 'lib/google/apis/compute_alpha/classes.rb', line 53533

def region
  @region
end

#statusString

The status of the public delegated prefix. Possible values are: INITIALIZING: The public delegated prefix is being initialized and addresses cannot be created yet. ANNOUNCED: The public delegated prefix is active. Corresponds to the JSON property status

Returns:

  • (String)


53541
53542
53543
# File 'lib/google/apis/compute_alpha/classes.rb', line 53541

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



53548
53549
53550
53551
53552
53553
53554
# File 'lib/google/apis/compute_alpha/classes.rb', line 53548

def update!(**args)
  @ip_range = args[:ip_range] if args.key?(:ip_range)
  @name = args[:name] if args.key?(:name)
  @project = args[:project] if args.key?(:project)
  @region = args[:region] if args.key?(:region)
  @status = args[:status] if args.key?(:status)
end