Class: Google::Apis::ComputeAlpha::PublicAdvertisedPrefixPublicDelegatedPrefix

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Represents a CIDR range which can be used to assign addresses.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PublicAdvertisedPrefixPublicDelegatedPrefix

Returns a new instance of PublicAdvertisedPrefixPublicDelegatedPrefix.



52017
52018
52019
# File 'lib/google/apis/compute_alpha/classes.rb', line 52017

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ip_rangeString

The IP address range of the public delegated prefix Corresponds to the JSON property ipRange

Returns:

  • (String)


51991
51992
51993
# File 'lib/google/apis/compute_alpha/classes.rb', line 51991

def ip_range
  @ip_range
end

#nameString

The name of the public delegated prefix Corresponds to the JSON property name

Returns:

  • (String)


51996
51997
51998
# File 'lib/google/apis/compute_alpha/classes.rb', line 51996

def name
  @name
end

#projectString

The project number of the public delegated prefix Corresponds to the JSON property project

Returns:

  • (String)


52001
52002
52003
# File 'lib/google/apis/compute_alpha/classes.rb', line 52001

def project
  @project
end

#regionString

The region of the public delegated prefix if it is regional. If absent, the prefix is global. Corresponds to the JSON property region

Returns:

  • (String)


52007
52008
52009
# File 'lib/google/apis/compute_alpha/classes.rb', line 52007

def region
  @region
end

#statusString

The status of the public delegated prefix. Possible values are: INITIALIZING: The public delegated prefix is being initialized and addresses cannot be created yet. ANNOUNCED: The public delegated prefix is active. Corresponds to the JSON property status

Returns:

  • (String)


52015
52016
52017
# File 'lib/google/apis/compute_alpha/classes.rb', line 52015

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



52022
52023
52024
52025
52026
52027
52028
# File 'lib/google/apis/compute_alpha/classes.rb', line 52022

def update!(**args)
  @ip_range = args[:ip_range] if args.key?(:ip_range)
  @name = args[:name] if args.key?(:name)
  @project = args[:project] if args.key?(:project)
  @region = args[:region] if args.key?(:region)
  @status = args[:status] if args.key?(:status)
end