Class: Google::Apis::ComputeAlpha::PublicDelegatedPrefix
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::PublicDelegatedPrefix
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
A PublicDelegatedPrefix resource represents an IP block within a PublicAdvertisedPrefix that is configured within a single cloud scope (global or region). IPs in the block can be allocated to resources within that scope. Public delegated prefixes may be further broken up into smaller IP blocks in the same scope as the parent block.
Instance Attribute Summary collapse
-
#allocatable_prefix_length ⇒ Fixnum
The allocatable prefix length supported by this public delegated prefix.
-
#byoip_api_version ⇒ String
Output only.
-
#creation_timestamp ⇒ String
Output only.
-
#description ⇒ String
An optional description of this resource.
-
#enable_enhanced_ipv4_allocation ⇒ Boolean
(also: #enable_enhanced_ipv4_allocation?)
Output only.
-
#fingerprint ⇒ String
Fingerprint of this resource.
-
#id ⇒ Fixnum
Output only.
-
#ip_cidr_range ⇒ String
The IP address range, in CIDR format, represented by this public delegated prefix.
-
#ipv6_access_type ⇒ String
Output only.
-
#is_live_migration ⇒ Boolean
(also: #is_live_migration?)
If true, the prefix will be live migrated.
-
#kind ⇒ String
Output only.
-
#mode ⇒ String
The public delegated prefix mode for IPv6 only.
-
#name ⇒ String
Name of the resource.
-
#network_tier ⇒ String
Network tier of the public delegated prefix.
-
#parent_prefix ⇒ String
The URL of parent prefix.
-
#public_delegated_sub_prefixs ⇒ Array<Google::Apis::ComputeAlpha::PublicDelegatedPrefixPublicDelegatedSubPrefix>
The list of sub public delegated prefixes that exist for this public delegated prefix.
-
#purpose ⇒ String
Immutable.
-
#region ⇒ String
Output only.
-
#self_link ⇒ String
Output only.
-
#self_link_with_id ⇒ String
Output only.
-
#status ⇒ String
[Output Only] The status of the public delegated prefix, which can be one of following values:.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PublicDelegatedPrefix
constructor
A new instance of PublicDelegatedPrefix.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PublicDelegatedPrefix
Returns a new instance of PublicDelegatedPrefix.
53719 53720 53721 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53719 def initialize(**args) update!(**args) end |
Instance Attribute Details
#allocatable_prefix_length ⇒ Fixnum
The allocatable prefix length supported by this public delegated prefix.
This field is optional and cannot be set for prefixes in DELEGATION mode.
It cannot be set for IPv4 prefixes either, and it always defaults to 32.
Corresponds to the JSON property allocatablePrefixLength
53553 53554 53555 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53553 def allocatable_prefix_length @allocatable_prefix_length end |
#byoip_api_version ⇒ String
Output only. [Output Only] The version of BYOIP API.
Corresponds to the JSON property byoipApiVersion
53558 53559 53560 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53558 def byoip_api_version @byoip_api_version end |
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
53564 53565 53566 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53564 def @creation_timestamp end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
53570 53571 53572 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53570 def description @description end |
#enable_enhanced_ipv4_allocation ⇒ Boolean Also known as: enable_enhanced_ipv4_allocation?
Output only. [Output Only] Whether this PDP supports enhanced IPv4 allocations.
Applicable for IPv4 PDPs only.
Corresponds to the JSON property enableEnhancedIpv4Allocation
53576 53577 53578 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53576 def enable_enhanced_ipv4_allocation @enable_enhanced_ipv4_allocation end |
#fingerprint ⇒ String
Fingerprint of this resource. A hash of the contents stored in this object.
This field is used in optimistic locking. This field will be ignored when
inserting a new PublicDelegatedPrefix. An up-to-date
fingerprint must be provided in order to update thePublicDelegatedPrefix,
otherwise the request will fail with
error 412 conditionNotMet.
To see the latest fingerprint, make a get() request to
retrieve a PublicDelegatedPrefix.
Corresponds to the JSON property fingerprint
NOTE: Values are automatically base64 encoded/decoded in the client library.
53590 53591 53592 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53590 def fingerprint @fingerprint end |
#id ⇒ Fixnum
Output only. [Output Only] The unique identifier for the resource type. The
server
generates this identifier.
Corresponds to the JSON property id
53597 53598 53599 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53597 def id @id end |
#ip_cidr_range ⇒ String
The IP address range, in CIDR format, represented by this public
delegated prefix.
Corresponds to the JSON property ipCidrRange
53603 53604 53605 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53603 def ip_cidr_range @ip_cidr_range end |
#ipv6_access_type ⇒ String
Output only. [Output Only] The internet access type for IPv6 Public Delegated
Prefixes.
Inherited from parent prefix.
Corresponds to the JSON property ipv6AccessType
53610 53611 53612 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53610 def ipv6_access_type @ipv6_access_type end |
#is_live_migration ⇒ Boolean Also known as: is_live_migration?
If true, the prefix will be live migrated.
Corresponds to the JSON property isLiveMigration
53615 53616 53617 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53615 def is_live_migration @is_live_migration end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#
publicDelegatedPrefix for public delegated prefixes.
Corresponds to the JSON property kind
53622 53623 53624 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53622 def kind @kind end |
#mode ⇒ String
The public delegated prefix mode for IPv6 only.
Corresponds to the JSON property mode
53627 53628 53629 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53627 def mode @mode end |
#name ⇒ String
Name of the resource. Provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must
be a dash, lowercase letter, or digit, except the last character, which
cannot be a dash.
Corresponds to the JSON property name
53638 53639 53640 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53638 def name @name end |
#network_tier ⇒ String
Network tier of the public delegated prefix. If populated, it must match
the network tier of the parent public advertised prefix. If not populated,
it defaults to the network tier of the parent public advertised prefix.
Corresponds to the JSON property networkTier
53645 53646 53647 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53645 def network_tier @network_tier end |
#parent_prefix ⇒ String
The URL of parent prefix. Either PublicAdvertisedPrefix or
PublicDelegatedPrefix.
Corresponds to the JSON property parentPrefix
53651 53652 53653 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53651 def parent_prefix @parent_prefix end |
#public_delegated_sub_prefixs ⇒ Array<Google::Apis::ComputeAlpha::PublicDelegatedPrefixPublicDelegatedSubPrefix>
The list of sub public delegated prefixes that exist for this public
delegated prefix.
Corresponds to the JSON property publicDelegatedSubPrefixs
53657 53658 53659 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53657 def public_delegated_sub_prefixs @public_delegated_sub_prefixs end |
#purpose ⇒ String
Immutable. The purpose of the public delegated prefix. This field can only be set for the top-level global public delegated prefix. It is an output-only field for the sub-delegates that inherit the value from the top-level global public delegated prefix. Once the value is set, it cannot be changed. The field cannot be set for regional public delegated prefixes. The supported values are:
- APPLICATION_AND_PROXY_LOAD_BALANCERS: The global public delegated prefix can only be used by Global External Application and Proxy Load Balancers to allocate addresses for forwarding rules. This is the default value.
- PASSTHROUGH_LOAD_BALANCER_AVAILABILITY_GROUP0: The global public delegated prefix can only be used by Global External Passthrough Network Load Balancers to allocate Availability Group 0 addresses for forwarding rules.
- PASSTHROUGH_LOAD_BALANCER_AVAILABILITY_GROUP1: The
global public delegated prefix can only be used by Global External
Passthrough Network Load Balancers to allocate Availability Group 1
addresses for forwarding rules.
Corresponds to the JSON property
purpose
53682 53683 53684 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53682 def purpose @purpose end |
#region ⇒ String
Output only. [Output Only] URL of the region where the public delegated prefix
resides.
This field applies only to the region resource. You must specify this
field as part of the HTTP request URL. It is not settable as a field in
the request body.
Corresponds to the JSON property region
53691 53692 53693 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53691 def region @region end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
53696 53697 53698 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53696 def self_link @self_link end |
#self_link_with_id ⇒ String
Output only. [Output Only] Server-defined URL with id for the resource.
Corresponds to the JSON property selfLinkWithId
53701 53702 53703 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53701 def self_link_with_id @self_link_with_id end |
#status ⇒ String
[Output Only] The status of the public delegated prefix, which can be one of following values:
INITIALIZINGThe public delegated prefix is being initialized and addresses cannot be created yet.READY_TO_ANNOUNCEThe public delegated prefix is a live migration prefix and is active.ANNOUNCEDThe public delegated prefix is announced and ready to use.DELETINGThe public delegated prefix is being deprovsioned.ACTIVEThe public delegated prefix is ready to use. Corresponds to the JSON propertystatus
53717 53718 53719 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53717 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
53724 53725 53726 53727 53728 53729 53730 53731 53732 53733 53734 53735 53736 53737 53738 53739 53740 53741 53742 53743 53744 53745 53746 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53724 def update!(**args) @allocatable_prefix_length = args[:allocatable_prefix_length] if args.key?(:allocatable_prefix_length) @byoip_api_version = args[:byoip_api_version] if args.key?(:byoip_api_version) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @enable_enhanced_ipv4_allocation = args[:enable_enhanced_ipv4_allocation] if args.key?(:enable_enhanced_ipv4_allocation) @fingerprint = args[:fingerprint] if args.key?(:fingerprint) @id = args[:id] if args.key?(:id) @ip_cidr_range = args[:ip_cidr_range] if args.key?(:ip_cidr_range) @ipv6_access_type = args[:ipv6_access_type] if args.key?(:ipv6_access_type) @is_live_migration = args[:is_live_migration] if args.key?(:is_live_migration) @kind = args[:kind] if args.key?(:kind) @mode = args[:mode] if args.key?(:mode) @name = args[:name] if args.key?(:name) @network_tier = args[:network_tier] if args.key?(:network_tier) @parent_prefix = args[:parent_prefix] if args.key?(:parent_prefix) @public_delegated_sub_prefixs = args[:public_delegated_sub_prefixs] if args.key?(:public_delegated_sub_prefixs) @purpose = args[:purpose] if args.key?(:purpose) @region = args[:region] if args.key?(:region) @self_link = args[:self_link] if args.key?(:self_link) @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id) @status = args[:status] if args.key?(:status) end |