Class: Google::Apis::ComputeAlpha::PublicDelegatedPrefixAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PublicDelegatedPrefixAggregatedList

Returns a new instance of PublicDelegatedPrefixAggregatedList.



55153
55154
55155
# File 'lib/google/apis/compute_alpha/classes.rb', line 55153

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


55114
55115
55116
# File 'lib/google/apis/compute_alpha/classes.rb', line 55114

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::PublicDelegatedPrefixesScopedList>

A list of PublicDelegatedPrefixesScopedList resources. Corresponds to the JSON property items



55119
55120
55121
# File 'lib/google/apis/compute_alpha/classes.rb', line 55119

def items
  @items
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# publicDelegatedPrefixAggregatedList for aggregated lists of public delegated prefixes. Corresponds to the JSON property kind

Returns:

  • (String)


55126
55127
55128
# File 'lib/google/apis/compute_alpha/classes.rb', line 55126

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


55136
55137
55138
# File 'lib/google/apis/compute_alpha/classes.rb', line 55136

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


55141
55142
55143
# File 'lib/google/apis/compute_alpha/classes.rb', line 55141

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


55146
55147
55148
# File 'lib/google/apis/compute_alpha/classes.rb', line 55146

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::PublicDelegatedPrefixAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



55151
55152
55153
# File 'lib/google/apis/compute_alpha/classes.rb', line 55151

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



55158
55159
55160
55161
55162
55163
55164
55165
55166
# File 'lib/google/apis/compute_alpha/classes.rb', line 55158

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end