Class: Google::Apis::ComputeAlpha::PublicDelegatedPrefixAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::PublicDelegatedPrefixAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::PublicDelegatedPrefixesScopedList>
A list of PublicDelegatedPrefixesScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::PublicDelegatedPrefixAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PublicDelegatedPrefixAggregatedList
constructor
A new instance of PublicDelegatedPrefixAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PublicDelegatedPrefixAggregatedList
Returns a new instance of PublicDelegatedPrefixAggregatedList.
53812 53813 53814 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53812 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
53773 53774 53775 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53773 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::PublicDelegatedPrefixesScopedList>
A list of PublicDelegatedPrefixesScopedList resources.
Corresponds to the JSON property items
53778 53779 53780 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53778 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#
publicDelegatedPrefixAggregatedList for aggregated
lists of public delegated prefixes.
Corresponds to the JSON property kind
53785 53786 53787 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53785 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
53795 53796 53797 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53795 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
53800 53801 53802 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53800 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
53805 53806 53807 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53805 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::PublicDelegatedPrefixAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
53810 53811 53812 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53810 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
53817 53818 53819 53820 53821 53822 53823 53824 53825 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53817 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |