Class: Google::Apis::ComputeAlpha::PublicDelegatedPrefixAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PublicDelegatedPrefixAggregatedList

Returns a new instance of PublicDelegatedPrefixAggregatedList.



53795
53796
53797
# File 'lib/google/apis/compute_alpha/classes.rb', line 53795

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


53756
53757
53758
# File 'lib/google/apis/compute_alpha/classes.rb', line 53756

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::PublicDelegatedPrefixesScopedList>

A list of PublicDelegatedPrefixesScopedList resources. Corresponds to the JSON property items



53761
53762
53763
# File 'lib/google/apis/compute_alpha/classes.rb', line 53761

def items
  @items
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# publicDelegatedPrefixAggregatedList for aggregated lists of public delegated prefixes. Corresponds to the JSON property kind

Returns:

  • (String)


53768
53769
53770
# File 'lib/google/apis/compute_alpha/classes.rb', line 53768

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


53778
53779
53780
# File 'lib/google/apis/compute_alpha/classes.rb', line 53778

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


53783
53784
53785
# File 'lib/google/apis/compute_alpha/classes.rb', line 53783

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


53788
53789
53790
# File 'lib/google/apis/compute_alpha/classes.rb', line 53788

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::PublicDelegatedPrefixAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



53793
53794
53795
# File 'lib/google/apis/compute_alpha/classes.rb', line 53793

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



53800
53801
53802
53803
53804
53805
53806
53807
53808
# File 'lib/google/apis/compute_alpha/classes.rb', line 53800

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end