Class: Google::Apis::ComputeAlpha::PublicDelegatedPrefixAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PublicDelegatedPrefixAggregatedList

Returns a new instance of PublicDelegatedPrefixAggregatedList.



53276
53277
53278
# File 'lib/google/apis/compute_alpha/classes.rb', line 53276

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


53237
53238
53239
# File 'lib/google/apis/compute_alpha/classes.rb', line 53237

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::PublicDelegatedPrefixesScopedList>

A list of PublicDelegatedPrefixesScopedList resources. Corresponds to the JSON property items



53242
53243
53244
# File 'lib/google/apis/compute_alpha/classes.rb', line 53242

def items
  @items
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# publicDelegatedPrefixAggregatedList for aggregated lists of public delegated prefixes. Corresponds to the JSON property kind

Returns:

  • (String)


53249
53250
53251
# File 'lib/google/apis/compute_alpha/classes.rb', line 53249

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


53259
53260
53261
# File 'lib/google/apis/compute_alpha/classes.rb', line 53259

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


53264
53265
53266
# File 'lib/google/apis/compute_alpha/classes.rb', line 53264

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


53269
53270
53271
# File 'lib/google/apis/compute_alpha/classes.rb', line 53269

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::PublicDelegatedPrefixAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



53274
53275
53276
# File 'lib/google/apis/compute_alpha/classes.rb', line 53274

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



53281
53282
53283
53284
53285
53286
53287
53288
53289
# File 'lib/google/apis/compute_alpha/classes.rb', line 53281

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end