Class: Google::Apis::ComputeAlpha::PublicDelegatedPrefixAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PublicDelegatedPrefixAggregatedList

Returns a new instance of PublicDelegatedPrefixAggregatedList.



53051
53052
53053
# File 'lib/google/apis/compute_alpha/classes.rb', line 53051

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


53012
53013
53014
# File 'lib/google/apis/compute_alpha/classes.rb', line 53012

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::PublicDelegatedPrefixesScopedList>

A list of PublicDelegatedPrefixesScopedList resources. Corresponds to the JSON property items



53017
53018
53019
# File 'lib/google/apis/compute_alpha/classes.rb', line 53017

def items
  @items
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# publicDelegatedPrefixAggregatedList for aggregated lists of public delegated prefixes. Corresponds to the JSON property kind

Returns:

  • (String)


53024
53025
53026
# File 'lib/google/apis/compute_alpha/classes.rb', line 53024

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


53034
53035
53036
# File 'lib/google/apis/compute_alpha/classes.rb', line 53034

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


53039
53040
53041
# File 'lib/google/apis/compute_alpha/classes.rb', line 53039

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


53044
53045
53046
# File 'lib/google/apis/compute_alpha/classes.rb', line 53044

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::PublicDelegatedPrefixAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



53049
53050
53051
# File 'lib/google/apis/compute_alpha/classes.rb', line 53049

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



53056
53057
53058
53059
53060
53061
53062
53063
53064
# File 'lib/google/apis/compute_alpha/classes.rb', line 53056

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end