Class: Google::Apis::ComputeAlpha::PublicDelegatedPrefixAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PublicDelegatedPrefixAggregatedList

Returns a new instance of PublicDelegatedPrefixAggregatedList.



52278
52279
52280
# File 'lib/google/apis/compute_alpha/classes.rb', line 52278

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


52239
52240
52241
# File 'lib/google/apis/compute_alpha/classes.rb', line 52239

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::PublicDelegatedPrefixesScopedList>

A list of PublicDelegatedPrefixesScopedList resources. Corresponds to the JSON property items



52244
52245
52246
# File 'lib/google/apis/compute_alpha/classes.rb', line 52244

def items
  @items
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# publicDelegatedPrefixAggregatedList for aggregated lists of public delegated prefixes. Corresponds to the JSON property kind

Returns:

  • (String)


52251
52252
52253
# File 'lib/google/apis/compute_alpha/classes.rb', line 52251

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


52261
52262
52263
# File 'lib/google/apis/compute_alpha/classes.rb', line 52261

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


52266
52267
52268
# File 'lib/google/apis/compute_alpha/classes.rb', line 52266

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


52271
52272
52273
# File 'lib/google/apis/compute_alpha/classes.rb', line 52271

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::PublicDelegatedPrefixAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



52276
52277
52278
# File 'lib/google/apis/compute_alpha/classes.rb', line 52276

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



52283
52284
52285
52286
52287
52288
52289
52290
52291
# File 'lib/google/apis/compute_alpha/classes.rb', line 52283

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end