Class: Google::Apis::ComputeAlpha::PublicDelegatedPrefixList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::PublicDelegatedPrefixList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::PublicDelegatedPrefix>
A list of PublicDelegatedPrefix resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
-
#warning ⇒ Google::Apis::ComputeAlpha::PublicDelegatedPrefixList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PublicDelegatedPrefixList
constructor
A new instance of PublicDelegatedPrefixList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PublicDelegatedPrefixList
Returns a new instance of PublicDelegatedPrefixList.
53939 53940 53941 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53939 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
53905 53906 53907 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53905 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::PublicDelegatedPrefix>
A list of PublicDelegatedPrefix resources.
Corresponds to the JSON property items
53910 53911 53912 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53910 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#
publicDelegatedPrefixList for public delegated
prefixes.
Corresponds to the JSON property kind
53917 53918 53919 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53917 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
53927 53928 53929 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53927 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
53932 53933 53934 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53932 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::PublicDelegatedPrefixList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
53937 53938 53939 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53937 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
53944 53945 53946 53947 53948 53949 53950 53951 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53944 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |