Class: Google::Apis::ComputeAlpha::PublicDelegatedPrefixList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PublicDelegatedPrefixList

Returns a new instance of PublicDelegatedPrefixList.



53405
53406
53407
# File 'lib/google/apis/compute_alpha/classes.rb', line 53405

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


53371
53372
53373
# File 'lib/google/apis/compute_alpha/classes.rb', line 53371

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::PublicDelegatedPrefix>

A list of PublicDelegatedPrefix resources. Corresponds to the JSON property items



53376
53377
53378
# File 'lib/google/apis/compute_alpha/classes.rb', line 53376

def items
  @items
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# publicDelegatedPrefixList for public delegated prefixes. Corresponds to the JSON property kind

Returns:

  • (String)


53383
53384
53385
# File 'lib/google/apis/compute_alpha/classes.rb', line 53383

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


53393
53394
53395
# File 'lib/google/apis/compute_alpha/classes.rb', line 53393

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


53398
53399
53400
# File 'lib/google/apis/compute_alpha/classes.rb', line 53398

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::PublicDelegatedPrefixList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



53403
53404
53405
# File 'lib/google/apis/compute_alpha/classes.rb', line 53403

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



53410
53411
53412
53413
53414
53415
53416
53417
# File 'lib/google/apis/compute_alpha/classes.rb', line 53410

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end