Class: Google::Apis::ComputeAlpha::PublicDelegatedPrefixList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PublicDelegatedPrefixList

Returns a new instance of PublicDelegatedPrefixList.



53178
53179
53180
# File 'lib/google/apis/compute_alpha/classes.rb', line 53178

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


53144
53145
53146
# File 'lib/google/apis/compute_alpha/classes.rb', line 53144

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::PublicDelegatedPrefix>

A list of PublicDelegatedPrefix resources. Corresponds to the JSON property items



53149
53150
53151
# File 'lib/google/apis/compute_alpha/classes.rb', line 53149

def items
  @items
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# publicDelegatedPrefixList for public delegated prefixes. Corresponds to the JSON property kind

Returns:

  • (String)


53156
53157
53158
# File 'lib/google/apis/compute_alpha/classes.rb', line 53156

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


53166
53167
53168
# File 'lib/google/apis/compute_alpha/classes.rb', line 53166

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


53171
53172
53173
# File 'lib/google/apis/compute_alpha/classes.rb', line 53171

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::PublicDelegatedPrefixList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



53176
53177
53178
# File 'lib/google/apis/compute_alpha/classes.rb', line 53176

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



53183
53184
53185
53186
53187
53188
53189
53190
# File 'lib/google/apis/compute_alpha/classes.rb', line 53183

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end