Class: Google::Apis::ComputeAlpha::PublicDelegatedPrefixPublicDelegatedSubPrefix

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Represents a sub PublicDelegatedPrefix.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PublicDelegatedPrefixPublicDelegatedSubPrefix

Returns a new instance of PublicDelegatedPrefixPublicDelegatedSubPrefix.



54083
54084
54085
# File 'lib/google/apis/compute_alpha/classes.rb', line 54083

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allocatable_prefix_lengthFixnum

The allocatable prefix length supported by this PublicDelegatedSubPrefix. Corresponds to the JSON property allocatablePrefixLength

Returns:

  • (Fixnum)


54014
54015
54016
# File 'lib/google/apis/compute_alpha/classes.rb', line 54014

def allocatable_prefix_length
  @allocatable_prefix_length
end

#delegatee_projectString

Name of the project scoping this PublicDelegatedSubPrefix. Corresponds to the JSON property delegateeProject

Returns:

  • (String)


54019
54020
54021
# File 'lib/google/apis/compute_alpha/classes.rb', line 54019

def delegatee_project
  @delegatee_project
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


54025
54026
54027
# File 'lib/google/apis/compute_alpha/classes.rb', line 54025

def description
  @description
end

#enable_enhanced_ipv4_allocationBoolean Also known as: enable_enhanced_ipv4_allocation?

Output only. [Output Only] Whether this PDP supports enhanced IPv4 allocations. Applicable for IPv4 PDPs only. Corresponds to the JSON property enableEnhancedIpv4Allocation

Returns:

  • (Boolean)


54031
54032
54033
# File 'lib/google/apis/compute_alpha/classes.rb', line 54031

def enable_enhanced_ipv4_allocation
  @enable_enhanced_ipv4_allocation
end

#ip_cidr_rangeString

The IP address range, in CIDR format, represented by this sub public delegated prefix. Corresponds to the JSON property ipCidrRange

Returns:

  • (String)


54038
54039
54040
# File 'lib/google/apis/compute_alpha/classes.rb', line 54038

def ip_cidr_range
  @ip_cidr_range
end

#ipv6_access_typeString

Output only. [Output Only] The internet access type for IPv6 Public Delegated Sub Prefixes. Inherited from parent prefix. Corresponds to the JSON property ipv6AccessType

Returns:

  • (String)


54045
54046
54047
# File 'lib/google/apis/compute_alpha/classes.rb', line 54045

def ipv6_access_type
  @ipv6_access_type
end

#is_addressBoolean Also known as: is_address?

Whether the sub prefix is delegated to create Address resources in the delegatee project. Corresponds to the JSON property isAddress

Returns:

  • (Boolean)


54051
54052
54053
# File 'lib/google/apis/compute_alpha/classes.rb', line 54051

def is_address
  @is_address
end

#modeString

The PublicDelegatedSubPrefix mode for IPv6 only. Corresponds to the JSON property mode

Returns:

  • (String)


54057
54058
54059
# File 'lib/google/apis/compute_alpha/classes.rb', line 54057

def mode
  @mode
end

#nameString

The name of the sub public delegated prefix. Corresponds to the JSON property name

Returns:

  • (String)


54062
54063
54064
# File 'lib/google/apis/compute_alpha/classes.rb', line 54062

def name
  @name
end

#purposeString

Output only. [Output Only] The purpose of the sub public delegated prefix. Inherited from parent prefix. Corresponds to the JSON property purpose

Returns:

  • (String)


54069
54070
54071
# File 'lib/google/apis/compute_alpha/classes.rb', line 54069

def purpose
  @purpose
end

#regionString

Output only. [Output Only] The region of the sub public delegated prefix if it is regional. If absent, the sub prefix is global. Corresponds to the JSON property region

Returns:

  • (String)


54076
54077
54078
# File 'lib/google/apis/compute_alpha/classes.rb', line 54076

def region
  @region
end

#statusString

Output only. [Output Only] The status of the sub public delegated prefix. Corresponds to the JSON property status

Returns:

  • (String)


54081
54082
54083
# File 'lib/google/apis/compute_alpha/classes.rb', line 54081

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



54088
54089
54090
54091
54092
54093
54094
54095
54096
54097
54098
54099
54100
54101
# File 'lib/google/apis/compute_alpha/classes.rb', line 54088

def update!(**args)
  @allocatable_prefix_length = args[:allocatable_prefix_length] if args.key?(:allocatable_prefix_length)
  @delegatee_project = args[:delegatee_project] if args.key?(:delegatee_project)
  @description = args[:description] if args.key?(:description)
  @enable_enhanced_ipv4_allocation = args[:enable_enhanced_ipv4_allocation] if args.key?(:enable_enhanced_ipv4_allocation)
  @ip_cidr_range = args[:ip_cidr_range] if args.key?(:ip_cidr_range)
  @ipv6_access_type = args[:ipv6_access_type] if args.key?(:ipv6_access_type)
  @is_address = args[:is_address] if args.key?(:is_address)
  @mode = args[:mode] if args.key?(:mode)
  @name = args[:name] if args.key?(:name)
  @purpose = args[:purpose] if args.key?(:purpose)
  @region = args[:region] if args.key?(:region)
  @status = args[:status] if args.key?(:status)
end