Class: Google::Apis::ComputeAlpha::PublicDelegatedPrefixPublicDelegatedSubPrefix

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Represents a sub PublicDelegatedPrefix.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PublicDelegatedPrefixPublicDelegatedSubPrefix

Returns a new instance of PublicDelegatedPrefixPublicDelegatedSubPrefix.



53566
53567
53568
# File 'lib/google/apis/compute_alpha/classes.rb', line 53566

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allocatable_prefix_lengthFixnum

The allocatable prefix length supported by this PublicDelegatedSubPrefix. Corresponds to the JSON property allocatablePrefixLength

Returns:

  • (Fixnum)


53497
53498
53499
# File 'lib/google/apis/compute_alpha/classes.rb', line 53497

def allocatable_prefix_length
  @allocatable_prefix_length
end

#delegatee_projectString

Name of the project scoping this PublicDelegatedSubPrefix. Corresponds to the JSON property delegateeProject

Returns:

  • (String)


53502
53503
53504
# File 'lib/google/apis/compute_alpha/classes.rb', line 53502

def delegatee_project
  @delegatee_project
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


53508
53509
53510
# File 'lib/google/apis/compute_alpha/classes.rb', line 53508

def description
  @description
end

#enable_enhanced_ipv4_allocationBoolean Also known as: enable_enhanced_ipv4_allocation?

Output only. [Output Only] Whether this PDP supports enhanced IPv4 allocations. Applicable for IPv4 PDPs only. Corresponds to the JSON property enableEnhancedIpv4Allocation

Returns:

  • (Boolean)


53514
53515
53516
# File 'lib/google/apis/compute_alpha/classes.rb', line 53514

def enable_enhanced_ipv4_allocation
  @enable_enhanced_ipv4_allocation
end

#ip_cidr_rangeString

The IP address range, in CIDR format, represented by this sub public delegated prefix. Corresponds to the JSON property ipCidrRange

Returns:

  • (String)


53521
53522
53523
# File 'lib/google/apis/compute_alpha/classes.rb', line 53521

def ip_cidr_range
  @ip_cidr_range
end

#ipv6_access_typeString

Output only. [Output Only] The internet access type for IPv6 Public Delegated Sub Prefixes. Inherited from parent prefix. Corresponds to the JSON property ipv6AccessType

Returns:

  • (String)


53528
53529
53530
# File 'lib/google/apis/compute_alpha/classes.rb', line 53528

def ipv6_access_type
  @ipv6_access_type
end

#is_addressBoolean Also known as: is_address?

Whether the sub prefix is delegated to create Address resources in the delegatee project. Corresponds to the JSON property isAddress

Returns:

  • (Boolean)


53534
53535
53536
# File 'lib/google/apis/compute_alpha/classes.rb', line 53534

def is_address
  @is_address
end

#modeString

The PublicDelegatedSubPrefix mode for IPv6 only. Corresponds to the JSON property mode

Returns:

  • (String)


53540
53541
53542
# File 'lib/google/apis/compute_alpha/classes.rb', line 53540

def mode
  @mode
end

#nameString

The name of the sub public delegated prefix. Corresponds to the JSON property name

Returns:

  • (String)


53545
53546
53547
# File 'lib/google/apis/compute_alpha/classes.rb', line 53545

def name
  @name
end

#purposeString

Output only. [Output Only] The purpose of the sub public delegated prefix. Inherited from parent prefix. Corresponds to the JSON property purpose

Returns:

  • (String)


53552
53553
53554
# File 'lib/google/apis/compute_alpha/classes.rb', line 53552

def purpose
  @purpose
end

#regionString

Output only. [Output Only] The region of the sub public delegated prefix if it is regional. If absent, the sub prefix is global. Corresponds to the JSON property region

Returns:

  • (String)


53559
53560
53561
# File 'lib/google/apis/compute_alpha/classes.rb', line 53559

def region
  @region
end

#statusString

Output only. [Output Only] The status of the sub public delegated prefix. Corresponds to the JSON property status

Returns:

  • (String)


53564
53565
53566
# File 'lib/google/apis/compute_alpha/classes.rb', line 53564

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



53571
53572
53573
53574
53575
53576
53577
53578
53579
53580
53581
53582
53583
53584
# File 'lib/google/apis/compute_alpha/classes.rb', line 53571

def update!(**args)
  @allocatable_prefix_length = args[:allocatable_prefix_length] if args.key?(:allocatable_prefix_length)
  @delegatee_project = args[:delegatee_project] if args.key?(:delegatee_project)
  @description = args[:description] if args.key?(:description)
  @enable_enhanced_ipv4_allocation = args[:enable_enhanced_ipv4_allocation] if args.key?(:enable_enhanced_ipv4_allocation)
  @ip_cidr_range = args[:ip_cidr_range] if args.key?(:ip_cidr_range)
  @ipv6_access_type = args[:ipv6_access_type] if args.key?(:ipv6_access_type)
  @is_address = args[:is_address] if args.key?(:is_address)
  @mode = args[:mode] if args.key?(:mode)
  @name = args[:name] if args.key?(:name)
  @purpose = args[:purpose] if args.key?(:purpose)
  @region = args[:region] if args.key?(:region)
  @status = args[:status] if args.key?(:status)
end