Class: Google::Apis::ComputeAlpha::PublicDelegatedPrefixPublicDelegatedSubPrefix
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::PublicDelegatedPrefixPublicDelegatedSubPrefix
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Represents a sub PublicDelegatedPrefix.
Instance Attribute Summary collapse
-
#allocatable_prefix_length ⇒ Fixnum
The allocatable prefix length supported by this PublicDelegatedSubPrefix.
-
#delegatee_project ⇒ String
Name of the project scoping this PublicDelegatedSubPrefix.
-
#description ⇒ String
An optional description of this resource.
-
#enable_enhanced_ipv4_allocation ⇒ Boolean
(also: #enable_enhanced_ipv4_allocation?)
Output only.
-
#ip_cidr_range ⇒ String
The IP address range, in CIDR format, represented by this sub public delegated prefix.
-
#ipv6_access_type ⇒ String
Output only.
-
#is_address ⇒ Boolean
(also: #is_address?)
Whether the sub prefix is delegated to create Address resources in the delegatee project.
-
#mode ⇒ String
The PublicDelegatedSubPrefix mode for IPv6 only.
-
#name ⇒ String
The name of the sub public delegated prefix.
-
#purpose ⇒ String
Output only.
-
#region ⇒ String
Output only.
-
#status ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PublicDelegatedPrefixPublicDelegatedSubPrefix
constructor
A new instance of PublicDelegatedPrefixPublicDelegatedSubPrefix.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PublicDelegatedPrefixPublicDelegatedSubPrefix
Returns a new instance of PublicDelegatedPrefixPublicDelegatedSubPrefix.
53564 53565 53566 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53564 def initialize(**args) update!(**args) end |
Instance Attribute Details
#allocatable_prefix_length ⇒ Fixnum
The allocatable prefix length supported by this PublicDelegatedSubPrefix.
Corresponds to the JSON property allocatablePrefixLength
53495 53496 53497 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53495 def allocatable_prefix_length @allocatable_prefix_length end |
#delegatee_project ⇒ String
Name of the project scoping this PublicDelegatedSubPrefix.
Corresponds to the JSON property delegateeProject
53500 53501 53502 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53500 def delegatee_project @delegatee_project end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
53506 53507 53508 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53506 def description @description end |
#enable_enhanced_ipv4_allocation ⇒ Boolean Also known as: enable_enhanced_ipv4_allocation?
Output only. [Output Only] Whether this PDP supports enhanced IPv4 allocations.
Applicable for IPv4 PDPs only.
Corresponds to the JSON property enableEnhancedIpv4Allocation
53512 53513 53514 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53512 def enable_enhanced_ipv4_allocation @enable_enhanced_ipv4_allocation end |
#ip_cidr_range ⇒ String
The IP address range, in CIDR format, represented by this sub public
delegated prefix.
Corresponds to the JSON property ipCidrRange
53519 53520 53521 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53519 def ip_cidr_range @ip_cidr_range end |
#ipv6_access_type ⇒ String
Output only. [Output Only] The internet access type for IPv6 Public Delegated
Sub
Prefixes. Inherited from parent prefix.
Corresponds to the JSON property ipv6AccessType
53526 53527 53528 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53526 def ipv6_access_type @ipv6_access_type end |
#is_address ⇒ Boolean Also known as: is_address?
Whether the sub prefix is delegated to create Address resources in the
delegatee project.
Corresponds to the JSON property isAddress
53532 53533 53534 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53532 def is_address @is_address end |
#mode ⇒ String
The PublicDelegatedSubPrefix mode for IPv6 only.
Corresponds to the JSON property mode
53538 53539 53540 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53538 def mode @mode end |
#name ⇒ String
The name of the sub public delegated prefix.
Corresponds to the JSON property name
53543 53544 53545 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53543 def name @name end |
#purpose ⇒ String
Output only. [Output Only] The purpose of the sub public delegated prefix.
Inherited
from parent prefix.
Corresponds to the JSON property purpose
53550 53551 53552 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53550 def purpose @purpose end |
#region ⇒ String
Output only. [Output Only] The region of the sub public delegated prefix if it
is
regional. If absent, the sub prefix is global.
Corresponds to the JSON property region
53557 53558 53559 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53557 def region @region end |
#status ⇒ String
Output only. [Output Only] The status of the sub public delegated prefix.
Corresponds to the JSON property status
53562 53563 53564 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53562 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
53569 53570 53571 53572 53573 53574 53575 53576 53577 53578 53579 53580 53581 53582 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53569 def update!(**args) @allocatable_prefix_length = args[:allocatable_prefix_length] if args.key?(:allocatable_prefix_length) @delegatee_project = args[:delegatee_project] if args.key?(:delegatee_project) @description = args[:description] if args.key?(:description) @enable_enhanced_ipv4_allocation = args[:enable_enhanced_ipv4_allocation] if args.key?(:enable_enhanced_ipv4_allocation) @ip_cidr_range = args[:ip_cidr_range] if args.key?(:ip_cidr_range) @ipv6_access_type = args[:ipv6_access_type] if args.key?(:ipv6_access_type) @is_address = args[:is_address] if args.key?(:is_address) @mode = args[:mode] if args.key?(:mode) @name = args[:name] if args.key?(:name) @purpose = args[:purpose] if args.key?(:purpose) @region = args[:region] if args.key?(:region) @status = args[:status] if args.key?(:status) end |