Class: Google::Apis::ComputeAlpha::QueuedResource
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::QueuedResource
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
QueuedResource represents a request for future capacity. The capacity is delivered in the form of other GCE resources, either Instances or Reservations.
Instance Attribute Summary collapse
-
#bulk_insert_instance_resource ⇒ Google::Apis::ComputeAlpha::BulkInsertInstanceResource
A transient resource used in compute.instances.bulkInsert and compute.regionInstances.bulkInsert .
-
#creation_timestamp ⇒ String
Output only.
-
#description ⇒ String
An optional description of this resource.
-
#id ⇒ Fixnum
Output only.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
Name of the resource.
-
#queuing_policy ⇒ Google::Apis::ComputeAlpha::QueuingPolicy
Queuing parameters for the requested deferred capacity.
-
#self_link ⇒ String
Output only.
-
#self_link_with_id ⇒ String
Output only.
-
#state ⇒ String
Output only.
-
#status ⇒ Google::Apis::ComputeAlpha::QueuedResourceStatus
[Output only] Result of queuing and provisioning based on deferred capacity.
-
#zone ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ QueuedResource
constructor
A new instance of QueuedResource.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ QueuedResource
Returns a new instance of QueuedResource.
54285 54286 54287 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54285 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bulk_insert_instance_resource ⇒ Google::Apis::ComputeAlpha::BulkInsertInstanceResource
A transient resource used in compute.instances.bulkInsert and
compute.regionInstances.bulkInsert . This resource is not persisted
anywhere, it is used only for processing the requests.
Corresponds to the JSON property bulkInsertInstanceResource
54212 54213 54214 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54212 def bulk_insert_instance_resource @bulk_insert_instance_resource end |
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp in RFC3339
text format.
Corresponds to the JSON property creationTimestamp
54218 54219 54220 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54218 def @creation_timestamp end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
54224 54225 54226 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54224 def description @description end |
#id ⇒ Fixnum
Output only. [Output Only] The unique identifier for the resource. This
identifier is
defined by the server.
Corresponds to the JSON property id
54231 54232 54233 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54231 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#queuedResource
for QueuedResources.
Corresponds to the JSON property kind
54237 54238 54239 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54237 def kind @kind end |
#name ⇒ String
Name of the resource. Provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character
must be a lowercase letter, and all following characters must be a dash,
lowercase letter, or digit, except the last character, which cannot be a
dash.
Corresponds to the JSON property name
54248 54249 54250 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54248 def name @name end |
#queuing_policy ⇒ Google::Apis::ComputeAlpha::QueuingPolicy
Queuing parameters for the requested deferred capacity.
Corresponds to the JSON property queuingPolicy
54253 54254 54255 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54253 def queuing_policy @queuing_policy end |
#self_link ⇒ String
Output only. [Output only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
54258 54259 54260 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54258 def self_link @self_link end |
#self_link_with_id ⇒ String
Output only. [Output Only] Server-defined URL for this resource with the
resource id.
Corresponds to the JSON property selfLinkWithId
54264 54265 54266 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54264 def self_link_with_id @self_link_with_id end |
#state ⇒ String
Output only. [Output only] High-level status of the request.
Corresponds to the JSON property state
54269 54270 54271 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54269 def state @state end |
#status ⇒ Google::Apis::ComputeAlpha::QueuedResourceStatus
[Output only] Result of queuing and provisioning based on deferred
capacity.
Corresponds to the JSON property status
54275 54276 54277 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54275 def status @status end |
#zone ⇒ String
Output only. [Output Only] URL of the zone where the resource resides. Only
applicable
for zonal resources. You must specify this field as part of the HTTP
request URL. It is not settable as a field in the request body.
Corresponds to the JSON property zone
54283 54284 54285 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54283 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
54290 54291 54292 54293 54294 54295 54296 54297 54298 54299 54300 54301 54302 54303 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54290 def update!(**args) @bulk_insert_instance_resource = args[:bulk_insert_instance_resource] if args.key?(:bulk_insert_instance_resource) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @queuing_policy = args[:queuing_policy] if args.key?(:queuing_policy) @self_link = args[:self_link] if args.key?(:self_link) @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id) @state = args[:state] if args.key?(:state) @status = args[:status] if args.key?(:status) @zone = args[:zone] if args.key?(:zone) end |