Class: Google::Apis::ComputeAlpha::QueuedResource
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::QueuedResource
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
QueuedResource represents a request for future capacity. The capacity is delivered in the form of other GCE resources, either Instances or Reservations.
Instance Attribute Summary collapse
-
#bulk_insert_instance_resource ⇒ Google::Apis::ComputeAlpha::BulkInsertInstanceResource
A transient resource used in compute.instances.bulkInsert and compute.regionInstances.bulkInsert .
-
#creation_timestamp ⇒ String
Output only.
-
#description ⇒ String
An optional description of this resource.
-
#id ⇒ Fixnum
Output only.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
Name of the resource.
-
#queuing_policy ⇒ Google::Apis::ComputeAlpha::QueuingPolicy
Queuing parameters for the requested deferred capacity.
-
#self_link ⇒ String
Output only.
-
#self_link_with_id ⇒ String
Output only.
-
#state ⇒ String
Output only.
-
#status ⇒ Google::Apis::ComputeAlpha::QueuedResourceStatus
[Output only] Result of queuing and provisioning based on deferred capacity.
-
#zone ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ QueuedResource
constructor
A new instance of QueuedResource.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ QueuedResource
Returns a new instance of QueuedResource.
52768 52769 52770 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 52768 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bulk_insert_instance_resource ⇒ Google::Apis::ComputeAlpha::BulkInsertInstanceResource
A transient resource used in compute.instances.bulkInsert and
compute.regionInstances.bulkInsert . This resource is not persisted
anywhere, it is used only for processing the requests.
Corresponds to the JSON property bulkInsertInstanceResource
52695 52696 52697 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 52695 def bulk_insert_instance_resource @bulk_insert_instance_resource end |
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp in RFC3339
text format.
Corresponds to the JSON property creationTimestamp
52701 52702 52703 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 52701 def @creation_timestamp end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
52707 52708 52709 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 52707 def description @description end |
#id ⇒ Fixnum
Output only. [Output Only] The unique identifier for the resource. This
identifier is
defined by the server.
Corresponds to the JSON property id
52714 52715 52716 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 52714 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#queuedResource
for QueuedResources.
Corresponds to the JSON property kind
52720 52721 52722 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 52720 def kind @kind end |
#name ⇒ String
Name of the resource. Provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character
must be a lowercase letter, and all following characters must be a dash,
lowercase letter, or digit, except the last character, which cannot be a
dash.
Corresponds to the JSON property name
52731 52732 52733 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 52731 def name @name end |
#queuing_policy ⇒ Google::Apis::ComputeAlpha::QueuingPolicy
Queuing parameters for the requested deferred capacity.
Corresponds to the JSON property queuingPolicy
52736 52737 52738 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 52736 def queuing_policy @queuing_policy end |
#self_link ⇒ String
Output only. [Output only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
52741 52742 52743 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 52741 def self_link @self_link end |
#self_link_with_id ⇒ String
Output only. [Output Only] Server-defined URL for this resource with the
resource id.
Corresponds to the JSON property selfLinkWithId
52747 52748 52749 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 52747 def self_link_with_id @self_link_with_id end |
#state ⇒ String
Output only. [Output only] High-level status of the request.
Corresponds to the JSON property state
52752 52753 52754 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 52752 def state @state end |
#status ⇒ Google::Apis::ComputeAlpha::QueuedResourceStatus
[Output only] Result of queuing and provisioning based on deferred
capacity.
Corresponds to the JSON property status
52758 52759 52760 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 52758 def status @status end |
#zone ⇒ String
Output only. [Output Only] URL of the zone where the resource resides. Only
applicable
for zonal resources. You must specify this field as part of the HTTP
request URL. It is not settable as a field in the request body.
Corresponds to the JSON property zone
52766 52767 52768 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 52766 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
52773 52774 52775 52776 52777 52778 52779 52780 52781 52782 52783 52784 52785 52786 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 52773 def update!(**args) @bulk_insert_instance_resource = args[:bulk_insert_instance_resource] if args.key?(:bulk_insert_instance_resource) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @queuing_policy = args[:queuing_policy] if args.key?(:queuing_policy) @self_link = args[:self_link] if args.key?(:self_link) @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id) @state = args[:state] if args.key?(:state) @status = args[:status] if args.key?(:status) @zone = args[:zone] if args.key?(:zone) end |