Class: Google::Apis::ComputeAlpha::QueuedResourceList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::QueuedResourceList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::QueuedResource>
A list of QueuedResource resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
This token allows you to get the next page of results formaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::QueuedResourceList::Warning
Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ QueuedResourceList
constructor
A new instance of QueuedResourceList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ QueuedResourceList
Returns a new instance of QueuedResourceList.
55948 55949 55950 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 55948 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
55912 55913 55914 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 55912 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::QueuedResource>
A list of QueuedResource resources.
Corresponds to the JSON property items
55917 55918 55919 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 55917 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
55922 55923 55924 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 55922 def kind @kind end |
#next_page_token ⇒ String
This token allows you to get the next page of results formaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
55931 55932 55933 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 55931 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
55936 55937 55938 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 55936 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output only] Unreachable resources.
Corresponds to the JSON property unreachables
55941 55942 55943 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 55941 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::QueuedResourceList::Warning
Informational warning message.
Corresponds to the JSON property warning
55946 55947 55948 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 55946 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
55953 55954 55955 55956 55957 55958 55959 55960 55961 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 55953 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |