Class: Google::Apis::ComputeAlpha::QueuedResourceList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::QueuedResourceList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::QueuedResource>
A list of QueuedResource resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
This token allows you to get the next page of results formaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::QueuedResourceList::Warning
Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ QueuedResourceList
constructor
A new instance of QueuedResourceList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ QueuedResourceList
Returns a new instance of QueuedResourceList.
55707 55708 55709 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 55707 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
55671 55672 55673 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 55671 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::QueuedResource>
A list of QueuedResource resources.
Corresponds to the JSON property items
55676 55677 55678 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 55676 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
55681 55682 55683 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 55681 def kind @kind end |
#next_page_token ⇒ String
This token allows you to get the next page of results formaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
55690 55691 55692 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 55690 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
55695 55696 55697 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 55695 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output only] Unreachable resources.
Corresponds to the JSON property unreachables
55700 55701 55702 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 55700 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::QueuedResourceList::Warning
Informational warning message.
Corresponds to the JSON property warning
55705 55706 55707 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 55705 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
55712 55713 55714 55715 55716 55717 55718 55719 55720 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 55712 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |