Class: Google::Apis::ComputeAlpha::QueuedResourceList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::QueuedResourceList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::QueuedResource>
A list of QueuedResource resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
This token allows you to get the next page of results formaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::QueuedResourceList::Warning
Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ QueuedResourceList
constructor
A new instance of QueuedResourceList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ QueuedResourceList
Returns a new instance of QueuedResourceList.
55422 55423 55424 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 55422 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
55386 55387 55388 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 55386 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::QueuedResource>
A list of QueuedResource resources.
Corresponds to the JSON property items
55391 55392 55393 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 55391 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
55396 55397 55398 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 55396 def kind @kind end |
#next_page_token ⇒ String
This token allows you to get the next page of results formaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
55405 55406 55407 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 55405 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
55410 55411 55412 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 55410 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output only] Unreachable resources.
Corresponds to the JSON property unreachables
55415 55416 55417 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 55415 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::QueuedResourceList::Warning
Informational warning message.
Corresponds to the JSON property warning
55420 55421 55422 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 55420 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
55427 55428 55429 55430 55431 55432 55433 55434 55435 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 55427 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |