Class: Google::Apis::ComputeAlpha::QueuedResourceList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ QueuedResourceList

Returns a new instance of QueuedResourceList.



54366
54367
54368
# File 'lib/google/apis/compute_alpha/classes.rb', line 54366

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


54330
54331
54332
# File 'lib/google/apis/compute_alpha/classes.rb', line 54330

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::QueuedResource>

A list of QueuedResource resources. Corresponds to the JSON property items



54335
54336
54337
# File 'lib/google/apis/compute_alpha/classes.rb', line 54335

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


54340
54341
54342
# File 'lib/google/apis/compute_alpha/classes.rb', line 54340

def kind
  @kind
end

#next_page_tokenString

This token allows you to get the next page of results formaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


54349
54350
54351
# File 'lib/google/apis/compute_alpha/classes.rb', line 54349

def next_page_token
  @next_page_token
end

Output only. [Output only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


54354
54355
54356
# File 'lib/google/apis/compute_alpha/classes.rb', line 54354

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


54359
54360
54361
# File 'lib/google/apis/compute_alpha/classes.rb', line 54359

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::QueuedResourceList::Warning

Informational warning message. Corresponds to the JSON property warning



54364
54365
54366
# File 'lib/google/apis/compute_alpha/classes.rb', line 54364

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



54371
54372
54373
54374
54375
54376
54377
54378
54379
# File 'lib/google/apis/compute_alpha/classes.rb', line 54371

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end