Class: Google::Apis::ComputeAlpha::QueuedResourceList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ QueuedResourceList

Returns a new instance of QueuedResourceList.



54349
54350
54351
# File 'lib/google/apis/compute_alpha/classes.rb', line 54349

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


54313
54314
54315
# File 'lib/google/apis/compute_alpha/classes.rb', line 54313

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::QueuedResource>

A list of QueuedResource resources. Corresponds to the JSON property items



54318
54319
54320
# File 'lib/google/apis/compute_alpha/classes.rb', line 54318

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


54323
54324
54325
# File 'lib/google/apis/compute_alpha/classes.rb', line 54323

def kind
  @kind
end

#next_page_tokenString

This token allows you to get the next page of results formaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


54332
54333
54334
# File 'lib/google/apis/compute_alpha/classes.rb', line 54332

def next_page_token
  @next_page_token
end

Output only. [Output only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


54337
54338
54339
# File 'lib/google/apis/compute_alpha/classes.rb', line 54337

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


54342
54343
54344
# File 'lib/google/apis/compute_alpha/classes.rb', line 54342

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::QueuedResourceList::Warning

Informational warning message. Corresponds to the JSON property warning



54347
54348
54349
# File 'lib/google/apis/compute_alpha/classes.rb', line 54347

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



54354
54355
54356
54357
54358
54359
54360
54361
54362
# File 'lib/google/apis/compute_alpha/classes.rb', line 54354

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end