Class: Google::Apis::ComputeAlpha::QueuedResourceList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::QueuedResourceList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::QueuedResource>
A list of QueuedResource resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
This token allows you to get the next page of results formaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::QueuedResourceList::Warning
Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ QueuedResourceList
constructor
A new instance of QueuedResourceList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ QueuedResourceList
Returns a new instance of QueuedResourceList.
53832 53833 53834 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53832 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
53796 53797 53798 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53796 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::QueuedResource>
A list of QueuedResource resources.
Corresponds to the JSON property items
53801 53802 53803 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53801 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
53806 53807 53808 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53806 def kind @kind end |
#next_page_token ⇒ String
This token allows you to get the next page of results formaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
53815 53816 53817 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53815 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
53820 53821 53822 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53820 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output only] Unreachable resources.
Corresponds to the JSON property unreachables
53825 53826 53827 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53825 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::QueuedResourceList::Warning
Informational warning message.
Corresponds to the JSON property warning
53830 53831 53832 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53830 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
53837 53838 53839 53840 53841 53842 53843 53844 53845 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53837 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |