Class: Google::Apis::ComputeAlpha::QueuedResourceList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ QueuedResourceList

Returns a new instance of QueuedResourceList.



52832
52833
52834
# File 'lib/google/apis/compute_alpha/classes.rb', line 52832

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


52796
52797
52798
# File 'lib/google/apis/compute_alpha/classes.rb', line 52796

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::QueuedResource>

A list of QueuedResource resources. Corresponds to the JSON property items



52801
52802
52803
# File 'lib/google/apis/compute_alpha/classes.rb', line 52801

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


52806
52807
52808
# File 'lib/google/apis/compute_alpha/classes.rb', line 52806

def kind
  @kind
end

#next_page_tokenString

This token allows you to get the next page of results formaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


52815
52816
52817
# File 'lib/google/apis/compute_alpha/classes.rb', line 52815

def next_page_token
  @next_page_token
end

Output only. [Output only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


52820
52821
52822
# File 'lib/google/apis/compute_alpha/classes.rb', line 52820

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


52825
52826
52827
# File 'lib/google/apis/compute_alpha/classes.rb', line 52825

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::QueuedResourceList::Warning

Informational warning message. Corresponds to the JSON property warning



52830
52831
52832
# File 'lib/google/apis/compute_alpha/classes.rb', line 52830

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



52837
52838
52839
52840
52841
52842
52843
52844
52845
# File 'lib/google/apis/compute_alpha/classes.rb', line 52837

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end