Class: Google::Apis::ComputeAlpha::QueuedResourceStatus

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

[Output only] Result of queuing and provisioning based on deferred capacity.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ QueuedResourceStatus

Returns a new instance of QueuedResourceStatus.



55816
55817
55818
# File 'lib/google/apis/compute_alpha/classes.rb', line 55816

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#failed_dataGoogle::Apis::ComputeAlpha::QueuedResourceStatusFailedData

Additional status detail for the FAILED state. Corresponds to the JSON property failedData



55801
55802
55803
# File 'lib/google/apis/compute_alpha/classes.rb', line 55801

def failed_data
  @failed_data
end

#provisioning_operationsArray<String>

Output only. [Output only] Fully qualified URL of the provisioning GCE operation to track the provisioning along with provisioning errors. The referenced operation may not exist after having been deleted or expired. Corresponds to the JSON property provisioningOperations

Returns:

  • (Array<String>)


55809
55810
55811
# File 'lib/google/apis/compute_alpha/classes.rb', line 55809

def provisioning_operations
  @provisioning_operations
end

#queuing_policyGoogle::Apis::ComputeAlpha::QueuingPolicy

Queuing parameters for the requested deferred capacity. Corresponds to the JSON property queuingPolicy



55814
55815
55816
# File 'lib/google/apis/compute_alpha/classes.rb', line 55814

def queuing_policy
  @queuing_policy
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



55821
55822
55823
55824
55825
# File 'lib/google/apis/compute_alpha/classes.rb', line 55821

def update!(**args)
  @failed_data = args[:failed_data] if args.key?(:failed_data)
  @provisioning_operations = args[:provisioning_operations] if args.key?(:provisioning_operations)
  @queuing_policy = args[:queuing_policy] if args.key?(:queuing_policy)
end