Class: Google::Apis::ComputeAlpha::QueuedResourceStatus

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

[Output only] Result of queuing and provisioning based on deferred capacity.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ QueuedResourceStatus

Returns a new instance of QueuedResourceStatus.



52941
52942
52943
# File 'lib/google/apis/compute_alpha/classes.rb', line 52941

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#failed_dataGoogle::Apis::ComputeAlpha::QueuedResourceStatusFailedData

Additional status detail for the FAILED state. Corresponds to the JSON property failedData



52926
52927
52928
# File 'lib/google/apis/compute_alpha/classes.rb', line 52926

def failed_data
  @failed_data
end

#provisioning_operationsArray<String>

Output only. [Output only] Fully qualified URL of the provisioning GCE operation to track the provisioning along with provisioning errors. The referenced operation may not exist after having been deleted or expired. Corresponds to the JSON property provisioningOperations

Returns:

  • (Array<String>)


52934
52935
52936
# File 'lib/google/apis/compute_alpha/classes.rb', line 52934

def provisioning_operations
  @provisioning_operations
end

#queuing_policyGoogle::Apis::ComputeAlpha::QueuingPolicy

Queuing parameters for the requested deferred capacity. Corresponds to the JSON property queuingPolicy



52939
52940
52941
# File 'lib/google/apis/compute_alpha/classes.rb', line 52939

def queuing_policy
  @queuing_policy
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



52946
52947
52948
52949
52950
# File 'lib/google/apis/compute_alpha/classes.rb', line 52946

def update!(**args)
  @failed_data = args[:failed_data] if args.key?(:failed_data)
  @provisioning_operations = args[:provisioning_operations] if args.key?(:provisioning_operations)
  @queuing_policy = args[:queuing_policy] if args.key?(:queuing_policy)
end