Class: Google::Apis::ComputeAlpha::QueuedResourcesAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ QueuedResourcesAggregatedList

Returns a new instance of QueuedResourcesAggregatedList.



55731
55732
55733
# File 'lib/google/apis/compute_alpha/classes.rb', line 55731

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


55692
55693
55694
# File 'lib/google/apis/compute_alpha/classes.rb', line 55692

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::QueuedResourcesScopedList>

A list of QueuedResourcesScopedList resources. Corresponds to the JSON property items



55697
55698
55699
# File 'lib/google/apis/compute_alpha/classes.rb', line 55697

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# queuedResourcesAggregatedList for lists of QueuedResource. Corresponds to the JSON property kind

Returns:

  • (String)


55704
55705
55706
# File 'lib/google/apis/compute_alpha/classes.rb', line 55704

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


55714
55715
55716
# File 'lib/google/apis/compute_alpha/classes.rb', line 55714

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


55719
55720
55721
# File 'lib/google/apis/compute_alpha/classes.rb', line 55719

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


55724
55725
55726
# File 'lib/google/apis/compute_alpha/classes.rb', line 55724

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::QueuedResourcesAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



55729
55730
55731
# File 'lib/google/apis/compute_alpha/classes.rb', line 55729

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



55736
55737
55738
55739
55740
55741
55742
55743
55744
# File 'lib/google/apis/compute_alpha/classes.rb', line 55736

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end