Class: Google::Apis::ComputeAlpha::QueuedResourcesAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ QueuedResourcesAggregatedList

Returns a new instance of QueuedResourcesAggregatedList.



54673
54674
54675
# File 'lib/google/apis/compute_alpha/classes.rb', line 54673

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


54634
54635
54636
# File 'lib/google/apis/compute_alpha/classes.rb', line 54634

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::QueuedResourcesScopedList>

A list of QueuedResourcesScopedList resources. Corresponds to the JSON property items



54639
54640
54641
# File 'lib/google/apis/compute_alpha/classes.rb', line 54639

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# queuedResourcesAggregatedList for lists of QueuedResource. Corresponds to the JSON property kind

Returns:

  • (String)


54646
54647
54648
# File 'lib/google/apis/compute_alpha/classes.rb', line 54646

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


54656
54657
54658
# File 'lib/google/apis/compute_alpha/classes.rb', line 54656

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


54661
54662
54663
# File 'lib/google/apis/compute_alpha/classes.rb', line 54661

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


54666
54667
54668
# File 'lib/google/apis/compute_alpha/classes.rb', line 54666

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::QueuedResourcesAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



54671
54672
54673
# File 'lib/google/apis/compute_alpha/classes.rb', line 54671

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



54678
54679
54680
54681
54682
54683
54684
54685
54686
# File 'lib/google/apis/compute_alpha/classes.rb', line 54678

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end