Class: Google::Apis::ComputeAlpha::QueuedResourcesAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::QueuedResourcesAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::QueuedResourcesScopedList>
A list of QueuedResourcesScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::QueuedResourcesAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ QueuedResourcesAggregatedList
constructor
A new instance of QueuedResourcesAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ QueuedResourcesAggregatedList
Returns a new instance of QueuedResourcesAggregatedList.
54139 54140 54141 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54139 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
54100 54101 54102 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54100 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::QueuedResourcesScopedList>
A list of QueuedResourcesScopedList resources.
Corresponds to the JSON property items
54105 54106 54107 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54105 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
queuedResourcesAggregatedList for lists of
QueuedResource.
Corresponds to the JSON property kind
54112 54113 54114 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54112 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
54122 54123 54124 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54122 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
54127 54128 54129 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54127 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
54132 54133 54134 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54132 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::QueuedResourcesAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
54137 54138 54139 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54137 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
54144 54145 54146 54147 54148 54149 54150 54151 54152 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54144 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |