Class: Google::Apis::ComputeAlpha::QueuedResourcesAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ QueuedResourcesAggregatedList

Returns a new instance of QueuedResourcesAggregatedList.



53912
53913
53914
# File 'lib/google/apis/compute_alpha/classes.rb', line 53912

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


53873
53874
53875
# File 'lib/google/apis/compute_alpha/classes.rb', line 53873

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::QueuedResourcesScopedList>

A list of QueuedResourcesScopedList resources. Corresponds to the JSON property items



53878
53879
53880
# File 'lib/google/apis/compute_alpha/classes.rb', line 53878

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# queuedResourcesAggregatedList for lists of QueuedResource. Corresponds to the JSON property kind

Returns:

  • (String)


53885
53886
53887
# File 'lib/google/apis/compute_alpha/classes.rb', line 53885

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


53895
53896
53897
# File 'lib/google/apis/compute_alpha/classes.rb', line 53895

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


53900
53901
53902
# File 'lib/google/apis/compute_alpha/classes.rb', line 53900

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


53905
53906
53907
# File 'lib/google/apis/compute_alpha/classes.rb', line 53905

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::QueuedResourcesAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



53910
53911
53912
# File 'lib/google/apis/compute_alpha/classes.rb', line 53910

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



53917
53918
53919
53920
53921
53922
53923
53924
53925
# File 'lib/google/apis/compute_alpha/classes.rb', line 53917

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end