Class: Google::Apis::ComputeAlpha::QueuingPolicy
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::QueuingPolicy
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Queuing parameters for the requested deferred capacity.
Instance Attribute Summary collapse
-
#valid_until_duration ⇒ Google::Apis::ComputeAlpha::Duration
A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution.
-
#valid_until_time ⇒ String
Absolute deadline for waiting for capacity inRFC3339 text format.
Instance Method Summary collapse
-
#initialize(**args) ⇒ QueuingPolicy
constructor
A new instance of QueuingPolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ QueuingPolicy
Returns a new instance of QueuingPolicy.
54338 54339 54340 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54338 def initialize(**args) update!(**args) end |
Instance Attribute Details
#valid_until_duration ⇒ Google::Apis::ComputeAlpha::Duration
A Duration represents a fixed-length span of time represented
as a count of seconds and fractions of seconds at nanosecond
resolution. It is independent of any calendar and concepts like "day"
or "month". Range is approximately 10,000 years.
Corresponds to the JSON property validUntilDuration
54330 54331 54332 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54330 def valid_until_duration @valid_until_duration end |
#valid_until_time ⇒ String
Absolute deadline for waiting for capacity inRFC3339
text format.
Corresponds to the JSON property validUntilTime
54336 54337 54338 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54336 def valid_until_time @valid_until_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
54343 54344 54345 54346 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54343 def update!(**args) @valid_until_duration = args[:valid_until_duration] if args.key?(:valid_until_duration) @valid_until_time = args[:valid_until_time] if args.key?(:valid_until_time) end |