Class: Google::Apis::ComputeAlpha::RecoverableSnapshot

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Represents a RecoverableSnapshot resource. A RecoverableSnapshot represents a snapshot in recycle bin.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RecoverableSnapshot

Returns a new instance of RecoverableSnapshot.



55068
55069
55070
# File 'lib/google/apis/compute_alpha/classes.rb', line 55068

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


54997
54998
54999
# File 'lib/google/apis/compute_alpha/classes.rb', line 54997

def creation_timestamp
  @creation_timestamp
end

#descriptionString

Optional. An optional description of this resource. Corresponds to the JSON property description

Returns:

  • (String)


55002
55003
55004
# File 'lib/google/apis/compute_alpha/classes.rb', line 55002

def description
  @description
end

#idFixnum

Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


55009
55010
55011
# File 'lib/google/apis/compute_alpha/classes.rb', line 55009

def id
  @id
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# recoverableSnapshot for RecoverableSnapshot resources. Corresponds to the JSON property kind

Returns:

  • (String)


55016
55017
55018
# File 'lib/google/apis/compute_alpha/classes.rb', line 55016

def kind
  @kind
end

#nameString

Output only. Identifier. Name of the recoverable snapshot generated on the deletion of the snapshot. The name will be 1-63 characters long, and comply withRFC1035. Specifically, the name will be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character will be a lowercase letter, and all following characters can be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


55028
55029
55030
# File 'lib/google/apis/compute_alpha/classes.rb', line 55028

def name
  @name
end

#original_resourceGoogle::Apis::ComputeAlpha::RecoverableSnapshotOriginalSnapshot

Output only. Output Only] The original snapshot resource. Corresponds to the JSON property originalResource



55033
55034
55035
# File 'lib/google/apis/compute_alpha/classes.rb', line 55033

def original_resource
  @original_resource
end

#purge_timestampString

Output only. [Output Only] Purge timestamp of recoverable snapshot inRFC3339 text format. Corresponds to the JSON property purgeTimestamp

Returns:

  • (String)


55039
55040
55041
# File 'lib/google/apis/compute_alpha/classes.rb', line 55039

def purge_timestamp
  @purge_timestamp
end

#satisfies_pziBoolean Also known as: satisfies_pzi?

Output only. [Output Only] Reserved for future use. Corresponds to the JSON property satisfiesPzi

Returns:

  • (Boolean)


55044
55045
55046
# File 'lib/google/apis/compute_alpha/classes.rb', line 55044

def satisfies_pzi
  @satisfies_pzi
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

Output only. [Output Only] Reserved for future use. Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


55050
55051
55052
# File 'lib/google/apis/compute_alpha/classes.rb', line 55050

def satisfies_pzs
  @satisfies_pzs
end

Output only. [Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


55056
55057
55058
# File 'lib/google/apis/compute_alpha/classes.rb', line 55056

def self_link
  @self_link
end

Output only. [Output Only] Server-defined URL for this resource's resource id. Corresponds to the JSON property selfLinkWithId

Returns:

  • (String)


55061
55062
55063
# File 'lib/google/apis/compute_alpha/classes.rb', line 55061

def self_link_with_id
  @self_link_with_id
end

#statusString

Output only. [Output Only] Status of the recoverable snapshot. Corresponds to the JSON property status

Returns:

  • (String)


55066
55067
55068
# File 'lib/google/apis/compute_alpha/classes.rb', line 55066

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



55073
55074
55075
55076
55077
55078
55079
55080
55081
55082
55083
55084
55085
55086
# File 'lib/google/apis/compute_alpha/classes.rb', line 55073

def update!(**args)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @original_resource = args[:original_resource] if args.key?(:original_resource)
  @purge_timestamp = args[:purge_timestamp] if args.key?(:purge_timestamp)
  @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @self_link = args[:self_link] if args.key?(:self_link)
  @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id)
  @status = args[:status] if args.key?(:status)
end