Class: Google::Apis::ComputeAlpha::RecoverableSnapshot
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::RecoverableSnapshot
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Represents a RecoverableSnapshot resource. A RecoverableSnapshot represents a snapshot in recycle bin.
Instance Attribute Summary collapse
-
#creation_timestamp ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#id ⇒ Fixnum
Output only.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
Output only.
-
#original_resource ⇒ Google::Apis::ComputeAlpha::RecoverableSnapshotOriginalSnapshot
Output only.
-
#purge_timestamp ⇒ String
Output only.
-
#satisfies_pzi ⇒ Boolean
(also: #satisfies_pzi?)
Output only.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
Output only.
-
#self_link ⇒ String
Output only.
-
#self_link_with_id ⇒ String
Output only.
-
#status ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RecoverableSnapshot
constructor
A new instance of RecoverableSnapshot.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RecoverableSnapshot
Returns a new instance of RecoverableSnapshot.
54549 54550 54551 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54549 def initialize(**args) update!(**args) end |
Instance Attribute Details
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
54478 54479 54480 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54478 def @creation_timestamp end |
#description ⇒ String
Optional. An optional description of this resource.
Corresponds to the JSON property description
54483 54484 54485 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54483 def description @description end |
#id ⇒ Fixnum
Output only. [Output Only] The unique identifier for the resource. This
identifier is
defined by the server.
Corresponds to the JSON property id
54490 54491 54492 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54490 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#
recoverableSnapshot for RecoverableSnapshot
resources.
Corresponds to the JSON property kind
54497 54498 54499 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54497 def kind @kind end |
#name ⇒ String
Output only. Identifier. Name of the recoverable snapshot generated on the
deletion of the snapshot.
The name will be 1-63 characters long, and comply withRFC1035.
Specifically, the name will be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character will be a lowercase letter, and all following characters can be
a dash, lowercase letter, or digit, except the last character, which cannot
be a dash.
Corresponds to the JSON property name
54509 54510 54511 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54509 def name @name end |
#original_resource ⇒ Google::Apis::ComputeAlpha::RecoverableSnapshotOriginalSnapshot
Output only. Output Only] The original snapshot resource.
Corresponds to the JSON property originalResource
54514 54515 54516 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54514 def original_resource @original_resource end |
#purge_timestamp ⇒ String
Output only. [Output Only] Purge timestamp of recoverable snapshot inRFC3339
text format.
Corresponds to the JSON property purgeTimestamp
54520 54521 54522 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54520 def @purge_timestamp end |
#satisfies_pzi ⇒ Boolean Also known as: satisfies_pzi?
Output only. [Output Only] Reserved for future use.
Corresponds to the JSON property satisfiesPzi
54525 54526 54527 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54525 def satisfies_pzi @satisfies_pzi end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
Output only. [Output Only] Reserved for future use.
Corresponds to the JSON property satisfiesPzs
54531 54532 54533 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54531 def satisfies_pzs @satisfies_pzs end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
54537 54538 54539 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54537 def self_link @self_link end |
#self_link_with_id ⇒ String
Output only. [Output Only] Server-defined URL for this resource's resource id.
Corresponds to the JSON property selfLinkWithId
54542 54543 54544 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54542 def self_link_with_id @self_link_with_id end |
#status ⇒ String
Output only. [Output Only] Status of the recoverable snapshot.
Corresponds to the JSON property status
54547 54548 54549 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54547 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
54554 54555 54556 54557 54558 54559 54560 54561 54562 54563 54564 54565 54566 54567 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54554 def update!(**args) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @original_resource = args[:original_resource] if args.key?(:original_resource) @purge_timestamp = args[:purge_timestamp] if args.key?(:purge_timestamp) @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @self_link = args[:self_link] if args.key?(:self_link) @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id) @status = args[:status] if args.key?(:status) end |