Class: Google::Apis::ComputeAlpha::RecoverableSnapshot
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::RecoverableSnapshot
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Represents a RecoverableSnapshot resource. A RecoverableSnapshot represents a snapshot in recycle bin.
Instance Attribute Summary collapse
-
#creation_timestamp ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#id ⇒ Fixnum
Output only.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
Output only.
-
#original_resource ⇒ Google::Apis::ComputeAlpha::RecoverableSnapshotOriginalSnapshot
Output only.
-
#purge_timestamp ⇒ String
Output only.
-
#satisfies_pzi ⇒ Boolean
(also: #satisfies_pzi?)
Output only.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
Output only.
-
#self_link ⇒ String
Output only.
-
#self_link_with_id ⇒ String
Output only.
-
#status ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RecoverableSnapshot
constructor
A new instance of RecoverableSnapshot.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RecoverableSnapshot
Returns a new instance of RecoverableSnapshot.
54324 54325 54326 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54324 def initialize(**args) update!(**args) end |
Instance Attribute Details
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
54253 54254 54255 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54253 def @creation_timestamp end |
#description ⇒ String
Optional. An optional description of this resource.
Corresponds to the JSON property description
54258 54259 54260 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54258 def description @description end |
#id ⇒ Fixnum
Output only. [Output Only] The unique identifier for the resource. This
identifier is
defined by the server.
Corresponds to the JSON property id
54265 54266 54267 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54265 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#
recoverableSnapshot for RecoverableSnapshot
resources.
Corresponds to the JSON property kind
54272 54273 54274 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54272 def kind @kind end |
#name ⇒ String
Output only. Identifier. Name of the recoverable snapshot generated on the
deletion of the snapshot.
The name will be 1-63 characters long, and comply withRFC1035.
Specifically, the name will be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character will be a lowercase letter, and all following characters can be
a dash, lowercase letter, or digit, except the last character, which cannot
be a dash.
Corresponds to the JSON property name
54284 54285 54286 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54284 def name @name end |
#original_resource ⇒ Google::Apis::ComputeAlpha::RecoverableSnapshotOriginalSnapshot
Output only. Output Only] The original snapshot resource.
Corresponds to the JSON property originalResource
54289 54290 54291 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54289 def original_resource @original_resource end |
#purge_timestamp ⇒ String
Output only. [Output Only] Purge timestamp of recoverable snapshot inRFC3339
text format.
Corresponds to the JSON property purgeTimestamp
54295 54296 54297 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54295 def @purge_timestamp end |
#satisfies_pzi ⇒ Boolean Also known as: satisfies_pzi?
Output only. [Output Only] Reserved for future use.
Corresponds to the JSON property satisfiesPzi
54300 54301 54302 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54300 def satisfies_pzi @satisfies_pzi end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
Output only. [Output Only] Reserved for future use.
Corresponds to the JSON property satisfiesPzs
54306 54307 54308 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54306 def satisfies_pzs @satisfies_pzs end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
54312 54313 54314 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54312 def self_link @self_link end |
#self_link_with_id ⇒ String
Output only. [Output Only] Server-defined URL for this resource's resource id.
Corresponds to the JSON property selfLinkWithId
54317 54318 54319 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54317 def self_link_with_id @self_link_with_id end |
#status ⇒ String
Output only. [Output Only] Status of the recoverable snapshot.
Corresponds to the JSON property status
54322 54323 54324 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54322 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
54329 54330 54331 54332 54333 54334 54335 54336 54337 54338 54339 54340 54341 54342 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54329 def update!(**args) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @original_resource = args[:original_resource] if args.key?(:original_resource) @purge_timestamp = args[:purge_timestamp] if args.key?(:purge_timestamp) @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @self_link = args[:self_link] if args.key?(:self_link) @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id) @status = args[:status] if args.key?(:status) end |