Class: Google::Apis::ComputeAlpha::RecoverableSnapshotList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::RecoverableSnapshotList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::RecoverableSnapshot>
A list of RecoverableSnapshots resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::RecoverableSnapshotList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RecoverableSnapshotList
constructor
A new instance of RecoverableSnapshotList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RecoverableSnapshotList
Returns a new instance of RecoverableSnapshotList.
56882 56883 56884 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 56882 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
56837 56838 56839 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 56837 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
56842 56843 56844 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 56842 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::RecoverableSnapshot>
A list of RecoverableSnapshots resources.
Corresponds to the JSON property items
56847 56848 56849 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 56847 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
recoverableSnapshotList for lists of
recoverablesnapshots.
Corresponds to the JSON property kind
56854 56855 56856 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 56854 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
56864 56865 56866 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 56864 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
56869 56870 56871 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 56869 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
end_interface: MixerListResponseWithEtagBuilder
Corresponds to the JSON property unreachables
56875 56876 56877 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 56875 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::RecoverableSnapshotList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
56880 56881 56882 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 56880 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
56887 56888 56889 56890 56891 56892 56893 56894 56895 56896 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 56887 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |