Class: Google::Apis::ComputeAlpha::RecoverableSnapshotList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RecoverableSnapshotList

Returns a new instance of RecoverableSnapshotList.



56356
56357
56358
# File 'lib/google/apis/compute_alpha/classes.rb', line 56356

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


56311
56312
56313
# File 'lib/google/apis/compute_alpha/classes.rb', line 56311

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


56316
56317
56318
# File 'lib/google/apis/compute_alpha/classes.rb', line 56316

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::RecoverableSnapshot>

A list of RecoverableSnapshots resources. Corresponds to the JSON property items



56321
56322
56323
# File 'lib/google/apis/compute_alpha/classes.rb', line 56321

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# recoverableSnapshotList for lists of recoverablesnapshots. Corresponds to the JSON property kind

Returns:

  • (String)


56328
56329
56330
# File 'lib/google/apis/compute_alpha/classes.rb', line 56328

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


56338
56339
56340
# File 'lib/google/apis/compute_alpha/classes.rb', line 56338

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


56343
56344
56345
# File 'lib/google/apis/compute_alpha/classes.rb', line 56343

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


56349
56350
56351
# File 'lib/google/apis/compute_alpha/classes.rb', line 56349

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::RecoverableSnapshotList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



56354
56355
56356
# File 'lib/google/apis/compute_alpha/classes.rb', line 56354

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



56361
56362
56363
56364
56365
56366
56367
56368
56369
56370
# File 'lib/google/apis/compute_alpha/classes.rb', line 56361

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end