Class: Google::Apis::ComputeAlpha::RecoverableSnapshotList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RecoverableSnapshotList

Returns a new instance of RecoverableSnapshotList.



55298
55299
55300
# File 'lib/google/apis/compute_alpha/classes.rb', line 55298

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


55253
55254
55255
# File 'lib/google/apis/compute_alpha/classes.rb', line 55253

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


55258
55259
55260
# File 'lib/google/apis/compute_alpha/classes.rb', line 55258

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::RecoverableSnapshot>

A list of RecoverableSnapshots resources. Corresponds to the JSON property items



55263
55264
55265
# File 'lib/google/apis/compute_alpha/classes.rb', line 55263

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# recoverableSnapshotList for lists of recoverablesnapshots. Corresponds to the JSON property kind

Returns:

  • (String)


55270
55271
55272
# File 'lib/google/apis/compute_alpha/classes.rb', line 55270

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


55280
55281
55282
# File 'lib/google/apis/compute_alpha/classes.rb', line 55280

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


55285
55286
55287
# File 'lib/google/apis/compute_alpha/classes.rb', line 55285

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


55291
55292
55293
# File 'lib/google/apis/compute_alpha/classes.rb', line 55291

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::RecoverableSnapshotList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



55296
55297
55298
# File 'lib/google/apis/compute_alpha/classes.rb', line 55296

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



55303
55304
55305
55306
55307
55308
55309
55310
55311
55312
# File 'lib/google/apis/compute_alpha/classes.rb', line 55303

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end