Class: Google::Apis::ComputeAlpha::RecoverableSnapshotList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RecoverableSnapshotList

Returns a new instance of RecoverableSnapshotList.



55281
55282
55283
# File 'lib/google/apis/compute_alpha/classes.rb', line 55281

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


55236
55237
55238
# File 'lib/google/apis/compute_alpha/classes.rb', line 55236

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


55241
55242
55243
# File 'lib/google/apis/compute_alpha/classes.rb', line 55241

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::RecoverableSnapshot>

A list of RecoverableSnapshots resources. Corresponds to the JSON property items



55246
55247
55248
# File 'lib/google/apis/compute_alpha/classes.rb', line 55246

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# recoverableSnapshotList for lists of recoverablesnapshots. Corresponds to the JSON property kind

Returns:

  • (String)


55253
55254
55255
# File 'lib/google/apis/compute_alpha/classes.rb', line 55253

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


55263
55264
55265
# File 'lib/google/apis/compute_alpha/classes.rb', line 55263

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


55268
55269
55270
# File 'lib/google/apis/compute_alpha/classes.rb', line 55268

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


55274
55275
55276
# File 'lib/google/apis/compute_alpha/classes.rb', line 55274

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::RecoverableSnapshotList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



55279
55280
55281
# File 'lib/google/apis/compute_alpha/classes.rb', line 55279

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



55286
55287
55288
55289
55290
55291
55292
55293
55294
55295
# File 'lib/google/apis/compute_alpha/classes.rb', line 55286

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end