Class: Google::Apis::ComputeAlpha::RecoverableSnapshotList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::RecoverableSnapshotList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::RecoverableSnapshot>
A list of RecoverableSnapshots resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::RecoverableSnapshotList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RecoverableSnapshotList
constructor
A new instance of RecoverableSnapshotList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RecoverableSnapshotList
Returns a new instance of RecoverableSnapshotList.
54764 54765 54766 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54764 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
54719 54720 54721 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54719 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
54724 54725 54726 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54724 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::RecoverableSnapshot>
A list of RecoverableSnapshots resources.
Corresponds to the JSON property items
54729 54730 54731 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54729 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
recoverableSnapshotList for lists of
recoverablesnapshots.
Corresponds to the JSON property kind
54736 54737 54738 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54736 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
54746 54747 54748 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54746 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
54751 54752 54753 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54751 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
end_interface: MixerListResponseWithEtagBuilder
Corresponds to the JSON property unreachables
54757 54758 54759 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54757 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::RecoverableSnapshotList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
54762 54763 54764 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54762 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
54769 54770 54771 54772 54773 54774 54775 54776 54777 54778 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54769 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |