Class: Google::Apis::ComputeAlpha::RecoverableSnapshotList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RecoverableSnapshotList

Returns a new instance of RecoverableSnapshotList.



54537
54538
54539
# File 'lib/google/apis/compute_alpha/classes.rb', line 54537

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


54492
54493
54494
# File 'lib/google/apis/compute_alpha/classes.rb', line 54492

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


54497
54498
54499
# File 'lib/google/apis/compute_alpha/classes.rb', line 54497

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::RecoverableSnapshot>

A list of RecoverableSnapshots resources. Corresponds to the JSON property items



54502
54503
54504
# File 'lib/google/apis/compute_alpha/classes.rb', line 54502

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# recoverableSnapshotList for lists of recoverablesnapshots. Corresponds to the JSON property kind

Returns:

  • (String)


54509
54510
54511
# File 'lib/google/apis/compute_alpha/classes.rb', line 54509

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


54519
54520
54521
# File 'lib/google/apis/compute_alpha/classes.rb', line 54519

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


54524
54525
54526
# File 'lib/google/apis/compute_alpha/classes.rb', line 54524

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


54530
54531
54532
# File 'lib/google/apis/compute_alpha/classes.rb', line 54530

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::RecoverableSnapshotList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



54535
54536
54537
# File 'lib/google/apis/compute_alpha/classes.rb', line 54535

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



54542
54543
54544
54545
54546
54547
54548
54549
54550
54551
# File 'lib/google/apis/compute_alpha/classes.rb', line 54542

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end