Class: Google::Apis::ComputeAlpha::RecoverableSnapshotList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::RecoverableSnapshotList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::RecoverableSnapshot>
A list of RecoverableSnapshots resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::RecoverableSnapshotList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RecoverableSnapshotList
constructor
A new instance of RecoverableSnapshotList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RecoverableSnapshotList
Returns a new instance of RecoverableSnapshotList.
53764 53765 53766 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53764 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
53719 53720 53721 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53719 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
53724 53725 53726 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53724 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::RecoverableSnapshot>
A list of RecoverableSnapshots resources.
Corresponds to the JSON property items
53729 53730 53731 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53729 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
recoverableSnapshotList for lists of
recoverablesnapshots.
Corresponds to the JSON property kind
53736 53737 53738 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53736 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
53746 53747 53748 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53746 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
53751 53752 53753 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53751 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
end_interface: MixerListResponseWithEtagBuilder
Corresponds to the JSON property unreachables
53757 53758 53759 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53757 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::RecoverableSnapshotList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
53762 53763 53764 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53762 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
53769 53770 53771 53772 53773 53774 53775 53776 53777 53778 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53769 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |