Class: Google::Apis::ComputeAlpha::RecoverableSnapshotOriginalSnapshot
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::RecoverableSnapshotOriginalSnapshot
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#architecture ⇒ String
Output only.
-
#auto_created ⇒ Boolean
(also: #auto_created?)
Output only.
-
#auto_created_by ⇒ String
ResourceKey of the resource policy or flow which created this auto snapshot Corresponds to the JSON property
autoCreatedBy. -
#chain_name ⇒ String
Creates the new snapshot in the snapshot chain labeled with the specified name.
-
#creation_size_bytes ⇒ Fixnum
Output only.
-
#creation_timestamp ⇒ String
Output only.
-
#deletion_timestamp ⇒ String
Output only.
-
#description ⇒ String
An optional description of this resource.
-
#disk_size_gb ⇒ Fixnum
Output only.
-
#download_bytes ⇒ Fixnum
Output only.
-
#enable_confidential_compute ⇒ Boolean
(also: #enable_confidential_compute?)
Output only.
-
#full ⇒ Boolean
(also: #full?)
Indicates the created snapshot is a full snapshot.
-
#guest_os_features ⇒ Array<Google::Apis::ComputeAlpha::GuestOsFeature>
Output only.
-
#id ⇒ Fixnum
Output only.
-
#label_fingerprint ⇒ String
A fingerprint for the labels being applied to this snapshot, which is essentially a hash of the labels set used for optimistic locking.
-
#labels ⇒ Hash<String,String>
Labels to apply to this snapshot.
-
#license_codes ⇒ Array<Fixnum>
Output only.
-
#licenses ⇒ Array<String>
Output only.
-
#max_retention_days ⇒ Fixnum
Number of days the snapshot should be retained before being deleted automatically.
-
#name ⇒ String
Name of the original snapshot provided by the client.
-
#region ⇒ String
Output only.
-
#satisfies_pzi ⇒ Boolean
(also: #satisfies_pzi?)
Output only.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
Output only.
-
#self_link ⇒ String
Output only.
-
#self_link_with_id ⇒ String
Output only.
-
#snapshot_encryption_key ⇒ Google::Apis::ComputeAlpha::CustomerEncryptionKey
Encrypts the snapshot using acustomer-supplied encryption key.
-
#snapshot_group_id ⇒ String
Output only.
-
#snapshot_group_name ⇒ String
Output only.
-
#snapshot_type ⇒ String
Indicates the type of the snapshot.
-
#source_disk ⇒ String
The source disk used to create this snapshot.
-
#source_disk_encryption_key ⇒ Google::Apis::ComputeAlpha::CustomerEncryptionKey
The customer-supplied encryption key of the source disk.
-
#source_disk_for_recovery_checkpoint ⇒ String
The source disk whose recovery checkpoint will be used to create this snapshot.
-
#source_disk_id ⇒ String
Output only.
-
#source_instant_snapshot ⇒ String
The source instant snapshot used to create this snapshot.
-
#source_instant_snapshot_encryption_key ⇒ Google::Apis::ComputeAlpha::CustomerEncryptionKey
Customer provided encryption key when creating Snapshot from Instant Snapshot.
-
#source_instant_snapshot_id ⇒ String
Output only.
-
#source_snapshot_schedule_policy ⇒ String
Output only.
-
#source_snapshot_schedule_policy_id ⇒ String
Output only.
-
#storage_bytes ⇒ Fixnum
Output only.
-
#storage_bytes_status ⇒ String
Output only.
-
#storage_locations ⇒ Array<String>
Cloud Storage bucket storage location of the snapshot (regional or multi-regional).
Instance Method Summary collapse
-
#initialize(**args) ⇒ RecoverableSnapshotOriginalSnapshot
constructor
A new instance of RecoverableSnapshotOriginalSnapshot.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RecoverableSnapshotOriginalSnapshot
Returns a new instance of RecoverableSnapshotOriginalSnapshot.
55137 55138 55139 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 55137 def initialize(**args) update!(**args) end |
Instance Attribute Details
#architecture ⇒ String
Output only. [Output Only] The architecture of the snapshot. Valid values are
ARM64 or X86_64.
Corresponds to the JSON property architecture
54859 54860 54861 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54859 def architecture @architecture end |
#auto_created ⇒ Boolean Also known as: auto_created?
Output only. [Output Only] Set to true if snapshots are automatically created
by
applying resource policy on the target disk.
Corresponds to the JSON property autoCreated
54866 54867 54868 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54866 def auto_created @auto_created end |
#auto_created_by ⇒ String
ResourceKey of the resource policy or flow which created this auto
snapshot
Corresponds to the JSON property autoCreatedBy
54873 54874 54875 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54873 def auto_created_by @auto_created_by end |
#chain_name ⇒ String
Creates the new snapshot in the snapshot chain labeled with the
specified name. The chain name must be 1-63 characters long and comply
with RFC1035. This is an uncommon option only for advanced service
owners who needs to create separate snapshot chains, for example,
for chargeback tracking. When you describe your snapshot resource, this
field is visible only if it has a non-empty value.
Corresponds to the JSON property chainName
54883 54884 54885 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54883 def chain_name @chain_name end |
#creation_size_bytes ⇒ Fixnum
Output only. [Output Only] Size in bytes of the snapshot at creation time.
Corresponds to the JSON property creationSizeBytes
54888 54889 54890 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54888 def creation_size_bytes @creation_size_bytes end |
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339 text format.
Corresponds to the JSON property creationTimestamp
54893 54894 54895 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54893 def @creation_timestamp end |
#deletion_timestamp ⇒ String
Output only. [Output Only] Purge timestamp of recoverable snapshot inRFC3339
text format.
Corresponds to the JSON property deletionTimestamp
54899 54900 54901 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54899 def @deletion_timestamp end |
#description ⇒ String
An optional description of this resource.
Corresponds to the JSON property description
54904 54905 54906 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54904 def description @description end |
#disk_size_gb ⇒ Fixnum
Output only. [Output Only] Size of the source disk, specified in GB.
Corresponds to the JSON property diskSizeGb
54909 54910 54911 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54909 def disk_size_gb @disk_size_gb end |
#download_bytes ⇒ Fixnum
Output only. [Output Only] Number of bytes downloaded to restore a snapshot to
a disk.
Corresponds to the JSON property downloadBytes
54915 54916 54917 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54915 def download_bytes @download_bytes end |
#enable_confidential_compute ⇒ Boolean Also known as: enable_confidential_compute?
Output only. Whether this snapshot is created from a confidential compute mode
disk.
[Output Only]: This field is not set by user, but from source disk.
Corresponds to the JSON property enableConfidentialCompute
54922 54923 54924 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54922 def enable_confidential_compute @enable_confidential_compute end |
#full ⇒ Boolean Also known as: full?
Indicates the created snapshot is a full snapshot.
Corresponds to the JSON property full
54928 54929 54930 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54928 def full @full end |
#guest_os_features ⇒ Array<Google::Apis::ComputeAlpha::GuestOsFeature>
Output only. [Output Only] A list of features to enable on the guest operating
system.
Applicable only for bootable images. Read
Enabling guest operating system features to see a list of available
options.
Corresponds to the JSON property guestOsFeatures
54938 54939 54940 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54938 def guest_os_features @guest_os_features end |
#id ⇒ Fixnum
Output only. [Output Only] The unique identifier for the original snapshot.
This
identifier is defined by the server.
Corresponds to the JSON property id
54945 54946 54947 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54945 def id @id end |
#label_fingerprint ⇒ String
A fingerprint for the labels being applied to this snapshot, which is
essentially a hash of the labels set used for optimistic locking. The
fingerprint is initially generated by Compute Engine and changes after
every request to modify or update labels. You must always provide an
up-to-date fingerprint hash in order to update or change labels,
otherwise the request will fail with error412 conditionNotMet.
To see the latest fingerprint, make a get() request to
retrieve a snapshot.
Corresponds to the JSON property labelFingerprint
NOTE: Values are automatically base64 encoded/decoded in the client library.
54958 54959 54960 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54958 def label_fingerprint @label_fingerprint end |
#labels ⇒ Hash<String,String>
Labels to apply to this snapshot. These can be later modified by
the setLabels method.
Label values may be empty.
Corresponds to the JSON property labels
54965 54966 54967 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54965 def labels @labels end |
#license_codes ⇒ Array<Fixnum>
Output only. [Output Only] Integer license codes indicating which licenses are
attached to this snapshot.
Corresponds to the JSON property licenseCodes
54971 54972 54973 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54971 def license_codes @license_codes end |
#licenses ⇒ Array<String>
Output only. [Output Only] A list of public visible licenses that apply to
this
snapshot.
Corresponds to the JSON property licenses
54978 54979 54980 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54978 def licenses @licenses end |
#max_retention_days ⇒ Fixnum
Number of days the snapshot should be retained before being deleted
automatically.
Corresponds to the JSON property maxRetentionDays
54984 54985 54986 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54984 def max_retention_days @max_retention_days end |
#name ⇒ String
Name of the original snapshot provided by the client. The name must be
1-63 characters long, and comply with RFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must
be a dash, lowercase letter, or digit, except the last character, which
cannot be a dash.
Corresponds to the JSON property name
54995 54996 54997 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54995 def name @name end |
#region ⇒ String
Output only. [Output Only] URL of the region where the snapshot resides. Only
applicable for regional snapshots.
Corresponds to the JSON property region
55001 55002 55003 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 55001 def region @region end |
#satisfies_pzi ⇒ Boolean Also known as: satisfies_pzi?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzi
55006 55007 55008 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 55006 def satisfies_pzi @satisfies_pzi end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
Output only. [Output Only] Reserved for future use.
Corresponds to the JSON property satisfiesPzs
55012 55013 55014 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 55012 def satisfies_pzs @satisfies_pzs end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
55018 55019 55020 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 55018 def self_link @self_link end |
#self_link_with_id ⇒ String
Output only. [Output Only] Server-defined URL for this resource's resource id.
Corresponds to the JSON property selfLinkWithId
55023 55024 55025 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 55023 def self_link_with_id @self_link_with_id end |
#snapshot_encryption_key ⇒ Google::Apis::ComputeAlpha::CustomerEncryptionKey
Encrypts the snapshot using acustomer-supplied
encryption key.
After you encrypt a snapshot using a customer-supplied key, you must
provide the same key if you use the snapshot later. For example, you must
provide the encryption key when you create a disk from the encrypted
snapshot in a future request.
Customer-supplied encryption keys do not protect access to metadata
of the snapshot.
If you do not provide an encryption key when creating the snapshot, then
the snapshot will be encrypted using an automatically generated key and
you do not need to provide a key to use the snapshot later.
Corresponds to the JSON property snapshotEncryptionKey
55038 55039 55040 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 55038 def snapshot_encryption_key @snapshot_encryption_key end |
#snapshot_group_id ⇒ String
Output only. [Output Only] The unique ID of the snapshot group that this
snapshot
belongs to. The usage of snapshot group feature is restricted.
Corresponds to the JSON property snapshotGroupId
55045 55046 55047 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 55045 def snapshot_group_id @snapshot_group_id end |
#snapshot_group_name ⇒ String
Output only. [Output only] The snapshot group that this snapshot belongs to.
The usage
of snapshot group feature is restricted.
Corresponds to the JSON property snapshotGroupName
55052 55053 55054 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 55052 def snapshot_group_name @snapshot_group_name end |
#snapshot_type ⇒ String
Indicates the type of the snapshot.
Corresponds to the JSON property snapshotType
55057 55058 55059 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 55057 def snapshot_type @snapshot_type end |
#source_disk ⇒ String
The source disk used to create this snapshot.
Corresponds to the JSON property sourceDisk
55062 55063 55064 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 55062 def source_disk @source_disk end |
#source_disk_encryption_key ⇒ Google::Apis::ComputeAlpha::CustomerEncryptionKey
The customer-supplied
encryption key of the source disk. Required if the source disk is
protected by a customer-supplied encryption key.
Corresponds to the JSON property sourceDiskEncryptionKey
55069 55070 55071 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 55069 def source_disk_encryption_key @source_disk_encryption_key end |
#source_disk_for_recovery_checkpoint ⇒ String
The source disk whose recovery checkpoint will be used to create this
snapshot.
Corresponds to the JSON property sourceDiskForRecoveryCheckpoint
55075 55076 55077 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 55075 def source_disk_for_recovery_checkpoint @source_disk_for_recovery_checkpoint end |
#source_disk_id ⇒ String
Output only. [Output Only] The ID value of the disk used to create this
snapshot
Corresponds to the JSON property sourceDiskId
55081 55082 55083 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 55081 def source_disk_id @source_disk_id end |
#source_instant_snapshot ⇒ String
The source instant snapshot used to create this snapshot.
Corresponds to the JSON property sourceInstantSnapshot
55086 55087 55088 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 55086 def source_instant_snapshot @source_instant_snapshot end |
#source_instant_snapshot_encryption_key ⇒ Google::Apis::ComputeAlpha::CustomerEncryptionKey
Customer provided encryption key when creating Snapshot from Instant
Snapshot.
Corresponds to the JSON property sourceInstantSnapshotEncryptionKey
55092 55093 55094 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 55092 def source_instant_snapshot_encryption_key @source_instant_snapshot_encryption_key end |
#source_instant_snapshot_id ⇒ String
Output only. [Output Only] The unique ID of the instant snapshot used to
create this
snapshot. This value identifies the exact instant snapshot that was used
to create this persistent disk. For example, if you created the
persistent disk from an instant snapshot that was later deleted and
recreated under the same name, the source instant snapshot ID would
identify the exact instant snapshot that was used.
Corresponds to the JSON property sourceInstantSnapshotId
55103 55104 55105 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 55103 def source_instant_snapshot_id @source_instant_snapshot_id end |
#source_snapshot_schedule_policy ⇒ String
Output only. [Output Only] URL of the resource policy which created this
scheduled snapshot.
Corresponds to the JSON property sourceSnapshotSchedulePolicy
55109 55110 55111 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 55109 def source_snapshot_schedule_policy @source_snapshot_schedule_policy end |
#source_snapshot_schedule_policy_id ⇒ String
Output only. [Output Only] ID of the resource policy which created this
scheduled snapshot.
Corresponds to the JSON property sourceSnapshotSchedulePolicyId
55115 55116 55117 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 55115 def source_snapshot_schedule_policy_id @source_snapshot_schedule_policy_id end |
#storage_bytes ⇒ Fixnum
Output only. [Output Only] A size of the storage used by the snapshot.
Corresponds to the JSON property storageBytes
55120 55121 55122 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 55120 def storage_bytes @storage_bytes end |
#storage_bytes_status ⇒ String
Output only. [Output Only] An indicator whether storageBytes is in a
stable state or it is being adjusted as a result of shared storage
reallocation. This status can either be UPDATING, meaning
the size of the snapshot is being updated, or UP_TO_DATE,
meaning the size of the snapshot is up-to-date.
Corresponds to the JSON property storageBytesStatus
55129 55130 55131 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 55129 def storage_bytes_status @storage_bytes_status end |
#storage_locations ⇒ Array<String>
Cloud Storage bucket storage location of the snapshot (regional or
multi-regional).
Corresponds to the JSON property storageLocations
55135 55136 55137 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 55135 def storage_locations @storage_locations end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
55142 55143 55144 55145 55146 55147 55148 55149 55150 55151 55152 55153 55154 55155 55156 55157 55158 55159 55160 55161 55162 55163 55164 55165 55166 55167 55168 55169 55170 55171 55172 55173 55174 55175 55176 55177 55178 55179 55180 55181 55182 55183 55184 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 55142 def update!(**args) @architecture = args[:architecture] if args.key?(:architecture) @auto_created = args[:auto_created] if args.key?(:auto_created) @auto_created_by = args[:auto_created_by] if args.key?(:auto_created_by) @chain_name = args[:chain_name] if args.key?(:chain_name) @creation_size_bytes = args[:creation_size_bytes] if args.key?(:creation_size_bytes) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @deletion_timestamp = args[:deletion_timestamp] if args.key?(:deletion_timestamp) @description = args[:description] if args.key?(:description) @disk_size_gb = args[:disk_size_gb] if args.key?(:disk_size_gb) @download_bytes = args[:download_bytes] if args.key?(:download_bytes) @enable_confidential_compute = args[:enable_confidential_compute] if args.key?(:enable_confidential_compute) @full = args[:full] if args.key?(:full) @guest_os_features = args[:guest_os_features] if args.key?(:guest_os_features) @id = args[:id] if args.key?(:id) @label_fingerprint = args[:label_fingerprint] if args.key?(:label_fingerprint) @labels = args[:labels] if args.key?(:labels) @license_codes = args[:license_codes] if args.key?(:license_codes) @licenses = args[:licenses] if args.key?(:licenses) @max_retention_days = args[:max_retention_days] if args.key?(:max_retention_days) @name = args[:name] if args.key?(:name) @region = args[:region] if args.key?(:region) @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @self_link = args[:self_link] if args.key?(:self_link) @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id) @snapshot_encryption_key = args[:snapshot_encryption_key] if args.key?(:snapshot_encryption_key) @snapshot_group_id = args[:snapshot_group_id] if args.key?(:snapshot_group_id) @snapshot_group_name = args[:snapshot_group_name] if args.key?(:snapshot_group_name) @snapshot_type = args[:snapshot_type] if args.key?(:snapshot_type) @source_disk = args[:source_disk] if args.key?(:source_disk) @source_disk_encryption_key = args[:source_disk_encryption_key] if args.key?(:source_disk_encryption_key) @source_disk_for_recovery_checkpoint = args[:source_disk_for_recovery_checkpoint] if args.key?(:source_disk_for_recovery_checkpoint) @source_disk_id = args[:source_disk_id] if args.key?(:source_disk_id) @source_instant_snapshot = args[:source_instant_snapshot] if args.key?(:source_instant_snapshot) @source_instant_snapshot_encryption_key = args[:source_instant_snapshot_encryption_key] if args.key?(:source_instant_snapshot_encryption_key) @source_instant_snapshot_id = args[:source_instant_snapshot_id] if args.key?(:source_instant_snapshot_id) @source_snapshot_schedule_policy = args[:source_snapshot_schedule_policy] if args.key?(:source_snapshot_schedule_policy) @source_snapshot_schedule_policy_id = args[:source_snapshot_schedule_policy_id] if args.key?(:source_snapshot_schedule_policy_id) @storage_bytes = args[:storage_bytes] if args.key?(:storage_bytes) @storage_bytes_status = args[:storage_bytes_status] if args.key?(:storage_bytes_status) @storage_locations = args[:storage_locations] if args.key?(:storage_locations) end |