Class: Google::Apis::ComputeAlpha::RecoverableSnapshotOriginalSnapshot

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RecoverableSnapshotOriginalSnapshot

Returns a new instance of RecoverableSnapshotOriginalSnapshot.



54910
54911
54912
# File 'lib/google/apis/compute_alpha/classes.rb', line 54910

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#architectureString

Output only. [Output Only] The architecture of the snapshot. Valid values are ARM64 or X86_64. Corresponds to the JSON property architecture

Returns:

  • (String)


54632
54633
54634
# File 'lib/google/apis/compute_alpha/classes.rb', line 54632

def architecture
  @architecture
end

#auto_createdBoolean Also known as: auto_created?

Output only. [Output Only] Set to true if snapshots are automatically created by applying resource policy on the target disk. Corresponds to the JSON property autoCreated

Returns:

  • (Boolean)


54639
54640
54641
# File 'lib/google/apis/compute_alpha/classes.rb', line 54639

def auto_created
  @auto_created
end

#auto_created_byString

ResourceKey of the resource policy or flow which created this auto snapshot Corresponds to the JSON property autoCreatedBy

Returns:

  • (String)


54646
54647
54648
# File 'lib/google/apis/compute_alpha/classes.rb', line 54646

def auto_created_by
  @auto_created_by
end

#chain_nameString

Creates the new snapshot in the snapshot chain labeled with the specified name. The chain name must be 1-63 characters long and comply with RFC1035. This is an uncommon option only for advanced service owners who needs to create separate snapshot chains, for example, for chargeback tracking. When you describe your snapshot resource, this field is visible only if it has a non-empty value. Corresponds to the JSON property chainName

Returns:

  • (String)


54656
54657
54658
# File 'lib/google/apis/compute_alpha/classes.rb', line 54656

def chain_name
  @chain_name
end

#creation_size_bytesFixnum

Output only. [Output Only] Size in bytes of the snapshot at creation time. Corresponds to the JSON property creationSizeBytes

Returns:

  • (Fixnum)


54661
54662
54663
# File 'lib/google/apis/compute_alpha/classes.rb', line 54661

def creation_size_bytes
  @creation_size_bytes
end

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


54666
54667
54668
# File 'lib/google/apis/compute_alpha/classes.rb', line 54666

def creation_timestamp
  @creation_timestamp
end

#deletion_timestampString

Output only. [Output Only] Purge timestamp of recoverable snapshot inRFC3339 text format. Corresponds to the JSON property deletionTimestamp

Returns:

  • (String)


54672
54673
54674
# File 'lib/google/apis/compute_alpha/classes.rb', line 54672

def deletion_timestamp
  @deletion_timestamp
end

#descriptionString

An optional description of this resource. Corresponds to the JSON property description

Returns:

  • (String)


54677
54678
54679
# File 'lib/google/apis/compute_alpha/classes.rb', line 54677

def description
  @description
end

#disk_size_gbFixnum

Output only. [Output Only] Size of the source disk, specified in GB. Corresponds to the JSON property diskSizeGb

Returns:

  • (Fixnum)


54682
54683
54684
# File 'lib/google/apis/compute_alpha/classes.rb', line 54682

def disk_size_gb
  @disk_size_gb
end

#download_bytesFixnum

Output only. [Output Only] Number of bytes downloaded to restore a snapshot to a disk. Corresponds to the JSON property downloadBytes

Returns:

  • (Fixnum)


54688
54689
54690
# File 'lib/google/apis/compute_alpha/classes.rb', line 54688

def download_bytes
  @download_bytes
end

#enable_confidential_computeBoolean Also known as: enable_confidential_compute?

Output only. Whether this snapshot is created from a confidential compute mode disk. [Output Only]: This field is not set by user, but from source disk. Corresponds to the JSON property enableConfidentialCompute

Returns:

  • (Boolean)


54695
54696
54697
# File 'lib/google/apis/compute_alpha/classes.rb', line 54695

def enable_confidential_compute
  @enable_confidential_compute
end

#fullBoolean Also known as: full?

Indicates the created snapshot is a full snapshot. Corresponds to the JSON property full

Returns:

  • (Boolean)


54701
54702
54703
# File 'lib/google/apis/compute_alpha/classes.rb', line 54701

def full
  @full
end

#guest_os_featuresArray<Google::Apis::ComputeAlpha::GuestOsFeature>

Output only. [Output Only] A list of features to enable on the guest operating system. Applicable only for bootable images. Read Enabling guest operating system features to see a list of available options. Corresponds to the JSON property guestOsFeatures



54711
54712
54713
# File 'lib/google/apis/compute_alpha/classes.rb', line 54711

def guest_os_features
  @guest_os_features
end

#idFixnum

Output only. [Output Only] The unique identifier for the original snapshot. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


54718
54719
54720
# File 'lib/google/apis/compute_alpha/classes.rb', line 54718

def id
  @id
end

#label_fingerprintString

A fingerprint for the labels being applied to this snapshot, which is essentially a hash of the labels set used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update labels. You must always provide an up-to-date fingerprint hash in order to update or change labels, otherwise the request will fail with error412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve a snapshot. Corresponds to the JSON property labelFingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


54731
54732
54733
# File 'lib/google/apis/compute_alpha/classes.rb', line 54731

def label_fingerprint
  @label_fingerprint
end

#labelsHash<String,String>

Labels to apply to this snapshot. These can be later modified by the setLabels method. Label values may be empty. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


54738
54739
54740
# File 'lib/google/apis/compute_alpha/classes.rb', line 54738

def labels
  @labels
end

#license_codesArray<Fixnum>

Output only. [Output Only] Integer license codes indicating which licenses are attached to this snapshot. Corresponds to the JSON property licenseCodes

Returns:

  • (Array<Fixnum>)


54744
54745
54746
# File 'lib/google/apis/compute_alpha/classes.rb', line 54744

def license_codes
  @license_codes
end

#licensesArray<String>

Output only. [Output Only] A list of public visible licenses that apply to this snapshot. Corresponds to the JSON property licenses

Returns:

  • (Array<String>)


54751
54752
54753
# File 'lib/google/apis/compute_alpha/classes.rb', line 54751

def licenses
  @licenses
end

#max_retention_daysFixnum

Number of days the snapshot should be retained before being deleted automatically. Corresponds to the JSON property maxRetentionDays

Returns:

  • (Fixnum)


54757
54758
54759
# File 'lib/google/apis/compute_alpha/classes.rb', line 54757

def max_retention_days
  @max_retention_days
end

#nameString

Name of the original snapshot provided by the client. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


54768
54769
54770
# File 'lib/google/apis/compute_alpha/classes.rb', line 54768

def name
  @name
end

#regionString

Output only. [Output Only] URL of the region where the snapshot resides. Only applicable for regional snapshots. Corresponds to the JSON property region

Returns:

  • (String)


54774
54775
54776
# File 'lib/google/apis/compute_alpha/classes.rb', line 54774

def region
  @region
end

#satisfies_pziBoolean Also known as: satisfies_pzi?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzi

Returns:

  • (Boolean)


54779
54780
54781
# File 'lib/google/apis/compute_alpha/classes.rb', line 54779

def satisfies_pzi
  @satisfies_pzi
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

Output only. [Output Only] Reserved for future use. Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


54785
54786
54787
# File 'lib/google/apis/compute_alpha/classes.rb', line 54785

def satisfies_pzs
  @satisfies_pzs
end

Output only. [Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


54791
54792
54793
# File 'lib/google/apis/compute_alpha/classes.rb', line 54791

def self_link
  @self_link
end

Output only. [Output Only] Server-defined URL for this resource's resource id. Corresponds to the JSON property selfLinkWithId

Returns:

  • (String)


54796
54797
54798
# File 'lib/google/apis/compute_alpha/classes.rb', line 54796

def self_link_with_id
  @self_link_with_id
end

#snapshot_encryption_keyGoogle::Apis::ComputeAlpha::CustomerEncryptionKey

Encrypts the snapshot using acustomer-supplied encryption key. After you encrypt a snapshot using a customer-supplied key, you must provide the same key if you use the snapshot later. For example, you must provide the encryption key when you create a disk from the encrypted snapshot in a future request. Customer-supplied encryption keys do not protect access to metadata of the snapshot. If you do not provide an encryption key when creating the snapshot, then the snapshot will be encrypted using an automatically generated key and you do not need to provide a key to use the snapshot later. Corresponds to the JSON property snapshotEncryptionKey



54811
54812
54813
# File 'lib/google/apis/compute_alpha/classes.rb', line 54811

def snapshot_encryption_key
  @snapshot_encryption_key
end

#snapshot_group_idString

Output only. [Output Only] The unique ID of the snapshot group that this snapshot belongs to. The usage of snapshot group feature is restricted. Corresponds to the JSON property snapshotGroupId

Returns:

  • (String)


54818
54819
54820
# File 'lib/google/apis/compute_alpha/classes.rb', line 54818

def snapshot_group_id
  @snapshot_group_id
end

#snapshot_group_nameString

Output only. [Output only] The snapshot group that this snapshot belongs to. The usage of snapshot group feature is restricted. Corresponds to the JSON property snapshotGroupName

Returns:

  • (String)


54825
54826
54827
# File 'lib/google/apis/compute_alpha/classes.rb', line 54825

def snapshot_group_name
  @snapshot_group_name
end

#snapshot_typeString

Indicates the type of the snapshot. Corresponds to the JSON property snapshotType

Returns:

  • (String)


54830
54831
54832
# File 'lib/google/apis/compute_alpha/classes.rb', line 54830

def snapshot_type
  @snapshot_type
end

#source_diskString

The source disk used to create this snapshot. Corresponds to the JSON property sourceDisk

Returns:

  • (String)


54835
54836
54837
# File 'lib/google/apis/compute_alpha/classes.rb', line 54835

def source_disk
  @source_disk
end

#source_disk_encryption_keyGoogle::Apis::ComputeAlpha::CustomerEncryptionKey

The customer-supplied encryption key of the source disk. Required if the source disk is protected by a customer-supplied encryption key. Corresponds to the JSON property sourceDiskEncryptionKey



54842
54843
54844
# File 'lib/google/apis/compute_alpha/classes.rb', line 54842

def source_disk_encryption_key
  @source_disk_encryption_key
end

#source_disk_for_recovery_checkpointString

The source disk whose recovery checkpoint will be used to create this snapshot. Corresponds to the JSON property sourceDiskForRecoveryCheckpoint

Returns:

  • (String)


54848
54849
54850
# File 'lib/google/apis/compute_alpha/classes.rb', line 54848

def source_disk_for_recovery_checkpoint
  @source_disk_for_recovery_checkpoint
end

#source_disk_idString

Output only. [Output Only] The ID value of the disk used to create this snapshot Corresponds to the JSON property sourceDiskId

Returns:

  • (String)


54854
54855
54856
# File 'lib/google/apis/compute_alpha/classes.rb', line 54854

def source_disk_id
  @source_disk_id
end

#source_instant_snapshotString

The source instant snapshot used to create this snapshot. Corresponds to the JSON property sourceInstantSnapshot

Returns:

  • (String)


54859
54860
54861
# File 'lib/google/apis/compute_alpha/classes.rb', line 54859

def source_instant_snapshot
  @source_instant_snapshot
end

#source_instant_snapshot_encryption_keyGoogle::Apis::ComputeAlpha::CustomerEncryptionKey

Customer provided encryption key when creating Snapshot from Instant Snapshot. Corresponds to the JSON property sourceInstantSnapshotEncryptionKey



54865
54866
54867
# File 'lib/google/apis/compute_alpha/classes.rb', line 54865

def source_instant_snapshot_encryption_key
  @source_instant_snapshot_encryption_key
end

#source_instant_snapshot_idString

Output only. [Output Only] The unique ID of the instant snapshot used to create this snapshot. This value identifies the exact instant snapshot that was used to create this persistent disk. For example, if you created the persistent disk from an instant snapshot that was later deleted and recreated under the same name, the source instant snapshot ID would identify the exact instant snapshot that was used. Corresponds to the JSON property sourceInstantSnapshotId

Returns:

  • (String)


54876
54877
54878
# File 'lib/google/apis/compute_alpha/classes.rb', line 54876

def source_instant_snapshot_id
  @source_instant_snapshot_id
end

#source_snapshot_schedule_policyString

Output only. [Output Only] URL of the resource policy which created this scheduled snapshot. Corresponds to the JSON property sourceSnapshotSchedulePolicy

Returns:

  • (String)


54882
54883
54884
# File 'lib/google/apis/compute_alpha/classes.rb', line 54882

def source_snapshot_schedule_policy
  @source_snapshot_schedule_policy
end

#source_snapshot_schedule_policy_idString

Output only. [Output Only] ID of the resource policy which created this scheduled snapshot. Corresponds to the JSON property sourceSnapshotSchedulePolicyId

Returns:

  • (String)


54888
54889
54890
# File 'lib/google/apis/compute_alpha/classes.rb', line 54888

def source_snapshot_schedule_policy_id
  @source_snapshot_schedule_policy_id
end

#storage_bytesFixnum

Output only. [Output Only] A size of the storage used by the snapshot. Corresponds to the JSON property storageBytes

Returns:

  • (Fixnum)


54893
54894
54895
# File 'lib/google/apis/compute_alpha/classes.rb', line 54893

def storage_bytes
  @storage_bytes
end

#storage_bytes_statusString

Output only. [Output Only] An indicator whether storageBytes is in a stable state or it is being adjusted as a result of shared storage reallocation. This status can either be UPDATING, meaning the size of the snapshot is being updated, or UP_TO_DATE, meaning the size of the snapshot is up-to-date. Corresponds to the JSON property storageBytesStatus

Returns:

  • (String)


54902
54903
54904
# File 'lib/google/apis/compute_alpha/classes.rb', line 54902

def storage_bytes_status
  @storage_bytes_status
end

#storage_locationsArray<String>

Cloud Storage bucket storage location of the snapshot (regional or multi-regional). Corresponds to the JSON property storageLocations

Returns:

  • (Array<String>)


54908
54909
54910
# File 'lib/google/apis/compute_alpha/classes.rb', line 54908

def storage_locations
  @storage_locations
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



54915
54916
54917
54918
54919
54920
54921
54922
54923
54924
54925
54926
54927
54928
54929
54930
54931
54932
54933
54934
54935
54936
54937
54938
54939
54940
54941
54942
54943
54944
54945
54946
54947
54948
54949
54950
54951
54952
54953
54954
54955
54956
54957
# File 'lib/google/apis/compute_alpha/classes.rb', line 54915

def update!(**args)
  @architecture = args[:architecture] if args.key?(:architecture)
  @auto_created = args[:auto_created] if args.key?(:auto_created)
  @auto_created_by = args[:auto_created_by] if args.key?(:auto_created_by)
  @chain_name = args[:chain_name] if args.key?(:chain_name)
  @creation_size_bytes = args[:creation_size_bytes] if args.key?(:creation_size_bytes)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @deletion_timestamp = args[:deletion_timestamp] if args.key?(:deletion_timestamp)
  @description = args[:description] if args.key?(:description)
  @disk_size_gb = args[:disk_size_gb] if args.key?(:disk_size_gb)
  @download_bytes = args[:download_bytes] if args.key?(:download_bytes)
  @enable_confidential_compute = args[:enable_confidential_compute] if args.key?(:enable_confidential_compute)
  @full = args[:full] if args.key?(:full)
  @guest_os_features = args[:guest_os_features] if args.key?(:guest_os_features)
  @id = args[:id] if args.key?(:id)
  @label_fingerprint = args[:label_fingerprint] if args.key?(:label_fingerprint)
  @labels = args[:labels] if args.key?(:labels)
  @license_codes = args[:license_codes] if args.key?(:license_codes)
  @licenses = args[:licenses] if args.key?(:licenses)
  @max_retention_days = args[:max_retention_days] if args.key?(:max_retention_days)
  @name = args[:name] if args.key?(:name)
  @region = args[:region] if args.key?(:region)
  @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @self_link = args[:self_link] if args.key?(:self_link)
  @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id)
  @snapshot_encryption_key = args[:snapshot_encryption_key] if args.key?(:snapshot_encryption_key)
  @snapshot_group_id = args[:snapshot_group_id] if args.key?(:snapshot_group_id)
  @snapshot_group_name = args[:snapshot_group_name] if args.key?(:snapshot_group_name)
  @snapshot_type = args[:snapshot_type] if args.key?(:snapshot_type)
  @source_disk = args[:source_disk] if args.key?(:source_disk)
  @source_disk_encryption_key = args[:source_disk_encryption_key] if args.key?(:source_disk_encryption_key)
  @source_disk_for_recovery_checkpoint = args[:source_disk_for_recovery_checkpoint] if args.key?(:source_disk_for_recovery_checkpoint)
  @source_disk_id = args[:source_disk_id] if args.key?(:source_disk_id)
  @source_instant_snapshot = args[:source_instant_snapshot] if args.key?(:source_instant_snapshot)
  @source_instant_snapshot_encryption_key = args[:source_instant_snapshot_encryption_key] if args.key?(:source_instant_snapshot_encryption_key)
  @source_instant_snapshot_id = args[:source_instant_snapshot_id] if args.key?(:source_instant_snapshot_id)
  @source_snapshot_schedule_policy = args[:source_snapshot_schedule_policy] if args.key?(:source_snapshot_schedule_policy)
  @source_snapshot_schedule_policy_id = args[:source_snapshot_schedule_policy_id] if args.key?(:source_snapshot_schedule_policy_id)
  @storage_bytes = args[:storage_bytes] if args.key?(:storage_bytes)
  @storage_bytes_status = args[:storage_bytes_status] if args.key?(:storage_bytes_status)
  @storage_locations = args[:storage_locations] if args.key?(:storage_locations)
end