Class: Google::Apis::ComputeAlpha::RecoverableSnapshotOriginalSnapshot
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::RecoverableSnapshotOriginalSnapshot
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#architecture ⇒ String
Output only.
-
#auto_created ⇒ Boolean
(also: #auto_created?)
Output only.
-
#auto_created_by ⇒ String
ResourceKey of the resource policy or flow which created this auto snapshot Corresponds to the JSON property
autoCreatedBy. -
#chain_name ⇒ String
Creates the new snapshot in the snapshot chain labeled with the specified name.
-
#creation_size_bytes ⇒ Fixnum
Output only.
-
#creation_timestamp ⇒ String
Output only.
-
#deletion_timestamp ⇒ String
Output only.
-
#description ⇒ String
An optional description of this resource.
-
#disk_size_gb ⇒ Fixnum
Output only.
-
#download_bytes ⇒ Fixnum
Output only.
-
#enable_confidential_compute ⇒ Boolean
(also: #enable_confidential_compute?)
Output only.
-
#full ⇒ Boolean
(also: #full?)
Indicates the created snapshot is a full snapshot.
-
#guest_os_features ⇒ Array<Google::Apis::ComputeAlpha::GuestOsFeature>
Output only.
-
#id ⇒ Fixnum
Output only.
-
#label_fingerprint ⇒ String
A fingerprint for the labels being applied to this snapshot, which is essentially a hash of the labels set used for optimistic locking.
-
#labels ⇒ Hash<String,String>
Labels to apply to this snapshot.
-
#license_codes ⇒ Array<Fixnum>
Output only.
-
#licenses ⇒ Array<String>
Output only.
-
#max_retention_days ⇒ Fixnum
Number of days the snapshot should be retained before being deleted automatically.
-
#name ⇒ String
Name of the original snapshot provided by the client.
-
#region ⇒ String
Output only.
-
#satisfies_pzi ⇒ Boolean
(also: #satisfies_pzi?)
Output only.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
Output only.
-
#self_link ⇒ String
Output only.
-
#self_link_with_id ⇒ String
Output only.
-
#snapshot_encryption_key ⇒ Google::Apis::ComputeAlpha::CustomerEncryptionKey
Encrypts the snapshot using acustomer-supplied encryption key.
-
#snapshot_group_id ⇒ String
Output only.
-
#snapshot_group_name ⇒ String
Output only.
-
#snapshot_type ⇒ String
Indicates the type of the snapshot.
-
#source_disk ⇒ String
The source disk used to create this snapshot.
-
#source_disk_encryption_key ⇒ Google::Apis::ComputeAlpha::CustomerEncryptionKey
The customer-supplied encryption key of the source disk.
-
#source_disk_for_recovery_checkpoint ⇒ String
The source disk whose recovery checkpoint will be used to create this snapshot.
-
#source_disk_id ⇒ String
Output only.
-
#source_instant_snapshot ⇒ String
The source instant snapshot used to create this snapshot.
-
#source_instant_snapshot_encryption_key ⇒ Google::Apis::ComputeAlpha::CustomerEncryptionKey
Customer provided encryption key when creating Snapshot from Instant Snapshot.
-
#source_instant_snapshot_id ⇒ String
Output only.
-
#source_snapshot_schedule_policy ⇒ String
Output only.
-
#source_snapshot_schedule_policy_id ⇒ String
Output only.
-
#storage_bytes ⇒ Fixnum
Output only.
-
#storage_bytes_status ⇒ String
Output only.
-
#storage_locations ⇒ Array<String>
Cloud Storage bucket storage location of the snapshot (regional or multi-regional).
Instance Method Summary collapse
-
#initialize(**args) ⇒ RecoverableSnapshotOriginalSnapshot
constructor
A new instance of RecoverableSnapshotOriginalSnapshot.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RecoverableSnapshotOriginalSnapshot
Returns a new instance of RecoverableSnapshotOriginalSnapshot.
54135 54136 54137 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54135 def initialize(**args) update!(**args) end |
Instance Attribute Details
#architecture ⇒ String
Output only. [Output Only] The architecture of the snapshot. Valid values are
ARM64 or X86_64.
Corresponds to the JSON property architecture
53859 53860 53861 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53859 def architecture @architecture end |
#auto_created ⇒ Boolean Also known as: auto_created?
Output only. [Output Only] Set to true if snapshots are automatically created
by
applying resource policy on the target disk.
Corresponds to the JSON property autoCreated
53866 53867 53868 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53866 def auto_created @auto_created end |
#auto_created_by ⇒ String
ResourceKey of the resource policy or flow which created this auto
snapshot
Corresponds to the JSON property autoCreatedBy
53873 53874 53875 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53873 def auto_created_by @auto_created_by end |
#chain_name ⇒ String
Creates the new snapshot in the snapshot chain labeled with the
specified name. The chain name must be 1-63 characters long and comply
with RFC1035. This is an uncommon option only for advanced service
owners who needs to create separate snapshot chains, for example,
for chargeback tracking. When you describe your snapshot resource, this
field is visible only if it has a non-empty value.
Corresponds to the JSON property chainName
53883 53884 53885 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53883 def chain_name @chain_name end |
#creation_size_bytes ⇒ Fixnum
Output only. [Output Only] Size in bytes of the snapshot at creation time.
Corresponds to the JSON property creationSizeBytes
53888 53889 53890 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53888 def creation_size_bytes @creation_size_bytes end |
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339 text format.
Corresponds to the JSON property creationTimestamp
53893 53894 53895 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53893 def @creation_timestamp end |
#deletion_timestamp ⇒ String
Output only. [Output Only] Purge timestamp of recoverable snapshot inRFC3339
text format.
Corresponds to the JSON property deletionTimestamp
53899 53900 53901 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53899 def @deletion_timestamp end |
#description ⇒ String
An optional description of this resource.
Corresponds to the JSON property description
53904 53905 53906 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53904 def description @description end |
#disk_size_gb ⇒ Fixnum
Output only. [Output Only] Size of the source disk, specified in GB.
Corresponds to the JSON property diskSizeGb
53909 53910 53911 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53909 def disk_size_gb @disk_size_gb end |
#download_bytes ⇒ Fixnum
Output only. [Output Only] Number of bytes downloaded to restore a snapshot to
a disk.
Corresponds to the JSON property downloadBytes
53915 53916 53917 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53915 def download_bytes @download_bytes end |
#enable_confidential_compute ⇒ Boolean Also known as: enable_confidential_compute?
Output only. Whether this snapshot is created from a confidential compute mode
disk.
[Output Only]: This field is not set by user, but from source disk.
Corresponds to the JSON property enableConfidentialCompute
53922 53923 53924 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53922 def enable_confidential_compute @enable_confidential_compute end |
#full ⇒ Boolean Also known as: full?
Indicates the created snapshot is a full snapshot.
Corresponds to the JSON property full
53928 53929 53930 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53928 def full @full end |
#guest_os_features ⇒ Array<Google::Apis::ComputeAlpha::GuestOsFeature>
Output only. [Output Only] A list of features to enable on the guest operating
system.
Applicable only for bootable images. Read
Enabling guest operating system features to see a list of available
options.
Corresponds to the JSON property guestOsFeatures
53938 53939 53940 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53938 def guest_os_features @guest_os_features end |
#id ⇒ Fixnum
Output only. [Output Only] The unique identifier for the original snapshot.
This
identifier is defined by the server.
Corresponds to the JSON property id
53945 53946 53947 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53945 def id @id end |
#label_fingerprint ⇒ String
A fingerprint for the labels being applied to this snapshot, which is
essentially a hash of the labels set used for optimistic locking. The
fingerprint is initially generated by Compute Engine and changes after
every request to modify or update labels. You must always provide an
up-to-date fingerprint hash in order to update or change labels,
otherwise the request will fail with error412 conditionNotMet.
To see the latest fingerprint, make a get() request to
retrieve a snapshot.
Corresponds to the JSON property labelFingerprint
NOTE: Values are automatically base64 encoded/decoded in the client library.
53958 53959 53960 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53958 def label_fingerprint @label_fingerprint end |
#labels ⇒ Hash<String,String>
Labels to apply to this snapshot. These can be later modified by
the setLabels method.
Label values may be empty.
Corresponds to the JSON property labels
53965 53966 53967 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53965 def labels @labels end |
#license_codes ⇒ Array<Fixnum>
Output only. [Output Only] Integer license codes indicating which licenses are
attached to this snapshot.
Corresponds to the JSON property licenseCodes
53971 53972 53973 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53971 def license_codes @license_codes end |
#licenses ⇒ Array<String>
Output only. [Output Only] A list of public visible licenses that apply to
this
snapshot.
Corresponds to the JSON property licenses
53978 53979 53980 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53978 def licenses @licenses end |
#max_retention_days ⇒ Fixnum
Number of days the snapshot should be retained before being deleted
automatically.
Corresponds to the JSON property maxRetentionDays
53984 53985 53986 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53984 def max_retention_days @max_retention_days end |
#name ⇒ String
Name of the original snapshot provided by the client. The name must be
1-63 characters long, and comply with RFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must
be a dash, lowercase letter, or digit, except the last character, which
cannot be a dash.
Corresponds to the JSON property name
53995 53996 53997 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 53995 def name @name end |
#region ⇒ String
Output only. [Output Only] URL of the region where the snapshot resides. Only
applicable for regional snapshots.
Corresponds to the JSON property region
54001 54002 54003 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54001 def region @region end |
#satisfies_pzi ⇒ Boolean Also known as: satisfies_pzi?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzi
54006 54007 54008 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54006 def satisfies_pzi @satisfies_pzi end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
Output only. [Output Only] Reserved for future use.
Corresponds to the JSON property satisfiesPzs
54012 54013 54014 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54012 def satisfies_pzs @satisfies_pzs end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
54018 54019 54020 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54018 def self_link @self_link end |
#self_link_with_id ⇒ String
Output only. [Output Only] Server-defined URL for this resource's resource id.
Corresponds to the JSON property selfLinkWithId
54023 54024 54025 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54023 def self_link_with_id @self_link_with_id end |
#snapshot_encryption_key ⇒ Google::Apis::ComputeAlpha::CustomerEncryptionKey
Encrypts the snapshot using acustomer-supplied
encryption key.
After you encrypt a snapshot using a customer-supplied key, you must
provide the same key if you use the snapshot later. For example, you must
provide the encryption key when you create a disk from the encrypted
snapshot in a future request.
Customer-supplied encryption keys do not protect access to metadata
of the snapshot.
If you do not provide an encryption key when creating the snapshot, then
the snapshot will be encrypted using an automatically generated key and
you do not need to provide a key to use the snapshot later.
Corresponds to the JSON property snapshotEncryptionKey
54038 54039 54040 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54038 def snapshot_encryption_key @snapshot_encryption_key end |
#snapshot_group_id ⇒ String
Output only. [Output Only] The unique ID of the snapshot group that this
snapshot
belongs to.
Corresponds to the JSON property snapshotGroupId
54045 54046 54047 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54045 def snapshot_group_id @snapshot_group_id end |
#snapshot_group_name ⇒ String
Output only. [Output only] The snapshot group that this snapshot belongs to.
Corresponds to the JSON property snapshotGroupName
54050 54051 54052 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54050 def snapshot_group_name @snapshot_group_name end |
#snapshot_type ⇒ String
Indicates the type of the snapshot.
Corresponds to the JSON property snapshotType
54055 54056 54057 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54055 def snapshot_type @snapshot_type end |
#source_disk ⇒ String
The source disk used to create this snapshot.
Corresponds to the JSON property sourceDisk
54060 54061 54062 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54060 def source_disk @source_disk end |
#source_disk_encryption_key ⇒ Google::Apis::ComputeAlpha::CustomerEncryptionKey
The customer-supplied
encryption key of the source disk. Required if the source disk is
protected by a customer-supplied encryption key.
Corresponds to the JSON property sourceDiskEncryptionKey
54067 54068 54069 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54067 def source_disk_encryption_key @source_disk_encryption_key end |
#source_disk_for_recovery_checkpoint ⇒ String
The source disk whose recovery checkpoint will be used to create this
snapshot.
Corresponds to the JSON property sourceDiskForRecoveryCheckpoint
54073 54074 54075 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54073 def source_disk_for_recovery_checkpoint @source_disk_for_recovery_checkpoint end |
#source_disk_id ⇒ String
Output only. [Output Only] The ID value of the disk used to create this
snapshot
Corresponds to the JSON property sourceDiskId
54079 54080 54081 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54079 def source_disk_id @source_disk_id end |
#source_instant_snapshot ⇒ String
The source instant snapshot used to create this snapshot.
Corresponds to the JSON property sourceInstantSnapshot
54084 54085 54086 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54084 def source_instant_snapshot @source_instant_snapshot end |
#source_instant_snapshot_encryption_key ⇒ Google::Apis::ComputeAlpha::CustomerEncryptionKey
Customer provided encryption key when creating Snapshot from Instant
Snapshot.
Corresponds to the JSON property sourceInstantSnapshotEncryptionKey
54090 54091 54092 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54090 def source_instant_snapshot_encryption_key @source_instant_snapshot_encryption_key end |
#source_instant_snapshot_id ⇒ String
Output only. [Output Only] The unique ID of the instant snapshot used to
create this
snapshot. This value identifies the exact instant snapshot that was used
to create this persistent disk. For example, if you created the
persistent disk from an instant snapshot that was later deleted and
recreated under the same name, the source instant snapshot ID would
identify the exact instant snapshot that was used.
Corresponds to the JSON property sourceInstantSnapshotId
54101 54102 54103 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54101 def source_instant_snapshot_id @source_instant_snapshot_id end |
#source_snapshot_schedule_policy ⇒ String
Output only. [Output Only] URL of the resource policy which created this
scheduled snapshot.
Corresponds to the JSON property sourceSnapshotSchedulePolicy
54107 54108 54109 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54107 def source_snapshot_schedule_policy @source_snapshot_schedule_policy end |
#source_snapshot_schedule_policy_id ⇒ String
Output only. [Output Only] ID of the resource policy which created this
scheduled snapshot.
Corresponds to the JSON property sourceSnapshotSchedulePolicyId
54113 54114 54115 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54113 def source_snapshot_schedule_policy_id @source_snapshot_schedule_policy_id end |
#storage_bytes ⇒ Fixnum
Output only. [Output Only] A size of the storage used by the snapshot.
Corresponds to the JSON property storageBytes
54118 54119 54120 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54118 def storage_bytes @storage_bytes end |
#storage_bytes_status ⇒ String
Output only. [Output Only] An indicator whether storageBytes is in a
stable state or it is being adjusted as a result of shared storage
reallocation. This status can either be UPDATING, meaning
the size of the snapshot is being updated, or UP_TO_DATE,
meaning the size of the snapshot is up-to-date.
Corresponds to the JSON property storageBytesStatus
54127 54128 54129 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54127 def storage_bytes_status @storage_bytes_status end |
#storage_locations ⇒ Array<String>
Cloud Storage bucket storage location of the snapshot (regional or
multi-regional).
Corresponds to the JSON property storageLocations
54133 54134 54135 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54133 def storage_locations @storage_locations end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
54140 54141 54142 54143 54144 54145 54146 54147 54148 54149 54150 54151 54152 54153 54154 54155 54156 54157 54158 54159 54160 54161 54162 54163 54164 54165 54166 54167 54168 54169 54170 54171 54172 54173 54174 54175 54176 54177 54178 54179 54180 54181 54182 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54140 def update!(**args) @architecture = args[:architecture] if args.key?(:architecture) @auto_created = args[:auto_created] if args.key?(:auto_created) @auto_created_by = args[:auto_created_by] if args.key?(:auto_created_by) @chain_name = args[:chain_name] if args.key?(:chain_name) @creation_size_bytes = args[:creation_size_bytes] if args.key?(:creation_size_bytes) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @deletion_timestamp = args[:deletion_timestamp] if args.key?(:deletion_timestamp) @description = args[:description] if args.key?(:description) @disk_size_gb = args[:disk_size_gb] if args.key?(:disk_size_gb) @download_bytes = args[:download_bytes] if args.key?(:download_bytes) @enable_confidential_compute = args[:enable_confidential_compute] if args.key?(:enable_confidential_compute) @full = args[:full] if args.key?(:full) @guest_os_features = args[:guest_os_features] if args.key?(:guest_os_features) @id = args[:id] if args.key?(:id) @label_fingerprint = args[:label_fingerprint] if args.key?(:label_fingerprint) @labels = args[:labels] if args.key?(:labels) @license_codes = args[:license_codes] if args.key?(:license_codes) @licenses = args[:licenses] if args.key?(:licenses) @max_retention_days = args[:max_retention_days] if args.key?(:max_retention_days) @name = args[:name] if args.key?(:name) @region = args[:region] if args.key?(:region) @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @self_link = args[:self_link] if args.key?(:self_link) @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id) @snapshot_encryption_key = args[:snapshot_encryption_key] if args.key?(:snapshot_encryption_key) @snapshot_group_id = args[:snapshot_group_id] if args.key?(:snapshot_group_id) @snapshot_group_name = args[:snapshot_group_name] if args.key?(:snapshot_group_name) @snapshot_type = args[:snapshot_type] if args.key?(:snapshot_type) @source_disk = args[:source_disk] if args.key?(:source_disk) @source_disk_encryption_key = args[:source_disk_encryption_key] if args.key?(:source_disk_encryption_key) @source_disk_for_recovery_checkpoint = args[:source_disk_for_recovery_checkpoint] if args.key?(:source_disk_for_recovery_checkpoint) @source_disk_id = args[:source_disk_id] if args.key?(:source_disk_id) @source_instant_snapshot = args[:source_instant_snapshot] if args.key?(:source_instant_snapshot) @source_instant_snapshot_encryption_key = args[:source_instant_snapshot_encryption_key] if args.key?(:source_instant_snapshot_encryption_key) @source_instant_snapshot_id = args[:source_instant_snapshot_id] if args.key?(:source_instant_snapshot_id) @source_snapshot_schedule_policy = args[:source_snapshot_schedule_policy] if args.key?(:source_snapshot_schedule_policy) @source_snapshot_schedule_policy_id = args[:source_snapshot_schedule_policy_id] if args.key?(:source_snapshot_schedule_policy_id) @storage_bytes = args[:storage_bytes] if args.key?(:storage_bytes) @storage_bytes_status = args[:storage_bytes_status] if args.key?(:storage_bytes_status) @storage_locations = args[:storage_locations] if args.key?(:storage_locations) end |