Class: Google::Apis::ComputeAlpha::Reference

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Represents a reference to a resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Reference

Returns a new instance of Reference.



56893
56894
56895
# File 'lib/google/apis/compute_alpha/classes.rb', line 56893

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#kindString

Output only. [Output Only] Type of the resource. Always compute#reference for references. Corresponds to the JSON property kind

Returns:

  • (String)


56872
56873
56874
# File 'lib/google/apis/compute_alpha/classes.rb', line 56872

def kind
  @kind
end

#reference_typeString

A description of the reference type with no implied semantics. Possible values include:

  1. MEMBER_OF Corresponds to the JSON property referenceType

Returns:

  • (String)


56881
56882
56883
# File 'lib/google/apis/compute_alpha/classes.rb', line 56881

def reference_type
  @reference_type
end

#referrerString

URL of the resource which refers to the target. Corresponds to the JSON property referrer

Returns:

  • (String)


56886
56887
56888
# File 'lib/google/apis/compute_alpha/classes.rb', line 56886

def referrer
  @referrer
end

#targetString

URL of the resource to which this reference points. Corresponds to the JSON property target

Returns:

  • (String)


56891
56892
56893
# File 'lib/google/apis/compute_alpha/classes.rb', line 56891

def target
  @target
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



56898
56899
56900
56901
56902
56903
# File 'lib/google/apis/compute_alpha/classes.rb', line 56898

def update!(**args)
  @kind = args[:kind] if args.key?(:kind)
  @reference_type = args[:reference_type] if args.key?(:reference_type)
  @referrer = args[:referrer] if args.key?(:referrer)
  @target = args[:target] if args.key?(:target)
end