Class: Google::Apis::ComputeAlpha::Reference
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::Reference
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Represents a reference to a resource.
Instance Attribute Summary collapse
-
#kind ⇒ String
Output only.
-
#reference_type ⇒ String
A description of the reference type with no implied semantics.
-
#referrer ⇒ String
URL of the resource which refers to the target.
-
#target ⇒ String
URL of the resource to which this reference points.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Reference
constructor
A new instance of Reference.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Reference
Returns a new instance of Reference.
55086 55087 55088 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 55086 def initialize(**args) update!(**args) end |
Instance Attribute Details
#kind ⇒ String
Output only. [Output Only] Type of the resource. Always compute#reference
for references.
Corresponds to the JSON property kind
55065 55066 55067 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 55065 def kind @kind end |
#reference_type ⇒ String
A description of the reference type with no implied semantics. Possible values include:
- MEMBER_OF
Corresponds to the JSON property
referenceType
55074 55075 55076 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 55074 def reference_type @reference_type end |
#referrer ⇒ String
URL of the resource which refers to the target.
Corresponds to the JSON property referrer
55079 55080 55081 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 55079 def referrer @referrer end |
#target ⇒ String
URL of the resource to which this reference points.
Corresponds to the JSON property target
55084 55085 55086 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 55084 def target @target end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
55091 55092 55093 55094 55095 55096 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 55091 def update!(**args) @kind = args[:kind] if args.key?(:kind) @reference_type = args[:reference_type] if args.key?(:reference_type) @referrer = args[:referrer] if args.key?(:referrer) @target = args[:target] if args.key?(:target) end |