Class: Google::Apis::ComputeAlpha::Region
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::Region
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Represents a Region resource. A region is a geographical area where a resource is located. For more information, readRegions and Zones.
Defined Under Namespace
Classes: QuotaStatusWarning
Instance Attribute Summary collapse
-
#creation_timestamp ⇒ String
[Output Only] Creation timestamp inRFC3339 text format.
-
#deprecated ⇒ Google::Apis::ComputeAlpha::DeprecationStatus
Deprecation status for a public resource.
-
#description ⇒ String
[Output Only] Textual description of the resource.
-
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
[Output Only] Name of the resource.
-
#quota_status_warning ⇒ Google::Apis::ComputeAlpha::Region::QuotaStatusWarning
Output only.
-
#quotas ⇒ Array<Google::Apis::ComputeAlpha::Quota>
[Output Only] Quotas assigned to this region.
-
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
-
#self_link_with_id ⇒ String
Output only.
-
#status ⇒ String
[Output Only] Status of the region, either UP orDOWN.
-
#supports_pzs ⇒ Boolean
(also: #supports_pzs?)
Output only.
-
#zones ⇒ Array<String>
[Output Only] A list of zones available in this region, in the form of resource URLs.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Region
constructor
A new instance of Region.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Region
Returns a new instance of Region.
57035 57036 57037 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 57035 def initialize(**args) update!(**args) end |
Instance Attribute Details
#creation_timestamp ⇒ String
[Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
56966 56967 56968 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 56966 def @creation_timestamp end |
#deprecated ⇒ Google::Apis::ComputeAlpha::DeprecationStatus
Deprecation status for a public resource.
Corresponds to the JSON property deprecated
56971 56972 56973 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 56971 def deprecated @deprecated end |
#description ⇒ String
[Output Only] Textual description of the resource.
Corresponds to the JSON property description
56976 56977 56978 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 56976 def description @description end |
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
56982 56983 56984 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 56982 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Always compute#region for
regions.
Corresponds to the JSON property kind
56988 56989 56990 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 56988 def kind @kind end |
#name ⇒ String
[Output Only] Name of the resource.
Corresponds to the JSON property name
56993 56994 56995 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 56993 def name @name end |
#quota_status_warning ⇒ Google::Apis::ComputeAlpha::Region::QuotaStatusWarning
Output only. [Output Only] Warning of fetching the quotas field for this
region. This
field is populated only if fetching of the quotas field fails.
Corresponds to the JSON property quotaStatusWarning
57000 57001 57002 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 57000 def quota_status_warning @quota_status_warning end |
#quotas ⇒ Array<Google::Apis::ComputeAlpha::Quota>
[Output Only] Quotas assigned to this region.
Corresponds to the JSON property quotas
57005 57006 57007 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 57005 def quotas @quotas end |
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
57010 57011 57012 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 57010 def self_link @self_link end |
#self_link_with_id ⇒ String
Output only. [Output Only] Server-defined URL for this resource with the
resource id.
Corresponds to the JSON property selfLinkWithId
57016 57017 57018 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 57016 def self_link_with_id @self_link_with_id end |
#status ⇒ String
[Output Only] Status of the region, either UP orDOWN.
Corresponds to the JSON property status
57021 57022 57023 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 57021 def status @status end |
#supports_pzs ⇒ Boolean Also known as: supports_pzs?
Output only. [Output Only] Reserved for future use.
Corresponds to the JSON property supportsPzs
57026 57027 57028 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 57026 def supports_pzs @supports_pzs end |
#zones ⇒ Array<String>
[Output Only] A list of zones available in this region, in the form of
resource URLs.
Corresponds to the JSON property zones
57033 57034 57035 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 57033 def zones @zones end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
57040 57041 57042 57043 57044 57045 57046 57047 57048 57049 57050 57051 57052 57053 57054 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 57040 def update!(**args) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @deprecated = args[:deprecated] if args.key?(:deprecated) @description = args[:description] if args.key?(:description) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @quota_status_warning = args[:quota_status_warning] if args.key?(:quota_status_warning) @quotas = args[:quotas] if args.key?(:quotas) @self_link = args[:self_link] if args.key?(:self_link) @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id) @status = args[:status] if args.key?(:status) @supports_pzs = args[:supports_pzs] if args.key?(:supports_pzs) @zones = args[:zones] if args.key?(:zones) end |