Class: Google::Apis::ComputeAlpha::Region

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Represents a Region resource. A region is a geographical area where a resource is located. For more information, readRegions and Zones.

Defined Under Namespace

Classes: QuotaStatusWarning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Region

Returns a new instance of Region.



55406
55407
55408
# File 'lib/google/apis/compute_alpha/classes.rb', line 55406

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#creation_timestampString

[Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


55337
55338
55339
# File 'lib/google/apis/compute_alpha/classes.rb', line 55337

def creation_timestamp
  @creation_timestamp
end

#deprecatedGoogle::Apis::ComputeAlpha::DeprecationStatus

Deprecation status for a public resource. Corresponds to the JSON property deprecated



55342
55343
55344
# File 'lib/google/apis/compute_alpha/classes.rb', line 55342

def deprecated
  @deprecated
end

#descriptionString

[Output Only] Textual description of the resource. Corresponds to the JSON property description

Returns:

  • (String)


55347
55348
55349
# File 'lib/google/apis/compute_alpha/classes.rb', line 55347

def description
  @description
end

#idFixnum

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


55353
55354
55355
# File 'lib/google/apis/compute_alpha/classes.rb', line 55353

def id
  @id
end

#kindString

Output only. [Output Only] Type of the resource. Always compute#region for regions. Corresponds to the JSON property kind

Returns:

  • (String)


55359
55360
55361
# File 'lib/google/apis/compute_alpha/classes.rb', line 55359

def kind
  @kind
end

#nameString

[Output Only] Name of the resource. Corresponds to the JSON property name

Returns:

  • (String)


55364
55365
55366
# File 'lib/google/apis/compute_alpha/classes.rb', line 55364

def name
  @name
end

#quota_status_warningGoogle::Apis::ComputeAlpha::Region::QuotaStatusWarning

Output only. [Output Only] Warning of fetching the quotas field for this region. This field is populated only if fetching of the quotas field fails. Corresponds to the JSON property quotaStatusWarning



55371
55372
55373
# File 'lib/google/apis/compute_alpha/classes.rb', line 55371

def quota_status_warning
  @quota_status_warning
end

#quotasArray<Google::Apis::ComputeAlpha::Quota>

[Output Only] Quotas assigned to this region. Corresponds to the JSON property quotas



55376
55377
55378
# File 'lib/google/apis/compute_alpha/classes.rb', line 55376

def quotas
  @quotas
end

[Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


55381
55382
55383
# File 'lib/google/apis/compute_alpha/classes.rb', line 55381

def self_link
  @self_link
end

Output only. [Output Only] Server-defined URL for this resource with the resource id. Corresponds to the JSON property selfLinkWithId

Returns:

  • (String)


55387
55388
55389
# File 'lib/google/apis/compute_alpha/classes.rb', line 55387

def self_link_with_id
  @self_link_with_id
end

#statusString

[Output Only] Status of the region, either UP orDOWN. Corresponds to the JSON property status

Returns:

  • (String)


55392
55393
55394
# File 'lib/google/apis/compute_alpha/classes.rb', line 55392

def status
  @status
end

#supports_pzsBoolean Also known as: supports_pzs?

Output only. [Output Only] Reserved for future use. Corresponds to the JSON property supportsPzs

Returns:

  • (Boolean)


55397
55398
55399
# File 'lib/google/apis/compute_alpha/classes.rb', line 55397

def supports_pzs
  @supports_pzs
end

#zonesArray<String>

[Output Only] A list of zones available in this region, in the form of resource URLs. Corresponds to the JSON property zones

Returns:

  • (Array<String>)


55404
55405
55406
# File 'lib/google/apis/compute_alpha/classes.rb', line 55404

def zones
  @zones
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



55411
55412
55413
55414
55415
55416
55417
55418
55419
55420
55421
55422
55423
55424
55425
# File 'lib/google/apis/compute_alpha/classes.rb', line 55411

def update!(**args)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @deprecated = args[:deprecated] if args.key?(:deprecated)
  @description = args[:description] if args.key?(:description)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @quota_status_warning = args[:quota_status_warning] if args.key?(:quota_status_warning)
  @quotas = args[:quotas] if args.key?(:quotas)
  @self_link = args[:self_link] if args.key?(:self_link)
  @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id)
  @status = args[:status] if args.key?(:status)
  @supports_pzs = args[:supports_pzs] if args.key?(:supports_pzs)
  @zones = args[:zones] if args.key?(:zones)
end