Class: Google::Apis::ComputeAlpha::Region

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Represents a Region resource. A region is a geographical area where a resource is located. For more information, readRegions and Zones.

Defined Under Namespace

Classes: QuotaStatusWarning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Region

Returns a new instance of Region.



54404
54405
54406
# File 'lib/google/apis/compute_alpha/classes.rb', line 54404

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#creation_timestampString

[Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


54335
54336
54337
# File 'lib/google/apis/compute_alpha/classes.rb', line 54335

def creation_timestamp
  @creation_timestamp
end

#deprecatedGoogle::Apis::ComputeAlpha::DeprecationStatus

Deprecation status for a public resource. Corresponds to the JSON property deprecated



54340
54341
54342
# File 'lib/google/apis/compute_alpha/classes.rb', line 54340

def deprecated
  @deprecated
end

#descriptionString

[Output Only] Textual description of the resource. Corresponds to the JSON property description

Returns:

  • (String)


54345
54346
54347
# File 'lib/google/apis/compute_alpha/classes.rb', line 54345

def description
  @description
end

#idFixnum

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


54351
54352
54353
# File 'lib/google/apis/compute_alpha/classes.rb', line 54351

def id
  @id
end

#kindString

Output only. [Output Only] Type of the resource. Always compute#region for regions. Corresponds to the JSON property kind

Returns:

  • (String)


54357
54358
54359
# File 'lib/google/apis/compute_alpha/classes.rb', line 54357

def kind
  @kind
end

#nameString

[Output Only] Name of the resource. Corresponds to the JSON property name

Returns:

  • (String)


54362
54363
54364
# File 'lib/google/apis/compute_alpha/classes.rb', line 54362

def name
  @name
end

#quota_status_warningGoogle::Apis::ComputeAlpha::Region::QuotaStatusWarning

Output only. [Output Only] Warning of fetching the quotas field for this region. This field is populated only if fetching of the quotas field fails. Corresponds to the JSON property quotaStatusWarning



54369
54370
54371
# File 'lib/google/apis/compute_alpha/classes.rb', line 54369

def quota_status_warning
  @quota_status_warning
end

#quotasArray<Google::Apis::ComputeAlpha::Quota>

[Output Only] Quotas assigned to this region. Corresponds to the JSON property quotas



54374
54375
54376
# File 'lib/google/apis/compute_alpha/classes.rb', line 54374

def quotas
  @quotas
end

[Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


54379
54380
54381
# File 'lib/google/apis/compute_alpha/classes.rb', line 54379

def self_link
  @self_link
end

Output only. [Output Only] Server-defined URL for this resource with the resource id. Corresponds to the JSON property selfLinkWithId

Returns:

  • (String)


54385
54386
54387
# File 'lib/google/apis/compute_alpha/classes.rb', line 54385

def self_link_with_id
  @self_link_with_id
end

#statusString

[Output Only] Status of the region, either UP orDOWN. Corresponds to the JSON property status

Returns:

  • (String)


54390
54391
54392
# File 'lib/google/apis/compute_alpha/classes.rb', line 54390

def status
  @status
end

#supports_pzsBoolean Also known as: supports_pzs?

Output only. [Output Only] Reserved for future use. Corresponds to the JSON property supportsPzs

Returns:

  • (Boolean)


54395
54396
54397
# File 'lib/google/apis/compute_alpha/classes.rb', line 54395

def supports_pzs
  @supports_pzs
end

#zonesArray<String>

[Output Only] A list of zones available in this region, in the form of resource URLs. Corresponds to the JSON property zones

Returns:

  • (Array<String>)


54402
54403
54404
# File 'lib/google/apis/compute_alpha/classes.rb', line 54402

def zones
  @zones
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



54409
54410
54411
54412
54413
54414
54415
54416
54417
54418
54419
54420
54421
54422
54423
# File 'lib/google/apis/compute_alpha/classes.rb', line 54409

def update!(**args)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @deprecated = args[:deprecated] if args.key?(:deprecated)
  @description = args[:description] if args.key?(:description)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @quota_status_warning = args[:quota_status_warning] if args.key?(:quota_status_warning)
  @quotas = args[:quotas] if args.key?(:quotas)
  @self_link = args[:self_link] if args.key?(:self_link)
  @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id)
  @status = args[:status] if args.key?(:status)
  @supports_pzs = args[:supports_pzs] if args.key?(:supports_pzs)
  @zones = args[:zones] if args.key?(:zones)
end