Class: Google::Apis::ComputeAlpha::RegionAutoscalerList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::RegionAutoscalerList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Contains a list of autoscalers.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::Autoscaler>
A list of Autoscaler resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::RegionAutoscalerList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RegionAutoscalerList
constructor
A new instance of RegionAutoscalerList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RegionAutoscalerList
Returns a new instance of RegionAutoscalerList.
57486 57487 57488 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 57486 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
57454 57455 57456 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 57454 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::Autoscaler>
A list of Autoscaler resources.
Corresponds to the JSON property items
57459 57460 57461 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 57459 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
57464 57465 57466 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 57464 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
57474 57475 57476 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 57474 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
57479 57480 57481 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 57479 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::RegionAutoscalerList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
57484 57485 57486 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 57484 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
57491 57492 57493 57494 57495 57496 57497 57498 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 57491 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |