Class: Google::Apis::ComputeAlpha::RegionAutoscalerList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of autoscalers.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RegionAutoscalerList

Returns a new instance of RegionAutoscalerList.



57201
57202
57203
# File 'lib/google/apis/compute_alpha/classes.rb', line 57201

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


57169
57170
57171
# File 'lib/google/apis/compute_alpha/classes.rb', line 57169

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::Autoscaler>

A list of Autoscaler resources. Corresponds to the JSON property items



57174
57175
57176
# File 'lib/google/apis/compute_alpha/classes.rb', line 57174

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


57179
57180
57181
# File 'lib/google/apis/compute_alpha/classes.rb', line 57179

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


57189
57190
57191
# File 'lib/google/apis/compute_alpha/classes.rb', line 57189

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


57194
57195
57196
# File 'lib/google/apis/compute_alpha/classes.rb', line 57194

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::RegionAutoscalerList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



57199
57200
57201
# File 'lib/google/apis/compute_alpha/classes.rb', line 57199

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



57206
57207
57208
57209
57210
57211
57212
57213
# File 'lib/google/apis/compute_alpha/classes.rb', line 57206

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end