Class: Google::Apis::ComputeAlpha::RegionAutoscalerList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of autoscalers.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RegionAutoscalerList

Returns a new instance of RegionAutoscalerList.



56143
56144
56145
# File 'lib/google/apis/compute_alpha/classes.rb', line 56143

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


56111
56112
56113
# File 'lib/google/apis/compute_alpha/classes.rb', line 56111

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::Autoscaler>

A list of Autoscaler resources. Corresponds to the JSON property items



56116
56117
56118
# File 'lib/google/apis/compute_alpha/classes.rb', line 56116

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


56121
56122
56123
# File 'lib/google/apis/compute_alpha/classes.rb', line 56121

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


56131
56132
56133
# File 'lib/google/apis/compute_alpha/classes.rb', line 56131

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


56136
56137
56138
# File 'lib/google/apis/compute_alpha/classes.rb', line 56136

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::RegionAutoscalerList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



56141
56142
56143
# File 'lib/google/apis/compute_alpha/classes.rb', line 56141

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



56148
56149
56150
56151
56152
56153
56154
56155
# File 'lib/google/apis/compute_alpha/classes.rb', line 56148

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end