Class: Google::Apis::ComputeAlpha::RegionAutoscalerList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of autoscalers.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RegionAutoscalerList

Returns a new instance of RegionAutoscalerList.



55570
55571
55572
# File 'lib/google/apis/compute_alpha/classes.rb', line 55570

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


55538
55539
55540
# File 'lib/google/apis/compute_alpha/classes.rb', line 55538

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::Autoscaler>

A list of Autoscaler resources. Corresponds to the JSON property items



55543
55544
55545
# File 'lib/google/apis/compute_alpha/classes.rb', line 55543

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


55548
55549
55550
# File 'lib/google/apis/compute_alpha/classes.rb', line 55548

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


55558
55559
55560
# File 'lib/google/apis/compute_alpha/classes.rb', line 55558

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


55563
55564
55565
# File 'lib/google/apis/compute_alpha/classes.rb', line 55563

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::RegionAutoscalerList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



55568
55569
55570
# File 'lib/google/apis/compute_alpha/classes.rb', line 55568

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



55575
55576
55577
55578
55579
55580
55581
55582
# File 'lib/google/apis/compute_alpha/classes.rb', line 55575

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end