Class: Google::Apis::ComputeAlpha::RegionAutoscalerList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::RegionAutoscalerList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Contains a list of autoscalers.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::Autoscaler>
A list of Autoscaler resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::RegionAutoscalerList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RegionAutoscalerList
constructor
A new instance of RegionAutoscalerList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RegionAutoscalerList
Returns a new instance of RegionAutoscalerList.
54570 54571 54572 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54570 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
54538 54539 54540 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54538 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::Autoscaler>
A list of Autoscaler resources.
Corresponds to the JSON property items
54543 54544 54545 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54543 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
54548 54549 54550 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54548 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
54558 54559 54560 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54558 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
54563 54564 54565 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54563 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::RegionAutoscalerList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
54568 54569 54570 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54568 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
54575 54576 54577 54578 54579 54580 54581 54582 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 54575 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |