Class: Google::Apis::ComputeAlpha::RegionInstanceGroupList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of InstanceGroup resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RegionInstanceGroupList

Returns a new instance of RegionInstanceGroupList.



55967
55968
55969
# File 'lib/google/apis/compute_alpha/classes.rb', line 55967

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Output only. [Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


55934
55935
55936
# File 'lib/google/apis/compute_alpha/classes.rb', line 55934

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::InstanceGroup>

A list of InstanceGroup resources. Corresponds to the JSON property items



55939
55940
55941
# File 'lib/google/apis/compute_alpha/classes.rb', line 55939

def items
  @items
end

#kindString

Output only. The resource type. Corresponds to the JSON property kind

Returns:

  • (String)


55944
55945
55946
# File 'lib/google/apis/compute_alpha/classes.rb', line 55944

def kind
  @kind
end

#next_page_tokenString

Output only. [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


55955
55956
55957
# File 'lib/google/apis/compute_alpha/classes.rb', line 55955

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


55960
55961
55962
# File 'lib/google/apis/compute_alpha/classes.rb', line 55960

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::RegionInstanceGroupList::Warning

Output only. [Output Only] Informational warning message. Corresponds to the JSON property warning



55965
55966
55967
# File 'lib/google/apis/compute_alpha/classes.rb', line 55965

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



55972
55973
55974
55975
55976
55977
55978
55979
# File 'lib/google/apis/compute_alpha/classes.rb', line 55972

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end