Class: Google::Apis::ComputeAlpha::RegionInstanceGroupManagerList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of managed instance groups.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RegionInstanceGroupManagerList

Returns a new instance of RegionInstanceGroupManagerList.



58029
58030
58031
# File 'lib/google/apis/compute_alpha/classes.rb', line 58029

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Output only. Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


57995
57996
57997
# File 'lib/google/apis/compute_alpha/classes.rb', line 57995

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::InstanceGroupManager>

A list of InstanceGroupManager resources. Corresponds to the JSON property items



58000
58001
58002
# File 'lib/google/apis/compute_alpha/classes.rb', line 58000

def items
  @items
end

#kindString

Output only. The resource type, which is always compute# instanceGroupManagerList for a list of managed instance groups that exist in th regional scope. Corresponds to the JSON property kind

Returns:

  • (String)


58007
58008
58009
# File 'lib/google/apis/compute_alpha/classes.rb', line 58007

def kind
  @kind
end

#next_page_tokenString

Output only. This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


58017
58018
58019
# File 'lib/google/apis/compute_alpha/classes.rb', line 58017

def next_page_token
  @next_page_token
end

Output only. Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


58022
58023
58024
# File 'lib/google/apis/compute_alpha/classes.rb', line 58022

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::RegionInstanceGroupManagerList::Warning

Output only. Informational warning message. Corresponds to the JSON property warning



58027
58028
58029
# File 'lib/google/apis/compute_alpha/classes.rb', line 58027

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



58034
58035
58036
58037
58038
58039
58040
58041
# File 'lib/google/apis/compute_alpha/classes.rb', line 58034

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end