Class: Google::Apis::ComputeAlpha::RegionInstanceGroupManagerList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::RegionInstanceGroupManagerList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Contains a list of managed instance groups.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
Output only.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::InstanceGroupManager>
A list of InstanceGroupManager resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
Output only.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::RegionInstanceGroupManagerList::Warning
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RegionInstanceGroupManagerList
constructor
A new instance of RegionInstanceGroupManagerList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RegionInstanceGroupManagerList
Returns a new instance of RegionInstanceGroupManagerList.
56686 56687 56688 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 56686 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
Output only. Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
56652 56653 56654 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 56652 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::InstanceGroupManager>
A list of InstanceGroupManager resources.
Corresponds to the JSON property items
56657 56658 56659 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 56657 def items @items end |
#kind ⇒ String
Output only. The resource type, which is always compute#
instanceGroupManagerList for a
list of managed instance groups that exist in th regional scope.
Corresponds to the JSON property kind
56664 56665 56666 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 56664 def kind @kind end |
#next_page_token ⇒ String
Output only. This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
56674 56675 56676 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 56674 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. Server-defined URL for this resource.
Corresponds to the JSON property selfLink
56679 56680 56681 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 56679 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::RegionInstanceGroupManagerList::Warning
Output only. Informational warning message.
Corresponds to the JSON property warning
56684 56685 56686 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 56684 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
56691 56692 56693 56694 56695 56696 56697 56698 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 56691 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |