Class: Google::Apis::ComputeAlpha::RegionInstanceGroupManagerList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::RegionInstanceGroupManagerList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Contains a list of managed instance groups.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
Output only.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::InstanceGroupManager>
A list of InstanceGroupManager resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
Output only.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::RegionInstanceGroupManagerList::Warning
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RegionInstanceGroupManagerList
constructor
A new instance of RegionInstanceGroupManagerList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RegionInstanceGroupManagerList
Returns a new instance of RegionInstanceGroupManagerList.
55890 55891 55892 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 55890 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
Output only. [Output Only] Unique identifier for the resource; defined by the
server.
Corresponds to the JSON property id
55855 55856 55857 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 55855 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::InstanceGroupManager>
A list of InstanceGroupManager resources.
Corresponds to the JSON property items
55860 55861 55862 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 55860 def items @items end |
#kind ⇒ String
Output only. [Output Only] The resource type, which is always
compute#instanceGroupManagerList for a list of managed instance groups that
exist in th regional scope.
Corresponds to the JSON property kind
55867 55868 55869 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 55867 def kind @kind end |
#next_page_token ⇒ String
Output only. [Output Only] This token allows you to get the next page of
results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
55878 55879 55880 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 55878 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
55883 55884 55885 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 55883 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::RegionInstanceGroupManagerList::Warning
Output only. [Output Only] Informational warning message.
Corresponds to the JSON property warning
55888 55889 55890 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 55888 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
55895 55896 55897 55898 55899 55900 55901 55902 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 55895 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |