Class: Google::Apis::ComputeAlpha::RegionInstanceGroupManagerList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of managed instance groups.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RegionInstanceGroupManagerList

Returns a new instance of RegionInstanceGroupManagerList.



55087
55088
55089
# File 'lib/google/apis/compute_alpha/classes.rb', line 55087

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Output only. [Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


55052
55053
55054
# File 'lib/google/apis/compute_alpha/classes.rb', line 55052

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::InstanceGroupManager>

A list of InstanceGroupManager resources. Corresponds to the JSON property items



55057
55058
55059
# File 'lib/google/apis/compute_alpha/classes.rb', line 55057

def items
  @items
end

#kindString

Output only. [Output Only] The resource type, which is always compute#instanceGroupManagerList for a list of managed instance groups that exist in th regional scope. Corresponds to the JSON property kind

Returns:

  • (String)


55064
55065
55066
# File 'lib/google/apis/compute_alpha/classes.rb', line 55064

def kind
  @kind
end

#next_page_tokenString

Output only. [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


55075
55076
55077
# File 'lib/google/apis/compute_alpha/classes.rb', line 55075

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


55080
55081
55082
# File 'lib/google/apis/compute_alpha/classes.rb', line 55080

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::RegionInstanceGroupManagerList::Warning

Output only. [Output Only] Informational warning message. Corresponds to the JSON property warning



55085
55086
55087
# File 'lib/google/apis/compute_alpha/classes.rb', line 55085

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



55092
55093
55094
55095
55096
55097
55098
55099
# File 'lib/google/apis/compute_alpha/classes.rb', line 55092

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end