Class: Google::Apis::ComputeAlpha::RegionInstanceGroupManagerResizeRequestsListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RegionInstanceGroupManagerResizeRequestsListResponse

Returns a new instance of RegionInstanceGroupManagerResizeRequestsListResponse.



57901
57902
57903
# File 'lib/google/apis/compute_alpha/classes.rb', line 57901

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


57856
57857
57858
# File 'lib/google/apis/compute_alpha/classes.rb', line 57856

def etag
  @etag
end

#idString

Output only. Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


57861
57862
57863
# File 'lib/google/apis/compute_alpha/classes.rb', line 57861

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::InstanceGroupManagerResizeRequest>

A list of Resize Request resources. Corresponds to the JSON property items



57866
57867
57868
# File 'lib/google/apis/compute_alpha/classes.rb', line 57866

def items
  @items
end

#kindString

Output only. Type of the resource. Alwayscompute# regionInstanceGroupManagerResizeRequestList for a list of Resize Requests. Corresponds to the JSON property kind

Returns:

  • (String)


57873
57874
57875
# File 'lib/google/apis/compute_alpha/classes.rb', line 57873

def kind
  @kind
end

#next_page_tokenString

Output only. This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


57883
57884
57885
# File 'lib/google/apis/compute_alpha/classes.rb', line 57883

def next_page_token
  @next_page_token
end

Output only. Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


57888
57889
57890
# File 'lib/google/apis/compute_alpha/classes.rb', line 57888

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


57894
57895
57896
# File 'lib/google/apis/compute_alpha/classes.rb', line 57894

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::RegionInstanceGroupManagerResizeRequestsListResponse::Warning

Output only. Informational warning message. Corresponds to the JSON property warning



57899
57900
57901
# File 'lib/google/apis/compute_alpha/classes.rb', line 57899

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



57906
57907
57908
57909
57910
57911
57912
57913
57914
57915
# File 'lib/google/apis/compute_alpha/classes.rb', line 57906

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end