Class: Google::Apis::ComputeAlpha::RegionInstanceGroupManagerResizeRequestsListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RegionInstanceGroupManagerResizeRequestsListResponse

Returns a new instance of RegionInstanceGroupManagerResizeRequestsListResponse.



56272
56273
56274
# File 'lib/google/apis/compute_alpha/classes.rb', line 56272

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


56227
56228
56229
# File 'lib/google/apis/compute_alpha/classes.rb', line 56227

def etag
  @etag
end

#idString

Output only. Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


56232
56233
56234
# File 'lib/google/apis/compute_alpha/classes.rb', line 56232

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::InstanceGroupManagerResizeRequest>

A list of Resize Request resources. Corresponds to the JSON property items



56237
56238
56239
# File 'lib/google/apis/compute_alpha/classes.rb', line 56237

def items
  @items
end

#kindString

Output only. Type of the resource. Alwayscompute# regionInstanceGroupManagerResizeRequestList for a list of Resize Requests. Corresponds to the JSON property kind

Returns:

  • (String)


56244
56245
56246
# File 'lib/google/apis/compute_alpha/classes.rb', line 56244

def kind
  @kind
end

#next_page_tokenString

Output only. This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


56254
56255
56256
# File 'lib/google/apis/compute_alpha/classes.rb', line 56254

def next_page_token
  @next_page_token
end

Output only. Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


56259
56260
56261
# File 'lib/google/apis/compute_alpha/classes.rb', line 56259

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


56265
56266
56267
# File 'lib/google/apis/compute_alpha/classes.rb', line 56265

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::RegionInstanceGroupManagerResizeRequestsListResponse::Warning

Output only. Informational warning message. Corresponds to the JSON property warning



56270
56271
56272
# File 'lib/google/apis/compute_alpha/classes.rb', line 56270

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



56277
56278
56279
56280
56281
56282
56283
56284
56285
56286
# File 'lib/google/apis/compute_alpha/classes.rb', line 56277

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end