Class: Google::Apis::ComputeAlpha::RegionInstanceGroupManagerResizeRequestsListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RegionInstanceGroupManagerResizeRequestsListResponse

Returns a new instance of RegionInstanceGroupManagerResizeRequestsListResponse.



56270
56271
56272
# File 'lib/google/apis/compute_alpha/classes.rb', line 56270

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


56225
56226
56227
# File 'lib/google/apis/compute_alpha/classes.rb', line 56225

def etag
  @etag
end

#idString

Output only. Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


56230
56231
56232
# File 'lib/google/apis/compute_alpha/classes.rb', line 56230

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::InstanceGroupManagerResizeRequest>

A list of Resize Request resources. Corresponds to the JSON property items



56235
56236
56237
# File 'lib/google/apis/compute_alpha/classes.rb', line 56235

def items
  @items
end

#kindString

Output only. Type of the resource. Alwayscompute# regionInstanceGroupManagerResizeRequestList for a list of Resize Requests. Corresponds to the JSON property kind

Returns:

  • (String)


56242
56243
56244
# File 'lib/google/apis/compute_alpha/classes.rb', line 56242

def kind
  @kind
end

#next_page_tokenString

Output only. This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


56252
56253
56254
# File 'lib/google/apis/compute_alpha/classes.rb', line 56252

def next_page_token
  @next_page_token
end

Output only. Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


56257
56258
56259
# File 'lib/google/apis/compute_alpha/classes.rb', line 56257

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


56263
56264
56265
# File 'lib/google/apis/compute_alpha/classes.rb', line 56263

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::RegionInstanceGroupManagerResizeRequestsListResponse::Warning

Output only. Informational warning message. Corresponds to the JSON property warning



56268
56269
56270
# File 'lib/google/apis/compute_alpha/classes.rb', line 56268

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



56275
56276
56277
56278
56279
56280
56281
56282
56283
56284
# File 'lib/google/apis/compute_alpha/classes.rb', line 56275

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end