Class: Google::Apis::ComputeAlpha::RegionInstanceGroupManagerResizeRequestsListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RegionInstanceGroupManagerResizeRequestsListResponse

Returns a new instance of RegionInstanceGroupManagerResizeRequestsListResponse.



55246
55247
55248
# File 'lib/google/apis/compute_alpha/classes.rb', line 55246

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


55199
55200
55201
# File 'lib/google/apis/compute_alpha/classes.rb', line 55199

def etag
  @etag
end

#idString

Output only. [Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


55205
55206
55207
# File 'lib/google/apis/compute_alpha/classes.rb', line 55205

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::InstanceGroupManagerResizeRequest>

A list of Resize Request resources. Corresponds to the JSON property items



55210
55211
55212
# File 'lib/google/apis/compute_alpha/classes.rb', line 55210

def items
  @items
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# regionInstanceGroupManagerResizeRequestList for a list of Resize Requests. Corresponds to the JSON property kind

Returns:

  • (String)


55217
55218
55219
# File 'lib/google/apis/compute_alpha/classes.rb', line 55217

def kind
  @kind
end

#next_page_tokenString

Output only. [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


55228
55229
55230
# File 'lib/google/apis/compute_alpha/classes.rb', line 55228

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


55233
55234
55235
# File 'lib/google/apis/compute_alpha/classes.rb', line 55233

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


55239
55240
55241
# File 'lib/google/apis/compute_alpha/classes.rb', line 55239

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::RegionInstanceGroupManagerResizeRequestsListResponse::Warning

Output only. [Output Only] Informational warning message. Corresponds to the JSON property warning



55244
55245
55246
# File 'lib/google/apis/compute_alpha/classes.rb', line 55244

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



55251
55252
55253
55254
55255
55256
55257
55258
55259
55260
# File 'lib/google/apis/compute_alpha/classes.rb', line 55251

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end