Class: Google::Apis::ComputeAlpha::RegionInstanceGroupManagersApplyUpdatesRequest
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::RegionInstanceGroupManagersApplyUpdatesRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
RegionInstanceGroupManagers.applyUpdatesToInstances
Instance Attribute Summary collapse
-
#all_instances ⇒ Boolean
(also: #all_instances?)
Flag to update all instances instead of specified list of “instances”.
-
#disruption_mode ⇒ String
Whether the boot disk is allowed to be updated with restart.
-
#instances ⇒ Array<String>
The list of URLs of one or more instances for which you want to apply updates.
-
#maximal_action ⇒ String
The maximal action that should be performed on the instances.
-
#minimal_action ⇒ String
The minimal action that you want to perform on each instance during the update:.
-
#most_disruptive_allowed_action ⇒ String
The most disruptive action that you want to perform on each instance during the update:.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RegionInstanceGroupManagersApplyUpdatesRequest
constructor
A new instance of RegionInstanceGroupManagersApplyUpdatesRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RegionInstanceGroupManagersApplyUpdatesRequest
Returns a new instance of RegionInstanceGroupManagersApplyUpdatesRequest.
56483 56484 56485 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 56483 def initialize(**args) update!(**args) end |
Instance Attribute Details
#all_instances ⇒ Boolean Also known as: all_instances?
Flag to update all instances instead of specified list of “instances”.
If the flag is set to true then the instances may not be specified
in the request.
Corresponds to the JSON property allInstances
56425 56426 56427 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 56425 def all_instances @all_instances end |
#disruption_mode ⇒ String
Whether the boot disk is allowed to be updated with restart.
Corresponds to the JSON property disruptionMode
56431 56432 56433 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 56431 def disruption_mode @disruption_mode end |
#instances ⇒ Array<String>
The list of URLs of one or more instances for which you want to apply
updates. Each URL can be a full URL or a partial URL, such aszones/[ZONE]/
instances/[INSTANCE_NAME].
Corresponds to the JSON property instances
56438 56439 56440 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 56438 def instances @instances end |
#maximal_action ⇒ String
The maximal action that should be performed on the instances.
By default REPLACE.
This field is deprecated, please use most_disruptive_allowed_action.
Corresponds to the JSON property maximalAction
56445 56446 56447 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 56445 def maximal_action @maximal_action end |
#minimal_action ⇒ String
The minimal action that you want to perform on each instance during the update:
- REPLACE: At minimum, delete the instance and create it again.
- RESTART: Stop the instance and start it again.
- REFRESH: Do not stop the instance and limit disruption as much as possible.
- NONE: Do not
disrupt the instance at all.
By default, the minimum action is NONE. If your update
requires a more disruptive action than you set with this flag, the
necessary action is performed to execute the update.
Corresponds to the JSON property
minimalAction
56464 56465 56466 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 56464 def minimal_action @minimal_action end |
#most_disruptive_allowed_action ⇒ String
The most disruptive action that you want to perform on each instance during the update:
- REPLACE: Delete the instance and create it again.
- RESTART: Stop the instance and start it again.
- REFRESH: Do not stop the instance and limit disruption as much as possible.
- NONE: Do not disrupt the
instance at all.
By default, the most disruptive allowed action is REPLACE. If
your update requires a more disruptive action than you set with this flag,
the update request will fail.
Corresponds to the JSON property
mostDisruptiveAllowedAction
56481 56482 56483 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 56481 def most_disruptive_allowed_action @most_disruptive_allowed_action end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
56488 56489 56490 56491 56492 56493 56494 56495 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 56488 def update!(**args) @all_instances = args[:all_instances] if args.key?(:all_instances) @disruption_mode = args[:disruption_mode] if args.key?(:disruption_mode) @instances = args[:instances] if args.key?(:instances) @maximal_action = args[:maximal_action] if args.key?(:maximal_action) @minimal_action = args[:minimal_action] if args.key?(:minimal_action) @most_disruptive_allowed_action = args[:most_disruptive_allowed_action] if args.key?(:most_disruptive_allowed_action) end |