Class: Google::Apis::ComputeAlpha::RegionInstanceGroupManagersDeleteInstancesRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RegionInstanceGroupManagersDeleteInstancesRequest

Returns a new instance of RegionInstanceGroupManagersDeleteInstancesRequest.



56318
56319
56320
# File 'lib/google/apis/compute_alpha/classes.rb', line 56318

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#instancesArray<String>

The URLs of one or more instances to delete. This can be a full URL or a partial URL, such as zones/[ZONE]/instances/[INSTANCE_NAME]. Corresponds to the JSON property instances

Returns:

  • (Array<String>)


56304
56305
56306
# File 'lib/google/apis/compute_alpha/classes.rb', line 56304

def instances
  @instances
end

#skip_instances_on_validation_errorBoolean Also known as: skip_instances_on_validation_error?

Specifies whether the request should proceed despite the inclusion of instances that are not members of the group or that are already in the process of being deleted or abandoned. If this field is set to false and such an instance is specified in the request, the operation fails. The operation always fails if the request contains a malformed instance URL or a reference to an instance that exists in a zone or region other than the group's zone or region. Corresponds to the JSON property skipInstancesOnValidationError

Returns:

  • (Boolean)


56315
56316
56317
# File 'lib/google/apis/compute_alpha/classes.rb', line 56315

def skip_instances_on_validation_error
  @skip_instances_on_validation_error
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



56323
56324
56325
56326
# File 'lib/google/apis/compute_alpha/classes.rb', line 56323

def update!(**args)
  @instances = args[:instances] if args.key?(:instances)
  @skip_instances_on_validation_error = args[:skip_instances_on_validation_error] if args.key?(:skip_instances_on_validation_error)
end