Class: Google::Apis::ComputeAlpha::RegionInstanceGroupManagersDeleteInstancesRequest
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::RegionInstanceGroupManagersDeleteInstancesRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#instances ⇒ Array<String>
The URLs of one or more instances to delete.
-
#skip_instances_on_validation_error ⇒ Boolean
(also: #skip_instances_on_validation_error?)
Specifies whether the request should proceed despite the inclusion of instances that are not members of the group or that are already in the process of being deleted or abandoned.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RegionInstanceGroupManagersDeleteInstancesRequest
constructor
A new instance of RegionInstanceGroupManagersDeleteInstancesRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RegionInstanceGroupManagersDeleteInstancesRequest
Returns a new instance of RegionInstanceGroupManagersDeleteInstancesRequest.
55515 55516 55517 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 55515 def initialize(**args) update!(**args) end |
Instance Attribute Details
#instances ⇒ Array<String>
The URLs of one or more instances to delete. This can be a full URL or
a partial URL, such as zones/[ZONE]/instances/[INSTANCE_NAME].
Corresponds to the JSON property instances
55501 55502 55503 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 55501 def instances @instances end |
#skip_instances_on_validation_error ⇒ Boolean Also known as: skip_instances_on_validation_error?
Specifies whether the request should proceed despite the inclusion of
instances that are not members of the group or that are already in the
process of being deleted or abandoned. If this field is set to false and
such an instance is specified in the request, the operation fails. The
operation always fails if the request contains a malformed instance URL or
a reference to an instance that exists in a zone or region other than the
group's zone or region.
Corresponds to the JSON property skipInstancesOnValidationError
55512 55513 55514 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 55512 def skip_instances_on_validation_error @skip_instances_on_validation_error end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
55520 55521 55522 55523 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 55520 def update!(**args) @instances = args[:instances] if args.key?(:instances) @skip_instances_on_validation_error = args[:skip_instances_on_validation_error] if args.key?(:skip_instances_on_validation_error) end |