Class: Google::Apis::ComputeAlpha::RegionInstanceGroupManagersListInstanceConfigsResp

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RegionInstanceGroupManagersListInstanceConfigsResp

Returns a new instance of RegionInstanceGroupManagersListInstanceConfigsResp.



57168
57169
57170
# File 'lib/google/apis/compute_alpha/classes.rb', line 57168

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#itemsArray<Google::Apis::ComputeAlpha::PerInstanceConfig>

Output only. [Output Only] The list of PerInstanceConfig. Corresponds to the JSON property items



57150
57151
57152
# File 'lib/google/apis/compute_alpha/classes.rb', line 57150

def items
  @items
end

#next_page_tokenString

Output only. [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


57161
57162
57163
# File 'lib/google/apis/compute_alpha/classes.rb', line 57161

def next_page_token
  @next_page_token
end

#warningGoogle::Apis::ComputeAlpha::RegionInstanceGroupManagersListInstanceConfigsResp::Warning

Output only. [Output Only] Informational warning message. Corresponds to the JSON property warning



57166
57167
57168
# File 'lib/google/apis/compute_alpha/classes.rb', line 57166

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



57173
57174
57175
57176
57177
# File 'lib/google/apis/compute_alpha/classes.rb', line 57173

def update!(**args)
  @items = args[:items] if args.key?(:items)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @warning = args[:warning] if args.key?(:warning)
end