Class: Google::Apis::ComputeAlpha::RegionInstanceGroupManagersListInstanceConfigsResp

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RegionInstanceGroupManagersListInstanceConfigsResp

Returns a new instance of RegionInstanceGroupManagersListInstanceConfigsResp.



55582
55583
55584
# File 'lib/google/apis/compute_alpha/classes.rb', line 55582

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#itemsArray<Google::Apis::ComputeAlpha::PerInstanceConfig>

Output only. [Output Only] The list of PerInstanceConfig. Corresponds to the JSON property items



55564
55565
55566
# File 'lib/google/apis/compute_alpha/classes.rb', line 55564

def items
  @items
end

#next_page_tokenString

Output only. [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


55575
55576
55577
# File 'lib/google/apis/compute_alpha/classes.rb', line 55575

def next_page_token
  @next_page_token
end

#warningGoogle::Apis::ComputeAlpha::RegionInstanceGroupManagersListInstanceConfigsResp::Warning

Output only. [Output Only] Informational warning message. Corresponds to the JSON property warning



55580
55581
55582
# File 'lib/google/apis/compute_alpha/classes.rb', line 55580

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



55587
55588
55589
55590
55591
# File 'lib/google/apis/compute_alpha/classes.rb', line 55587

def update!(**args)
  @items = args[:items] if args.key?(:items)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @warning = args[:warning] if args.key?(:warning)
end