Class: Google::Apis::ComputeAlpha::RegionInstanceGroupManagersListInstancesResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RegionInstanceGroupManagersListInstancesResponse

Returns a new instance of RegionInstanceGroupManagersListInstancesResponse.



58345
58346
58347
# File 'lib/google/apis/compute_alpha/classes.rb', line 58345

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#managed_instancesArray<Google::Apis::ComputeAlpha::ManagedInstance>

A list of managed instances. Corresponds to the JSON property managedInstances



58332
58333
58334
# File 'lib/google/apis/compute_alpha/classes.rb', line 58332

def managed_instances
  @managed_instances
end

#next_page_tokenString

Output only. [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


58343
58344
58345
# File 'lib/google/apis/compute_alpha/classes.rb', line 58343

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



58350
58351
58352
58353
# File 'lib/google/apis/compute_alpha/classes.rb', line 58350

def update!(**args)
  @managed_instances = args[:managed_instances] if args.key?(:managed_instances)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end