Class: Google::Apis::ComputeAlpha::RegionInstanceGroupManagersListInstancesResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RegionInstanceGroupManagersListInstancesResponse

Returns a new instance of RegionInstanceGroupManagersListInstancesResponse.



56708
56709
56710
# File 'lib/google/apis/compute_alpha/classes.rb', line 56708

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#managed_instancesArray<Google::Apis::ComputeAlpha::ManagedInstance>

A list of managed instances. Corresponds to the JSON property managedInstances



56695
56696
56697
# File 'lib/google/apis/compute_alpha/classes.rb', line 56695

def managed_instances
  @managed_instances
end

#next_page_tokenString

Output only. [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


56706
56707
56708
# File 'lib/google/apis/compute_alpha/classes.rb', line 56706

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



56713
56714
56715
56716
# File 'lib/google/apis/compute_alpha/classes.rb', line 56713

def update!(**args)
  @managed_instances = args[:managed_instances] if args.key?(:managed_instances)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end