Class: Google::Apis::ComputeAlpha::RegionInstanceGroupsListInstances

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RegionInstanceGroupsListInstances

Returns a new instance of RegionInstanceGroupsListInstances.



57575
57576
57577
# File 'lib/google/apis/compute_alpha/classes.rb', line 57575

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Output only. [Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


57542
57543
57544
# File 'lib/google/apis/compute_alpha/classes.rb', line 57542

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::InstanceWithNamedPorts>

A list of InstanceWithNamedPorts resources. Corresponds to the JSON property items



57547
57548
57549
# File 'lib/google/apis/compute_alpha/classes.rb', line 57547

def items
  @items
end

#kindString

Output only. The resource type. Corresponds to the JSON property kind

Returns:

  • (String)


57552
57553
57554
# File 'lib/google/apis/compute_alpha/classes.rb', line 57552

def kind
  @kind
end

#next_page_tokenString

Output only. [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


57563
57564
57565
# File 'lib/google/apis/compute_alpha/classes.rb', line 57563

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


57568
57569
57570
# File 'lib/google/apis/compute_alpha/classes.rb', line 57568

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::RegionInstanceGroupsListInstances::Warning

Output only. [Output Only] Informational warning message. Corresponds to the JSON property warning



57573
57574
57575
# File 'lib/google/apis/compute_alpha/classes.rb', line 57573

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



57580
57581
57582
57583
57584
57585
57586
57587
# File 'lib/google/apis/compute_alpha/classes.rb', line 57580

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end