Class: Google::Apis::ComputeAlpha::RegionInstanceGroupsListInstances

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RegionInstanceGroupsListInstances

Returns a new instance of RegionInstanceGroupsListInstances.



56996
56997
56998
# File 'lib/google/apis/compute_alpha/classes.rb', line 56996

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Output only. [Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


56963
56964
56965
# File 'lib/google/apis/compute_alpha/classes.rb', line 56963

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::InstanceWithNamedPorts>

A list of InstanceWithNamedPorts resources. Corresponds to the JSON property items



56968
56969
56970
# File 'lib/google/apis/compute_alpha/classes.rb', line 56968

def items
  @items
end

#kindString

Output only. The resource type. Corresponds to the JSON property kind

Returns:

  • (String)


56973
56974
56975
# File 'lib/google/apis/compute_alpha/classes.rb', line 56973

def kind
  @kind
end

#next_page_tokenString

Output only. [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


56984
56985
56986
# File 'lib/google/apis/compute_alpha/classes.rb', line 56984

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


56989
56990
56991
# File 'lib/google/apis/compute_alpha/classes.rb', line 56989

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::RegionInstanceGroupsListInstances::Warning

Output only. [Output Only] Informational warning message. Corresponds to the JSON property warning



56994
56995
56996
# File 'lib/google/apis/compute_alpha/classes.rb', line 56994

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



57001
57002
57003
57004
57005
57006
57007
57008
# File 'lib/google/apis/compute_alpha/classes.rb', line 57001

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end