Class: Google::Apis::ComputeAlpha::RegionInstanceGroupsListInstancesRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RegionInstanceGroupsListInstancesRequest

Returns a new instance of RegionInstanceGroupsListInstancesRequest.



59021
59022
59023
# File 'lib/google/apis/compute_alpha/classes.rb', line 59021

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#instance_stateString

Instances in which state should be returned. Valid options are: 'ALL', 'RUNNING'. By default, it lists all instances. Corresponds to the JSON property instanceState

Returns:

  • (String)


59011
59012
59013
# File 'lib/google/apis/compute_alpha/classes.rb', line 59011

def instance_state
  @instance_state
end

#port_nameString

Name of port user is interested in. It is optional. If it is set, only information about this ports will be returned. If it is not set, all the named ports will be returned. Always lists all instances. Corresponds to the JSON property portName

Returns:

  • (String)


59019
59020
59021
# File 'lib/google/apis/compute_alpha/classes.rb', line 59019

def port_name
  @port_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



59026
59027
59028
59029
# File 'lib/google/apis/compute_alpha/classes.rb', line 59026

def update!(**args)
  @instance_state = args[:instance_state] if args.key?(:instance_state)
  @port_name = args[:port_name] if args.key?(:port_name)
end