Class: Google::Apis::ComputeAlpha::RegionInstanceGroupsSetNamedPortsRequest
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::RegionInstanceGroupsSetNamedPortsRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#fingerprint ⇒ String
The fingerprint of the named ports information for this instance group.
-
#named_ports ⇒ Array<Google::Apis::ComputeAlpha::NamedPort>
The list of named ports to set for this instance group.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RegionInstanceGroupsSetNamedPortsRequest
constructor
A new instance of RegionInstanceGroupsSetNamedPortsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RegionInstanceGroupsSetNamedPortsRequest
Returns a new instance of RegionInstanceGroupsSetNamedPortsRequest.
59053 59054 59055 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59053 def initialize(**args) update!(**args) end |
Instance Attribute Details
#fingerprint ⇒ String
The fingerprint of the named ports information for this instance group.
Use this optional property to prevent conflicts when multiple users change
the named ports settings concurrently. Obtain the fingerprint with
theinstanceGroups.get
method. Then, include the fingerprint in your request to ensure that you
do not overwrite changes that were applied from another
concurrent request.
Corresponds to the JSON property fingerprint
NOTE: Values are automatically base64 encoded/decoded in the client library.
59046 59047 59048 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59046 def fingerprint @fingerprint end |
#named_ports ⇒ Array<Google::Apis::ComputeAlpha::NamedPort>
The list of named ports to set for this instance group.
Corresponds to the JSON property namedPorts
59051 59052 59053 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59051 def named_ports @named_ports end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
59058 59059 59060 59061 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59058 def update!(**args) @fingerprint = args[:fingerprint] if args.key?(:fingerprint) @named_ports = args[:named_ports] if args.key?(:named_ports) end |