Class: Google::Apis::ComputeAlpha::RegionInstanceGroupsSetNamedPortsRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RegionInstanceGroupsSetNamedPortsRequest

Returns a new instance of RegionInstanceGroupsSetNamedPortsRequest.



56910
56911
56912
# File 'lib/google/apis/compute_alpha/classes.rb', line 56910

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#fingerprintString

The fingerprint of the named ports information for this instance group. Use this optional property to prevent conflicts when multiple users change the named ports settings concurrently. Obtain the fingerprint with theinstanceGroups.get method. Then, include the fingerprint in your request to ensure that you do not overwrite changes that were applied from another concurrent request. Corresponds to the JSON property fingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


56903
56904
56905
# File 'lib/google/apis/compute_alpha/classes.rb', line 56903

def fingerprint
  @fingerprint
end

#named_portsArray<Google::Apis::ComputeAlpha::NamedPort>

The list of named ports to set for this instance group. Corresponds to the JSON property namedPorts



56908
56909
56910
# File 'lib/google/apis/compute_alpha/classes.rb', line 56908

def named_ports
  @named_ports
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



56915
56916
56917
56918
# File 'lib/google/apis/compute_alpha/classes.rb', line 56915

def update!(**args)
  @fingerprint = args[:fingerprint] if args.key?(:fingerprint)
  @named_ports = args[:named_ports] if args.key?(:named_ports)
end