Class: Google::Apis::ComputeAlpha::RegionList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::RegionList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Contains a list of region resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::Region>
A list of Region resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::RegionList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RegionList
constructor
A new instance of RegionList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RegionList
Returns a new instance of RegionList.
59104 59105 59106 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59104 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
59071 59072 59073 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59071 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::Region>
A list of Region resources.
Corresponds to the JSON property items
59076 59077 59078 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59076 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#regionList for
lists of regions.
Corresponds to the JSON property kind
59082 59083 59084 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59082 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
59092 59093 59094 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59092 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
59097 59098 59099 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59097 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::RegionList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
59102 59103 59104 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59102 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
59109 59110 59111 59112 59113 59114 59115 59116 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59109 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |