Class: Google::Apis::ComputeAlpha::RegionList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::RegionList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Contains a list of region resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::Region>
A list of Region resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::RegionList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RegionList
constructor
A new instance of RegionList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RegionList
Returns a new instance of RegionList.
58819 58820 58821 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58819 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
58786 58787 58788 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58786 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::Region>
A list of Region resources.
Corresponds to the JSON property items
58791 58792 58793 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58791 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#regionList for
lists of regions.
Corresponds to the JSON property kind
58797 58798 58799 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58797 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
58807 58808 58809 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58807 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
58812 58813 58814 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58812 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::RegionList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
58817 58818 58819 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58817 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
58824 58825 58826 58827 58828 58829 58830 58831 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58824 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |