Class: Google::Apis::ComputeAlpha::RegionList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of region resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RegionList

Returns a new instance of RegionList.



57744
57745
57746
# File 'lib/google/apis/compute_alpha/classes.rb', line 57744

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


57711
57712
57713
# File 'lib/google/apis/compute_alpha/classes.rb', line 57711

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::Region>

A list of Region resources. Corresponds to the JSON property items



57716
57717
57718
# File 'lib/google/apis/compute_alpha/classes.rb', line 57716

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#regionList for lists of regions. Corresponds to the JSON property kind

Returns:

  • (String)


57722
57723
57724
# File 'lib/google/apis/compute_alpha/classes.rb', line 57722

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


57732
57733
57734
# File 'lib/google/apis/compute_alpha/classes.rb', line 57732

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


57737
57738
57739
# File 'lib/google/apis/compute_alpha/classes.rb', line 57737

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::RegionList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



57742
57743
57744
# File 'lib/google/apis/compute_alpha/classes.rb', line 57742

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



57749
57750
57751
57752
57753
57754
57755
57756
# File 'lib/google/apis/compute_alpha/classes.rb', line 57749

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end