Class: Google::Apis::ComputeAlpha::RegionList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of region resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RegionList

Returns a new instance of RegionList.



57182
57183
57184
# File 'lib/google/apis/compute_alpha/classes.rb', line 57182

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


57149
57150
57151
# File 'lib/google/apis/compute_alpha/classes.rb', line 57149

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::Region>

A list of Region resources. Corresponds to the JSON property items



57154
57155
57156
# File 'lib/google/apis/compute_alpha/classes.rb', line 57154

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#regionList for lists of regions. Corresponds to the JSON property kind

Returns:

  • (String)


57160
57161
57162
# File 'lib/google/apis/compute_alpha/classes.rb', line 57160

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


57170
57171
57172
# File 'lib/google/apis/compute_alpha/classes.rb', line 57170

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


57175
57176
57177
# File 'lib/google/apis/compute_alpha/classes.rb', line 57175

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::RegionList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



57180
57181
57182
# File 'lib/google/apis/compute_alpha/classes.rb', line 57180

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



57187
57188
57189
57190
57191
57192
57193
57194
# File 'lib/google/apis/compute_alpha/classes.rb', line 57187

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end