Class: Google::Apis::ComputeAlpha::RegionList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::RegionList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Contains a list of region resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::Region>
A list of Region resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::RegionList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RegionList
constructor
A new instance of RegionList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RegionList
Returns a new instance of RegionList.
56961 56962 56963 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 56961 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
56928 56929 56930 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 56928 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::Region>
A list of Region resources.
Corresponds to the JSON property items
56933 56934 56935 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 56933 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#regionList for
lists of regions.
Corresponds to the JSON property kind
56939 56940 56941 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 56939 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
56949 56950 56951 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 56949 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
56954 56955 56956 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 56954 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::RegionList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
56959 56960 56961 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 56959 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
56966 56967 56968 56969 56970 56971 56972 56973 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 56966 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |