Class: Google::Apis::ComputeAlpha::RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponse

Returns a new instance of RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponse.



57323
57324
57325
# File 'lib/google/apis/compute_alpha/classes.rb', line 57323

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#firewall_policysArray<Google::Apis::ComputeAlpha::RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponseEffectiveFirewallPolicy>

Output only. [Output only] Effective firewalls from firewall policy. It applies to Regional Network Firewall Policies in the specified region, Global Network Firewall Policies and Hierachial Firewall Policies which are associated with the network. Corresponds to the JSON property firewallPolicys



57316
57317
57318
# File 'lib/google/apis/compute_alpha/classes.rb', line 57316

def firewall_policys
  @firewall_policys
end

#firewallsArray<Google::Apis::ComputeAlpha::Firewall>

Effective firewalls on the network. Corresponds to the JSON property firewalls



57321
57322
57323
# File 'lib/google/apis/compute_alpha/classes.rb', line 57321

def firewalls
  @firewalls
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



57328
57329
57330
57331
# File 'lib/google/apis/compute_alpha/classes.rb', line 57328

def update!(**args)
  @firewall_policys = args[:firewall_policys] if args.key?(:firewall_policys)
  @firewalls = args[:firewalls] if args.key?(:firewalls)
end