Class: Google::Apis::ComputeAlpha::RegionSetLabelsRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RegionSetLabelsRequest

Returns a new instance of RegionSetLabelsRequest.



59330
59331
59332
# File 'lib/google/apis/compute_alpha/classes.rb', line 59330

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#label_fingerprintString

The fingerprint of the previous set of labels for this resource, used to detect conflicts. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update labels. You must always provide an up-to-date fingerprint hash in order to update or change labels. Make a get() request to the resource to get the latest fingerprint. Corresponds to the JSON property labelFingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


59323
59324
59325
# File 'lib/google/apis/compute_alpha/classes.rb', line 59323

def label_fingerprint
  @label_fingerprint
end

#labelsHash<String,String>

The labels to set for this resource. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


59328
59329
59330
# File 'lib/google/apis/compute_alpha/classes.rb', line 59328

def labels
  @labels
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



59335
59336
59337
59338
# File 'lib/google/apis/compute_alpha/classes.rb', line 59335

def update!(**args)
  @label_fingerprint = args[:label_fingerprint] if args.key?(:label_fingerprint)
  @labels = args[:labels] if args.key?(:labels)
end