Class: Google::Apis::ComputeAlpha::RegionSetLabelsRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RegionSetLabelsRequest

Returns a new instance of RegionSetLabelsRequest.



57970
57971
57972
# File 'lib/google/apis/compute_alpha/classes.rb', line 57970

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#label_fingerprintString

The fingerprint of the previous set of labels for this resource, used to detect conflicts. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update labels. You must always provide an up-to-date fingerprint hash in order to update or change labels. Make a get() request to the resource to get the latest fingerprint. Corresponds to the JSON property labelFingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


57963
57964
57965
# File 'lib/google/apis/compute_alpha/classes.rb', line 57963

def label_fingerprint
  @label_fingerprint
end

#labelsHash<String,String>

The labels to set for this resource. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


57968
57969
57970
# File 'lib/google/apis/compute_alpha/classes.rb', line 57968

def labels
  @labels
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



57975
57976
57977
57978
# File 'lib/google/apis/compute_alpha/classes.rb', line 57975

def update!(**args)
  @label_fingerprint = args[:label_fingerprint] if args.key?(:label_fingerprint)
  @labels = args[:labels] if args.key?(:labels)
end