Class: Google::Apis::ComputeAlpha::ReliabilityRisk
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::ReliabilityRisk
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Represents a ReliabilityRisk resource.
Instance Attribute Summary collapse
-
#creation_timestamp ⇒ String
Output only.
-
#description ⇒ String
An optional textual description of the resource; provided when the resource is created.
-
#details ⇒ Google::Apis::ComputeAlpha::RiskDetails
Detailed insights and metrics about a detected reliability risk.
-
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
Name of the resource.
-
#recommendation ⇒ Google::Apis::ComputeAlpha::RiskRecommendation
Recommendation for mitigating a reliability risk, including a reference URL.
-
#self_link ⇒ String
Output only.
-
#self_link_with_id ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReliabilityRisk
constructor
A new instance of ReliabilityRisk.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReliabilityRisk
Returns a new instance of ReliabilityRisk.
59317 59318 59319 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59317 def initialize(**args) update!(**args) end |
Instance Attribute Details
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp in RFC3339
text format.
Corresponds to the JSON property creationTimestamp
59270 59271 59272 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59270 def @creation_timestamp end |
#description ⇒ String
An optional textual description of the resource; provided when the
resource is created.
Corresponds to the JSON property description
59276 59277 59278 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59276 def description @description end |
#details ⇒ Google::Apis::ComputeAlpha::RiskDetails
Detailed insights and metrics about a detected reliability risk.
Corresponds to the JSON property details
59281 59282 59283 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59281 def details @details end |
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
59287 59288 59289 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59287 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#reliabilityRisk
for reliability risks.
Corresponds to the JSON property kind
59293 59294 59295 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59293 def kind @kind end |
#name ⇒ String
Name of the resource. The name must be 1-63 characters long and
comply with RFC1035.
Corresponds to the JSON property name
59299 59300 59301 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59299 def name @name end |
#recommendation ⇒ Google::Apis::ComputeAlpha::RiskRecommendation
Recommendation for mitigating a reliability risk, including a reference URL.
Corresponds to the JSON property recommendation
59304 59305 59306 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59304 def recommendation @recommendation end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
59309 59310 59311 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59309 def self_link @self_link end |
#self_link_with_id ⇒ String
Output only. [Output Only] Server-defined URL for this resource with the
resource id.
Corresponds to the JSON property selfLinkWithId
59315 59316 59317 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59315 def self_link_with_id @self_link_with_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
59322 59323 59324 59325 59326 59327 59328 59329 59330 59331 59332 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59322 def update!(**args) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @details = args[:details] if args.key?(:details) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @recommendation = args[:recommendation] if args.key?(:recommendation) @self_link = args[:self_link] if args.key?(:self_link) @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id) end |