Class: Google::Apis::ComputeAlpha::ReliabilityRisksListResponse
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::ReliabilityRisksListResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Response message for the List method of ReliabilityRisksService.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
[Output Only] An ETag of the resource.
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::ReliabilityRisk>
A list of ReliabilityRisk resources.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::ReliabilityRisksListResponse::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReliabilityRisksListResponse
constructor
A new instance of ReliabilityRisksListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReliabilityRisksListResponse
Returns a new instance of ReliabilityRisksListResponse.
59932 59933 59934 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59932 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
[Output Only] An ETag of the resource.
Corresponds to the JSON property etag
59894 59895 59896 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59894 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
59899 59900 59901 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59899 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::ReliabilityRisk>
A list of ReliabilityRisk resources.
Corresponds to the JSON property items
59904 59905 59906 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59904 def items @items end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
59914 59915 59916 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59914 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
59919 59920 59921 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59919 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
end_interface: MixerListResponseWithEtagBuilder
Corresponds to the JSON property unreachables
59925 59926 59927 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59925 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::ReliabilityRisksListResponse::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
59930 59931 59932 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59930 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
59937 59938 59939 59940 59941 59942 59943 59944 59945 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59937 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |