Class: Google::Apis::ComputeAlpha::ReliabilityRisksListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Response message for the List method of ReliabilityRisksService.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReliabilityRisksListResponse

Returns a new instance of ReliabilityRisksListResponse.



59380
59381
59382
# File 'lib/google/apis/compute_alpha/classes.rb', line 59380

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


59342
59343
59344
# File 'lib/google/apis/compute_alpha/classes.rb', line 59342

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


59347
59348
59349
# File 'lib/google/apis/compute_alpha/classes.rb', line 59347

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::ReliabilityRisk>

A list of ReliabilityRisk resources. Corresponds to the JSON property items



59352
59353
59354
# File 'lib/google/apis/compute_alpha/classes.rb', line 59352

def items
  @items
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


59362
59363
59364
# File 'lib/google/apis/compute_alpha/classes.rb', line 59362

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


59367
59368
59369
# File 'lib/google/apis/compute_alpha/classes.rb', line 59367

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


59373
59374
59375
# File 'lib/google/apis/compute_alpha/classes.rb', line 59373

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::ReliabilityRisksListResponse::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



59378
59379
59380
# File 'lib/google/apis/compute_alpha/classes.rb', line 59378

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



59385
59386
59387
59388
59389
59390
59391
59392
59393
# File 'lib/google/apis/compute_alpha/classes.rb', line 59385

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end