Class: Google::Apis::ComputeAlpha::ReliabilityRisksListResponse
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::ReliabilityRisksListResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::ReliabilityRisk>
A list of ReliabilityRisk resources.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::ReliabilityRisksListResponse::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReliabilityRisksListResponse
constructor
A new instance of ReliabilityRisksListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReliabilityRisksListResponse
Returns a new instance of ReliabilityRisksListResponse.
57745 57746 57747 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 57745 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
57707 57708 57709 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 57707 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
57712 57713 57714 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 57712 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::ReliabilityRisk>
A list of ReliabilityRisk resources.
Corresponds to the JSON property items
57717 57718 57719 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 57717 def items @items end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
57727 57728 57729 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 57727 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
57732 57733 57734 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 57732 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
end_interface: MixerListResponseWithEtagBuilder
Corresponds to the JSON property unreachables
57738 57739 57740 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 57738 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::ReliabilityRisksListResponse::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
57743 57744 57745 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 57743 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
57750 57751 57752 57753 57754 57755 57756 57757 57758 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 57750 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |