Class: Google::Apis::ComputeAlpha::ReliabilityRisksListResponse
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::ReliabilityRisksListResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::ReliabilityRisk>
A list of ReliabilityRisk resources.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::ReliabilityRisksListResponse::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReliabilityRisksListResponse
constructor
A new instance of ReliabilityRisksListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReliabilityRisksListResponse
Returns a new instance of ReliabilityRisksListResponse.
57522 57523 57524 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 57522 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
57484 57485 57486 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 57484 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
57489 57490 57491 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 57489 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::ReliabilityRisk>
A list of ReliabilityRisk resources.
Corresponds to the JSON property items
57494 57495 57496 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 57494 def items @items end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
57504 57505 57506 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 57504 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
57509 57510 57511 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 57509 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
end_interface: MixerListResponseWithEtagBuilder
Corresponds to the JSON property unreachables
57515 57516 57517 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 57515 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::ReliabilityRisksListResponse::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
57520 57521 57522 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 57520 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
57527 57528 57529 57530 57531 57532 57533 57534 57535 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 57527 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |