Class: Google::Apis::ComputeAlpha::ReplicationDetails

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReplicationDetails

Returns a new instance of ReplicationDetails.



58409
58410
58411
# File 'lib/google/apis/compute_alpha/classes.rb', line 58409

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#last_replication_timeString

Output only. The last sync time of the device pair. Corresponds to the JSON property lastReplicationTime

Returns:

  • (String)


58398
58399
58400
# File 'lib/google/apis/compute_alpha/classes.rb', line 58398

def last_replication_time
  @last_replication_time
end

#seconds_since_last_replicationFixnum

Output only. Replication lag in seconds. This will only be populated if device is in replicating state. Note that the value is calculated sometime during request processing and at the instant the client receives the response, the current replication_lag may have changed. Corresponds to the JSON property secondsSinceLastReplication

Returns:

  • (Fixnum)


58407
58408
58409
# File 'lib/google/apis/compute_alpha/classes.rb', line 58407

def seconds_since_last_replication
  @seconds_since_last_replication
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



58414
58415
58416
58417
# File 'lib/google/apis/compute_alpha/classes.rb', line 58414

def update!(**args)
  @last_replication_time = args[:last_replication_time] if args.key?(:last_replication_time)
  @seconds_since_last_replication = args[:seconds_since_last_replication] if args.key?(:seconds_since_last_replication)
end