Class: Google::Apis::ComputeAlpha::ReservationAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of reservations.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReservationAggregatedList

Returns a new instance of ReservationAggregatedList.



60188
60189
60190
# File 'lib/google/apis/compute_alpha/classes.rb', line 60188

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


60151
60152
60153
# File 'lib/google/apis/compute_alpha/classes.rb', line 60151

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::ReservationsScopedList>

A list of Allocation resources. Corresponds to the JSON property items



60156
60157
60158
# File 'lib/google/apis/compute_alpha/classes.rb', line 60156

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


60161
60162
60163
# File 'lib/google/apis/compute_alpha/classes.rb', line 60161

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


60171
60172
60173
# File 'lib/google/apis/compute_alpha/classes.rb', line 60171

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


60176
60177
60178
# File 'lib/google/apis/compute_alpha/classes.rb', line 60176

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


60181
60182
60183
# File 'lib/google/apis/compute_alpha/classes.rb', line 60181

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::ReservationAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



60186
60187
60188
# File 'lib/google/apis/compute_alpha/classes.rb', line 60186

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



60193
60194
60195
60196
60197
60198
60199
60200
60201
# File 'lib/google/apis/compute_alpha/classes.rb', line 60193

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end