Class: Google::Apis::ComputeAlpha::ReservationAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of reservations.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReservationAggregatedList

Returns a new instance of ReservationAggregatedList.



59903
59904
59905
# File 'lib/google/apis/compute_alpha/classes.rb', line 59903

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


59866
59867
59868
# File 'lib/google/apis/compute_alpha/classes.rb', line 59866

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::ReservationsScopedList>

A list of Allocation resources. Corresponds to the JSON property items



59871
59872
59873
# File 'lib/google/apis/compute_alpha/classes.rb', line 59871

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


59876
59877
59878
# File 'lib/google/apis/compute_alpha/classes.rb', line 59876

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


59886
59887
59888
# File 'lib/google/apis/compute_alpha/classes.rb', line 59886

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


59891
59892
59893
# File 'lib/google/apis/compute_alpha/classes.rb', line 59891

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


59896
59897
59898
# File 'lib/google/apis/compute_alpha/classes.rb', line 59896

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::ReservationAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



59901
59902
59903
# File 'lib/google/apis/compute_alpha/classes.rb', line 59901

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



59908
59909
59910
59911
59912
59913
59914
59915
59916
# File 'lib/google/apis/compute_alpha/classes.rb', line 59908

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end