Class: Google::Apis::ComputeAlpha::ReservationAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of reservations.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReservationAggregatedList

Returns a new instance of ReservationAggregatedList.



58845
58846
58847
# File 'lib/google/apis/compute_alpha/classes.rb', line 58845

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


58808
58809
58810
# File 'lib/google/apis/compute_alpha/classes.rb', line 58808

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::ReservationsScopedList>

A list of Allocation resources. Corresponds to the JSON property items



58813
58814
58815
# File 'lib/google/apis/compute_alpha/classes.rb', line 58813

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


58818
58819
58820
# File 'lib/google/apis/compute_alpha/classes.rb', line 58818

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


58828
58829
58830
# File 'lib/google/apis/compute_alpha/classes.rb', line 58828

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


58833
58834
58835
# File 'lib/google/apis/compute_alpha/classes.rb', line 58833

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


58838
58839
58840
# File 'lib/google/apis/compute_alpha/classes.rb', line 58838

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::ReservationAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



58843
58844
58845
# File 'lib/google/apis/compute_alpha/classes.rb', line 58843

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



58850
58851
58852
58853
58854
58855
58856
58857
58858
# File 'lib/google/apis/compute_alpha/classes.rb', line 58850

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end