Class: Google::Apis::ComputeAlpha::ReservationAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of reservations.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReservationAggregatedList

Returns a new instance of ReservationAggregatedList.



58828
58829
58830
# File 'lib/google/apis/compute_alpha/classes.rb', line 58828

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


58791
58792
58793
# File 'lib/google/apis/compute_alpha/classes.rb', line 58791

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::ReservationsScopedList>

A list of Allocation resources. Corresponds to the JSON property items



58796
58797
58798
# File 'lib/google/apis/compute_alpha/classes.rb', line 58796

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


58801
58802
58803
# File 'lib/google/apis/compute_alpha/classes.rb', line 58801

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


58811
58812
58813
# File 'lib/google/apis/compute_alpha/classes.rb', line 58811

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


58816
58817
58818
# File 'lib/google/apis/compute_alpha/classes.rb', line 58816

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


58821
58822
58823
# File 'lib/google/apis/compute_alpha/classes.rb', line 58821

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::ReservationAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



58826
58827
58828
# File 'lib/google/apis/compute_alpha/classes.rb', line 58826

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



58833
58834
58835
58836
58837
58838
58839
58840
58841
# File 'lib/google/apis/compute_alpha/classes.rb', line 58833

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end