Class: Google::Apis::ComputeAlpha::ReservationAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::ReservationAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Contains a list of reservations.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::ReservationsScopedList>
A list of Allocation resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::ReservationAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReservationAggregatedList
constructor
A new instance of ReservationAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReservationAggregatedList
Returns a new instance of ReservationAggregatedList.
58268 58269 58270 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58268 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
58231 58232 58233 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58231 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::ReservationsScopedList>
A list of Allocation resources.
Corresponds to the JSON property items
58236 58237 58238 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58236 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
58241 58242 58243 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58241 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
58251 58252 58253 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58251 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
58256 58257 58258 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58256 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
58261 58262 58263 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58261 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::ReservationAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
58266 58267 58268 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58266 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
58273 58274 58275 58276 58277 58278 58279 58280 58281 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58273 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |