Class: Google::Apis::ComputeAlpha::ReservationAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::ReservationAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Contains a list of reservations.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::ReservationsScopedList>
A list of Allocation resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::ReservationAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReservationAggregatedList
constructor
A new instance of ReservationAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReservationAggregatedList
Returns a new instance of ReservationAggregatedList.
58266 58267 58268 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58266 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
58229 58230 58231 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58229 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::ReservationsScopedList>
A list of Allocation resources.
Corresponds to the JSON property items
58234 58235 58236 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58234 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
58239 58240 58241 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58239 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
58249 58250 58251 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58249 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
58254 58255 58256 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58254 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
58259 58260 58261 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58259 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::ReservationAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
58264 58265 58266 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58264 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
58271 58272 58273 58274 58275 58276 58277 58278 58279 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58271 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |