Class: Google::Apis::ComputeAlpha::ReservationAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of reservations.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReservationAggregatedList

Returns a new instance of ReservationAggregatedList.



58045
58046
58047
# File 'lib/google/apis/compute_alpha/classes.rb', line 58045

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


58008
58009
58010
# File 'lib/google/apis/compute_alpha/classes.rb', line 58008

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::ReservationsScopedList>

A list of Allocation resources. Corresponds to the JSON property items



58013
58014
58015
# File 'lib/google/apis/compute_alpha/classes.rb', line 58013

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


58018
58019
58020
# File 'lib/google/apis/compute_alpha/classes.rb', line 58018

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


58028
58029
58030
# File 'lib/google/apis/compute_alpha/classes.rb', line 58028

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


58033
58034
58035
# File 'lib/google/apis/compute_alpha/classes.rb', line 58033

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


58038
58039
58040
# File 'lib/google/apis/compute_alpha/classes.rb', line 58038

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::ReservationAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



58043
58044
58045
# File 'lib/google/apis/compute_alpha/classes.rb', line 58043

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



58050
58051
58052
58053
58054
58055
58056
58057
58058
# File 'lib/google/apis/compute_alpha/classes.rb', line 58050

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end