Class: Google::Apis::ComputeAlpha::ReservationAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::ReservationAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Contains a list of reservations.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::ReservationsScopedList>
A list of Allocation resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::ReservationAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReservationAggregatedList
constructor
A new instance of ReservationAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReservationAggregatedList
Returns a new instance of ReservationAggregatedList.
57208 57209 57210 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 57208 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
57171 57172 57173 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 57171 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::ReservationsScopedList>
A list of Allocation resources.
Corresponds to the JSON property items
57176 57177 57178 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 57176 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
57181 57182 57183 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 57181 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
57191 57192 57193 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 57191 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
57196 57197 57198 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 57196 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
57201 57202 57203 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 57201 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::ReservationAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
57206 57207 57208 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 57206 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
57213 57214 57215 57216 57217 57218 57219 57220 57221 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 57213 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |