Class: Google::Apis::ComputeAlpha::ReservationBlock

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Represents a reservation block resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReservationBlock

Returns a new instance of ReservationBlock.



60100
60101
60102
# File 'lib/google/apis/compute_alpha/classes.rb', line 60100

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#countFixnum

Output only. [Output Only] The number of resources that are allocated in this reservation block. Corresponds to the JSON property count

Returns:

  • (Fixnum)


59997
59998
59999
# File 'lib/google/apis/compute_alpha/classes.rb', line 59997

def count
  @count
end

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


60002
60003
60004
# File 'lib/google/apis/compute_alpha/classes.rb', line 60002

def creation_timestamp
  @creation_timestamp
end

#health_infoGoogle::Apis::ComputeAlpha::ReservationBlockHealthInfo

Health information for the reservation block. Corresponds to the JSON property healthInfo



60007
60008
60009
# File 'lib/google/apis/compute_alpha/classes.rb', line 60007

def health_info
  @health_info
end

#idFixnum

Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


60014
60015
60016
# File 'lib/google/apis/compute_alpha/classes.rb', line 60014

def id
  @id
end

#in_use_countFixnum

Output only. [Output Only] The number of instances that are currently in use on this reservation block. Corresponds to the JSON property inUseCount

Returns:

  • (Fixnum)


60021
60022
60023
# File 'lib/google/apis/compute_alpha/classes.rb', line 60021

def in_use_count
  @in_use_count
end

#in_use_host_countFixnum

Output only. Number of hosts currently in use. If there is one or more Instances running on the host, it is considered in use. Corresponds to the JSON property inUseHostCount

Returns:

  • (Fixnum)


60028
60029
60030
# File 'lib/google/apis/compute_alpha/classes.rb', line 60028

def in_use_host_count
  @in_use_host_count
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# reservationBlock for reservation blocks. Corresponds to the JSON property kind

Returns:

  • (String)


60034
60035
60036
# File 'lib/google/apis/compute_alpha/classes.rb', line 60034

def kind
  @kind
end

#location_prefixString

Output only. [Output Only] Obfuscated location where this reservation block physically resides in format /CCCC/GGGG. This matches the tripod specified in the VM topology information. Example: /USEAB1/0101/ is the location prefix in /USEAB1/0101/031/003 Corresponds to the JSON property locationPrefix

Returns:

  • (String)


60043
60044
60045
# File 'lib/google/apis/compute_alpha/classes.rb', line 60043

def location_prefix
  @location_prefix
end

#nameString

Output only. [Output Only] The name of this reservation block generated by Google Compute Engine. The name must be 1-63 characters long, and comply with RFC1035 @pattern a-z? Corresponds to the JSON property name

Returns:

  • (String)


60051
60052
60053
# File 'lib/google/apis/compute_alpha/classes.rb', line 60051

def name
  @name
end

#physical_topologyGoogle::Apis::ComputeAlpha::ReservationBlockPhysicalTopology

Output only. [Output Only] The physical topology of the reservation block. Corresponds to the JSON property physicalTopology



60056
60057
60058
# File 'lib/google/apis/compute_alpha/classes.rb', line 60056

def physical_topology
  @physical_topology
end

#reservation_maintenanceGoogle::Apis::ComputeAlpha::GroupMaintenanceInfo

Maintenance Info for ReservationBlocks. Corresponds to the JSON property reservationMaintenance



60061
60062
60063
# File 'lib/google/apis/compute_alpha/classes.rb', line 60061

def reservation_maintenance
  @reservation_maintenance
end

#reservation_sub_block_countFixnum

Output only. [Output Only] The number of reservation subBlocks associated with this reservation block. Corresponds to the JSON property reservationSubBlockCount

Returns:

  • (Fixnum)


60068
60069
60070
# File 'lib/google/apis/compute_alpha/classes.rb', line 60068

def reservation_sub_block_count
  @reservation_sub_block_count
end

#reservation_sub_block_in_use_countFixnum

Output only. [Output Only] The number of in-use reservation subBlocks associated with this reservation block. If at least one VM is running on a subBlock, it is considered in-use. Corresponds to the JSON property reservationSubBlockInUseCount

Returns:

  • (Fixnum)


60076
60077
60078
# File 'lib/google/apis/compute_alpha/classes.rb', line 60076

def reservation_sub_block_in_use_count
  @reservation_sub_block_in_use_count
end

Output only. [Output Only] Server-defined fully-qualified URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


60082
60083
60084
# File 'lib/google/apis/compute_alpha/classes.rb', line 60082

def self_link
  @self_link
end

Output only. [Output Only] Server-defined URL for this resource with the resource id. Corresponds to the JSON property selfLinkWithId

Returns:

  • (String)


60088
60089
60090
# File 'lib/google/apis/compute_alpha/classes.rb', line 60088

def self_link_with_id
  @self_link_with_id
end

#statusString

Output only. [Output Only] Status of the reservation block. Corresponds to the JSON property status

Returns:

  • (String)


60093
60094
60095
# File 'lib/google/apis/compute_alpha/classes.rb', line 60093

def status
  @status
end

#zoneString

Output only. [Output Only] Zone in which the reservation block resides. Corresponds to the JSON property zone

Returns:

  • (String)


60098
60099
60100
# File 'lib/google/apis/compute_alpha/classes.rb', line 60098

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



60105
60106
60107
60108
60109
60110
60111
60112
60113
60114
60115
60116
60117
60118
60119
60120
60121
60122
60123
# File 'lib/google/apis/compute_alpha/classes.rb', line 60105

def update!(**args)
  @count = args[:count] if args.key?(:count)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @health_info = args[:health_info] if args.key?(:health_info)
  @id = args[:id] if args.key?(:id)
  @in_use_count = args[:in_use_count] if args.key?(:in_use_count)
  @in_use_host_count = args[:in_use_host_count] if args.key?(:in_use_host_count)
  @kind = args[:kind] if args.key?(:kind)
  @location_prefix = args[:location_prefix] if args.key?(:location_prefix)
  @name = args[:name] if args.key?(:name)
  @physical_topology = args[:physical_topology] if args.key?(:physical_topology)
  @reservation_maintenance = args[:reservation_maintenance] if args.key?(:reservation_maintenance)
  @reservation_sub_block_count = args[:reservation_sub_block_count] if args.key?(:reservation_sub_block_count)
  @reservation_sub_block_in_use_count = args[:reservation_sub_block_in_use_count] if args.key?(:reservation_sub_block_in_use_count)
  @self_link = args[:self_link] if args.key?(:self_link)
  @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id)
  @status = args[:status] if args.key?(:status)
  @zone = args[:zone] if args.key?(:zone)
end