Class: Google::Apis::ComputeAlpha::ReservationBlock
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::ReservationBlock
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Represents a reservation block resource.
Instance Attribute Summary collapse
-
#count ⇒ Fixnum
Output only.
-
#creation_timestamp ⇒ String
Output only.
-
#health_info ⇒ Google::Apis::ComputeAlpha::ReservationBlockHealthInfo
Health information for the reservation block.
-
#id ⇒ Fixnum
Output only.
-
#in_use_count ⇒ Fixnum
Output only.
-
#in_use_host_count ⇒ Fixnum
Output only.
-
#kind ⇒ String
Output only.
-
#location_prefix ⇒ String
Output only.
-
#name ⇒ String
Output only.
-
#physical_topology ⇒ Google::Apis::ComputeAlpha::ReservationBlockPhysicalTopology
Output only.
-
#reservation_maintenance ⇒ Google::Apis::ComputeAlpha::GroupMaintenanceInfo
Maintenance Info for ReservationBlocks.
-
#reservation_sub_block_count ⇒ Fixnum
Output only.
-
#reservation_sub_block_in_use_count ⇒ Fixnum
Output only.
-
#self_link ⇒ String
Output only.
-
#self_link_with_id ⇒ String
Output only.
-
#status ⇒ String
Output only.
-
#zone ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReservationBlock
constructor
A new instance of ReservationBlock.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReservationBlock
Returns a new instance of ReservationBlock.
59025 59026 59027 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59025 def initialize(**args) update!(**args) end |
Instance Attribute Details
#count ⇒ Fixnum
Output only. [Output Only] The number of resources that are allocated in this
reservation block.
Corresponds to the JSON property count
58922 58923 58924 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58922 def count @count end |
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339 text format.
Corresponds to the JSON property creationTimestamp
58927 58928 58929 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58927 def @creation_timestamp end |
#health_info ⇒ Google::Apis::ComputeAlpha::ReservationBlockHealthInfo
Health information for the reservation block.
Corresponds to the JSON property healthInfo
58932 58933 58934 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58932 def health_info @health_info end |
#id ⇒ Fixnum
Output only. [Output Only] The unique identifier for the resource. This
identifier is
defined by the server.
Corresponds to the JSON property id
58939 58940 58941 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58939 def id @id end |
#in_use_count ⇒ Fixnum
Output only. [Output Only] The number of instances that are currently in use
on this
reservation block.
Corresponds to the JSON property inUseCount
58946 58947 58948 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58946 def in_use_count @in_use_count end |
#in_use_host_count ⇒ Fixnum
Output only. Number of hosts currently in use. If there is one or more
Instances running
on the host, it is considered in use.
Corresponds to the JSON property inUseHostCount
58953 58954 58955 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58953 def in_use_host_count @in_use_host_count end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#
reservationBlock for reservation blocks.
Corresponds to the JSON property kind
58959 58960 58961 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58959 def kind @kind end |
#location_prefix ⇒ String
Output only. [Output Only] Obfuscated location where this reservation block
physically
resides in format /CCCC/GGGG. This matches the tripod specified in the VM
topology information. Example: /USEAB1/0101/ is the location prefix in
/USEAB1/0101/031/003
Corresponds to the JSON property locationPrefix
58968 58969 58970 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58968 def location_prefix @location_prefix end |
#name ⇒ String
Output only. [Output Only] The name of this reservation block generated by
Google
Compute Engine. The name must be 1-63 characters long, and comply with
RFC1035 @pattern a-z?
Corresponds to the JSON property name
58976 58977 58978 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58976 def name @name end |
#physical_topology ⇒ Google::Apis::ComputeAlpha::ReservationBlockPhysicalTopology
Output only. [Output Only] The physical topology of the reservation block.
Corresponds to the JSON property physicalTopology
58981 58982 58983 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58981 def physical_topology @physical_topology end |
#reservation_maintenance ⇒ Google::Apis::ComputeAlpha::GroupMaintenanceInfo
Maintenance Info for ReservationBlocks.
Corresponds to the JSON property reservationMaintenance
58986 58987 58988 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58986 def reservation_maintenance @reservation_maintenance end |
#reservation_sub_block_count ⇒ Fixnum
Output only. [Output Only] The number of reservation subBlocks associated with
this
reservation block.
Corresponds to the JSON property reservationSubBlockCount
58993 58994 58995 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58993 def reservation_sub_block_count @reservation_sub_block_count end |
#reservation_sub_block_in_use_count ⇒ Fixnum
Output only. [Output Only] The number of in-use reservation subBlocks
associated with
this reservation block. If at least one VM is running on a subBlock, it is
considered in-use.
Corresponds to the JSON property reservationSubBlockInUseCount
59001 59002 59003 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59001 def reservation_sub_block_in_use_count @reservation_sub_block_in_use_count end |
#self_link ⇒ String
Output only. [Output Only] Server-defined fully-qualified URL for this
resource.
Corresponds to the JSON property selfLink
59007 59008 59009 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59007 def self_link @self_link end |
#self_link_with_id ⇒ String
Output only. [Output Only] Server-defined URL for this resource with the
resource id.
Corresponds to the JSON property selfLinkWithId
59013 59014 59015 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59013 def self_link_with_id @self_link_with_id end |
#status ⇒ String
Output only. [Output Only] Status of the reservation block.
Corresponds to the JSON property status
59018 59019 59020 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59018 def status @status end |
#zone ⇒ String
Output only. [Output Only] Zone in which the reservation block resides.
Corresponds to the JSON property zone
59023 59024 59025 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59023 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
59030 59031 59032 59033 59034 59035 59036 59037 59038 59039 59040 59041 59042 59043 59044 59045 59046 59047 59048 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59030 def update!(**args) @count = args[:count] if args.key?(:count) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @health_info = args[:health_info] if args.key?(:health_info) @id = args[:id] if args.key?(:id) @in_use_count = args[:in_use_count] if args.key?(:in_use_count) @in_use_host_count = args[:in_use_host_count] if args.key?(:in_use_host_count) @kind = args[:kind] if args.key?(:kind) @location_prefix = args[:location_prefix] if args.key?(:location_prefix) @name = args[:name] if args.key?(:name) @physical_topology = args[:physical_topology] if args.key?(:physical_topology) @reservation_maintenance = args[:reservation_maintenance] if args.key?(:reservation_maintenance) @reservation_sub_block_count = args[:reservation_sub_block_count] if args.key?(:reservation_sub_block_count) @reservation_sub_block_in_use_count = args[:reservation_sub_block_in_use_count] if args.key?(:reservation_sub_block_in_use_count) @self_link = args[:self_link] if args.key?(:self_link) @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id) @status = args[:status] if args.key?(:status) @zone = args[:zone] if args.key?(:zone) end |