Class: Google::Apis::ComputeAlpha::ReservationBlock
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::ReservationBlock
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Represents a reservation block resource.
Instance Attribute Summary collapse
-
#count ⇒ Fixnum
Output only.
-
#creation_timestamp ⇒ String
Output only.
-
#health_info ⇒ Google::Apis::ComputeAlpha::ReservationBlockHealthInfo
Health information for the reservation block.
-
#id ⇒ Fixnum
Output only.
-
#in_use_count ⇒ Fixnum
Output only.
-
#in_use_host_count ⇒ Fixnum
Output only.
-
#kind ⇒ String
Output only.
-
#location_prefix ⇒ String
Output only.
-
#name ⇒ String
Output only.
-
#physical_topology ⇒ Google::Apis::ComputeAlpha::ReservationBlockPhysicalTopology
Output only.
-
#reservation_maintenance ⇒ Google::Apis::ComputeAlpha::GroupMaintenanceInfo
Maintenance Info for ReservationBlocks.
-
#reservation_sub_block_count ⇒ Fixnum
Output only.
-
#reservation_sub_block_in_use_count ⇒ Fixnum
Output only.
-
#self_link ⇒ String
Output only.
-
#self_link_with_id ⇒ String
Output only.
-
#status ⇒ String
Output only.
-
#zone ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReservationBlock
constructor
A new instance of ReservationBlock.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReservationBlock
Returns a new instance of ReservationBlock.
58465 58466 58467 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58465 def initialize(**args) update!(**args) end |
Instance Attribute Details
#count ⇒ Fixnum
Output only. [Output Only] The number of resources that are allocated in this
reservation block.
Corresponds to the JSON property count
58362 58363 58364 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58362 def count @count end |
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339 text format.
Corresponds to the JSON property creationTimestamp
58367 58368 58369 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58367 def @creation_timestamp end |
#health_info ⇒ Google::Apis::ComputeAlpha::ReservationBlockHealthInfo
Health information for the reservation block.
Corresponds to the JSON property healthInfo
58372 58373 58374 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58372 def health_info @health_info end |
#id ⇒ Fixnum
Output only. [Output Only] The unique identifier for the resource. This
identifier is
defined by the server.
Corresponds to the JSON property id
58379 58380 58381 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58379 def id @id end |
#in_use_count ⇒ Fixnum
Output only. [Output Only] The number of instances that are currently in use
on this
reservation block.
Corresponds to the JSON property inUseCount
58386 58387 58388 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58386 def in_use_count @in_use_count end |
#in_use_host_count ⇒ Fixnum
Output only. Number of hosts currently in use. If there is one or more
Instances running
on the host, it is considered in use.
Corresponds to the JSON property inUseHostCount
58393 58394 58395 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58393 def in_use_host_count @in_use_host_count end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#
reservationBlock for reservation blocks.
Corresponds to the JSON property kind
58399 58400 58401 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58399 def kind @kind end |
#location_prefix ⇒ String
Output only. [Output Only] Obfuscated location where this reservation block
physically
resides in format /CCCC/GGGG. This matches the tripod specified in the VM
topology information. Example: /USEAB1/0101/ is the location prefix in
/USEAB1/0101/031/003
Corresponds to the JSON property locationPrefix
58408 58409 58410 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58408 def location_prefix @location_prefix end |
#name ⇒ String
Output only. [Output Only] The name of this reservation block generated by
Google
Compute Engine. The name must be 1-63 characters long, and comply with
RFC1035 @pattern a-z?
Corresponds to the JSON property name
58416 58417 58418 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58416 def name @name end |
#physical_topology ⇒ Google::Apis::ComputeAlpha::ReservationBlockPhysicalTopology
Output only. [Output Only] The physical topology of the reservation block.
Corresponds to the JSON property physicalTopology
58421 58422 58423 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58421 def physical_topology @physical_topology end |
#reservation_maintenance ⇒ Google::Apis::ComputeAlpha::GroupMaintenanceInfo
Maintenance Info for ReservationBlocks.
Corresponds to the JSON property reservationMaintenance
58426 58427 58428 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58426 def reservation_maintenance @reservation_maintenance end |
#reservation_sub_block_count ⇒ Fixnum
Output only. [Output Only] The number of reservation subBlocks associated with
this
reservation block.
Corresponds to the JSON property reservationSubBlockCount
58433 58434 58435 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58433 def reservation_sub_block_count @reservation_sub_block_count end |
#reservation_sub_block_in_use_count ⇒ Fixnum
Output only. [Output Only] The number of in-use reservation subBlocks
associated with
this reservation block. If at least one VM is running on a subBlock, it is
considered in-use.
Corresponds to the JSON property reservationSubBlockInUseCount
58441 58442 58443 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58441 def reservation_sub_block_in_use_count @reservation_sub_block_in_use_count end |
#self_link ⇒ String
Output only. [Output Only] Server-defined fully-qualified URL for this
resource.
Corresponds to the JSON property selfLink
58447 58448 58449 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58447 def self_link @self_link end |
#self_link_with_id ⇒ String
Output only. [Output Only] Server-defined URL for this resource with the
resource id.
Corresponds to the JSON property selfLinkWithId
58453 58454 58455 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58453 def self_link_with_id @self_link_with_id end |
#status ⇒ String
Output only. [Output Only] Status of the reservation block.
Corresponds to the JSON property status
58458 58459 58460 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58458 def status @status end |
#zone ⇒ String
Output only. [Output Only] Zone in which the reservation block resides.
Corresponds to the JSON property zone
58463 58464 58465 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58463 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
58470 58471 58472 58473 58474 58475 58476 58477 58478 58479 58480 58481 58482 58483 58484 58485 58486 58487 58488 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58470 def update!(**args) @count = args[:count] if args.key?(:count) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @health_info = args[:health_info] if args.key?(:health_info) @id = args[:id] if args.key?(:id) @in_use_count = args[:in_use_count] if args.key?(:in_use_count) @in_use_host_count = args[:in_use_host_count] if args.key?(:in_use_host_count) @kind = args[:kind] if args.key?(:kind) @location_prefix = args[:location_prefix] if args.key?(:location_prefix) @name = args[:name] if args.key?(:name) @physical_topology = args[:physical_topology] if args.key?(:physical_topology) @reservation_maintenance = args[:reservation_maintenance] if args.key?(:reservation_maintenance) @reservation_sub_block_count = args[:reservation_sub_block_count] if args.key?(:reservation_sub_block_count) @reservation_sub_block_in_use_count = args[:reservation_sub_block_in_use_count] if args.key?(:reservation_sub_block_in_use_count) @self_link = args[:self_link] if args.key?(:self_link) @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id) @status = args[:status] if args.key?(:status) @zone = args[:zone] if args.key?(:zone) end |