Class: Google::Apis::ComputeAlpha::ReservationBlock

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Represents a reservation block resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReservationBlock

Returns a new instance of ReservationBlock.



58463
58464
58465
# File 'lib/google/apis/compute_alpha/classes.rb', line 58463

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#countFixnum

Output only. [Output Only] The number of resources that are allocated in this reservation block. Corresponds to the JSON property count

Returns:

  • (Fixnum)


58360
58361
58362
# File 'lib/google/apis/compute_alpha/classes.rb', line 58360

def count
  @count
end

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


58365
58366
58367
# File 'lib/google/apis/compute_alpha/classes.rb', line 58365

def creation_timestamp
  @creation_timestamp
end

#health_infoGoogle::Apis::ComputeAlpha::ReservationBlockHealthInfo

Health information for the reservation block. Corresponds to the JSON property healthInfo



58370
58371
58372
# File 'lib/google/apis/compute_alpha/classes.rb', line 58370

def health_info
  @health_info
end

#idFixnum

Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


58377
58378
58379
# File 'lib/google/apis/compute_alpha/classes.rb', line 58377

def id
  @id
end

#in_use_countFixnum

Output only. [Output Only] The number of instances that are currently in use on this reservation block. Corresponds to the JSON property inUseCount

Returns:

  • (Fixnum)


58384
58385
58386
# File 'lib/google/apis/compute_alpha/classes.rb', line 58384

def in_use_count
  @in_use_count
end

#in_use_host_countFixnum

Output only. Number of hosts currently in use. If there is one or more Instances running on the host, it is considered in use. Corresponds to the JSON property inUseHostCount

Returns:

  • (Fixnum)


58391
58392
58393
# File 'lib/google/apis/compute_alpha/classes.rb', line 58391

def in_use_host_count
  @in_use_host_count
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# reservationBlock for reservation blocks. Corresponds to the JSON property kind

Returns:

  • (String)


58397
58398
58399
# File 'lib/google/apis/compute_alpha/classes.rb', line 58397

def kind
  @kind
end

#location_prefixString

Output only. [Output Only] Obfuscated location where this reservation block physically resides in format /CCCC/GGGG. This matches the tripod specified in the VM topology information. Example: /USEAB1/0101/ is the location prefix in /USEAB1/0101/031/003 Corresponds to the JSON property locationPrefix

Returns:

  • (String)


58406
58407
58408
# File 'lib/google/apis/compute_alpha/classes.rb', line 58406

def location_prefix
  @location_prefix
end

#nameString

Output only. [Output Only] The name of this reservation block generated by Google Compute Engine. The name must be 1-63 characters long, and comply with RFC1035 @pattern a-z? Corresponds to the JSON property name

Returns:

  • (String)


58414
58415
58416
# File 'lib/google/apis/compute_alpha/classes.rb', line 58414

def name
  @name
end

#physical_topologyGoogle::Apis::ComputeAlpha::ReservationBlockPhysicalTopology

Output only. [Output Only] The physical topology of the reservation block. Corresponds to the JSON property physicalTopology



58419
58420
58421
# File 'lib/google/apis/compute_alpha/classes.rb', line 58419

def physical_topology
  @physical_topology
end

#reservation_maintenanceGoogle::Apis::ComputeAlpha::GroupMaintenanceInfo

Maintenance Info for ReservationBlocks. Corresponds to the JSON property reservationMaintenance



58424
58425
58426
# File 'lib/google/apis/compute_alpha/classes.rb', line 58424

def reservation_maintenance
  @reservation_maintenance
end

#reservation_sub_block_countFixnum

Output only. [Output Only] The number of reservation subBlocks associated with this reservation block. Corresponds to the JSON property reservationSubBlockCount

Returns:

  • (Fixnum)


58431
58432
58433
# File 'lib/google/apis/compute_alpha/classes.rb', line 58431

def reservation_sub_block_count
  @reservation_sub_block_count
end

#reservation_sub_block_in_use_countFixnum

Output only. [Output Only] The number of in-use reservation subBlocks associated with this reservation block. If at least one VM is running on a subBlock, it is considered in-use. Corresponds to the JSON property reservationSubBlockInUseCount

Returns:

  • (Fixnum)


58439
58440
58441
# File 'lib/google/apis/compute_alpha/classes.rb', line 58439

def reservation_sub_block_in_use_count
  @reservation_sub_block_in_use_count
end

Output only. [Output Only] Server-defined fully-qualified URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


58445
58446
58447
# File 'lib/google/apis/compute_alpha/classes.rb', line 58445

def self_link
  @self_link
end

Output only. [Output Only] Server-defined URL for this resource with the resource id. Corresponds to the JSON property selfLinkWithId

Returns:

  • (String)


58451
58452
58453
# File 'lib/google/apis/compute_alpha/classes.rb', line 58451

def self_link_with_id
  @self_link_with_id
end

#statusString

Output only. [Output Only] Status of the reservation block. Corresponds to the JSON property status

Returns:

  • (String)


58456
58457
58458
# File 'lib/google/apis/compute_alpha/classes.rb', line 58456

def status
  @status
end

#zoneString

Output only. [Output Only] Zone in which the reservation block resides. Corresponds to the JSON property zone

Returns:

  • (String)


58461
58462
58463
# File 'lib/google/apis/compute_alpha/classes.rb', line 58461

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



58468
58469
58470
58471
58472
58473
58474
58475
58476
58477
58478
58479
58480
58481
58482
58483
58484
58485
58486
# File 'lib/google/apis/compute_alpha/classes.rb', line 58468

def update!(**args)
  @count = args[:count] if args.key?(:count)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @health_info = args[:health_info] if args.key?(:health_info)
  @id = args[:id] if args.key?(:id)
  @in_use_count = args[:in_use_count] if args.key?(:in_use_count)
  @in_use_host_count = args[:in_use_host_count] if args.key?(:in_use_host_count)
  @kind = args[:kind] if args.key?(:kind)
  @location_prefix = args[:location_prefix] if args.key?(:location_prefix)
  @name = args[:name] if args.key?(:name)
  @physical_topology = args[:physical_topology] if args.key?(:physical_topology)
  @reservation_maintenance = args[:reservation_maintenance] if args.key?(:reservation_maintenance)
  @reservation_sub_block_count = args[:reservation_sub_block_count] if args.key?(:reservation_sub_block_count)
  @reservation_sub_block_in_use_count = args[:reservation_sub_block_in_use_count] if args.key?(:reservation_sub_block_in_use_count)
  @self_link = args[:self_link] if args.key?(:self_link)
  @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id)
  @status = args[:status] if args.key?(:status)
  @zone = args[:zone] if args.key?(:zone)
end