Class: Google::Apis::ComputeAlpha::ReservationBlock
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::ReservationBlock
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Represents a reservation block resource.
Instance Attribute Summary collapse
-
#count ⇒ Fixnum
Output only.
-
#creation_timestamp ⇒ String
Output only.
-
#health_info ⇒ Google::Apis::ComputeAlpha::ReservationBlockHealthInfo
Health information for the reservation block.
-
#id ⇒ Fixnum
Output only.
-
#in_use_count ⇒ Fixnum
Output only.
-
#in_use_host_count ⇒ Fixnum
Output only.
-
#kind ⇒ String
Output only.
-
#location_prefix ⇒ String
Output only.
-
#name ⇒ String
Output only.
-
#physical_topology ⇒ Google::Apis::ComputeAlpha::ReservationBlockPhysicalTopology
Output only.
-
#reservation_maintenance ⇒ Google::Apis::ComputeAlpha::GroupMaintenanceInfo
Maintenance Info for ReservationBlocks.
-
#reservation_sub_block_count ⇒ Fixnum
Output only.
-
#reservation_sub_block_in_use_count ⇒ Fixnum
Output only.
-
#self_link ⇒ String
Output only.
-
#self_link_with_id ⇒ String
Output only.
-
#status ⇒ String
Output only.
-
#zone ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReservationBlock
constructor
A new instance of ReservationBlock.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReservationBlock
Returns a new instance of ReservationBlock.
58242 58243 58244 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58242 def initialize(**args) update!(**args) end |
Instance Attribute Details
#count ⇒ Fixnum
Output only. [Output Only] The number of resources that are allocated in this
reservation block.
Corresponds to the JSON property count
58139 58140 58141 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58139 def count @count end |
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339 text format.
Corresponds to the JSON property creationTimestamp
58144 58145 58146 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58144 def @creation_timestamp end |
#health_info ⇒ Google::Apis::ComputeAlpha::ReservationBlockHealthInfo
Health information for the reservation block.
Corresponds to the JSON property healthInfo
58149 58150 58151 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58149 def health_info @health_info end |
#id ⇒ Fixnum
Output only. [Output Only] The unique identifier for the resource. This
identifier is
defined by the server.
Corresponds to the JSON property id
58156 58157 58158 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58156 def id @id end |
#in_use_count ⇒ Fixnum
Output only. [Output Only] The number of instances that are currently in use
on this
reservation block.
Corresponds to the JSON property inUseCount
58163 58164 58165 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58163 def in_use_count @in_use_count end |
#in_use_host_count ⇒ Fixnum
Output only. Number of hosts currently in use. If there is one or more
Instances running
on the host, it is considered in use.
Corresponds to the JSON property inUseHostCount
58170 58171 58172 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58170 def in_use_host_count @in_use_host_count end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#
reservationBlock for reservation blocks.
Corresponds to the JSON property kind
58176 58177 58178 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58176 def kind @kind end |
#location_prefix ⇒ String
Output only. [Output Only] Obfuscated location where this reservation block
physically
resides in format /CCCC/GGGG. This matches the tripod specified in the VM
topology information. Example: /USEAB1/0101/ is the location prefix in
/USEAB1/0101/031/003
Corresponds to the JSON property locationPrefix
58185 58186 58187 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58185 def location_prefix @location_prefix end |
#name ⇒ String
Output only. [Output Only] The name of this reservation block generated by
Google
Compute Engine. The name must be 1-63 characters long, and comply with
RFC1035 @pattern a-z?
Corresponds to the JSON property name
58193 58194 58195 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58193 def name @name end |
#physical_topology ⇒ Google::Apis::ComputeAlpha::ReservationBlockPhysicalTopology
Output only. [Output Only] The physical topology of the reservation block.
Corresponds to the JSON property physicalTopology
58198 58199 58200 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58198 def physical_topology @physical_topology end |
#reservation_maintenance ⇒ Google::Apis::ComputeAlpha::GroupMaintenanceInfo
Maintenance Info for ReservationBlocks.
Corresponds to the JSON property reservationMaintenance
58203 58204 58205 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58203 def reservation_maintenance @reservation_maintenance end |
#reservation_sub_block_count ⇒ Fixnum
Output only. [Output Only] The number of reservation subBlocks associated with
this
reservation block.
Corresponds to the JSON property reservationSubBlockCount
58210 58211 58212 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58210 def reservation_sub_block_count @reservation_sub_block_count end |
#reservation_sub_block_in_use_count ⇒ Fixnum
Output only. [Output Only] The number of in-use reservation subBlocks
associated with
this reservation block. If at least one VM is running on a subBlock, it is
considered in-use.
Corresponds to the JSON property reservationSubBlockInUseCount
58218 58219 58220 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58218 def reservation_sub_block_in_use_count @reservation_sub_block_in_use_count end |
#self_link ⇒ String
Output only. [Output Only] Server-defined fully-qualified URL for this
resource.
Corresponds to the JSON property selfLink
58224 58225 58226 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58224 def self_link @self_link end |
#self_link_with_id ⇒ String
Output only. [Output Only] Server-defined URL for this resource with the
resource id.
Corresponds to the JSON property selfLinkWithId
58230 58231 58232 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58230 def self_link_with_id @self_link_with_id end |
#status ⇒ String
Output only. [Output Only] Status of the reservation block.
Corresponds to the JSON property status
58235 58236 58237 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58235 def status @status end |
#zone ⇒ String
Output only. [Output Only] Zone in which the reservation block resides.
Corresponds to the JSON property zone
58240 58241 58242 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58240 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
58247 58248 58249 58250 58251 58252 58253 58254 58255 58256 58257 58258 58259 58260 58261 58262 58263 58264 58265 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58247 def update!(**args) @count = args[:count] if args.key?(:count) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @health_info = args[:health_info] if args.key?(:health_info) @id = args[:id] if args.key?(:id) @in_use_count = args[:in_use_count] if args.key?(:in_use_count) @in_use_host_count = args[:in_use_host_count] if args.key?(:in_use_host_count) @kind = args[:kind] if args.key?(:kind) @location_prefix = args[:location_prefix] if args.key?(:location_prefix) @name = args[:name] if args.key?(:name) @physical_topology = args[:physical_topology] if args.key?(:physical_topology) @reservation_maintenance = args[:reservation_maintenance] if args.key?(:reservation_maintenance) @reservation_sub_block_count = args[:reservation_sub_block_count] if args.key?(:reservation_sub_block_count) @reservation_sub_block_in_use_count = args[:reservation_sub_block_in_use_count] if args.key?(:reservation_sub_block_in_use_count) @self_link = args[:self_link] if args.key?(:self_link) @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id) @status = args[:status] if args.key?(:status) @zone = args[:zone] if args.key?(:zone) end |