Class: Google::Apis::ComputeAlpha::ReservationBlock
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::ReservationBlock
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Represents a reservation block resource.
Instance Attribute Summary collapse
-
#count ⇒ Fixnum
Output only.
-
#creation_timestamp ⇒ String
Output only.
-
#health_info ⇒ Google::Apis::ComputeAlpha::ReservationBlockHealthInfo
Health information for the reservation block.
-
#id ⇒ Fixnum
Output only.
-
#in_use_count ⇒ Fixnum
Output only.
-
#in_use_host_count ⇒ Fixnum
Output only.
-
#kind ⇒ String
Output only.
-
#location_prefix ⇒ String
Output only.
-
#name ⇒ String
Output only.
-
#physical_topology ⇒ Google::Apis::ComputeAlpha::ReservationBlockPhysicalTopology
Output only.
-
#reservation_maintenance ⇒ Google::Apis::ComputeAlpha::GroupMaintenanceInfo
Maintenance Info for ReservationBlocks.
-
#reservation_sub_block_count ⇒ Fixnum
Output only.
-
#reservation_sub_block_in_use_count ⇒ Fixnum
Output only.
-
#self_link ⇒ String
Output only.
-
#self_link_with_id ⇒ String
Output only.
-
#status ⇒ String
Output only.
-
#zone ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReservationBlock
constructor
A new instance of ReservationBlock.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReservationBlock
Returns a new instance of ReservationBlock.
57405 57406 57407 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 57405 def initialize(**args) update!(**args) end |
Instance Attribute Details
#count ⇒ Fixnum
Output only. [Output Only] The number of resources that are allocated in this
reservation block.
Corresponds to the JSON property count
57302 57303 57304 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 57302 def count @count end |
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339 text format.
Corresponds to the JSON property creationTimestamp
57307 57308 57309 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 57307 def @creation_timestamp end |
#health_info ⇒ Google::Apis::ComputeAlpha::ReservationBlockHealthInfo
Health information for the reservation block.
Corresponds to the JSON property healthInfo
57312 57313 57314 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 57312 def health_info @health_info end |
#id ⇒ Fixnum
Output only. [Output Only] The unique identifier for the resource. This
identifier is
defined by the server.
Corresponds to the JSON property id
57319 57320 57321 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 57319 def id @id end |
#in_use_count ⇒ Fixnum
Output only. [Output Only] The number of instances that are currently in use
on this
reservation block.
Corresponds to the JSON property inUseCount
57326 57327 57328 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 57326 def in_use_count @in_use_count end |
#in_use_host_count ⇒ Fixnum
Output only. Number of hosts currently in use. If there is one or more
Instances running
on the host, it is considered in use.
Corresponds to the JSON property inUseHostCount
57333 57334 57335 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 57333 def in_use_host_count @in_use_host_count end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#
reservationBlock for reservation blocks.
Corresponds to the JSON property kind
57339 57340 57341 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 57339 def kind @kind end |
#location_prefix ⇒ String
Output only. [Output Only] Obfuscated location where this reservation block
physically
resides in format /CCCC/GGGG. This matches the tripod specified in the VM
topology information. Example: /USEAB1/0101/ is the location prefix in
/USEAB1/0101/031/003
Corresponds to the JSON property locationPrefix
57348 57349 57350 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 57348 def location_prefix @location_prefix end |
#name ⇒ String
Output only. [Output Only] The name of this reservation block generated by
Google
Compute Engine. The name must be 1-63 characters long, and comply with
RFC1035 @pattern a-z?
Corresponds to the JSON property name
57356 57357 57358 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 57356 def name @name end |
#physical_topology ⇒ Google::Apis::ComputeAlpha::ReservationBlockPhysicalTopology
Output only. [Output Only] The physical topology of the reservation block.
Corresponds to the JSON property physicalTopology
57361 57362 57363 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 57361 def physical_topology @physical_topology end |
#reservation_maintenance ⇒ Google::Apis::ComputeAlpha::GroupMaintenanceInfo
Maintenance Info for ReservationBlocks.
Corresponds to the JSON property reservationMaintenance
57366 57367 57368 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 57366 def reservation_maintenance @reservation_maintenance end |
#reservation_sub_block_count ⇒ Fixnum
Output only. [Output Only] The number of reservation subBlocks associated with
this
reservation block.
Corresponds to the JSON property reservationSubBlockCount
57373 57374 57375 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 57373 def reservation_sub_block_count @reservation_sub_block_count end |
#reservation_sub_block_in_use_count ⇒ Fixnum
Output only. [Output Only] The number of in-use reservation subBlocks
associated with
this reservation block. If at least one VM is running on a subBlock, it is
considered in-use.
Corresponds to the JSON property reservationSubBlockInUseCount
57381 57382 57383 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 57381 def reservation_sub_block_in_use_count @reservation_sub_block_in_use_count end |
#self_link ⇒ String
Output only. [Output Only] Server-defined fully-qualified URL for this
resource.
Corresponds to the JSON property selfLink
57387 57388 57389 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 57387 def self_link @self_link end |
#self_link_with_id ⇒ String
Output only. [Output Only] Server-defined URL for this resource with the
resource id.
Corresponds to the JSON property selfLinkWithId
57393 57394 57395 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 57393 def self_link_with_id @self_link_with_id end |
#status ⇒ String
Output only. [Output Only] Status of the reservation block.
Corresponds to the JSON property status
57398 57399 57400 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 57398 def status @status end |
#zone ⇒ String
Output only. [Output Only] Zone in which the reservation block resides.
Corresponds to the JSON property zone
57403 57404 57405 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 57403 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
57410 57411 57412 57413 57414 57415 57416 57417 57418 57419 57420 57421 57422 57423 57424 57425 57426 57427 57428 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 57410 def update!(**args) @count = args[:count] if args.key?(:count) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @health_info = args[:health_info] if args.key?(:health_info) @id = args[:id] if args.key?(:id) @in_use_count = args[:in_use_count] if args.key?(:in_use_count) @in_use_host_count = args[:in_use_host_count] if args.key?(:in_use_host_count) @kind = args[:kind] if args.key?(:kind) @location_prefix = args[:location_prefix] if args.key?(:location_prefix) @name = args[:name] if args.key?(:name) @physical_topology = args[:physical_topology] if args.key?(:physical_topology) @reservation_maintenance = args[:reservation_maintenance] if args.key?(:reservation_maintenance) @reservation_sub_block_count = args[:reservation_sub_block_count] if args.key?(:reservation_sub_block_count) @reservation_sub_block_in_use_count = args[:reservation_sub_block_in_use_count] if args.key?(:reservation_sub_block_in_use_count) @self_link = args[:self_link] if args.key?(:self_link) @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id) @status = args[:status] if args.key?(:status) @zone = args[:zone] if args.key?(:zone) end |