Class: Google::Apis::ComputeAlpha::ReservationBlockPhysicalTopology

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReservationBlockPhysicalTopology

Returns a new instance of ReservationBlockPhysicalTopology.



59118
59119
59120
# File 'lib/google/apis/compute_alpha/classes.rb', line 59118

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#blockString

The hash of the capacity block within the cluster. Corresponds to the JSON property block

Returns:

  • (String)


59106
59107
59108
# File 'lib/google/apis/compute_alpha/classes.rb', line 59106

def block
  @block
end

#clusterString

The cluster name of the reservation block. Corresponds to the JSON property cluster

Returns:

  • (String)


59111
59112
59113
# File 'lib/google/apis/compute_alpha/classes.rb', line 59111

def cluster
  @cluster
end

#instancesArray<Google::Apis::ComputeAlpha::ReservationBlockPhysicalTopologyInstance>

Output only. The detailed instances information for a given Block Corresponds to the JSON property instances



59116
59117
59118
# File 'lib/google/apis/compute_alpha/classes.rb', line 59116

def instances
  @instances
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



59123
59124
59125
59126
59127
# File 'lib/google/apis/compute_alpha/classes.rb', line 59123

def update!(**args)
  @block = args[:block] if args.key?(:block)
  @cluster = args[:cluster] if args.key?(:cluster)
  @instances = args[:instances] if args.key?(:instances)
end