Class: Google::Apis::ComputeAlpha::ReservationBlockPhysicalTopology

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReservationBlockPhysicalTopology

Returns a new instance of ReservationBlockPhysicalTopology.



58541
58542
58543
# File 'lib/google/apis/compute_alpha/classes.rb', line 58541

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#blockString

The hash of the capacity block within the cluster. Corresponds to the JSON property block

Returns:

  • (String)


58529
58530
58531
# File 'lib/google/apis/compute_alpha/classes.rb', line 58529

def block
  @block
end

#clusterString

The cluster name of the reservation block. Corresponds to the JSON property cluster

Returns:

  • (String)


58534
58535
58536
# File 'lib/google/apis/compute_alpha/classes.rb', line 58534

def cluster
  @cluster
end

#instancesArray<Google::Apis::ComputeAlpha::ReservationBlockPhysicalTopologyInstance>

Output only. The detailed instances information for a given Block Corresponds to the JSON property instances



58539
58540
58541
# File 'lib/google/apis/compute_alpha/classes.rb', line 58539

def instances
  @instances
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



58546
58547
58548
58549
58550
# File 'lib/google/apis/compute_alpha/classes.rb', line 58546

def update!(**args)
  @block = args[:block] if args.key?(:block)
  @cluster = args[:cluster] if args.key?(:cluster)
  @instances = args[:instances] if args.key?(:instances)
end