Class: Google::Apis::ComputeAlpha::ReservationBlockPhysicalTopology

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReservationBlockPhysicalTopology

Returns a new instance of ReservationBlockPhysicalTopology.



57481
57482
57483
# File 'lib/google/apis/compute_alpha/classes.rb', line 57481

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#blockString

The hash of the capacity block within the cluster. Corresponds to the JSON property block

Returns:

  • (String)


57469
57470
57471
# File 'lib/google/apis/compute_alpha/classes.rb', line 57469

def block
  @block
end

#clusterString

The cluster name of the reservation block. Corresponds to the JSON property cluster

Returns:

  • (String)


57474
57475
57476
# File 'lib/google/apis/compute_alpha/classes.rb', line 57474

def cluster
  @cluster
end

#instancesArray<Google::Apis::ComputeAlpha::ReservationBlockPhysicalTopologyInstance>

Output only. The detailed instances information for a given Block Corresponds to the JSON property instances



57479
57480
57481
# File 'lib/google/apis/compute_alpha/classes.rb', line 57479

def instances
  @instances
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



57486
57487
57488
57489
57490
# File 'lib/google/apis/compute_alpha/classes.rb', line 57486

def update!(**args)
  @block = args[:block] if args.key?(:block)
  @cluster = args[:cluster] if args.key?(:cluster)
  @instances = args[:instances] if args.key?(:instances)
end