Class: Google::Apis::ComputeAlpha::ReservationBlockPhysicalTopologyInstancePhysicalHostTopology
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::ReservationBlockPhysicalTopologyInstancePhysicalHostTopology
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
The PhysicalHostTopology of the instance within a Block resource.
Instance Attribute Summary collapse
-
#host ⇒ String
Host hash for a given instance Corresponds to the JSON property
host. -
#sub_block ⇒ String
Sub block hash for a given instance Corresponds to the JSON property
subBlock.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReservationBlockPhysicalTopologyInstancePhysicalHostTopology
constructor
A new instance of ReservationBlockPhysicalTopologyInstancePhysicalHostTopology.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReservationBlockPhysicalTopologyInstancePhysicalHostTopology
Returns a new instance of ReservationBlockPhysicalTopologyInstancePhysicalHostTopology.
60518 60519 60520 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 60518 def initialize(**args) update!(**args) end |
Instance Attribute Details
#host ⇒ String
Host hash for a given instance
Corresponds to the JSON property host
60511 60512 60513 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 60511 def host @host end |
#sub_block ⇒ String
Sub block hash for a given instance
Corresponds to the JSON property subBlock
60516 60517 60518 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 60516 def sub_block @sub_block end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
60523 60524 60525 60526 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 60523 def update!(**args) @host = args[:host] if args.key?(:host) @sub_block = args[:sub_block] if args.key?(:sub_block) end |