Class: Google::Apis::ComputeAlpha::ReservationBlockPhysicalTopologyInstancePhysicalHostTopology

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

The PhysicalHostTopology of the instance within a Block resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReservationBlockPhysicalTopologyInstancePhysicalHostTopology

Returns a new instance of ReservationBlockPhysicalTopologyInstancePhysicalHostTopology.



58375
58376
58377
# File 'lib/google/apis/compute_alpha/classes.rb', line 58375

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#hostString

Host hash for a given instance Corresponds to the JSON property host

Returns:

  • (String)


58368
58369
58370
# File 'lib/google/apis/compute_alpha/classes.rb', line 58368

def host
  @host
end

#sub_blockString

Sub block hash for a given instance Corresponds to the JSON property subBlock

Returns:

  • (String)


58373
58374
58375
# File 'lib/google/apis/compute_alpha/classes.rb', line 58373

def sub_block
  @sub_block
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



58380
58381
58382
58383
# File 'lib/google/apis/compute_alpha/classes.rb', line 58380

def update!(**args)
  @host = args[:host] if args.key?(:host)
  @sub_block = args[:sub_block] if args.key?(:sub_block)
end