Class: Google::Apis::ComputeAlpha::ReservationBlocksListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

A list of reservation blocks under a single reservation.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReservationBlocksListResponse

Returns a new instance of ReservationBlocksListResponse.



60588
60589
60590
# File 'lib/google/apis/compute_alpha/classes.rb', line 60588

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


60555
60556
60557
# File 'lib/google/apis/compute_alpha/classes.rb', line 60555

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::ReservationBlock>

A list of reservation block resources. Corresponds to the JSON property items



60560
60561
60562
# File 'lib/google/apis/compute_alpha/classes.rb', line 60560

def items
  @items
end

#kindString

Type of the resource. Alwayscompute#reservationBlock for a list of reservation blocks. Corresponds to the JSON property kind

Returns:

  • (String)


60566
60567
60568
# File 'lib/google/apis/compute_alpha/classes.rb', line 60566

def kind
  @kind
end

#next_page_tokenString

This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


60576
60577
60578
# File 'lib/google/apis/compute_alpha/classes.rb', line 60576

def next_page_token
  @next_page_token
end

Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


60581
60582
60583
# File 'lib/google/apis/compute_alpha/classes.rb', line 60581

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::ReservationBlocksListResponse::Warning

Informational warning message. Corresponds to the JSON property warning



60586
60587
60588
# File 'lib/google/apis/compute_alpha/classes.rb', line 60586

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



60593
60594
60595
60596
60597
60598
60599
60600
# File 'lib/google/apis/compute_alpha/classes.rb', line 60593

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end