Class: Google::Apis::ComputeAlpha::ReservationBlocksListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

A list of reservation blocks under a single reservation.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReservationBlocksListResponse

Returns a new instance of ReservationBlocksListResponse.



59228
59229
59230
# File 'lib/google/apis/compute_alpha/classes.rb', line 59228

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


59195
59196
59197
# File 'lib/google/apis/compute_alpha/classes.rb', line 59195

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::ReservationBlock>

A list of reservation block resources. Corresponds to the JSON property items



59200
59201
59202
# File 'lib/google/apis/compute_alpha/classes.rb', line 59200

def items
  @items
end

#kindString

Type of the resource. Alwayscompute#reservationBlock for a list of reservation blocks. Corresponds to the JSON property kind

Returns:

  • (String)


59206
59207
59208
# File 'lib/google/apis/compute_alpha/classes.rb', line 59206

def kind
  @kind
end

#next_page_tokenString

This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


59216
59217
59218
# File 'lib/google/apis/compute_alpha/classes.rb', line 59216

def next_page_token
  @next_page_token
end

Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


59221
59222
59223
# File 'lib/google/apis/compute_alpha/classes.rb', line 59221

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::ReservationBlocksListResponse::Warning

Informational warning message. Corresponds to the JSON property warning



59226
59227
59228
# File 'lib/google/apis/compute_alpha/classes.rb', line 59226

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



59233
59234
59235
59236
59237
59238
59239
59240
# File 'lib/google/apis/compute_alpha/classes.rb', line 59233

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end