Class: Google::Apis::ComputeAlpha::ReservationBlocksListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

A list of reservation blocks under a single reservation.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReservationBlocksListResponse

Returns a new instance of ReservationBlocksListResponse.



58445
58446
58447
# File 'lib/google/apis/compute_alpha/classes.rb', line 58445

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


58412
58413
58414
# File 'lib/google/apis/compute_alpha/classes.rb', line 58412

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::ReservationBlock>

A list of reservation block resources. Corresponds to the JSON property items



58417
58418
58419
# File 'lib/google/apis/compute_alpha/classes.rb', line 58417

def items
  @items
end

#kindString

Type of the resource. Alwayscompute#reservationBlock for a list of reservation blocks. Corresponds to the JSON property kind

Returns:

  • (String)


58423
58424
58425
# File 'lib/google/apis/compute_alpha/classes.rb', line 58423

def kind
  @kind
end

#next_page_tokenString

This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


58433
58434
58435
# File 'lib/google/apis/compute_alpha/classes.rb', line 58433

def next_page_token
  @next_page_token
end

Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


58438
58439
58440
# File 'lib/google/apis/compute_alpha/classes.rb', line 58438

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::ReservationBlocksListResponse::Warning

Informational warning message. Corresponds to the JSON property warning



58443
58444
58445
# File 'lib/google/apis/compute_alpha/classes.rb', line 58443

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



58450
58451
58452
58453
58454
58455
58456
58457
# File 'lib/google/apis/compute_alpha/classes.rb', line 58450

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end