Class: Google::Apis::ComputeAlpha::ReservationBlocksListResponse
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::ReservationBlocksListResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
A list of reservation blocks under a single reservation.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::ReservationBlock>
A list of reservation block resources.
-
#kind ⇒ String
Type of the resource.
-
#next_page_token ⇒ String
This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Server-defined URL for this resource.
-
#warning ⇒ Google::Apis::ComputeAlpha::ReservationBlocksListResponse::Warning
Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReservationBlocksListResponse
constructor
A new instance of ReservationBlocksListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReservationBlocksListResponse
Returns a new instance of ReservationBlocksListResponse.
57608 57609 57610 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 57608 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
57575 57576 57577 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 57575 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::ReservationBlock>
A list of reservation block resources.
Corresponds to the JSON property items
57580 57581 57582 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 57580 def items @items end |
#kind ⇒ String
Type of the resource. Alwayscompute#reservationBlock for a list of reservation
blocks.
Corresponds to the JSON property kind
57586 57587 57588 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 57586 def kind @kind end |
#next_page_token ⇒ String
This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
57596 57597 57598 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 57596 def next_page_token @next_page_token end |
#self_link ⇒ String
Server-defined URL for this resource.
Corresponds to the JSON property selfLink
57601 57602 57603 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 57601 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::ReservationBlocksListResponse::Warning
Informational warning message.
Corresponds to the JSON property warning
57606 57607 57608 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 57606 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
57613 57614 57615 57616 57617 57618 57619 57620 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 57613 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |