Class: Google::Apis::ComputeAlpha::ReservationConsumedInstancesListResponse
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::ReservationConsumedInstancesListResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Response message for listing reservation consumed instances.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
Uniquely identifies the type of this resource.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::ReservationConsumedInstance>
A list of ReservationConsumedInstance resources.
-
#kind ⇒ String
Identifies the resource as a list of reservation consumed instances.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::ReservationConsumedInstancesListResponse::Warning
[Output Only] Informational warning which replaces the result in some cases.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReservationConsumedInstancesListResponse
constructor
A new instance of ReservationConsumedInstancesListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReservationConsumedInstancesListResponse
Returns a new instance of ReservationConsumedInstancesListResponse.
60882 60883 60884 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 60882 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
Uniquely identifies the type of this resource.
Corresponds to the JSON property id
60853 60854 60855 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 60853 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::ReservationConsumedInstance>
A list of ReservationConsumedInstance resources.
Corresponds to the JSON property items
60858 60859 60860 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 60858 def items @items end |
#kind ⇒ String
Identifies the resource as a list of reservation consumed instances.
Corresponds to the JSON property kind
60863 60864 60865 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 60863 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests.
Corresponds to the JSON property nextPageToken
60869 60870 60871 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 60869 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
60874 60875 60876 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 60874 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::ReservationConsumedInstancesListResponse::Warning
[Output Only] Informational warning which replaces the result in some
cases.
Corresponds to the JSON property warning
60880 60881 60882 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 60880 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
60887 60888 60889 60890 60891 60892 60893 60894 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 60887 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |