Class: Google::Apis::ComputeAlpha::ReservationConsumedInstancesListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Response message for listing reservation consumed instances.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReservationConsumedInstancesListResponse

Returns a new instance of ReservationConsumedInstancesListResponse.



60597
60598
60599
# File 'lib/google/apis/compute_alpha/classes.rb', line 60597

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Uniquely identifies the type of this resource. Corresponds to the JSON property id

Returns:

  • (String)


60568
60569
60570
# File 'lib/google/apis/compute_alpha/classes.rb', line 60568

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::ReservationConsumedInstance>

A list of ReservationConsumedInstance resources. Corresponds to the JSON property items



60573
60574
60575
# File 'lib/google/apis/compute_alpha/classes.rb', line 60573

def items
  @items
end

#kindString

Identifies the resource as a list of reservation consumed instances. Corresponds to the JSON property kind

Returns:

  • (String)


60578
60579
60580
# File 'lib/google/apis/compute_alpha/classes.rb', line 60578

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


60584
60585
60586
# File 'lib/google/apis/compute_alpha/classes.rb', line 60584

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


60589
60590
60591
# File 'lib/google/apis/compute_alpha/classes.rb', line 60589

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::ReservationConsumedInstancesListResponse::Warning

[Output Only] Informational warning which replaces the result in some cases. Corresponds to the JSON property warning



60595
60596
60597
# File 'lib/google/apis/compute_alpha/classes.rb', line 60595

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



60602
60603
60604
60605
60606
60607
60608
60609
# File 'lib/google/apis/compute_alpha/classes.rb', line 60602

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end