Class: Google::Apis::ComputeAlpha::ReservationList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::ReservationList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] The unique identifier for the resource.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::Reservation>
[Output Only] A list of Allocation resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::ReservationList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReservationList
constructor
A new instance of ReservationList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReservationList
Returns a new instance of ReservationList.
61276 61277 61278 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61276 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
61243 61244 61245 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61243 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::Reservation>
[Output Only] A list of Allocation resources.
Corresponds to the JSON property items
61248 61249 61250 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61248 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource.Always compute#reservationsList
for listsof reservations
Corresponds to the JSON property kind
61254 61255 61256 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61254 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
61264 61265 61266 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61264 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
61269 61270 61271 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61269 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::ReservationList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
61274 61275 61276 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61274 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
61281 61282 61283 61284 61285 61286 61287 61288 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61281 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |