Class: Google::Apis::ComputeAlpha::ReservationList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReservationList

Returns a new instance of ReservationList.



61009
61010
61011
# File 'lib/google/apis/compute_alpha/classes.rb', line 61009

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


60976
60977
60978
# File 'lib/google/apis/compute_alpha/classes.rb', line 60976

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::Reservation>

[Output Only] A list of Allocation resources. Corresponds to the JSON property items



60981
60982
60983
# File 'lib/google/apis/compute_alpha/classes.rb', line 60981

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource.Always compute#reservationsList for listsof reservations Corresponds to the JSON property kind

Returns:

  • (String)


60987
60988
60989
# File 'lib/google/apis/compute_alpha/classes.rb', line 60987

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


60997
60998
60999
# File 'lib/google/apis/compute_alpha/classes.rb', line 60997

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


61002
61003
61004
# File 'lib/google/apis/compute_alpha/classes.rb', line 61002

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::ReservationList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



61007
61008
61009
# File 'lib/google/apis/compute_alpha/classes.rb', line 61007

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



61014
61015
61016
61017
61018
61019
61020
61021
# File 'lib/google/apis/compute_alpha/classes.rb', line 61014

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end