Class: Google::Apis::ComputeAlpha::ReservationList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReservationList

Returns a new instance of ReservationList.



59371
59372
59373
# File 'lib/google/apis/compute_alpha/classes.rb', line 59371

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


59338
59339
59340
# File 'lib/google/apis/compute_alpha/classes.rb', line 59338

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::Reservation>

[Output Only] A list of Allocation resources. Corresponds to the JSON property items



59343
59344
59345
# File 'lib/google/apis/compute_alpha/classes.rb', line 59343

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource.Always compute#reservationsList for listsof reservations Corresponds to the JSON property kind

Returns:

  • (String)


59349
59350
59351
# File 'lib/google/apis/compute_alpha/classes.rb', line 59349

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


59359
59360
59361
# File 'lib/google/apis/compute_alpha/classes.rb', line 59359

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


59364
59365
59366
# File 'lib/google/apis/compute_alpha/classes.rb', line 59364

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::ReservationList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



59369
59370
59371
# File 'lib/google/apis/compute_alpha/classes.rb', line 59369

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



59376
59377
59378
59379
59380
59381
59382
59383
# File 'lib/google/apis/compute_alpha/classes.rb', line 59376

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end