Class: Google::Apis::ComputeAlpha::ReservationList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::ReservationList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] The unique identifier for the resource.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::Reservation>
[Output Only] A list of Allocation resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::ReservationList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReservationList
constructor
A new instance of ReservationList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReservationList
Returns a new instance of ReservationList.
59354 59355 59356 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59354 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
59321 59322 59323 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59321 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::Reservation>
[Output Only] A list of Allocation resources.
Corresponds to the JSON property items
59326 59327 59328 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59326 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource.Always compute#reservationsList
for listsof reservations
Corresponds to the JSON property kind
59332 59333 59334 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59332 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
59342 59343 59344 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59342 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
59347 59348 59349 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59347 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::ReservationList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
59352 59353 59354 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59352 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
59359 59360 59361 59362 59363 59364 59365 59366 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59359 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |