Class: Google::Apis::ComputeAlpha::ReservationList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReservationList

Returns a new instance of ReservationList.



58571
58572
58573
# File 'lib/google/apis/compute_alpha/classes.rb', line 58571

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


58538
58539
58540
# File 'lib/google/apis/compute_alpha/classes.rb', line 58538

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::Reservation>

[Output Only] A list of Allocation resources. Corresponds to the JSON property items



58543
58544
58545
# File 'lib/google/apis/compute_alpha/classes.rb', line 58543

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource.Always compute#reservationsList for listsof reservations Corresponds to the JSON property kind

Returns:

  • (String)


58549
58550
58551
# File 'lib/google/apis/compute_alpha/classes.rb', line 58549

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


58559
58560
58561
# File 'lib/google/apis/compute_alpha/classes.rb', line 58559

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


58564
58565
58566
# File 'lib/google/apis/compute_alpha/classes.rb', line 58564

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::ReservationList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



58569
58570
58571
# File 'lib/google/apis/compute_alpha/classes.rb', line 58569

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



58576
58577
58578
58579
58580
58581
58582
58583
# File 'lib/google/apis/compute_alpha/classes.rb', line 58576

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end