Class: Google::Apis::ComputeAlpha::ReservationSlot
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::ReservationSlot
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Represents a reservation slot resource.
Instance Attribute Summary collapse
-
#creation_timestamp ⇒ String
Output only.
-
#id ⇒ Fixnum
Output only.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
Output only.
-
#physical_topology ⇒ Google::Apis::ComputeAlpha::ReservationSlotPhysicalTopology
Output only.
-
#self_link ⇒ String
Output only.
-
#self_link_with_id ⇒ String
Output only.
-
#share_settings ⇒ Google::Apis::ComputeAlpha::ShareSettings
The share setting for reservations and sole tenancy node groups.
-
#state ⇒ String
Output only.
-
#status ⇒ Google::Apis::ComputeAlpha::ReservationSlotStatus
Output only.
-
#zone ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReservationSlot
constructor
A new instance of ReservationSlot.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReservationSlot
Returns a new instance of ReservationSlot.
60898 60899 60900 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 60898 def initialize(**args) update!(**args) end |
Instance Attribute Details
#creation_timestamp ⇒ String
Output only. [Output Only] The creation timestamp, formatted asRFC3339 text.
Corresponds to the JSON property creationTimestamp
60841 60842 60843 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 60841 def @creation_timestamp end |
#id ⇒ Fixnum
Output only. [Output Only] The unique identifier for this resource. This
identifier is
defined by the server.
Corresponds to the JSON property id
60848 60849 60850 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 60848 def id @id end |
#kind ⇒ String
Output only. [Output Only] The type of resource. Alwayscompute#reservationSlot
for reservation slots.
Corresponds to the JSON property kind
60854 60855 60856 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 60854 def kind @kind end |
#name ⇒ String
Output only. [Output Only] The name of the reservation slot.
Corresponds to the JSON property name
60859 60860 60861 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 60859 def name @name end |
#physical_topology ⇒ Google::Apis::ComputeAlpha::ReservationSlotPhysicalTopology
Output only. [Output Only] The physical topology of the reservation slot.
Corresponds to the JSON property physicalTopology
60864 60865 60866 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 60864 def physical_topology @physical_topology end |
#self_link ⇒ String
Output only. [Output Only] A server-defined fully-qualified URL for this
resource.
Corresponds to the JSON property selfLink
60870 60871 60872 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 60870 def self_link @self_link end |
#self_link_with_id ⇒ String
Output only. [Output Only] A server-defined URL for this resource with the
resource ID.
Corresponds to the JSON property selfLinkWithId
60876 60877 60878 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 60876 def self_link_with_id @self_link_with_id end |
#share_settings ⇒ Google::Apis::ComputeAlpha::ShareSettings
The share setting for reservations and sole tenancy node groups.
Corresponds to the JSON property shareSettings
60881 60882 60883 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 60881 def share_settings @share_settings end |
#state ⇒ String
Output only. [Output Only] The state of the reservation slot.
Corresponds to the JSON property state
60886 60887 60888 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 60886 def state @state end |
#status ⇒ Google::Apis::ComputeAlpha::ReservationSlotStatus
Output only. [Output Only] The status of the reservation slot.
Corresponds to the JSON property status
60891 60892 60893 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 60891 def status @status end |
#zone ⇒ String
Output only. [Output Only] The zone in which the reservation slot resides.
Corresponds to the JSON property zone
60896 60897 60898 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 60896 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
60903 60904 60905 60906 60907 60908 60909 60910 60911 60912 60913 60914 60915 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 60903 def update!(**args) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @physical_topology = args[:physical_topology] if args.key?(:physical_topology) @self_link = args[:self_link] if args.key?(:self_link) @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id) @share_settings = args[:share_settings] if args.key?(:share_settings) @state = args[:state] if args.key?(:state) @status = args[:status] if args.key?(:status) @zone = args[:zone] if args.key?(:zone) end |