Class: Google::Apis::ComputeAlpha::ReservationSlot
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::ReservationSlot
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Represents a reservation slot resource.
Instance Attribute Summary collapse
-
#creation_timestamp ⇒ String
Output only.
-
#id ⇒ Fixnum
Output only.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
Output only.
-
#physical_topology ⇒ Google::Apis::ComputeAlpha::ReservationSlotPhysicalTopology
Output only.
-
#self_link ⇒ String
Output only.
-
#self_link_with_id ⇒ String
Output only.
-
#share_settings ⇒ Google::Apis::ComputeAlpha::ShareSettings
The share setting for reservations and sole tenancy node groups.
-
#state ⇒ String
Output only.
-
#status ⇒ Google::Apis::ComputeAlpha::ReservationSlotStatus
Output only.
-
#zone ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReservationSlot
constructor
A new instance of ReservationSlot.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReservationSlot
Returns a new instance of ReservationSlot.
59528 59529 59530 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59528 def initialize(**args) update!(**args) end |
Instance Attribute Details
#creation_timestamp ⇒ String
Output only. [Output Only] The creation timestamp, formatted asRFC3339 text.
Corresponds to the JSON property creationTimestamp
59471 59472 59473 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59471 def @creation_timestamp end |
#id ⇒ Fixnum
Output only. [Output Only] The unique identifier for this resource. This
identifier is
defined by the server.
Corresponds to the JSON property id
59478 59479 59480 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59478 def id @id end |
#kind ⇒ String
Output only. [Output Only] The type of resource. Alwayscompute#reservationSlot
for reservation slots.
Corresponds to the JSON property kind
59484 59485 59486 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59484 def kind @kind end |
#name ⇒ String
Output only. [Output Only] The name of the reservation slot.
Corresponds to the JSON property name
59489 59490 59491 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59489 def name @name end |
#physical_topology ⇒ Google::Apis::ComputeAlpha::ReservationSlotPhysicalTopology
Output only. [Output Only] The physical topology of the reservation slot.
Corresponds to the JSON property physicalTopology
59494 59495 59496 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59494 def physical_topology @physical_topology end |
#self_link ⇒ String
Output only. [Output Only] A server-defined fully-qualified URL for this
resource.
Corresponds to the JSON property selfLink
59500 59501 59502 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59500 def self_link @self_link end |
#self_link_with_id ⇒ String
Output only. [Output Only] A server-defined URL for this resource with the
resource ID.
Corresponds to the JSON property selfLinkWithId
59506 59507 59508 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59506 def self_link_with_id @self_link_with_id end |
#share_settings ⇒ Google::Apis::ComputeAlpha::ShareSettings
The share setting for reservations and sole tenancy node groups.
Corresponds to the JSON property shareSettings
59511 59512 59513 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59511 def share_settings @share_settings end |
#state ⇒ String
Output only. [Output Only] The state of the reservation slot.
Corresponds to the JSON property state
59516 59517 59518 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59516 def state @state end |
#status ⇒ Google::Apis::ComputeAlpha::ReservationSlotStatus
Output only. [Output Only] The status of the reservation slot.
Corresponds to the JSON property status
59521 59522 59523 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59521 def status @status end |
#zone ⇒ String
Output only. [Output Only] The zone in which the reservation slot resides.
Corresponds to the JSON property zone
59526 59527 59528 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59526 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
59533 59534 59535 59536 59537 59538 59539 59540 59541 59542 59543 59544 59545 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59533 def update!(**args) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @physical_topology = args[:physical_topology] if args.key?(:physical_topology) @self_link = args[:self_link] if args.key?(:self_link) @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id) @share_settings = args[:share_settings] if args.key?(:share_settings) @state = args[:state] if args.key?(:state) @status = args[:status] if args.key?(:status) @zone = args[:zone] if args.key?(:zone) end |