Class: Google::Apis::ComputeAlpha::ReservationSlot
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::ReservationSlot
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Represents a reservation slot resource.
Instance Attribute Summary collapse
-
#creation_timestamp ⇒ String
Output only.
-
#id ⇒ Fixnum
Output only.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
Output only.
-
#physical_topology ⇒ Google::Apis::ComputeAlpha::ReservationSlotPhysicalTopology
Output only.
-
#self_link ⇒ String
Output only.
-
#self_link_with_id ⇒ String
Output only.
-
#share_settings ⇒ Google::Apis::ComputeAlpha::ShareSettings
The share setting for reservations and sole tenancy node groups.
-
#state ⇒ String
Output only.
-
#status ⇒ Google::Apis::ComputeAlpha::ReservationSlotStatus
Output only.
-
#zone ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReservationSlot
constructor
A new instance of ReservationSlot.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReservationSlot
Returns a new instance of ReservationSlot.
58966 58967 58968 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58966 def initialize(**args) update!(**args) end |
Instance Attribute Details
#creation_timestamp ⇒ String
Output only. [Output Only] The creation timestamp, formatted asRFC3339 text.
Corresponds to the JSON property creationTimestamp
58909 58910 58911 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58909 def @creation_timestamp end |
#id ⇒ Fixnum
Output only. [Output Only] The unique identifier for this resource. This
identifier is
defined by the server.
Corresponds to the JSON property id
58916 58917 58918 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58916 def id @id end |
#kind ⇒ String
Output only. [Output Only] The type of resource. Alwayscompute#reservationSlot
for reservation slots.
Corresponds to the JSON property kind
58922 58923 58924 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58922 def kind @kind end |
#name ⇒ String
Output only. [Output Only] The name of the reservation slot.
Corresponds to the JSON property name
58927 58928 58929 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58927 def name @name end |
#physical_topology ⇒ Google::Apis::ComputeAlpha::ReservationSlotPhysicalTopology
Output only. [Output Only] The physical topology of the reservation slot.
Corresponds to the JSON property physicalTopology
58932 58933 58934 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58932 def physical_topology @physical_topology end |
#self_link ⇒ String
Output only. [Output Only] A server-defined fully-qualified URL for this
resource.
Corresponds to the JSON property selfLink
58938 58939 58940 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58938 def self_link @self_link end |
#self_link_with_id ⇒ String
Output only. [Output Only] A server-defined URL for this resource with the
resource ID.
Corresponds to the JSON property selfLinkWithId
58944 58945 58946 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58944 def self_link_with_id @self_link_with_id end |
#share_settings ⇒ Google::Apis::ComputeAlpha::ShareSettings
The share setting for reservations and sole tenancy node groups.
Corresponds to the JSON property shareSettings
58949 58950 58951 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58949 def share_settings @share_settings end |
#state ⇒ String
Output only. [Output Only] The state of the reservation slot.
Corresponds to the JSON property state
58954 58955 58956 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58954 def state @state end |
#status ⇒ Google::Apis::ComputeAlpha::ReservationSlotStatus
Output only. [Output Only] The status of the reservation slot.
Corresponds to the JSON property status
58959 58960 58961 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58959 def status @status end |
#zone ⇒ String
Output only. [Output Only] The zone in which the reservation slot resides.
Corresponds to the JSON property zone
58964 58965 58966 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58964 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
58971 58972 58973 58974 58975 58976 58977 58978 58979 58980 58981 58982 58983 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58971 def update!(**args) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @physical_topology = args[:physical_topology] if args.key?(:physical_topology) @self_link = args[:self_link] if args.key?(:self_link) @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id) @share_settings = args[:share_settings] if args.key?(:share_settings) @state = args[:state] if args.key?(:state) @status = args[:status] if args.key?(:status) @zone = args[:zone] if args.key?(:zone) end |