Class: Google::Apis::ComputeAlpha::ReservationSlot
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::ReservationSlot
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Represents a reservation slot resource.
Instance Attribute Summary collapse
-
#creation_timestamp ⇒ String
Output only.
-
#id ⇒ Fixnum
Output only.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
Output only.
-
#physical_topology ⇒ Google::Apis::ComputeAlpha::ReservationSlotPhysicalTopology
Output only.
-
#self_link ⇒ String
Output only.
-
#self_link_with_id ⇒ String
Output only.
-
#share_settings ⇒ Google::Apis::ComputeAlpha::ShareSettings
The share setting for reservations and sole tenancy node groups.
-
#state ⇒ String
Output only.
-
#status ⇒ Google::Apis::ComputeAlpha::ReservationSlotStatus
Output only.
-
#zone ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReservationSlot
constructor
A new instance of ReservationSlot.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReservationSlot
Returns a new instance of ReservationSlot.
58745 58746 58747 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58745 def initialize(**args) update!(**args) end |
Instance Attribute Details
#creation_timestamp ⇒ String
Output only. [Output Only] The creation timestamp, formatted asRFC3339 text.
Corresponds to the JSON property creationTimestamp
58688 58689 58690 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58688 def @creation_timestamp end |
#id ⇒ Fixnum
Output only. [Output Only] The unique identifier for this resource. This
identifier is
defined by the server.
Corresponds to the JSON property id
58695 58696 58697 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58695 def id @id end |
#kind ⇒ String
Output only. [Output Only] The type of resource. Alwayscompute#reservationSlot
for reservation slots.
Corresponds to the JSON property kind
58701 58702 58703 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58701 def kind @kind end |
#name ⇒ String
Output only. [Output Only] The name of the reservation slot.
Corresponds to the JSON property name
58706 58707 58708 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58706 def name @name end |
#physical_topology ⇒ Google::Apis::ComputeAlpha::ReservationSlotPhysicalTopology
Output only. [Output Only] The physical topology of the reservation slot.
Corresponds to the JSON property physicalTopology
58711 58712 58713 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58711 def physical_topology @physical_topology end |
#self_link ⇒ String
Output only. [Output Only] A server-defined fully-qualified URL for this
resource.
Corresponds to the JSON property selfLink
58717 58718 58719 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58717 def self_link @self_link end |
#self_link_with_id ⇒ String
Output only. [Output Only] A server-defined URL for this resource with the
resource ID.
Corresponds to the JSON property selfLinkWithId
58723 58724 58725 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58723 def self_link_with_id @self_link_with_id end |
#share_settings ⇒ Google::Apis::ComputeAlpha::ShareSettings
The share setting for reservations and sole tenancy node groups.
Corresponds to the JSON property shareSettings
58728 58729 58730 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58728 def share_settings @share_settings end |
#state ⇒ String
Output only. [Output Only] The state of the reservation slot.
Corresponds to the JSON property state
58733 58734 58735 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58733 def state @state end |
#status ⇒ Google::Apis::ComputeAlpha::ReservationSlotStatus
Output only. [Output Only] The status of the reservation slot.
Corresponds to the JSON property status
58738 58739 58740 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58738 def status @status end |
#zone ⇒ String
Output only. [Output Only] The zone in which the reservation slot resides.
Corresponds to the JSON property zone
58743 58744 58745 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58743 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
58750 58751 58752 58753 58754 58755 58756 58757 58758 58759 58760 58761 58762 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58750 def update!(**args) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @physical_topology = args[:physical_topology] if args.key?(:physical_topology) @self_link = args[:self_link] if args.key?(:self_link) @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id) @share_settings = args[:share_settings] if args.key?(:share_settings) @state = args[:state] if args.key?(:state) @status = args[:status] if args.key?(:status) @zone = args[:zone] if args.key?(:zone) end |