Class: Google::Apis::ComputeAlpha::ReservationSlotPhysicalTopology

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReservationSlotPhysicalTopology

Returns a new instance of ReservationSlotPhysicalTopology.



59590
59591
59592
# File 'lib/google/apis/compute_alpha/classes.rb', line 59590

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#blockString

The unique identifier of the capacity block within the cluster. Corresponds to the JSON property block

Returns:

  • (String)


59572
59573
59574
# File 'lib/google/apis/compute_alpha/classes.rb', line 59572

def block
  @block
end

#clusterString

The cluster name of the reservation sub-block. Corresponds to the JSON property cluster

Returns:

  • (String)


59577
59578
59579
# File 'lib/google/apis/compute_alpha/classes.rb', line 59577

def cluster
  @cluster
end

#hostString

The unique identifier of the capacity host within the capacity sub-block. Corresponds to the JSON property host

Returns:

  • (String)


59582
59583
59584
# File 'lib/google/apis/compute_alpha/classes.rb', line 59582

def host
  @host
end

#sub_blockString

The unique identifier of the capacity sub-block within the capacity block. Corresponds to the JSON property subBlock

Returns:

  • (String)


59588
59589
59590
# File 'lib/google/apis/compute_alpha/classes.rb', line 59588

def sub_block
  @sub_block
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



59595
59596
59597
59598
59599
59600
# File 'lib/google/apis/compute_alpha/classes.rb', line 59595

def update!(**args)
  @block = args[:block] if args.key?(:block)
  @cluster = args[:cluster] if args.key?(:cluster)
  @host = args[:host] if args.key?(:host)
  @sub_block = args[:sub_block] if args.key?(:sub_block)
end