Class: Google::Apis::ComputeAlpha::ReservationSlotPhysicalTopology
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::ReservationSlotPhysicalTopology
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#block ⇒ String
The unique identifier of the capacity block within the cluster.
-
#cluster ⇒ String
The cluster name of the reservation sub-block.
-
#host ⇒ String
The unique identifier of the capacity host within the capacity sub-block.
-
#sub_block ⇒ String
The unique identifier of the capacity sub-block within the capacity block.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReservationSlotPhysicalTopology
constructor
A new instance of ReservationSlotPhysicalTopology.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReservationSlotPhysicalTopology
Returns a new instance of ReservationSlotPhysicalTopology.
59573 59574 59575 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59573 def initialize(**args) update!(**args) end |
Instance Attribute Details
#block ⇒ String
The unique identifier of the capacity block within the cluster.
Corresponds to the JSON property block
59555 59556 59557 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59555 def block @block end |
#cluster ⇒ String
The cluster name of the reservation sub-block.
Corresponds to the JSON property cluster
59560 59561 59562 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59560 def cluster @cluster end |
#host ⇒ String
The unique identifier of the capacity host within the capacity sub-block.
Corresponds to the JSON property host
59565 59566 59567 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59565 def host @host end |
#sub_block ⇒ String
The unique identifier of the capacity sub-block within the capacity
block.
Corresponds to the JSON property subBlock
59571 59572 59573 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59571 def sub_block @sub_block end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
59578 59579 59580 59581 59582 59583 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59578 def update!(**args) @block = args[:block] if args.key?(:block) @cluster = args[:cluster] if args.key?(:cluster) @host = args[:host] if args.key?(:host) @sub_block = args[:sub_block] if args.key?(:sub_block) end |