Class: Google::Apis::ComputeAlpha::ReservationSlotPhysicalTopology
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::ReservationSlotPhysicalTopology
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#block ⇒ String
The unique identifier of the capacity block within the cluster.
-
#cluster ⇒ String
The cluster name of the reservation sub-block.
-
#host ⇒ String
The unique identifier of the capacity host within the capacity sub-block.
-
#sub_block ⇒ String
The unique identifier of the capacity sub-block within the capacity block.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReservationSlotPhysicalTopology
constructor
A new instance of ReservationSlotPhysicalTopology.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReservationSlotPhysicalTopology
Returns a new instance of ReservationSlotPhysicalTopology.
59011 59012 59013 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59011 def initialize(**args) update!(**args) end |
Instance Attribute Details
#block ⇒ String
The unique identifier of the capacity block within the cluster.
Corresponds to the JSON property block
58993 58994 58995 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58993 def block @block end |
#cluster ⇒ String
The cluster name of the reservation sub-block.
Corresponds to the JSON property cluster
58998 58999 59000 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58998 def cluster @cluster end |
#host ⇒ String
The unique identifier of the capacity host within the capacity sub-block.
Corresponds to the JSON property host
59003 59004 59005 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59003 def host @host end |
#sub_block ⇒ String
The unique identifier of the capacity sub-block within the capacity
block.
Corresponds to the JSON property subBlock
59009 59010 59011 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59009 def sub_block @sub_block end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
59016 59017 59018 59019 59020 59021 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59016 def update!(**args) @block = args[:block] if args.key?(:block) @cluster = args[:cluster] if args.key?(:cluster) @host = args[:host] if args.key?(:host) @sub_block = args[:sub_block] if args.key?(:sub_block) end |