Class: Google::Apis::ComputeAlpha::ReservationSlotsListResponse
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::ReservationSlotsListResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
A list of reservation slots within a single reservation.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
The unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::ReservationSlot>
A list of reservation slot resources.
-
#kind ⇒ String
The type of resource.
-
#next_page_token ⇒ String
This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
The server-defined URL for this resource.
-
#warning ⇒ Google::Apis::ComputeAlpha::ReservationSlotsListResponse::Warning
An informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReservationSlotsListResponse
constructor
A new instance of ReservationSlotsListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReservationSlotsListResponse
Returns a new instance of ReservationSlotsListResponse.
61617 61618 61619 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61617 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
The unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
61584 61585 61586 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61584 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::ReservationSlot>
A list of reservation slot resources.
Corresponds to the JSON property items
61589 61590 61591 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61589 def items @items end |
#kind ⇒ String
The type of resource. Alwayscompute#reservationSlot for a list of reservation
slots.
Corresponds to the JSON property kind
61595 61596 61597 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61595 def kind @kind end |
#next_page_token ⇒ String
This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
61605 61606 61607 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61605 def next_page_token @next_page_token end |
#self_link ⇒ String
The server-defined URL for this resource.
Corresponds to the JSON property selfLink
61610 61611 61612 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61610 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::ReservationSlotsListResponse::Warning
An informational warning message.
Corresponds to the JSON property warning
61615 61616 61617 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61615 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
61622 61623 61624 61625 61626 61627 61628 61629 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61622 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |