Class: Google::Apis::ComputeAlpha::ReservationSlotsListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

A list of reservation slots within a single reservation.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReservationSlotsListResponse

Returns a new instance of ReservationSlotsListResponse.



59712
59713
59714
# File 'lib/google/apis/compute_alpha/classes.rb', line 59712

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

The unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


59679
59680
59681
# File 'lib/google/apis/compute_alpha/classes.rb', line 59679

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::ReservationSlot>

A list of reservation slot resources. Corresponds to the JSON property items



59684
59685
59686
# File 'lib/google/apis/compute_alpha/classes.rb', line 59684

def items
  @items
end

#kindString

The type of resource. Alwayscompute#reservationSlot for a list of reservation slots. Corresponds to the JSON property kind

Returns:

  • (String)


59690
59691
59692
# File 'lib/google/apis/compute_alpha/classes.rb', line 59690

def kind
  @kind
end

#next_page_tokenString

This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


59700
59701
59702
# File 'lib/google/apis/compute_alpha/classes.rb', line 59700

def next_page_token
  @next_page_token
end

The server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


59705
59706
59707
# File 'lib/google/apis/compute_alpha/classes.rb', line 59705

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::ReservationSlotsListResponse::Warning

An informational warning message. Corresponds to the JSON property warning



59710
59711
59712
# File 'lib/google/apis/compute_alpha/classes.rb', line 59710

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



59717
59718
59719
59720
59721
59722
59723
59724
# File 'lib/google/apis/compute_alpha/classes.rb', line 59717

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end