Class: Google::Apis::ComputeAlpha::ReservationSlotsListResponse
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::ReservationSlotsListResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
A list of reservation slots within a single reservation.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
The unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::ReservationSlot>
A list of reservation slot resources.
-
#kind ⇒ String
The type of resource.
-
#next_page_token ⇒ String
This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
The server-defined URL for this resource.
-
#warning ⇒ Google::Apis::ComputeAlpha::ReservationSlotsListResponse::Warning
An informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReservationSlotsListResponse
constructor
A new instance of ReservationSlotsListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReservationSlotsListResponse
Returns a new instance of ReservationSlotsListResponse.
59695 59696 59697 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59695 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
The unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
59662 59663 59664 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59662 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::ReservationSlot>
A list of reservation slot resources.
Corresponds to the JSON property items
59667 59668 59669 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59667 def items @items end |
#kind ⇒ String
The type of resource. Alwayscompute#reservationSlot for a list of reservation
slots.
Corresponds to the JSON property kind
59673 59674 59675 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59673 def kind @kind end |
#next_page_token ⇒ String
This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
59683 59684 59685 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59683 def next_page_token @next_page_token end |
#self_link ⇒ String
The server-defined URL for this resource.
Corresponds to the JSON property selfLink
59688 59689 59690 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59688 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::ReservationSlotsListResponse::Warning
An informational warning message.
Corresponds to the JSON property warning
59693 59694 59695 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59693 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
59700 59701 59702 59703 59704 59705 59706 59707 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59700 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |