Class: Google::Apis::ComputeAlpha::ReservationSlotsListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

A list of reservation slots within a single reservation.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReservationSlotsListResponse

Returns a new instance of ReservationSlotsListResponse.



59133
59134
59135
# File 'lib/google/apis/compute_alpha/classes.rb', line 59133

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

The unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


59100
59101
59102
# File 'lib/google/apis/compute_alpha/classes.rb', line 59100

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::ReservationSlot>

A list of reservation slot resources. Corresponds to the JSON property items



59105
59106
59107
# File 'lib/google/apis/compute_alpha/classes.rb', line 59105

def items
  @items
end

#kindString

The type of resource. Alwayscompute#reservationSlot for a list of reservation slots. Corresponds to the JSON property kind

Returns:

  • (String)


59111
59112
59113
# File 'lib/google/apis/compute_alpha/classes.rb', line 59111

def kind
  @kind
end

#next_page_tokenString

This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


59121
59122
59123
# File 'lib/google/apis/compute_alpha/classes.rb', line 59121

def next_page_token
  @next_page_token
end

The server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


59126
59127
59128
# File 'lib/google/apis/compute_alpha/classes.rb', line 59126

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::ReservationSlotsListResponse::Warning

An informational warning message. Corresponds to the JSON property warning



59131
59132
59133
# File 'lib/google/apis/compute_alpha/classes.rb', line 59131

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



59138
59139
59140
59141
59142
59143
59144
59145
# File 'lib/google/apis/compute_alpha/classes.rb', line 59138

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end