Class: Google::Apis::ComputeAlpha::ReservationSlotsListResponse
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::ReservationSlotsListResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
A list of reservation slots within a single reservation.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
The unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::ReservationSlot>
A list of reservation slot resources.
-
#kind ⇒ String
The type of resource.
-
#next_page_token ⇒ String
This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
The server-defined URL for this resource.
-
#warning ⇒ Google::Apis::ComputeAlpha::ReservationSlotsListResponse::Warning
An informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReservationSlotsListResponse
constructor
A new instance of ReservationSlotsListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReservationSlotsListResponse
Returns a new instance of ReservationSlotsListResponse.
58912 58913 58914 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58912 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
The unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
58879 58880 58881 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58879 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::ReservationSlot>
A list of reservation slot resources.
Corresponds to the JSON property items
58884 58885 58886 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58884 def items @items end |
#kind ⇒ String
The type of resource. Alwayscompute#reservationSlot for a list of reservation
slots.
Corresponds to the JSON property kind
58890 58891 58892 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58890 def kind @kind end |
#next_page_token ⇒ String
This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
58900 58901 58902 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58900 def next_page_token @next_page_token end |
#self_link ⇒ String
The server-defined URL for this resource.
Corresponds to the JSON property selfLink
58905 58906 58907 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58905 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::ReservationSlotsListResponse::Warning
An informational warning message.
Corresponds to the JSON property warning
58910 58911 58912 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58910 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
58917 58918 58919 58920 58921 58922 58923 58924 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58917 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |