Class: Google::Apis::ComputeAlpha::ReservationSlotsListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

A list of reservation slots within a single reservation.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReservationSlotsListResponse

Returns a new instance of ReservationSlotsListResponse.



58075
58076
58077
# File 'lib/google/apis/compute_alpha/classes.rb', line 58075

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

The unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


58042
58043
58044
# File 'lib/google/apis/compute_alpha/classes.rb', line 58042

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::ReservationSlot>

A list of reservation slot resources. Corresponds to the JSON property items



58047
58048
58049
# File 'lib/google/apis/compute_alpha/classes.rb', line 58047

def items
  @items
end

#kindString

The type of resource. Alwayscompute#reservationSlot for a list of reservation slots. Corresponds to the JSON property kind

Returns:

  • (String)


58053
58054
58055
# File 'lib/google/apis/compute_alpha/classes.rb', line 58053

def kind
  @kind
end

#next_page_tokenString

This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


58063
58064
58065
# File 'lib/google/apis/compute_alpha/classes.rb', line 58063

def next_page_token
  @next_page_token
end

The server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


58068
58069
58070
# File 'lib/google/apis/compute_alpha/classes.rb', line 58068

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::ReservationSlotsListResponse::Warning

An informational warning message. Corresponds to the JSON property warning



58073
58074
58075
# File 'lib/google/apis/compute_alpha/classes.rb', line 58073

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



58080
58081
58082
58083
58084
58085
58086
58087
# File 'lib/google/apis/compute_alpha/classes.rb', line 58080

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end