Class: Google::Apis::ComputeAlpha::ReservationSubBlock
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::ReservationSubBlock
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Represents a reservation subBlock resource.
Instance Attribute Summary collapse
-
#accelerator_topologies_info ⇒ Google::Apis::ComputeAlpha::AcceleratorTopologiesInfo
Info for accelerator topologies within a densely packed reservation.
-
#count ⇒ Fixnum
Output only.
-
#creation_timestamp ⇒ String
Output only.
-
#health_info ⇒ Google::Apis::ComputeAlpha::ReservationSubBlockHealthInfo
Health information for the reservation subBlock.
-
#id ⇒ Fixnum
Output only.
-
#in_use_count ⇒ Fixnum
Output only.
-
#in_use_host_count ⇒ Fixnum
Output only.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
Output only.
-
#physical_topology ⇒ Google::Apis::ComputeAlpha::ReservationSubBlockPhysicalTopology
Output only.
-
#reservation_sub_block_maintenance ⇒ Google::Apis::ComputeAlpha::GroupMaintenanceInfo
Maintenance Info for ReservationBlocks.
-
#retention_priority ⇒ Fixnum
Customer specified retention priority for power shedding events.
-
#self_link ⇒ String
Output only.
-
#self_link_with_id ⇒ String
Output only.
-
#status ⇒ String
Output only.
-
#zone ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReservationSubBlock
constructor
A new instance of ReservationSubBlock.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReservationSubBlock
Returns a new instance of ReservationSubBlock.
61534 61535 61536 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61534 def initialize(**args) update!(**args) end |
Instance Attribute Details
#accelerator_topologies_info ⇒ Google::Apis::ComputeAlpha::AcceleratorTopologiesInfo
Info for accelerator topologies within a densely packed reservation.
Corresponds to the JSON property acceleratorTopologiesInfo
61442 61443 61444 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61442 def accelerator_topologies_info @accelerator_topologies_info end |
#count ⇒ Fixnum
Output only. [Output Only] The number of hosts that are allocated in this
reservation subBlock.
Corresponds to the JSON property count
61448 61449 61450 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61448 def count @count end |
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339 text format.
Corresponds to the JSON property creationTimestamp
61453 61454 61455 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61453 def @creation_timestamp end |
#health_info ⇒ Google::Apis::ComputeAlpha::ReservationSubBlockHealthInfo
Health information for the reservation subBlock.
Corresponds to the JSON property healthInfo
61458 61459 61460 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61458 def health_info @health_info end |
#id ⇒ Fixnum
Output only. [Output Only] The unique identifier for the resource. This
identifier is
defined by the server.
Corresponds to the JSON property id
61465 61466 61467 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61465 def id @id end |
#in_use_count ⇒ Fixnum
Output only. [Output Only] The number of instances that are currently in use
on this
reservation subBlock.
Corresponds to the JSON property inUseCount
61472 61473 61474 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61472 def in_use_count @in_use_count end |
#in_use_host_count ⇒ Fixnum
Output only. Number of hosts currently in use. If there is one or more
Instances running
on the host, it is considered in use.
Corresponds to the JSON property inUseHostCount
61479 61480 61481 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61479 def in_use_host_count @in_use_host_count end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#
reservationSubBlock for reservation subBlocks.
Corresponds to the JSON property kind
61485 61486 61487 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61485 def kind @kind end |
#name ⇒ String
Output only. [Output Only] The name of this reservation subBlock generated by
Google
Compute Engine. The name must be 1-63 characters long, and comply with
RFC1035 @pattern a-z?
Corresponds to the JSON property name
61493 61494 61495 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61493 def name @name end |
#physical_topology ⇒ Google::Apis::ComputeAlpha::ReservationSubBlockPhysicalTopology
Output only. [Output Only] The physical topology of the reservation subBlock.
Corresponds to the JSON property physicalTopology
61498 61499 61500 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61498 def physical_topology @physical_topology end |
#reservation_sub_block_maintenance ⇒ Google::Apis::ComputeAlpha::GroupMaintenanceInfo
Maintenance Info for ReservationBlocks.
Corresponds to the JSON property reservationSubBlockMaintenance
61503 61504 61505 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61503 def reservation_sub_block_maintenance @reservation_sub_block_maintenance end |
#retention_priority ⇒ Fixnum
Customer specified retention priority for power shedding events.
Used to determine priority of the subBlock relative to others during
a power shedding event. Higher priorities are retained over lower ones.
Corresponds to the JSON property retentionPriority
61510 61511 61512 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61510 def retention_priority @retention_priority end |
#self_link ⇒ String
Output only. [Output Only] Server-defined fully-qualified URL for this
resource.
Corresponds to the JSON property selfLink
61516 61517 61518 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61516 def self_link @self_link end |
#self_link_with_id ⇒ String
Output only. [Output Only] Server-defined URL for this resource with the
resource id.
Corresponds to the JSON property selfLinkWithId
61522 61523 61524 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61522 def self_link_with_id @self_link_with_id end |
#status ⇒ String
Output only. [Output Only] Status of the reservation subBlock.
Corresponds to the JSON property status
61527 61528 61529 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61527 def status @status end |
#zone ⇒ String
Output only. [Output Only] Zone in which the reservation subBlock resides.
Corresponds to the JSON property zone
61532 61533 61534 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61532 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
61539 61540 61541 61542 61543 61544 61545 61546 61547 61548 61549 61550 61551 61552 61553 61554 61555 61556 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61539 def update!(**args) @accelerator_topologies_info = args[:accelerator_topologies_info] if args.key?(:accelerator_topologies_info) @count = args[:count] if args.key?(:count) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @health_info = args[:health_info] if args.key?(:health_info) @id = args[:id] if args.key?(:id) @in_use_count = args[:in_use_count] if args.key?(:in_use_count) @in_use_host_count = args[:in_use_host_count] if args.key?(:in_use_host_count) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @physical_topology = args[:physical_topology] if args.key?(:physical_topology) @reservation_sub_block_maintenance = args[:reservation_sub_block_maintenance] if args.key?(:reservation_sub_block_maintenance) @retention_priority = args[:retention_priority] if args.key?(:retention_priority) @self_link = args[:self_link] if args.key?(:self_link) @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id) @status = args[:status] if args.key?(:status) @zone = args[:zone] if args.key?(:zone) end |