Class: Google::Apis::ComputeAlpha::ReservationSubBlock
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::ReservationSubBlock
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Represents a reservation subBlock resource.
Instance Attribute Summary collapse
-
#accelerator_topologies_info ⇒ Google::Apis::ComputeAlpha::AcceleratorTopologiesInfo
Info for accelerator topologies within a densely packed reservation.
-
#count ⇒ Fixnum
Output only.
-
#creation_timestamp ⇒ String
Output only.
-
#id ⇒ Fixnum
Output only.
-
#in_use_count ⇒ Fixnum
Output only.
-
#in_use_host_count ⇒ Fixnum
Output only.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
Output only.
-
#physical_topology ⇒ Google::Apis::ComputeAlpha::ReservationSubBlockPhysicalTopology
Output only.
-
#reservation_sub_block_maintenance ⇒ Google::Apis::ComputeAlpha::GroupMaintenanceInfo
Maintenance Info for ReservationBlocks.
-
#retention_priority ⇒ Fixnum
Customer specified retention priority for power shedding events.
-
#self_link ⇒ String
Output only.
-
#self_link_with_id ⇒ String
Output only.
-
#status ⇒ String
Output only.
-
#sub_block_health_info ⇒ Google::Apis::ComputeAlpha::ReservationSubBlockHealthInfo
Health information for the reservation subBlock.
-
#zone ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReservationSubBlock
constructor
A new instance of ReservationSubBlock.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReservationSubBlock
Returns a new instance of ReservationSubBlock.
59896 59897 59898 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59896 def initialize(**args) update!(**args) end |
Instance Attribute Details
#accelerator_topologies_info ⇒ Google::Apis::ComputeAlpha::AcceleratorTopologiesInfo
Info for accelerator topologies within a densely packed reservation.
Corresponds to the JSON property acceleratorTopologiesInfo
59804 59805 59806 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59804 def accelerator_topologies_info @accelerator_topologies_info end |
#count ⇒ Fixnum
Output only. [Output Only] The number of hosts that are allocated in this
reservation subBlock.
Corresponds to the JSON property count
59810 59811 59812 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59810 def count @count end |
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339 text format.
Corresponds to the JSON property creationTimestamp
59815 59816 59817 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59815 def @creation_timestamp end |
#id ⇒ Fixnum
Output only. [Output Only] The unique identifier for the resource. This
identifier is
defined by the server.
Corresponds to the JSON property id
59822 59823 59824 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59822 def id @id end |
#in_use_count ⇒ Fixnum
Output only. [Output Only] The number of instances that are currently in use
on this
reservation subBlock.
Corresponds to the JSON property inUseCount
59829 59830 59831 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59829 def in_use_count @in_use_count end |
#in_use_host_count ⇒ Fixnum
Output only. Number of hosts currently in use. If there is one or more
Instances running
on the host, it is considered in use.
Corresponds to the JSON property inUseHostCount
59836 59837 59838 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59836 def in_use_host_count @in_use_host_count end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#
reservationSubBlock for reservation subBlocks.
Corresponds to the JSON property kind
59842 59843 59844 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59842 def kind @kind end |
#name ⇒ String
Output only. [Output Only] The name of this reservation subBlock generated by
Google
Compute Engine. The name must be 1-63 characters long, and comply with
RFC1035 @pattern a-z?
Corresponds to the JSON property name
59850 59851 59852 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59850 def name @name end |
#physical_topology ⇒ Google::Apis::ComputeAlpha::ReservationSubBlockPhysicalTopology
Output only. [Output Only] The physical topology of the reservation subBlock.
Corresponds to the JSON property physicalTopology
59855 59856 59857 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59855 def physical_topology @physical_topology end |
#reservation_sub_block_maintenance ⇒ Google::Apis::ComputeAlpha::GroupMaintenanceInfo
Maintenance Info for ReservationBlocks.
Corresponds to the JSON property reservationSubBlockMaintenance
59860 59861 59862 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59860 def reservation_sub_block_maintenance @reservation_sub_block_maintenance end |
#retention_priority ⇒ Fixnum
Customer specified retention priority for power shedding events.
Used to determine priority of the subBlock relative to others during
a power shedding event. Higher priorities are retained over lower ones.
Corresponds to the JSON property retentionPriority
59867 59868 59869 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59867 def retention_priority @retention_priority end |
#self_link ⇒ String
Output only. [Output Only] Server-defined fully-qualified URL for this
resource.
Corresponds to the JSON property selfLink
59873 59874 59875 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59873 def self_link @self_link end |
#self_link_with_id ⇒ String
Output only. [Output Only] Server-defined URL for this resource with the
resource id.
Corresponds to the JSON property selfLinkWithId
59879 59880 59881 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59879 def self_link_with_id @self_link_with_id end |
#status ⇒ String
Output only. [Output Only] Status of the reservation subBlock.
Corresponds to the JSON property status
59884 59885 59886 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59884 def status @status end |
#sub_block_health_info ⇒ Google::Apis::ComputeAlpha::ReservationSubBlockHealthInfo
Health information for the reservation subBlock.
Corresponds to the JSON property subBlockHealthInfo
59889 59890 59891 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59889 def sub_block_health_info @sub_block_health_info end |
#zone ⇒ String
Output only. [Output Only] Zone in which the reservation subBlock resides.
Corresponds to the JSON property zone
59894 59895 59896 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59894 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
59901 59902 59903 59904 59905 59906 59907 59908 59909 59910 59911 59912 59913 59914 59915 59916 59917 59918 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59901 def update!(**args) @accelerator_topologies_info = args[:accelerator_topologies_info] if args.key?(:accelerator_topologies_info) @count = args[:count] if args.key?(:count) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @id = args[:id] if args.key?(:id) @in_use_count = args[:in_use_count] if args.key?(:in_use_count) @in_use_host_count = args[:in_use_host_count] if args.key?(:in_use_host_count) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @physical_topology = args[:physical_topology] if args.key?(:physical_topology) @reservation_sub_block_maintenance = args[:reservation_sub_block_maintenance] if args.key?(:reservation_sub_block_maintenance) @retention_priority = args[:retention_priority] if args.key?(:retention_priority) @self_link = args[:self_link] if args.key?(:self_link) @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id) @status = args[:status] if args.key?(:status) @sub_block_health_info = args[:sub_block_health_info] if args.key?(:sub_block_health_info) @zone = args[:zone] if args.key?(:zone) end |