Class: Google::Apis::ComputeAlpha::ReservationSubBlock

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Represents a reservation subBlock resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReservationSubBlock

Returns a new instance of ReservationSubBlock.



59312
59313
59314
# File 'lib/google/apis/compute_alpha/classes.rb', line 59312

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#accelerator_topologies_infoGoogle::Apis::ComputeAlpha::AcceleratorTopologiesInfo

Info for accelerator topologies within a densely packed reservation. Corresponds to the JSON property acceleratorTopologiesInfo



59227
59228
59229
# File 'lib/google/apis/compute_alpha/classes.rb', line 59227

def accelerator_topologies_info
  @accelerator_topologies_info
end

#countFixnum

Output only. [Output Only] The number of hosts that are allocated in this reservation subBlock. Corresponds to the JSON property count

Returns:

  • (Fixnum)


59233
59234
59235
# File 'lib/google/apis/compute_alpha/classes.rb', line 59233

def count
  @count
end

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


59238
59239
59240
# File 'lib/google/apis/compute_alpha/classes.rb', line 59238

def creation_timestamp
  @creation_timestamp
end

#health_infoGoogle::Apis::ComputeAlpha::ReservationSubBlockHealthInfo

Health information for the reservation subBlock. Corresponds to the JSON property healthInfo



59243
59244
59245
# File 'lib/google/apis/compute_alpha/classes.rb', line 59243

def health_info
  @health_info
end

#idFixnum

Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


59250
59251
59252
# File 'lib/google/apis/compute_alpha/classes.rb', line 59250

def id
  @id
end

#in_use_countFixnum

Output only. [Output Only] The number of instances that are currently in use on this reservation subBlock. Corresponds to the JSON property inUseCount

Returns:

  • (Fixnum)


59257
59258
59259
# File 'lib/google/apis/compute_alpha/classes.rb', line 59257

def in_use_count
  @in_use_count
end

#in_use_host_countFixnum

Output only. Number of hosts currently in use. If there is one or more Instances running on the host, it is considered in use. Corresponds to the JSON property inUseHostCount

Returns:

  • (Fixnum)


59264
59265
59266
# File 'lib/google/apis/compute_alpha/classes.rb', line 59264

def in_use_host_count
  @in_use_host_count
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# reservationSubBlock for reservation subBlocks. Corresponds to the JSON property kind

Returns:

  • (String)


59270
59271
59272
# File 'lib/google/apis/compute_alpha/classes.rb', line 59270

def kind
  @kind
end

#nameString

Output only. [Output Only] The name of this reservation subBlock generated by Google Compute Engine. The name must be 1-63 characters long, and comply with RFC1035 @pattern a-z? Corresponds to the JSON property name

Returns:

  • (String)


59278
59279
59280
# File 'lib/google/apis/compute_alpha/classes.rb', line 59278

def name
  @name
end

#physical_topologyGoogle::Apis::ComputeAlpha::ReservationSubBlockPhysicalTopology

Output only. [Output Only] The physical topology of the reservation subBlock. Corresponds to the JSON property physicalTopology



59283
59284
59285
# File 'lib/google/apis/compute_alpha/classes.rb', line 59283

def physical_topology
  @physical_topology
end

#reservation_sub_block_maintenanceGoogle::Apis::ComputeAlpha::GroupMaintenanceInfo

Maintenance Info for ReservationBlocks. Corresponds to the JSON property reservationSubBlockMaintenance



59288
59289
59290
# File 'lib/google/apis/compute_alpha/classes.rb', line 59288

def reservation_sub_block_maintenance
  @reservation_sub_block_maintenance
end

Output only. [Output Only] Server-defined fully-qualified URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


59294
59295
59296
# File 'lib/google/apis/compute_alpha/classes.rb', line 59294

def self_link
  @self_link
end

Output only. [Output Only] Server-defined URL for this resource with the resource id. Corresponds to the JSON property selfLinkWithId

Returns:

  • (String)


59300
59301
59302
# File 'lib/google/apis/compute_alpha/classes.rb', line 59300

def self_link_with_id
  @self_link_with_id
end

#statusString

Output only. [Output Only] Status of the reservation subBlock. Corresponds to the JSON property status

Returns:

  • (String)


59305
59306
59307
# File 'lib/google/apis/compute_alpha/classes.rb', line 59305

def status
  @status
end

#zoneString

Output only. [Output Only] Zone in which the reservation subBlock resides. Corresponds to the JSON property zone

Returns:

  • (String)


59310
59311
59312
# File 'lib/google/apis/compute_alpha/classes.rb', line 59310

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



59317
59318
59319
59320
59321
59322
59323
59324
59325
59326
59327
59328
59329
59330
59331
59332
59333
# File 'lib/google/apis/compute_alpha/classes.rb', line 59317

def update!(**args)
  @accelerator_topologies_info = args[:accelerator_topologies_info] if args.key?(:accelerator_topologies_info)
  @count = args[:count] if args.key?(:count)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @health_info = args[:health_info] if args.key?(:health_info)
  @id = args[:id] if args.key?(:id)
  @in_use_count = args[:in_use_count] if args.key?(:in_use_count)
  @in_use_host_count = args[:in_use_host_count] if args.key?(:in_use_host_count)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @physical_topology = args[:physical_topology] if args.key?(:physical_topology)
  @reservation_sub_block_maintenance = args[:reservation_sub_block_maintenance] if args.key?(:reservation_sub_block_maintenance)
  @self_link = args[:self_link] if args.key?(:self_link)
  @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id)
  @status = args[:status] if args.key?(:status)
  @zone = args[:zone] if args.key?(:zone)
end