Class: Google::Apis::ComputeAlpha::ReservationSubBlock
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::ReservationSubBlock
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Represents a reservation subBlock resource.
Instance Attribute Summary collapse
-
#accelerator_topologies_info ⇒ Google::Apis::ComputeAlpha::AcceleratorTopologiesInfo
Info for accelerator topologies within a densely packed reservation.
-
#count ⇒ Fixnum
Output only.
-
#creation_timestamp ⇒ String
Output only.
-
#health_info ⇒ Google::Apis::ComputeAlpha::ReservationSubBlockHealthInfo
Health information for the reservation subBlock.
-
#id ⇒ Fixnum
Output only.
-
#in_use_count ⇒ Fixnum
Output only.
-
#in_use_host_count ⇒ Fixnum
Output only.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
Output only.
-
#physical_topology ⇒ Google::Apis::ComputeAlpha::ReservationSubBlockPhysicalTopology
Output only.
-
#reservation_sub_block_maintenance ⇒ Google::Apis::ComputeAlpha::GroupMaintenanceInfo
Maintenance Info for ReservationBlocks.
-
#self_link ⇒ String
Output only.
-
#self_link_with_id ⇒ String
Output only.
-
#status ⇒ String
Output only.
-
#zone ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReservationSubBlock
constructor
A new instance of ReservationSubBlock.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReservationSubBlock
Returns a new instance of ReservationSubBlock.
59310 59311 59312 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59310 def initialize(**args) update!(**args) end |
Instance Attribute Details
#accelerator_topologies_info ⇒ Google::Apis::ComputeAlpha::AcceleratorTopologiesInfo
Info for accelerator topologies within a densely packed reservation.
Corresponds to the JSON property acceleratorTopologiesInfo
59225 59226 59227 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59225 def accelerator_topologies_info @accelerator_topologies_info end |
#count ⇒ Fixnum
Output only. [Output Only] The number of hosts that are allocated in this
reservation subBlock.
Corresponds to the JSON property count
59231 59232 59233 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59231 def count @count end |
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339 text format.
Corresponds to the JSON property creationTimestamp
59236 59237 59238 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59236 def @creation_timestamp end |
#health_info ⇒ Google::Apis::ComputeAlpha::ReservationSubBlockHealthInfo
Health information for the reservation subBlock.
Corresponds to the JSON property healthInfo
59241 59242 59243 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59241 def health_info @health_info end |
#id ⇒ Fixnum
Output only. [Output Only] The unique identifier for the resource. This
identifier is
defined by the server.
Corresponds to the JSON property id
59248 59249 59250 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59248 def id @id end |
#in_use_count ⇒ Fixnum
Output only. [Output Only] The number of instances that are currently in use
on this
reservation subBlock.
Corresponds to the JSON property inUseCount
59255 59256 59257 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59255 def in_use_count @in_use_count end |
#in_use_host_count ⇒ Fixnum
Output only. Number of hosts currently in use. If there is one or more
Instances running
on the host, it is considered in use.
Corresponds to the JSON property inUseHostCount
59262 59263 59264 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59262 def in_use_host_count @in_use_host_count end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#
reservationSubBlock for reservation subBlocks.
Corresponds to the JSON property kind
59268 59269 59270 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59268 def kind @kind end |
#name ⇒ String
Output only. [Output Only] The name of this reservation subBlock generated by
Google
Compute Engine. The name must be 1-63 characters long, and comply with
RFC1035 @pattern a-z?
Corresponds to the JSON property name
59276 59277 59278 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59276 def name @name end |
#physical_topology ⇒ Google::Apis::ComputeAlpha::ReservationSubBlockPhysicalTopology
Output only. [Output Only] The physical topology of the reservation subBlock.
Corresponds to the JSON property physicalTopology
59281 59282 59283 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59281 def physical_topology @physical_topology end |
#reservation_sub_block_maintenance ⇒ Google::Apis::ComputeAlpha::GroupMaintenanceInfo
Maintenance Info for ReservationBlocks.
Corresponds to the JSON property reservationSubBlockMaintenance
59286 59287 59288 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59286 def reservation_sub_block_maintenance @reservation_sub_block_maintenance end |
#self_link ⇒ String
Output only. [Output Only] Server-defined fully-qualified URL for this
resource.
Corresponds to the JSON property selfLink
59292 59293 59294 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59292 def self_link @self_link end |
#self_link_with_id ⇒ String
Output only. [Output Only] Server-defined URL for this resource with the
resource id.
Corresponds to the JSON property selfLinkWithId
59298 59299 59300 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59298 def self_link_with_id @self_link_with_id end |
#status ⇒ String
Output only. [Output Only] Status of the reservation subBlock.
Corresponds to the JSON property status
59303 59304 59305 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59303 def status @status end |
#zone ⇒ String
Output only. [Output Only] Zone in which the reservation subBlock resides.
Corresponds to the JSON property zone
59308 59309 59310 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59308 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
59315 59316 59317 59318 59319 59320 59321 59322 59323 59324 59325 59326 59327 59328 59329 59330 59331 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59315 def update!(**args) @accelerator_topologies_info = args[:accelerator_topologies_info] if args.key?(:accelerator_topologies_info) @count = args[:count] if args.key?(:count) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @health_info = args[:health_info] if args.key?(:health_info) @id = args[:id] if args.key?(:id) @in_use_count = args[:in_use_count] if args.key?(:in_use_count) @in_use_host_count = args[:in_use_host_count] if args.key?(:in_use_host_count) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @physical_topology = args[:physical_topology] if args.key?(:physical_topology) @reservation_sub_block_maintenance = args[:reservation_sub_block_maintenance] if args.key?(:reservation_sub_block_maintenance) @self_link = args[:self_link] if args.key?(:self_link) @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id) @status = args[:status] if args.key?(:status) @zone = args[:zone] if args.key?(:zone) end |