Class: Google::Apis::ComputeAlpha::ReservationSubBlockHealthInfo
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::ReservationSubBlockHealthInfo
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Health information for the reservation subBlock.
Instance Attribute Summary collapse
-
#degraded_host_count ⇒ Fixnum
The number of degraded hosts in the reservation subBlock.
-
#degraded_infra_count ⇒ Fixnum
The number of degraded infrastructure (e.g NV link domain) in the reservation subblock.
-
#health_status ⇒ String
The health status of the reservation subBlock.
-
#healthy_host_count ⇒ Fixnum
The number of healthy hosts in the reservation subBlock.
-
#healthy_infra_count ⇒ Fixnum
The number of healthy infrastructure (e.g NV link domain) in the reservation subblock.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReservationSubBlockHealthInfo
constructor
A new instance of ReservationSubBlockHealthInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReservationSubBlockHealthInfo
Returns a new instance of ReservationSubBlockHealthInfo.
61305 61306 61307 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61305 def initialize(**args) update!(**args) end |
Instance Attribute Details
#degraded_host_count ⇒ Fixnum
The number of degraded hosts in the reservation subBlock.
Corresponds to the JSON property degradedHostCount
61281 61282 61283 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61281 def degraded_host_count @degraded_host_count end |
#degraded_infra_count ⇒ Fixnum
The number of degraded infrastructure (e.g NV link domain) in the
reservation subblock.
Corresponds to the JSON property degradedInfraCount
61287 61288 61289 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61287 def degraded_infra_count @degraded_infra_count end |
#health_status ⇒ String
The health status of the reservation subBlock.
Corresponds to the JSON property healthStatus
61292 61293 61294 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61292 def health_status @health_status end |
#healthy_host_count ⇒ Fixnum
The number of healthy hosts in the reservation subBlock.
Corresponds to the JSON property healthyHostCount
61297 61298 61299 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61297 def healthy_host_count @healthy_host_count end |
#healthy_infra_count ⇒ Fixnum
The number of healthy infrastructure (e.g NV link domain) in the
reservation subblock.
Corresponds to the JSON property healthyInfraCount
61303 61304 61305 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61303 def healthy_infra_count @healthy_infra_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
61310 61311 61312 61313 61314 61315 61316 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61310 def update!(**args) @degraded_host_count = args[:degraded_host_count] if args.key?(:degraded_host_count) @degraded_infra_count = args[:degraded_infra_count] if args.key?(:degraded_infra_count) @health_status = args[:health_status] if args.key?(:health_status) @healthy_host_count = args[:healthy_host_count] if args.key?(:healthy_host_count) @healthy_infra_count = args[:healthy_infra_count] if args.key?(:healthy_infra_count) end |