Class: Google::Apis::ComputeAlpha::ReservationSubBlockHealthInfo

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Health information for the reservation subBlock.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReservationSubBlockHealthInfo

Returns a new instance of ReservationSubBlockHealthInfo.



59927
59928
59929
# File 'lib/google/apis/compute_alpha/classes.rb', line 59927

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#degraded_host_countFixnum

The number of degraded hosts in the reservation subBlock. Corresponds to the JSON property degradedHostCount

Returns:

  • (Fixnum)


59903
59904
59905
# File 'lib/google/apis/compute_alpha/classes.rb', line 59903

def degraded_host_count
  @degraded_host_count
end

#degraded_infra_countFixnum

The number of degraded infrastructure (e.g NV link domain) in the reservation subblock. Corresponds to the JSON property degradedInfraCount

Returns:

  • (Fixnum)


59909
59910
59911
# File 'lib/google/apis/compute_alpha/classes.rb', line 59909

def degraded_infra_count
  @degraded_infra_count
end

#health_statusString

The health status of the reservation subBlock. Corresponds to the JSON property healthStatus

Returns:

  • (String)


59914
59915
59916
# File 'lib/google/apis/compute_alpha/classes.rb', line 59914

def health_status
  @health_status
end

#healthy_host_countFixnum

The number of healthy hosts in the reservation subBlock. Corresponds to the JSON property healthyHostCount

Returns:

  • (Fixnum)


59919
59920
59921
# File 'lib/google/apis/compute_alpha/classes.rb', line 59919

def healthy_host_count
  @healthy_host_count
end

#healthy_infra_countFixnum

The number of healthy infrastructure (e.g NV link domain) in the reservation subblock. Corresponds to the JSON property healthyInfraCount

Returns:

  • (Fixnum)


59925
59926
59927
# File 'lib/google/apis/compute_alpha/classes.rb', line 59925

def healthy_infra_count
  @healthy_infra_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



59932
59933
59934
59935
59936
59937
59938
# File 'lib/google/apis/compute_alpha/classes.rb', line 59932

def update!(**args)
  @degraded_host_count = args[:degraded_host_count] if args.key?(:degraded_host_count)
  @degraded_infra_count = args[:degraded_infra_count] if args.key?(:degraded_infra_count)
  @health_status = args[:health_status] if args.key?(:health_status)
  @healthy_host_count = args[:healthy_host_count] if args.key?(:healthy_host_count)
  @healthy_infra_count = args[:healthy_infra_count] if args.key?(:healthy_infra_count)
end