Class: Google::Apis::ComputeAlpha::ReservationSubBlocksListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

A list of reservation subBlocks under a single reservation.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReservationSubBlocksListResponse

Returns a new instance of ReservationSubBlocksListResponse.



61429
61430
61431
# File 'lib/google/apis/compute_alpha/classes.rb', line 61429

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


61395
61396
61397
# File 'lib/google/apis/compute_alpha/classes.rb', line 61395

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::ReservationSubBlock>

A list of reservation subBlock resources. Corresponds to the JSON property items



61400
61401
61402
# File 'lib/google/apis/compute_alpha/classes.rb', line 61400

def items
  @items
end

#kindString

Type of the resource. Alwayscompute#reservationSubBlock for a list of reservation subBlocks. Corresponds to the JSON property kind

Returns:

  • (String)


61407
61408
61409
# File 'lib/google/apis/compute_alpha/classes.rb', line 61407

def kind
  @kind
end

#next_page_tokenString

This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


61417
61418
61419
# File 'lib/google/apis/compute_alpha/classes.rb', line 61417

def next_page_token
  @next_page_token
end

Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


61422
61423
61424
# File 'lib/google/apis/compute_alpha/classes.rb', line 61422

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::ReservationSubBlocksListResponse::Warning

Informational warning message. Corresponds to the JSON property warning



61427
61428
61429
# File 'lib/google/apis/compute_alpha/classes.rb', line 61427

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



61434
61435
61436
61437
61438
61439
61440
61441
# File 'lib/google/apis/compute_alpha/classes.rb', line 61434

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end