Class: Google::Apis::ComputeAlpha::ReservationSubBlocksListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

A list of reservation subBlocks under a single reservation.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReservationSubBlocksListResponse

Returns a new instance of ReservationSubBlocksListResponse.



60076
60077
60078
# File 'lib/google/apis/compute_alpha/classes.rb', line 60076

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


60042
60043
60044
# File 'lib/google/apis/compute_alpha/classes.rb', line 60042

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::ReservationSubBlock>

A list of reservation subBlock resources. Corresponds to the JSON property items



60047
60048
60049
# File 'lib/google/apis/compute_alpha/classes.rb', line 60047

def items
  @items
end

#kindString

Type of the resource. Alwayscompute#reservationSubBlock for a list of reservation subBlocks. Corresponds to the JSON property kind

Returns:

  • (String)


60054
60055
60056
# File 'lib/google/apis/compute_alpha/classes.rb', line 60054

def kind
  @kind
end

#next_page_tokenString

This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


60064
60065
60066
# File 'lib/google/apis/compute_alpha/classes.rb', line 60064

def next_page_token
  @next_page_token
end

Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


60069
60070
60071
# File 'lib/google/apis/compute_alpha/classes.rb', line 60069

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::ReservationSubBlocksListResponse::Warning

Informational warning message. Corresponds to the JSON property warning



60074
60075
60076
# File 'lib/google/apis/compute_alpha/classes.rb', line 60074

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



60081
60082
60083
60084
60085
60086
60087
60088
# File 'lib/google/apis/compute_alpha/classes.rb', line 60081

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end