Class: Google::Apis::ComputeAlpha::ReservationSubBlocksListResponse
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::ReservationSubBlocksListResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
A list of reservation subBlocks under a single reservation.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::ReservationSubBlock>
A list of reservation subBlock resources.
-
#kind ⇒ String
Type of the resource.
-
#next_page_token ⇒ String
This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Server-defined URL for this resource.
-
#warning ⇒ Google::Apis::ComputeAlpha::ReservationSubBlocksListResponse::Warning
Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReservationSubBlocksListResponse
constructor
A new instance of ReservationSubBlocksListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReservationSubBlocksListResponse
Returns a new instance of ReservationSubBlocksListResponse.
60051 60052 60053 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 60051 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
60017 60018 60019 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 60017 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::ReservationSubBlock>
A list of reservation subBlock resources.
Corresponds to the JSON property items
60022 60023 60024 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 60022 def items @items end |
#kind ⇒ String
Type of the resource. Alwayscompute#reservationSubBlock for a list of
reservation
subBlocks.
Corresponds to the JSON property kind
60029 60030 60031 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 60029 def kind @kind end |
#next_page_token ⇒ String
This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
60039 60040 60041 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 60039 def next_page_token @next_page_token end |
#self_link ⇒ String
Server-defined URL for this resource.
Corresponds to the JSON property selfLink
60044 60045 60046 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 60044 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::ReservationSubBlocksListResponse::Warning
Informational warning message.
Corresponds to the JSON property warning
60049 60050 60051 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 60049 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
60056 60057 60058 60059 60060 60061 60062 60063 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 60056 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |