Class: Google::Apis::ComputeAlpha::ReservationSubBlocksListResponse
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::ReservationSubBlocksListResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
A list of reservation subBlocks under a single reservation.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::ReservationSubBlock>
A list of reservation subBlock resources.
-
#kind ⇒ String
Type of the resource.
-
#next_page_token ⇒ String
This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Server-defined URL for this resource.
-
#warning ⇒ Google::Apis::ComputeAlpha::ReservationSubBlocksListResponse::Warning
Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReservationSubBlocksListResponse
constructor
A new instance of ReservationSubBlocksListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReservationSubBlocksListResponse
Returns a new instance of ReservationSubBlocksListResponse.
59491 59492 59493 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59491 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
59457 59458 59459 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59457 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::ReservationSubBlock>
A list of reservation subBlock resources.
Corresponds to the JSON property items
59462 59463 59464 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59462 def items @items end |
#kind ⇒ String
Type of the resource. Alwayscompute#reservationSubBlock for a list of
reservation
subBlocks.
Corresponds to the JSON property kind
59469 59470 59471 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59469 def kind @kind end |
#next_page_token ⇒ String
This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
59479 59480 59481 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59479 def next_page_token @next_page_token end |
#self_link ⇒ String
Server-defined URL for this resource.
Corresponds to the JSON property selfLink
59484 59485 59486 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59484 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::ReservationSubBlocksListResponse::Warning
Informational warning message.
Corresponds to the JSON property warning
59489 59490 59491 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59489 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
59496 59497 59498 59499 59500 59501 59502 59503 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59496 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |