Class: Google::Apis::ComputeAlpha::ReservationSubBlocksListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

A list of reservation subBlocks under a single reservation.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReservationSubBlocksListResponse

Returns a new instance of ReservationSubBlocksListResponse.



59489
59490
59491
# File 'lib/google/apis/compute_alpha/classes.rb', line 59489

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


59455
59456
59457
# File 'lib/google/apis/compute_alpha/classes.rb', line 59455

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::ReservationSubBlock>

A list of reservation subBlock resources. Corresponds to the JSON property items



59460
59461
59462
# File 'lib/google/apis/compute_alpha/classes.rb', line 59460

def items
  @items
end

#kindString

Type of the resource. Alwayscompute#reservationSubBlock for a list of reservation subBlocks. Corresponds to the JSON property kind

Returns:

  • (String)


59467
59468
59469
# File 'lib/google/apis/compute_alpha/classes.rb', line 59467

def kind
  @kind
end

#next_page_tokenString

This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


59477
59478
59479
# File 'lib/google/apis/compute_alpha/classes.rb', line 59477

def next_page_token
  @next_page_token
end

Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


59482
59483
59484
# File 'lib/google/apis/compute_alpha/classes.rb', line 59482

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::ReservationSubBlocksListResponse::Warning

Informational warning message. Corresponds to the JSON property warning



59487
59488
59489
# File 'lib/google/apis/compute_alpha/classes.rb', line 59487

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



59494
59495
59496
59497
59498
59499
59500
59501
# File 'lib/google/apis/compute_alpha/classes.rb', line 59494

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end