Class: Google::Apis::ComputeAlpha::ReservationSubBlocksListResponse
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::ReservationSubBlocksListResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
A list of reservation subBlocks under a single reservation.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::ReservationSubBlock>
A list of reservation subBlock resources.
-
#kind ⇒ String
Type of the resource.
-
#next_page_token ⇒ String
This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Server-defined URL for this resource.
-
#warning ⇒ Google::Apis::ComputeAlpha::ReservationSubBlocksListResponse::Warning
Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReservationSubBlocksListResponse
constructor
A new instance of ReservationSubBlocksListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReservationSubBlocksListResponse
Returns a new instance of ReservationSubBlocksListResponse.
59268 59269 59270 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59268 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
59234 59235 59236 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59234 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::ReservationSubBlock>
A list of reservation subBlock resources.
Corresponds to the JSON property items
59239 59240 59241 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59239 def items @items end |
#kind ⇒ String
Type of the resource. Alwayscompute#reservationSubBlock for a list of
reservation
subBlocks.
Corresponds to the JSON property kind
59246 59247 59248 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59246 def kind @kind end |
#next_page_token ⇒ String
This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
59256 59257 59258 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59256 def next_page_token @next_page_token end |
#self_link ⇒ String
Server-defined URL for this resource.
Corresponds to the JSON property selfLink
59261 59262 59263 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59261 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::ReservationSubBlocksListResponse::Warning
Informational warning message.
Corresponds to the JSON property warning
59266 59267 59268 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59266 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
59273 59274 59275 59276 59277 59278 59279 59280 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59273 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |