Class: Google::Apis::ComputeAlpha::ReservationSubBlocksListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

A list of reservation subBlocks under a single reservation.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReservationSubBlocksListResponse

Returns a new instance of ReservationSubBlocksListResponse.



58431
58432
58433
# File 'lib/google/apis/compute_alpha/classes.rb', line 58431

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


58397
58398
58399
# File 'lib/google/apis/compute_alpha/classes.rb', line 58397

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::ReservationSubBlock>

A list of reservation subBlock resources. Corresponds to the JSON property items



58402
58403
58404
# File 'lib/google/apis/compute_alpha/classes.rb', line 58402

def items
  @items
end

#kindString

Type of the resource. Alwayscompute#reservationSubBlock for a list of reservation subBlocks. Corresponds to the JSON property kind

Returns:

  • (String)


58409
58410
58411
# File 'lib/google/apis/compute_alpha/classes.rb', line 58409

def kind
  @kind
end

#next_page_tokenString

This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


58419
58420
58421
# File 'lib/google/apis/compute_alpha/classes.rb', line 58419

def next_page_token
  @next_page_token
end

Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


58424
58425
58426
# File 'lib/google/apis/compute_alpha/classes.rb', line 58424

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::ReservationSubBlocksListResponse::Warning

Informational warning message. Corresponds to the JSON property warning



58429
58430
58431
# File 'lib/google/apis/compute_alpha/classes.rb', line 58429

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



58436
58437
58438
58439
58440
58441
58442
58443
# File 'lib/google/apis/compute_alpha/classes.rb', line 58436

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end