Class: Google::Apis::ComputeAlpha::ReservationSubBlocksReportFaultyRequest
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::ReservationSubBlocksReportFaultyRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#disruption_schedule ⇒ String
The disruption schedule for the subBlock.
-
#failure_component ⇒ String
The component that experienced the fault.
-
#fault_reasons ⇒ Array<Google::Apis::ComputeAlpha::ReservationSubBlocksReportFaultyRequestFaultReason>
The reasons for the fault experienced with the subBlock.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReservationSubBlocksReportFaultyRequest
constructor
A new instance of ReservationSubBlocksReportFaultyRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReservationSubBlocksReportFaultyRequest
Returns a new instance of ReservationSubBlocksReportFaultyRequest.
58535 58536 58537 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58535 def initialize(**args) update!(**args) end |
Instance Attribute Details
#disruption_schedule ⇒ String
The disruption schedule for the subBlock.
Corresponds to the JSON property disruptionSchedule
58523 58524 58525 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58523 def disruption_schedule @disruption_schedule end |
#failure_component ⇒ String
The component that experienced the fault.
Corresponds to the JSON property failureComponent
58528 58529 58530 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58528 def failure_component @failure_component end |
#fault_reasons ⇒ Array<Google::Apis::ComputeAlpha::ReservationSubBlocksReportFaultyRequestFaultReason>
The reasons for the fault experienced with the subBlock.
Corresponds to the JSON property faultReasons
58533 58534 58535 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58533 def fault_reasons @fault_reasons end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
58540 58541 58542 58543 58544 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58540 def update!(**args) @disruption_schedule = args[:disruption_schedule] if args.key?(:disruption_schedule) @failure_component = args[:failure_component] if args.key?(:failure_component) @fault_reasons = args[:fault_reasons] if args.key?(:fault_reasons) end |