Class: Google::Apis::ComputeAlpha::ReservationSubBlocksReportFaultyRequestFaultReason
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::ReservationSubBlocksReportFaultyRequestFaultReason
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
The reason for the fault experienced with the subBlock.
Instance Attribute Summary collapse
-
#behavior ⇒ String
The behavior of the fault experienced with the subBlock.
-
#description ⇒ String
The description of the fault experienced with the subBlock.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReservationSubBlocksReportFaultyRequestFaultReason
constructor
A new instance of ReservationSubBlocksReportFaultyRequestFaultReason.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReservationSubBlocksReportFaultyRequestFaultReason
Returns a new instance of ReservationSubBlocksReportFaultyRequestFaultReason.
60206 60207 60208 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 60206 def initialize(**args) update!(**args) end |
Instance Attribute Details
#behavior ⇒ String
The behavior of the fault experienced with the subBlock.
Corresponds to the JSON property behavior
60199 60200 60201 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 60199 def behavior @behavior end |
#description ⇒ String
The description of the fault experienced with the subBlock.
Corresponds to the JSON property description
60204 60205 60206 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 60204 def description @description end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
60211 60212 60213 60214 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 60211 def update!(**args) @behavior = args[:behavior] if args.key?(:behavior) @description = args[:description] if args.key?(:description) end |