Class: Google::Apis::ComputeAlpha::ReservationSubBlocksReportFaultyRequestFaultReason

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

The reason for the fault experienced with the subBlock.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReservationSubBlocksReportFaultyRequestFaultReason

Returns a new instance of ReservationSubBlocksReportFaultyRequestFaultReason.



59619
59620
59621
# File 'lib/google/apis/compute_alpha/classes.rb', line 59619

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#behaviorString

The behavior of the fault experienced with the subBlock. Corresponds to the JSON property behavior

Returns:

  • (String)


59612
59613
59614
# File 'lib/google/apis/compute_alpha/classes.rb', line 59612

def behavior
  @behavior
end

#descriptionString

The description of the fault experienced with the subBlock. Corresponds to the JSON property description

Returns:

  • (String)


59617
59618
59619
# File 'lib/google/apis/compute_alpha/classes.rb', line 59617

def description
  @description
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



59624
59625
59626
59627
# File 'lib/google/apis/compute_alpha/classes.rb', line 59624

def update!(**args)
  @behavior = args[:behavior] if args.key?(:behavior)
  @description = args[:description] if args.key?(:description)
end