Class: Google::Apis::ComputeAlpha::ReservationSubBlocksReportFaultyRequestFaultReason

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

The reason for the fault experienced with the subBlock.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReservationSubBlocksReportFaultyRequestFaultReason

Returns a new instance of ReservationSubBlocksReportFaultyRequestFaultReason.



59398
59399
59400
# File 'lib/google/apis/compute_alpha/classes.rb', line 59398

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#behaviorString

The behavior of the fault experienced with the subBlock. Corresponds to the JSON property behavior

Returns:

  • (String)


59391
59392
59393
# File 'lib/google/apis/compute_alpha/classes.rb', line 59391

def behavior
  @behavior
end

#descriptionString

The description of the fault experienced with the subBlock. Corresponds to the JSON property description

Returns:

  • (String)


59396
59397
59398
# File 'lib/google/apis/compute_alpha/classes.rb', line 59396

def description
  @description
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



59403
59404
59405
59406
# File 'lib/google/apis/compute_alpha/classes.rb', line 59403

def update!(**args)
  @behavior = args[:behavior] if args.key?(:behavior)
  @description = args[:description] if args.key?(:description)
end