Class: Google::Apis::ComputeAlpha::ReservationSubBlocksReportFaultyRequestFaultReason

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

The reason for the fault experienced with the subBlock.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReservationSubBlocksReportFaultyRequestFaultReason

Returns a new instance of ReservationSubBlocksReportFaultyRequestFaultReason.



58561
58562
58563
# File 'lib/google/apis/compute_alpha/classes.rb', line 58561

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#behaviorString

The behavior of the fault experienced with the subBlock. Corresponds to the JSON property behavior

Returns:

  • (String)


58554
58555
58556
# File 'lib/google/apis/compute_alpha/classes.rb', line 58554

def behavior
  @behavior
end

#descriptionString

The description of the fault experienced with the subBlock. Corresponds to the JSON property description

Returns:

  • (String)


58559
58560
58561
# File 'lib/google/apis/compute_alpha/classes.rb', line 58559

def description
  @description
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



58566
58567
58568
58569
# File 'lib/google/apis/compute_alpha/classes.rb', line 58566

def update!(**args)
  @behavior = args[:behavior] if args.key?(:behavior)
  @description = args[:description] if args.key?(:description)
end