Class: Google::Apis::ComputeAlpha::ResourcePolicy
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::ResourcePolicy
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Represents a Resource Policy resource. You can use resource policies to schedule actions for some Compute Engine resources. For example, you can use them toschedule persistent disk snapshots.
Instance Attribute Summary collapse
-
#creation_timestamp ⇒ String
Output only.
-
#description ⇒ String
Corresponds to the JSON property
description. -
#disk_consistency_group_policy ⇒ Google::Apis::ComputeAlpha::ResourcePolicyDiskConsistencyGroupPolicy
Resource policy for disk consistency groups.
-
#group_placement_policy ⇒ Google::Apis::ComputeAlpha::ResourcePolicyGroupPlacementPolicy
A GroupPlacementPolicy specifies resource placement configuration.
-
#id ⇒ Fixnum
Output only.
-
#instance_schedule_policy ⇒ Google::Apis::ComputeAlpha::ResourcePolicyInstanceSchedulePolicy
An InstanceSchedulePolicy specifies when and how frequent certain operations are performed on the instance.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
The name of the resource, provided by the client when initially creating the resource.
-
#region ⇒ String
Corresponds to the JSON property
region. -
#resource_status ⇒ Google::Apis::ComputeAlpha::ResourcePolicyResourceStatus
Contains output only fields.
-
#self_link ⇒ String
Output only.
-
#self_link_with_id ⇒ String
Output only.
-
#snapshot_schedule_policy ⇒ Google::Apis::ComputeAlpha::ResourcePolicySnapshotSchedulePolicy
A snapshot schedule policy specifies when and how frequently snapshots are to be created for the target disk.
-
#status ⇒ String
Output only.
-
#vm_maintenance_policy ⇒ Google::Apis::ComputeAlpha::ResourcePolicyVmMaintenancePolicy
Resource policy applicable to VMs for infrastructure maintenance.
-
#workload_policy ⇒ Google::Apis::ComputeAlpha::ResourcePolicyWorkloadPolicy
Represents the workload policy.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ResourcePolicy
constructor
A new instance of ResourcePolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ResourcePolicy
Returns a new instance of ResourcePolicy.
62284 62285 62286 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 62284 def initialize(**args) update!(**args) end |
Instance Attribute Details
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
62188 62189 62190 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 62188 def @creation_timestamp end |
#description ⇒ String
Corresponds to the JSON property description
62193 62194 62195 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 62193 def description @description end |
#disk_consistency_group_policy ⇒ Google::Apis::ComputeAlpha::ResourcePolicyDiskConsistencyGroupPolicy
Resource policy for disk consistency groups.
Corresponds to the JSON property diskConsistencyGroupPolicy
62198 62199 62200 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 62198 def disk_consistency_group_policy @disk_consistency_group_policy end |
#group_placement_policy ⇒ Google::Apis::ComputeAlpha::ResourcePolicyGroupPlacementPolicy
A GroupPlacementPolicy specifies resource placement configuration.
It specifies the failure bucket separation
Corresponds to the JSON property groupPlacementPolicy
62204 62205 62206 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 62204 def group_placement_policy @group_placement_policy end |
#id ⇒ Fixnum
Output only. [Output Only] The unique identifier for the resource. This
identifier is
defined by the server.
Corresponds to the JSON property id
62211 62212 62213 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 62211 def id @id end |
#instance_schedule_policy ⇒ Google::Apis::ComputeAlpha::ResourcePolicyInstanceSchedulePolicy
An InstanceSchedulePolicy specifies when and how frequent certain
operations are performed on the instance.
Corresponds to the JSON property instanceSchedulePolicy
62217 62218 62219 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 62217 def instance_schedule_policy @instance_schedule_policy end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#
resource_policies for resource policies.
Corresponds to the JSON property kind
62223 62224 62225 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 62223 def kind @kind end |
#name ⇒ String
The name of the resource, provided by the client when initially creating
the resource. The resource name must be 1-63 characters long, and comply
withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must be
a dash, lowercase letter, or digit, except the last character, which cannot
be a dash.
Corresponds to the JSON property name
62235 62236 62237 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 62235 def name @name end |
#region ⇒ String
Corresponds to the JSON property region
62240 62241 62242 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 62240 def region @region end |
#resource_status ⇒ Google::Apis::ComputeAlpha::ResourcePolicyResourceStatus
Contains output only fields.
Use this sub-message for all output fields set on ResourcePolicy.
The internal structure of this "status" field should mimic the structure
of ResourcePolicy proto specification.
Corresponds to the JSON property resourceStatus
62248 62249 62250 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 62248 def resource_status @resource_status end |
#self_link ⇒ String
Output only. [Output Only] Server-defined fully-qualified URL for this
resource.
Corresponds to the JSON property selfLink
62254 62255 62256 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 62254 def self_link @self_link end |
#self_link_with_id ⇒ String
Output only. [Output Only] Server-defined URL for this resource with the
resource id.
Corresponds to the JSON property selfLinkWithId
62260 62261 62262 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 62260 def self_link_with_id @self_link_with_id end |
#snapshot_schedule_policy ⇒ Google::Apis::ComputeAlpha::ResourcePolicySnapshotSchedulePolicy
A snapshot schedule policy specifies when and how frequently snapshots are
to be created for the target disk. Also specifies how many and how long
these scheduled snapshots should be retained.
Corresponds to the JSON property snapshotSchedulePolicy
62267 62268 62269 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 62267 def snapshot_schedule_policy @snapshot_schedule_policy end |
#status ⇒ String
Output only. [Output Only] The status of resource policy creation.
Corresponds to the JSON property status
62272 62273 62274 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 62272 def status @status end |
#vm_maintenance_policy ⇒ Google::Apis::ComputeAlpha::ResourcePolicyVmMaintenancePolicy
Resource policy applicable to VMs for infrastructure maintenance.
Corresponds to the JSON property vmMaintenancePolicy
62277 62278 62279 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 62277 def vm_maintenance_policy @vm_maintenance_policy end |
#workload_policy ⇒ Google::Apis::ComputeAlpha::ResourcePolicyWorkloadPolicy
Represents the workload policy.
Corresponds to the JSON property workloadPolicy
62282 62283 62284 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 62282 def workload_policy @workload_policy end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
62289 62290 62291 62292 62293 62294 62295 62296 62297 62298 62299 62300 62301 62302 62303 62304 62305 62306 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 62289 def update!(**args) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @disk_consistency_group_policy = args[:disk_consistency_group_policy] if args.key?(:disk_consistency_group_policy) @group_placement_policy = args[:group_placement_policy] if args.key?(:group_placement_policy) @id = args[:id] if args.key?(:id) @instance_schedule_policy = args[:instance_schedule_policy] if args.key?(:instance_schedule_policy) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @region = args[:region] if args.key?(:region) @resource_status = args[:resource_status] if args.key?(:resource_status) @self_link = args[:self_link] if args.key?(:self_link) @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id) @snapshot_schedule_policy = args[:snapshot_schedule_policy] if args.key?(:snapshot_schedule_policy) @status = args[:status] if args.key?(:status) @vm_maintenance_policy = args[:vm_maintenance_policy] if args.key?(:vm_maintenance_policy) @workload_policy = args[:workload_policy] if args.key?(:workload_policy) end |