Class: Google::Apis::ComputeAlpha::ResourcePolicy

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Represents a Resource Policy resource. You can use resource policies to schedule actions for some Compute Engine resources. For example, you can use them toschedule persistent disk snapshots.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ResourcePolicy

Returns a new instance of ResourcePolicy.



61999
62000
62001
# File 'lib/google/apis/compute_alpha/classes.rb', line 61999

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


61903
61904
61905
# File 'lib/google/apis/compute_alpha/classes.rb', line 61903

def creation_timestamp
  @creation_timestamp
end

#descriptionString

Corresponds to the JSON property description

Returns:

  • (String)


61908
61909
61910
# File 'lib/google/apis/compute_alpha/classes.rb', line 61908

def description
  @description
end

#disk_consistency_group_policyGoogle::Apis::ComputeAlpha::ResourcePolicyDiskConsistencyGroupPolicy

Resource policy for disk consistency groups. Corresponds to the JSON property diskConsistencyGroupPolicy



61913
61914
61915
# File 'lib/google/apis/compute_alpha/classes.rb', line 61913

def disk_consistency_group_policy
  @disk_consistency_group_policy
end

#group_placement_policyGoogle::Apis::ComputeAlpha::ResourcePolicyGroupPlacementPolicy

A GroupPlacementPolicy specifies resource placement configuration. It specifies the failure bucket separation Corresponds to the JSON property groupPlacementPolicy



61919
61920
61921
# File 'lib/google/apis/compute_alpha/classes.rb', line 61919

def group_placement_policy
  @group_placement_policy
end

#idFixnum

Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


61926
61927
61928
# File 'lib/google/apis/compute_alpha/classes.rb', line 61926

def id
  @id
end

#instance_schedule_policyGoogle::Apis::ComputeAlpha::ResourcePolicyInstanceSchedulePolicy

An InstanceSchedulePolicy specifies when and how frequent certain operations are performed on the instance. Corresponds to the JSON property instanceSchedulePolicy



61932
61933
61934
# File 'lib/google/apis/compute_alpha/classes.rb', line 61932

def instance_schedule_policy
  @instance_schedule_policy
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# resource_policies for resource policies. Corresponds to the JSON property kind

Returns:

  • (String)


61938
61939
61940
# File 'lib/google/apis/compute_alpha/classes.rb', line 61938

def kind
  @kind
end

#nameString

The name of the resource, provided by the client when initially creating the resource. The resource name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


61950
61951
61952
# File 'lib/google/apis/compute_alpha/classes.rb', line 61950

def name
  @name
end

#regionString

Corresponds to the JSON property region

Returns:

  • (String)


61955
61956
61957
# File 'lib/google/apis/compute_alpha/classes.rb', line 61955

def region
  @region
end

#resource_statusGoogle::Apis::ComputeAlpha::ResourcePolicyResourceStatus

Contains output only fields. Use this sub-message for all output fields set on ResourcePolicy. The internal structure of this "status" field should mimic the structure of ResourcePolicy proto specification. Corresponds to the JSON property resourceStatus



61963
61964
61965
# File 'lib/google/apis/compute_alpha/classes.rb', line 61963

def resource_status
  @resource_status
end

Output only. [Output Only] Server-defined fully-qualified URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


61969
61970
61971
# File 'lib/google/apis/compute_alpha/classes.rb', line 61969

def self_link
  @self_link
end

Output only. [Output Only] Server-defined URL for this resource with the resource id. Corresponds to the JSON property selfLinkWithId

Returns:

  • (String)


61975
61976
61977
# File 'lib/google/apis/compute_alpha/classes.rb', line 61975

def self_link_with_id
  @self_link_with_id
end

#snapshot_schedule_policyGoogle::Apis::ComputeAlpha::ResourcePolicySnapshotSchedulePolicy

A snapshot schedule policy specifies when and how frequently snapshots are to be created for the target disk. Also specifies how many and how long these scheduled snapshots should be retained. Corresponds to the JSON property snapshotSchedulePolicy



61982
61983
61984
# File 'lib/google/apis/compute_alpha/classes.rb', line 61982

def snapshot_schedule_policy
  @snapshot_schedule_policy
end

#statusString

Output only. [Output Only] The status of resource policy creation. Corresponds to the JSON property status

Returns:

  • (String)


61987
61988
61989
# File 'lib/google/apis/compute_alpha/classes.rb', line 61987

def status
  @status
end

#vm_maintenance_policyGoogle::Apis::ComputeAlpha::ResourcePolicyVmMaintenancePolicy

Resource policy applicable to VMs for infrastructure maintenance. Corresponds to the JSON property vmMaintenancePolicy



61992
61993
61994
# File 'lib/google/apis/compute_alpha/classes.rb', line 61992

def vm_maintenance_policy
  @vm_maintenance_policy
end

#workload_policyGoogle::Apis::ComputeAlpha::ResourcePolicyWorkloadPolicy

Represents the workload policy. Corresponds to the JSON property workloadPolicy



61997
61998
61999
# File 'lib/google/apis/compute_alpha/classes.rb', line 61997

def workload_policy
  @workload_policy
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



62004
62005
62006
62007
62008
62009
62010
62011
62012
62013
62014
62015
62016
62017
62018
62019
62020
62021
# File 'lib/google/apis/compute_alpha/classes.rb', line 62004

def update!(**args)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @disk_consistency_group_policy = args[:disk_consistency_group_policy] if args.key?(:disk_consistency_group_policy)
  @group_placement_policy = args[:group_placement_policy] if args.key?(:group_placement_policy)
  @id = args[:id] if args.key?(:id)
  @instance_schedule_policy = args[:instance_schedule_policy] if args.key?(:instance_schedule_policy)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @region = args[:region] if args.key?(:region)
  @resource_status = args[:resource_status] if args.key?(:resource_status)
  @self_link = args[:self_link] if args.key?(:self_link)
  @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id)
  @snapshot_schedule_policy = args[:snapshot_schedule_policy] if args.key?(:snapshot_schedule_policy)
  @status = args[:status] if args.key?(:status)
  @vm_maintenance_policy = args[:vm_maintenance_policy] if args.key?(:vm_maintenance_policy)
  @workload_policy = args[:workload_policy] if args.key?(:workload_policy)
end