Class: Google::Apis::ComputeAlpha::ResourcePolicy

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Represents a Resource Policy resource. You can use resource policies to schedule actions for some Compute Engine resources. For example, you can use them toschedule persistent disk snapshots.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ResourcePolicy

Returns a new instance of ResourcePolicy.



60646
60647
60648
# File 'lib/google/apis/compute_alpha/classes.rb', line 60646

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


60550
60551
60552
# File 'lib/google/apis/compute_alpha/classes.rb', line 60550

def creation_timestamp
  @creation_timestamp
end

#descriptionString

Corresponds to the JSON property description

Returns:

  • (String)


60555
60556
60557
# File 'lib/google/apis/compute_alpha/classes.rb', line 60555

def description
  @description
end

#disk_consistency_group_policyGoogle::Apis::ComputeAlpha::ResourcePolicyDiskConsistencyGroupPolicy

Resource policy for disk consistency groups. Corresponds to the JSON property diskConsistencyGroupPolicy



60560
60561
60562
# File 'lib/google/apis/compute_alpha/classes.rb', line 60560

def disk_consistency_group_policy
  @disk_consistency_group_policy
end

#group_placement_policyGoogle::Apis::ComputeAlpha::ResourcePolicyGroupPlacementPolicy

A GroupPlacementPolicy specifies resource placement configuration. It specifies the failure bucket separation Corresponds to the JSON property groupPlacementPolicy



60566
60567
60568
# File 'lib/google/apis/compute_alpha/classes.rb', line 60566

def group_placement_policy
  @group_placement_policy
end

#idFixnum

Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


60573
60574
60575
# File 'lib/google/apis/compute_alpha/classes.rb', line 60573

def id
  @id
end

#instance_schedule_policyGoogle::Apis::ComputeAlpha::ResourcePolicyInstanceSchedulePolicy

An InstanceSchedulePolicy specifies when and how frequent certain operations are performed on the instance. Corresponds to the JSON property instanceSchedulePolicy



60579
60580
60581
# File 'lib/google/apis/compute_alpha/classes.rb', line 60579

def instance_schedule_policy
  @instance_schedule_policy
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# resource_policies for resource policies. Corresponds to the JSON property kind

Returns:

  • (String)


60585
60586
60587
# File 'lib/google/apis/compute_alpha/classes.rb', line 60585

def kind
  @kind
end

#nameString

The name of the resource, provided by the client when initially creating the resource. The resource name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


60597
60598
60599
# File 'lib/google/apis/compute_alpha/classes.rb', line 60597

def name
  @name
end

#regionString

Corresponds to the JSON property region

Returns:

  • (String)


60602
60603
60604
# File 'lib/google/apis/compute_alpha/classes.rb', line 60602

def region
  @region
end

#resource_statusGoogle::Apis::ComputeAlpha::ResourcePolicyResourceStatus

Contains output only fields. Use this sub-message for all output fields set on ResourcePolicy. The internal structure of this "status" field should mimic the structure of ResourcePolicy proto specification. Corresponds to the JSON property resourceStatus



60610
60611
60612
# File 'lib/google/apis/compute_alpha/classes.rb', line 60610

def resource_status
  @resource_status
end

Output only. [Output Only] Server-defined fully-qualified URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


60616
60617
60618
# File 'lib/google/apis/compute_alpha/classes.rb', line 60616

def self_link
  @self_link
end

Output only. [Output Only] Server-defined URL for this resource with the resource id. Corresponds to the JSON property selfLinkWithId

Returns:

  • (String)


60622
60623
60624
# File 'lib/google/apis/compute_alpha/classes.rb', line 60622

def self_link_with_id
  @self_link_with_id
end

#snapshot_schedule_policyGoogle::Apis::ComputeAlpha::ResourcePolicySnapshotSchedulePolicy

A snapshot schedule policy specifies when and how frequently snapshots are to be created for the target disk. Also specifies how many and how long these scheduled snapshots should be retained. Corresponds to the JSON property snapshotSchedulePolicy



60629
60630
60631
# File 'lib/google/apis/compute_alpha/classes.rb', line 60629

def snapshot_schedule_policy
  @snapshot_schedule_policy
end

#statusString

Output only. [Output Only] The status of resource policy creation. Corresponds to the JSON property status

Returns:

  • (String)


60634
60635
60636
# File 'lib/google/apis/compute_alpha/classes.rb', line 60634

def status
  @status
end

#vm_maintenance_policyGoogle::Apis::ComputeAlpha::ResourcePolicyVmMaintenancePolicy

Resource policy applicable to VMs for infrastructure maintenance. Corresponds to the JSON property vmMaintenancePolicy



60639
60640
60641
# File 'lib/google/apis/compute_alpha/classes.rb', line 60639

def vm_maintenance_policy
  @vm_maintenance_policy
end

#workload_policyGoogle::Apis::ComputeAlpha::ResourcePolicyWorkloadPolicy

Represents the workload policy. Corresponds to the JSON property workloadPolicy



60644
60645
60646
# File 'lib/google/apis/compute_alpha/classes.rb', line 60644

def workload_policy
  @workload_policy
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



60651
60652
60653
60654
60655
60656
60657
60658
60659
60660
60661
60662
60663
60664
60665
60666
60667
60668
# File 'lib/google/apis/compute_alpha/classes.rb', line 60651

def update!(**args)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @disk_consistency_group_policy = args[:disk_consistency_group_policy] if args.key?(:disk_consistency_group_policy)
  @group_placement_policy = args[:group_placement_policy] if args.key?(:group_placement_policy)
  @id = args[:id] if args.key?(:id)
  @instance_schedule_policy = args[:instance_schedule_policy] if args.key?(:instance_schedule_policy)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @region = args[:region] if args.key?(:region)
  @resource_status = args[:resource_status] if args.key?(:resource_status)
  @self_link = args[:self_link] if args.key?(:self_link)
  @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id)
  @snapshot_schedule_policy = args[:snapshot_schedule_policy] if args.key?(:snapshot_schedule_policy)
  @status = args[:status] if args.key?(:status)
  @vm_maintenance_policy = args[:vm_maintenance_policy] if args.key?(:vm_maintenance_policy)
  @workload_policy = args[:workload_policy] if args.key?(:workload_policy)
end