Class: Google::Apis::ComputeAlpha::ResourcePolicy
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::ResourcePolicy
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Represents a Resource Policy resource. You can use resource policies to schedule actions for some Compute Engine resources. For example, you can use them toschedule persistent disk snapshots.
Instance Attribute Summary collapse
-
#creation_timestamp ⇒ String
Output only.
-
#description ⇒ String
Corresponds to the JSON property
description. -
#disk_consistency_group_policy ⇒ Google::Apis::ComputeAlpha::ResourcePolicyDiskConsistencyGroupPolicy
Resource policy for disk consistency groups.
-
#group_placement_policy ⇒ Google::Apis::ComputeAlpha::ResourcePolicyGroupPlacementPolicy
A GroupPlacementPolicy specifies resource placement configuration.
-
#id ⇒ Fixnum
Output only.
-
#instance_schedule_policy ⇒ Google::Apis::ComputeAlpha::ResourcePolicyInstanceSchedulePolicy
An InstanceSchedulePolicy specifies when and how frequent certain operations are performed on the instance.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
The name of the resource, provided by the client when initially creating the resource.
-
#region ⇒ String
Corresponds to the JSON property
region. -
#resource_status ⇒ Google::Apis::ComputeAlpha::ResourcePolicyResourceStatus
Contains output only fields.
-
#self_link ⇒ String
Output only.
-
#self_link_with_id ⇒ String
Output only.
-
#snapshot_schedule_policy ⇒ Google::Apis::ComputeAlpha::ResourcePolicySnapshotSchedulePolicy
A snapshot schedule policy specifies when and how frequently snapshots are to be created for the target disk.
-
#status ⇒ String
Output only.
-
#vm_maintenance_policy ⇒ Google::Apis::ComputeAlpha::ResourcePolicyVmMaintenancePolicy
Resource policy applicable to VMs for infrastructure maintenance.
-
#workload_policy ⇒ Google::Apis::ComputeAlpha::ResourcePolicyWorkloadPolicy
Represents the workload policy.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ResourcePolicy
constructor
A new instance of ResourcePolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ResourcePolicy
Returns a new instance of ResourcePolicy.
59001 59002 59003 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59001 def initialize(**args) update!(**args) end |
Instance Attribute Details
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
58905 58906 58907 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58905 def @creation_timestamp end |
#description ⇒ String
Corresponds to the JSON property description
58910 58911 58912 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58910 def description @description end |
#disk_consistency_group_policy ⇒ Google::Apis::ComputeAlpha::ResourcePolicyDiskConsistencyGroupPolicy
Resource policy for disk consistency groups.
Corresponds to the JSON property diskConsistencyGroupPolicy
58915 58916 58917 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58915 def disk_consistency_group_policy @disk_consistency_group_policy end |
#group_placement_policy ⇒ Google::Apis::ComputeAlpha::ResourcePolicyGroupPlacementPolicy
A GroupPlacementPolicy specifies resource placement configuration.
It specifies the failure bucket separation
Corresponds to the JSON property groupPlacementPolicy
58921 58922 58923 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58921 def group_placement_policy @group_placement_policy end |
#id ⇒ Fixnum
Output only. [Output Only] The unique identifier for the resource. This
identifier is
defined by the server.
Corresponds to the JSON property id
58928 58929 58930 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58928 def id @id end |
#instance_schedule_policy ⇒ Google::Apis::ComputeAlpha::ResourcePolicyInstanceSchedulePolicy
An InstanceSchedulePolicy specifies when and how frequent certain
operations are performed on the instance.
Corresponds to the JSON property instanceSchedulePolicy
58934 58935 58936 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58934 def instance_schedule_policy @instance_schedule_policy end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#
resource_policies for resource policies.
Corresponds to the JSON property kind
58940 58941 58942 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58940 def kind @kind end |
#name ⇒ String
The name of the resource, provided by the client when initially creating
the resource. The resource name must be 1-63 characters long, and comply
withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must be
a dash, lowercase letter, or digit, except the last character, which cannot
be a dash.
Corresponds to the JSON property name
58952 58953 58954 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58952 def name @name end |
#region ⇒ String
Corresponds to the JSON property region
58957 58958 58959 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58957 def region @region end |
#resource_status ⇒ Google::Apis::ComputeAlpha::ResourcePolicyResourceStatus
Contains output only fields.
Use this sub-message for all output fields set on ResourcePolicy.
The internal structure of this "status" field should mimic the structure
of ResourcePolicy proto specification.
Corresponds to the JSON property resourceStatus
58965 58966 58967 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58965 def resource_status @resource_status end |
#self_link ⇒ String
Output only. [Output Only] Server-defined fully-qualified URL for this
resource.
Corresponds to the JSON property selfLink
58971 58972 58973 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58971 def self_link @self_link end |
#self_link_with_id ⇒ String
Output only. [Output Only] Server-defined URL for this resource with the
resource id.
Corresponds to the JSON property selfLinkWithId
58977 58978 58979 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58977 def self_link_with_id @self_link_with_id end |
#snapshot_schedule_policy ⇒ Google::Apis::ComputeAlpha::ResourcePolicySnapshotSchedulePolicy
A snapshot schedule policy specifies when and how frequently snapshots are
to be created for the target disk. Also specifies how many and how long
these scheduled snapshots should be retained.
Corresponds to the JSON property snapshotSchedulePolicy
58984 58985 58986 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58984 def snapshot_schedule_policy @snapshot_schedule_policy end |
#status ⇒ String
Output only. [Output Only] The status of resource policy creation.
Corresponds to the JSON property status
58989 58990 58991 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58989 def status @status end |
#vm_maintenance_policy ⇒ Google::Apis::ComputeAlpha::ResourcePolicyVmMaintenancePolicy
Resource policy applicable to VMs for infrastructure maintenance.
Corresponds to the JSON property vmMaintenancePolicy
58994 58995 58996 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58994 def vm_maintenance_policy @vm_maintenance_policy end |
#workload_policy ⇒ Google::Apis::ComputeAlpha::ResourcePolicyWorkloadPolicy
Represents the workload policy.
Corresponds to the JSON property workloadPolicy
58999 59000 59001 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 58999 def workload_policy @workload_policy end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
59006 59007 59008 59009 59010 59011 59012 59013 59014 59015 59016 59017 59018 59019 59020 59021 59022 59023 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59006 def update!(**args) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @disk_consistency_group_policy = args[:disk_consistency_group_policy] if args.key?(:disk_consistency_group_policy) @group_placement_policy = args[:group_placement_policy] if args.key?(:group_placement_policy) @id = args[:id] if args.key?(:id) @instance_schedule_policy = args[:instance_schedule_policy] if args.key?(:instance_schedule_policy) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @region = args[:region] if args.key?(:region) @resource_status = args[:resource_status] if args.key?(:resource_status) @self_link = args[:self_link] if args.key?(:self_link) @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id) @snapshot_schedule_policy = args[:snapshot_schedule_policy] if args.key?(:snapshot_schedule_policy) @status = args[:status] if args.key?(:status) @vm_maintenance_policy = args[:vm_maintenance_policy] if args.key?(:vm_maintenance_policy) @workload_policy = args[:workload_policy] if args.key?(:workload_policy) end |