Class: Google::Apis::ComputeAlpha::ResourcePolicyAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::ResourcePolicyAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Contains a list of resourcePolicies.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::ResourcePoliciesScopedList>
A list of ResourcePolicy resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::ResourcePolicyAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ResourcePolicyAggregatedList
constructor
A new instance of ResourcePolicyAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ResourcePolicyAggregatedList
Returns a new instance of ResourcePolicyAggregatedList.
62625 62626 62627 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 62625 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
62583 62584 62585 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 62583 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
62588 62589 62590 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 62588 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::ResourcePoliciesScopedList>
A list of ResourcePolicy resources.
Corresponds to the JSON property items
62593 62594 62595 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 62593 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
62598 62599 62600 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 62598 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
62608 62609 62610 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 62608 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
62613 62614 62615 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 62613 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
62618 62619 62620 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 62618 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::ResourcePolicyAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
62623 62624 62625 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 62623 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
62630 62631 62632 62633 62634 62635 62636 62637 62638 62639 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 62630 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |