Class: Google::Apis::ComputeAlpha::ResourcePolicyAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of resourcePolicies.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ResourcePolicyAggregatedList

Returns a new instance of ResourcePolicyAggregatedList.



62358
62359
62360
# File 'lib/google/apis/compute_alpha/classes.rb', line 62358

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


62316
62317
62318
# File 'lib/google/apis/compute_alpha/classes.rb', line 62316

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


62321
62322
62323
# File 'lib/google/apis/compute_alpha/classes.rb', line 62321

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::ResourcePoliciesScopedList>

A list of ResourcePolicy resources. Corresponds to the JSON property items



62326
62327
62328
# File 'lib/google/apis/compute_alpha/classes.rb', line 62326

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


62331
62332
62333
# File 'lib/google/apis/compute_alpha/classes.rb', line 62331

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


62341
62342
62343
# File 'lib/google/apis/compute_alpha/classes.rb', line 62341

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


62346
62347
62348
# File 'lib/google/apis/compute_alpha/classes.rb', line 62346

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


62351
62352
62353
# File 'lib/google/apis/compute_alpha/classes.rb', line 62351

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::ResourcePolicyAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



62356
62357
62358
# File 'lib/google/apis/compute_alpha/classes.rb', line 62356

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



62363
62364
62365
62366
62367
62368
62369
62370
62371
62372
# File 'lib/google/apis/compute_alpha/classes.rb', line 62363

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end