Class: Google::Apis::ComputeAlpha::ResourcePolicyAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of resourcePolicies.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ResourcePolicyAggregatedList

Returns a new instance of ResourcePolicyAggregatedList.



60135
60136
60137
# File 'lib/google/apis/compute_alpha/classes.rb', line 60135

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


60093
60094
60095
# File 'lib/google/apis/compute_alpha/classes.rb', line 60093

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


60098
60099
60100
# File 'lib/google/apis/compute_alpha/classes.rb', line 60098

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::ResourcePoliciesScopedList>

A list of ResourcePolicy resources. Corresponds to the JSON property items



60103
60104
60105
# File 'lib/google/apis/compute_alpha/classes.rb', line 60103

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


60108
60109
60110
# File 'lib/google/apis/compute_alpha/classes.rb', line 60108

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


60118
60119
60120
# File 'lib/google/apis/compute_alpha/classes.rb', line 60118

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


60123
60124
60125
# File 'lib/google/apis/compute_alpha/classes.rb', line 60123

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


60128
60129
60130
# File 'lib/google/apis/compute_alpha/classes.rb', line 60128

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::ResourcePolicyAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



60133
60134
60135
# File 'lib/google/apis/compute_alpha/classes.rb', line 60133

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



60140
60141
60142
60143
60144
60145
60146
60147
60148
60149
# File 'lib/google/apis/compute_alpha/classes.rb', line 60140

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end