Class: Google::Apis::ComputeAlpha::ResourcePolicyAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::ResourcePolicyAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Contains a list of resourcePolicies.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::ResourcePoliciesScopedList>
A list of ResourcePolicy resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::ResourcePolicyAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ResourcePolicyAggregatedList
constructor
A new instance of ResourcePolicyAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ResourcePolicyAggregatedList
Returns a new instance of ResourcePolicyAggregatedList.
59912 59913 59914 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59912 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
59870 59871 59872 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59870 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
59875 59876 59877 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59875 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::ResourcePoliciesScopedList>
A list of ResourcePolicy resources.
Corresponds to the JSON property items
59880 59881 59882 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59880 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
59885 59886 59887 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59885 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
59895 59896 59897 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59895 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
59900 59901 59902 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59900 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
59905 59906 59907 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59905 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::ResourcePolicyAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
59910 59911 59912 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59910 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
59917 59918 59919 59920 59921 59922 59923 59924 59925 59926 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 59917 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |