Class: Google::Apis::ComputeAlpha::ResourcePolicyGroupPlacementPolicy
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::ResourcePolicyGroupPlacementPolicy
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
A GroupPlacementPolicy specifies resource placement configuration. It specifies the failure bucket separation
Instance Attribute Summary collapse
-
#accelerator_topology_mode ⇒ String
Specifies the connection mode for the accelerator topology.
-
#availability_domain_count ⇒ Fixnum
The number of availability domains to spread instances across.
-
#collocation ⇒ String
Specifies network collocation Corresponds to the JSON property
collocation. -
#gpu_topology ⇒ String
Specifies the shape of the GPU slice, in slice based GPU families eg.
-
#max_distance ⇒ Fixnum
Specifies the number of max logical switches.
-
#scope ⇒ String
Scope specifies the availability domain to which the VMs should be spread.
-
#slice_count ⇒ Fixnum
Specifies the number of slices in a multislice workload.
-
#tpu_topology ⇒ String
Specifies the shape of the TPU slice Corresponds to the JSON property
tpuTopology. -
#vm_count ⇒ Fixnum
Number of VMs in this placement group.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ResourcePolicyGroupPlacementPolicy
constructor
A new instance of ResourcePolicyGroupPlacementPolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ResourcePolicyGroupPlacementPolicy
Returns a new instance of ResourcePolicyGroupPlacementPolicy.
62551 62552 62553 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 62551 def initialize(**args) update!(**args) end |
Instance Attribute Details
#accelerator_topology_mode ⇒ String
Specifies the connection mode for the accelerator topology. If not
specified, the default is AUTO_CONNECT.
Corresponds to the JSON property acceleratorTopologyMode
62503 62504 62505 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 62503 def accelerator_topology_mode @accelerator_topology_mode end |
#availability_domain_count ⇒ Fixnum
The number of availability domains to spread instances across. If two
instances are in different availability domain, they are not in the same
low latency network.
Corresponds to the JSON property availabilityDomainCount
62510 62511 62512 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 62510 def availability_domain_count @availability_domain_count end |
#collocation ⇒ String
Specifies network collocation
Corresponds to the JSON property collocation
62515 62516 62517 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 62515 def collocation @collocation end |
#gpu_topology ⇒ String
Specifies the shape of the GPU slice, in slice based GPU families eg.
A4X.
Corresponds to the JSON property gpuTopology
62521 62522 62523 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 62521 def gpu_topology @gpu_topology end |
#max_distance ⇒ Fixnum
Specifies the number of max logical switches.
Corresponds to the JSON property maxDistance
62526 62527 62528 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 62526 def max_distance @max_distance end |
#scope ⇒ String
Scope specifies the availability domain to which the VMs should be
spread.
Corresponds to the JSON property scope
62532 62533 62534 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 62532 def scope @scope end |
#slice_count ⇒ Fixnum
Specifies the number of slices in a multislice workload.
Corresponds to the JSON property sliceCount
62537 62538 62539 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 62537 def slice_count @slice_count end |
#tpu_topology ⇒ String
Specifies the shape of the TPU slice
Corresponds to the JSON property tpuTopology
62542 62543 62544 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 62542 def tpu_topology @tpu_topology end |
#vm_count ⇒ Fixnum
Number of VMs in this placement group. Google does not recommend that you
use this field unless you use a compact policy and you want your policy
to work only if it contains this exact number of VMs.
Corresponds to the JSON property vmCount
62549 62550 62551 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 62549 def vm_count @vm_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
62556 62557 62558 62559 62560 62561 62562 62563 62564 62565 62566 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 62556 def update!(**args) @accelerator_topology_mode = args[:accelerator_topology_mode] if args.key?(:accelerator_topology_mode) @availability_domain_count = args[:availability_domain_count] if args.key?(:availability_domain_count) @collocation = args[:collocation] if args.key?(:collocation) @gpu_topology = args[:gpu_topology] if args.key?(:gpu_topology) @max_distance = args[:max_distance] if args.key?(:max_distance) @scope = args[:scope] if args.key?(:scope) @slice_count = args[:slice_count] if args.key?(:slice_count) @tpu_topology = args[:tpu_topology] if args.key?(:tpu_topology) @vm_count = args[:vm_count] if args.key?(:vm_count) end |