Class: Google::Apis::ComputeAlpha::ResourcePolicyGroupPlacementPolicy

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

A GroupPlacementPolicy specifies resource placement configuration. It specifies the failure bucket separation

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ResourcePolicyGroupPlacementPolicy

Returns a new instance of ResourcePolicyGroupPlacementPolicy.



60888
60889
60890
# File 'lib/google/apis/compute_alpha/classes.rb', line 60888

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#accelerator_topology_modeString

Specifies the connection mode for the accelerator topology. If not specified, the default is AUTO_CONNECT. Corresponds to the JSON property acceleratorTopologyMode

Returns:

  • (String)


60840
60841
60842
# File 'lib/google/apis/compute_alpha/classes.rb', line 60840

def accelerator_topology_mode
  @accelerator_topology_mode
end

#availability_domain_countFixnum

The number of availability domains to spread instances across. If two instances are in different availability domain, they are not in the same low latency network. Corresponds to the JSON property availabilityDomainCount

Returns:

  • (Fixnum)


60847
60848
60849
# File 'lib/google/apis/compute_alpha/classes.rb', line 60847

def availability_domain_count
  @availability_domain_count
end

#collocationString

Specifies network collocation Corresponds to the JSON property collocation

Returns:

  • (String)


60852
60853
60854
# File 'lib/google/apis/compute_alpha/classes.rb', line 60852

def collocation
  @collocation
end

#gpu_topologyString

Specifies the shape of the GPU slice, in slice based GPU families eg. A4X. Corresponds to the JSON property gpuTopology

Returns:

  • (String)


60858
60859
60860
# File 'lib/google/apis/compute_alpha/classes.rb', line 60858

def gpu_topology
  @gpu_topology
end

#max_distanceFixnum

Specifies the number of max logical switches. Corresponds to the JSON property maxDistance

Returns:

  • (Fixnum)


60863
60864
60865
# File 'lib/google/apis/compute_alpha/classes.rb', line 60863

def max_distance
  @max_distance
end

#scopeString

Scope specifies the availability domain to which the VMs should be spread. Corresponds to the JSON property scope

Returns:

  • (String)


60869
60870
60871
# File 'lib/google/apis/compute_alpha/classes.rb', line 60869

def scope
  @scope
end

#slice_countFixnum

Specifies the number of slices in a multislice workload. Corresponds to the JSON property sliceCount

Returns:

  • (Fixnum)


60874
60875
60876
# File 'lib/google/apis/compute_alpha/classes.rb', line 60874

def slice_count
  @slice_count
end

#tpu_topologyString

Specifies the shape of the TPU slice Corresponds to the JSON property tpuTopology

Returns:

  • (String)


60879
60880
60881
# File 'lib/google/apis/compute_alpha/classes.rb', line 60879

def tpu_topology
  @tpu_topology
end

#vm_countFixnum

Number of VMs in this placement group. Google does not recommend that you use this field unless you use a compact policy and you want your policy to work only if it contains this exact number of VMs. Corresponds to the JSON property vmCount

Returns:

  • (Fixnum)


60886
60887
60888
# File 'lib/google/apis/compute_alpha/classes.rb', line 60886

def vm_count
  @vm_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



60893
60894
60895
60896
60897
60898
60899
60900
60901
60902
60903
# File 'lib/google/apis/compute_alpha/classes.rb', line 60893

def update!(**args)
  @accelerator_topology_mode = args[:accelerator_topology_mode] if args.key?(:accelerator_topology_mode)
  @availability_domain_count = args[:availability_domain_count] if args.key?(:availability_domain_count)
  @collocation = args[:collocation] if args.key?(:collocation)
  @gpu_topology = args[:gpu_topology] if args.key?(:gpu_topology)
  @max_distance = args[:max_distance] if args.key?(:max_distance)
  @scope = args[:scope] if args.key?(:scope)
  @slice_count = args[:slice_count] if args.key?(:slice_count)
  @tpu_topology = args[:tpu_topology] if args.key?(:tpu_topology)
  @vm_count = args[:vm_count] if args.key?(:vm_count)
end