Class: Google::Apis::ComputeAlpha::ResourcePolicyList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ResourcePolicyList

Returns a new instance of ResourcePolicyList.



62715
62716
62717
# File 'lib/google/apis/compute_alpha/classes.rb', line 62715

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


62676
62677
62678
# File 'lib/google/apis/compute_alpha/classes.rb', line 62676

def etag
  @etag
end

#idString

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


62682
62683
62684
# File 'lib/google/apis/compute_alpha/classes.rb', line 62682

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::ResourcePolicy>

[Output Only] A list of ResourcePolicy resources. Corresponds to the JSON property items



62687
62688
62689
# File 'lib/google/apis/compute_alpha/classes.rb', line 62687

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource.Alwayscompute#resourcePoliciesList for listsof resourcePolicies Corresponds to the JSON property kind

Returns:

  • (String)


62693
62694
62695
# File 'lib/google/apis/compute_alpha/classes.rb', line 62693

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


62703
62704
62705
# File 'lib/google/apis/compute_alpha/classes.rb', line 62703

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


62708
62709
62710
# File 'lib/google/apis/compute_alpha/classes.rb', line 62708

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::ResourcePolicyList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



62713
62714
62715
# File 'lib/google/apis/compute_alpha/classes.rb', line 62713

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



62720
62721
62722
62723
62724
62725
62726
62727
62728
# File 'lib/google/apis/compute_alpha/classes.rb', line 62720

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end