Class: Google::Apis::ComputeAlpha::ResourcePolicyList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ResourcePolicyList

Returns a new instance of ResourcePolicyList.



62430
62431
62432
# File 'lib/google/apis/compute_alpha/classes.rb', line 62430

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


62391
62392
62393
# File 'lib/google/apis/compute_alpha/classes.rb', line 62391

def etag
  @etag
end

#idString

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


62397
62398
62399
# File 'lib/google/apis/compute_alpha/classes.rb', line 62397

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::ResourcePolicy>

[Output Only] A list of ResourcePolicy resources. Corresponds to the JSON property items



62402
62403
62404
# File 'lib/google/apis/compute_alpha/classes.rb', line 62402

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource.Alwayscompute#resourcePoliciesList for listsof resourcePolicies Corresponds to the JSON property kind

Returns:

  • (String)


62408
62409
62410
# File 'lib/google/apis/compute_alpha/classes.rb', line 62408

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


62418
62419
62420
# File 'lib/google/apis/compute_alpha/classes.rb', line 62418

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


62423
62424
62425
# File 'lib/google/apis/compute_alpha/classes.rb', line 62423

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::ResourcePolicyList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



62428
62429
62430
# File 'lib/google/apis/compute_alpha/classes.rb', line 62428

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



62435
62436
62437
62438
62439
62440
62441
62442
62443
# File 'lib/google/apis/compute_alpha/classes.rb', line 62435

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end