Class: Google::Apis::ComputeAlpha::ResourcePolicyList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ResourcePolicyList

Returns a new instance of ResourcePolicyList.



61077
61078
61079
# File 'lib/google/apis/compute_alpha/classes.rb', line 61077

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


61038
61039
61040
# File 'lib/google/apis/compute_alpha/classes.rb', line 61038

def etag
  @etag
end

#idString

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


61044
61045
61046
# File 'lib/google/apis/compute_alpha/classes.rb', line 61044

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::ResourcePolicy>

[Output Only] A list of ResourcePolicy resources. Corresponds to the JSON property items



61049
61050
61051
# File 'lib/google/apis/compute_alpha/classes.rb', line 61049

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource.Alwayscompute#resourcePoliciesList for listsof resourcePolicies Corresponds to the JSON property kind

Returns:

  • (String)


61055
61056
61057
# File 'lib/google/apis/compute_alpha/classes.rb', line 61055

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


61065
61066
61067
# File 'lib/google/apis/compute_alpha/classes.rb', line 61065

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


61070
61071
61072
# File 'lib/google/apis/compute_alpha/classes.rb', line 61070

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::ResourcePolicyList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



61075
61076
61077
# File 'lib/google/apis/compute_alpha/classes.rb', line 61075

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



61082
61083
61084
61085
61086
61087
61088
61089
61090
# File 'lib/google/apis/compute_alpha/classes.rb', line 61082

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end