Class: Google::Apis::ComputeAlpha::ResourcePolicyList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ResourcePolicyList

Returns a new instance of ResourcePolicyList.



61052
61053
61054
# File 'lib/google/apis/compute_alpha/classes.rb', line 61052

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


61013
61014
61015
# File 'lib/google/apis/compute_alpha/classes.rb', line 61013

def etag
  @etag
end

#idString

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


61019
61020
61021
# File 'lib/google/apis/compute_alpha/classes.rb', line 61019

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::ResourcePolicy>

[Output Only] A list of ResourcePolicy resources. Corresponds to the JSON property items



61024
61025
61026
# File 'lib/google/apis/compute_alpha/classes.rb', line 61024

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource.Alwayscompute#resourcePoliciesList for listsof resourcePolicies Corresponds to the JSON property kind

Returns:

  • (String)


61030
61031
61032
# File 'lib/google/apis/compute_alpha/classes.rb', line 61030

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


61040
61041
61042
# File 'lib/google/apis/compute_alpha/classes.rb', line 61040

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


61045
61046
61047
# File 'lib/google/apis/compute_alpha/classes.rb', line 61045

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::ResourcePolicyList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



61050
61051
61052
# File 'lib/google/apis/compute_alpha/classes.rb', line 61050

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



61057
61058
61059
61060
61061
61062
61063
61064
61065
# File 'lib/google/apis/compute_alpha/classes.rb', line 61057

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end