Class: Google::Apis::ComputeAlpha::ResourcePolicyList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::ResourcePolicyList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] The unique identifier for the resource.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::ResourcePolicy>
[Output Only] A list of ResourcePolicy resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::ResourcePolicyList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ResourcePolicyList
constructor
A new instance of ResourcePolicyList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ResourcePolicyList
Returns a new instance of ResourcePolicyList.
60490 60491 60492 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 60490 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
60451 60452 60453 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 60451 def etag @etag end |
#id ⇒ String
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
60457 60458 60459 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 60457 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::ResourcePolicy>
[Output Only] A list of ResourcePolicy resources.
Corresponds to the JSON property items
60462 60463 60464 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 60462 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource.Alwayscompute#resourcePoliciesList
for listsof resourcePolicies
Corresponds to the JSON property kind
60468 60469 60470 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 60468 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
60478 60479 60480 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 60478 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
60483 60484 60485 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 60483 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::ResourcePolicyList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
60488 60489 60490 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 60488 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
60495 60496 60497 60498 60499 60500 60501 60502 60503 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 60495 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |