Class: Google::Apis::ComputeAlpha::ResourcePolicyList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ResourcePolicyList

Returns a new instance of ResourcePolicyList.



59432
59433
59434
# File 'lib/google/apis/compute_alpha/classes.rb', line 59432

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


59393
59394
59395
# File 'lib/google/apis/compute_alpha/classes.rb', line 59393

def etag
  @etag
end

#idString

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


59399
59400
59401
# File 'lib/google/apis/compute_alpha/classes.rb', line 59399

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::ResourcePolicy>

[Output Only] A list of ResourcePolicy resources. Corresponds to the JSON property items



59404
59405
59406
# File 'lib/google/apis/compute_alpha/classes.rb', line 59404

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource.Alwayscompute#resourcePoliciesList for listsof resourcePolicies Corresponds to the JSON property kind

Returns:

  • (String)


59410
59411
59412
# File 'lib/google/apis/compute_alpha/classes.rb', line 59410

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


59420
59421
59422
# File 'lib/google/apis/compute_alpha/classes.rb', line 59420

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


59425
59426
59427
# File 'lib/google/apis/compute_alpha/classes.rb', line 59425

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::ResourcePolicyList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



59430
59431
59432
# File 'lib/google/apis/compute_alpha/classes.rb', line 59430

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



59437
59438
59439
59440
59441
59442
59443
59444
59445
# File 'lib/google/apis/compute_alpha/classes.rb', line 59437

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end