Class: Google::Apis::ComputeAlpha::ResourcePolicySnapshotSchedulePolicyRetentionPolicy
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::ResourcePolicySnapshotSchedulePolicyRetentionPolicy
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Policy for retention of scheduled snapshots.
Instance Attribute Summary collapse
-
#max_retention_days ⇒ Fixnum
Maximum age of the snapshot that is allowed to be kept.
-
#on_policy_switch ⇒ String
Corresponds to the JSON property
onPolicySwitch. -
#on_source_disk_delete ⇒ String
Specifies the behavior to apply to scheduled snapshots when the source disk is deleted.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ResourcePolicySnapshotSchedulePolicyRetentionPolicy
constructor
A new instance of ResourcePolicySnapshotSchedulePolicyRetentionPolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ResourcePolicySnapshotSchedulePolicyRetentionPolicy
Returns a new instance of ResourcePolicySnapshotSchedulePolicyRetentionPolicy.
60684 60685 60686 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 60684 def initialize(**args) update!(**args) end |
Instance Attribute Details
#max_retention_days ⇒ Fixnum
Maximum age of the snapshot that is allowed to be kept.
Corresponds to the JSON property maxRetentionDays
60671 60672 60673 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 60671 def max_retention_days @max_retention_days end |
#on_policy_switch ⇒ String
Corresponds to the JSON property onPolicySwitch
60676 60677 60678 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 60676 def on_policy_switch @on_policy_switch end |
#on_source_disk_delete ⇒ String
Specifies the behavior to apply to scheduled snapshots when
the source disk is deleted.
Corresponds to the JSON property onSourceDiskDelete
60682 60683 60684 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 60682 def on_source_disk_delete @on_source_disk_delete end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
60689 60690 60691 60692 60693 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 60689 def update!(**args) @max_retention_days = args[:max_retention_days] if args.key?(:max_retention_days) @on_policy_switch = args[:on_policy_switch] if args.key?(:on_policy_switch) @on_source_disk_delete = args[:on_source_disk_delete] if args.key?(:on_source_disk_delete) end |