Class: Google::Apis::ComputeAlpha::ResourcePolicySnapshotSchedulePolicyRetentionPolicy

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Policy for retention of scheduled snapshots.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ResourcePolicySnapshotSchedulePolicyRetentionPolicy

Returns a new instance of ResourcePolicySnapshotSchedulePolicyRetentionPolicy.



59624
59625
59626
# File 'lib/google/apis/compute_alpha/classes.rb', line 59624

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#max_retention_daysFixnum

Maximum age of the snapshot that is allowed to be kept. Corresponds to the JSON property maxRetentionDays

Returns:

  • (Fixnum)


59611
59612
59613
# File 'lib/google/apis/compute_alpha/classes.rb', line 59611

def max_retention_days
  @max_retention_days
end

#on_policy_switchString

Corresponds to the JSON property onPolicySwitch

Returns:

  • (String)


59616
59617
59618
# File 'lib/google/apis/compute_alpha/classes.rb', line 59616

def on_policy_switch
  @on_policy_switch
end

#on_source_disk_deleteString

Specifies the behavior to apply to scheduled snapshots when the source disk is deleted. Corresponds to the JSON property onSourceDiskDelete

Returns:

  • (String)


59622
59623
59624
# File 'lib/google/apis/compute_alpha/classes.rb', line 59622

def on_source_disk_delete
  @on_source_disk_delete
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



59629
59630
59631
59632
59633
# File 'lib/google/apis/compute_alpha/classes.rb', line 59629

def update!(**args)
  @max_retention_days = args[:max_retention_days] if args.key?(:max_retention_days)
  @on_policy_switch = args[:on_policy_switch] if args.key?(:on_policy_switch)
  @on_source_disk_delete = args[:on_source_disk_delete] if args.key?(:on_source_disk_delete)
end