Class: Google::Apis::ComputeAlpha::ResourcePolicySnapshotSchedulePolicySnapshotProperties

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Specified snapshot properties for scheduled snapshots created by this policy.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ResourcePolicySnapshotSchedulePolicySnapshotProperties

Returns a new instance of ResourcePolicySnapshotSchedulePolicySnapshotProperties.



60537
60538
60539
# File 'lib/google/apis/compute_alpha/classes.rb', line 60537

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#chain_nameString

Chain name that the snapshot is created in. Corresponds to the JSON property chainName

Returns:

  • (String)


60512
60513
60514
# File 'lib/google/apis/compute_alpha/classes.rb', line 60512

def chain_name
  @chain_name
end

#guest_flushBoolean Also known as: guest_flush?

Indication to perform a 'guest aware' snapshot. Corresponds to the JSON property guestFlush

Returns:

  • (Boolean)


60517
60518
60519
# File 'lib/google/apis/compute_alpha/classes.rb', line 60517

def guest_flush
  @guest_flush
end

#labelsHash<String,String>

Labels to apply to scheduled snapshots. These can be later modified by the setLabels method. Label values may be empty. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


60524
60525
60526
# File 'lib/google/apis/compute_alpha/classes.rb', line 60524

def labels
  @labels
end

#regionString

Region where the snapshot is scoped to. Corresponds to the JSON property region

Returns:

  • (String)


60529
60530
60531
# File 'lib/google/apis/compute_alpha/classes.rb', line 60529

def region
  @region
end

#storage_locationsArray<String>

Cloud Storage bucket storage location of the auto snapshot (regional or multi-regional). Corresponds to the JSON property storageLocations

Returns:

  • (Array<String>)


60535
60536
60537
# File 'lib/google/apis/compute_alpha/classes.rb', line 60535

def storage_locations
  @storage_locations
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



60542
60543
60544
60545
60546
60547
60548
# File 'lib/google/apis/compute_alpha/classes.rb', line 60542

def update!(**args)
  @chain_name = args[:chain_name] if args.key?(:chain_name)
  @guest_flush = args[:guest_flush] if args.key?(:guest_flush)
  @labels = args[:labels] if args.key?(:labels)
  @region = args[:region] if args.key?(:region)
  @storage_locations = args[:storage_locations] if args.key?(:storage_locations)
end