Class: Google::Apis::ComputeAlpha::ResourcePolicySnapshotSchedulePolicySnapshotProperties

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Specified snapshot properties for scheduled snapshots created by this policy.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ResourcePolicySnapshotSchedulePolicySnapshotProperties

Returns a new instance of ResourcePolicySnapshotSchedulePolicySnapshotProperties.



59700
59701
59702
# File 'lib/google/apis/compute_alpha/classes.rb', line 59700

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#chain_nameString

Chain name that the snapshot is created in. Corresponds to the JSON property chainName

Returns:

  • (String)


59675
59676
59677
# File 'lib/google/apis/compute_alpha/classes.rb', line 59675

def chain_name
  @chain_name
end

#guest_flushBoolean Also known as: guest_flush?

Indication to perform a 'guest aware' snapshot. Corresponds to the JSON property guestFlush

Returns:

  • (Boolean)


59680
59681
59682
# File 'lib/google/apis/compute_alpha/classes.rb', line 59680

def guest_flush
  @guest_flush
end

#labelsHash<String,String>

Labels to apply to scheduled snapshots. These can be later modified by the setLabels method. Label values may be empty. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


59687
59688
59689
# File 'lib/google/apis/compute_alpha/classes.rb', line 59687

def labels
  @labels
end

#regionString

Region where the snapshot is scoped to. Corresponds to the JSON property region

Returns:

  • (String)


59692
59693
59694
# File 'lib/google/apis/compute_alpha/classes.rb', line 59692

def region
  @region
end

#storage_locationsArray<String>

Cloud Storage bucket storage location of the auto snapshot (regional or multi-regional). Corresponds to the JSON property storageLocations

Returns:

  • (Array<String>)


59698
59699
59700
# File 'lib/google/apis/compute_alpha/classes.rb', line 59698

def storage_locations
  @storage_locations
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



59705
59706
59707
59708
59709
59710
59711
# File 'lib/google/apis/compute_alpha/classes.rb', line 59705

def update!(**args)
  @chain_name = args[:chain_name] if args.key?(:chain_name)
  @guest_flush = args[:guest_flush] if args.key?(:guest_flush)
  @labels = args[:labels] if args.key?(:labels)
  @region = args[:region] if args.key?(:region)
  @storage_locations = args[:storage_locations] if args.key?(:storage_locations)
end