Class: Google::Apis::ComputeAlpha::ResourcePolicyWeeklyCycleDayOfWeek

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ResourcePolicyWeeklyCycleDayOfWeek

Returns a new instance of ResourcePolicyWeeklyCycleDayOfWeek.



60667
60668
60669
# File 'lib/google/apis/compute_alpha/classes.rb', line 60667

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dayString

Defines a schedule that runs on specific days of the week. Specify one or more days. The following options are available: MONDAY, TUESDAY, WEDNESDAY, THURSDAY, FRIDAY, SATURDAY, SUNDAY. Corresponds to the JSON property day

Returns:

  • (String)


60652
60653
60654
# File 'lib/google/apis/compute_alpha/classes.rb', line 60652

def day
  @day
end

#durationString

Output only. [Output only] Duration of the time window, automatically chosen to be smallest possible in the given scenario. Corresponds to the JSON property duration

Returns:

  • (String)


60659
60660
60661
# File 'lib/google/apis/compute_alpha/classes.rb', line 60659

def duration
  @duration
end

#start_timeString

Time within the window to start the operations. It must be in format "HH:MM", where HH : [00-23] and MM : [00-00] GMT. Corresponds to the JSON property startTime

Returns:

  • (String)


60665
60666
60667
# File 'lib/google/apis/compute_alpha/classes.rb', line 60665

def start_time
  @start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



60672
60673
60674
60675
60676
# File 'lib/google/apis/compute_alpha/classes.rb', line 60672

def update!(**args)
  @day = args[:day] if args.key?(:day)
  @duration = args[:duration] if args.key?(:duration)
  @start_time = args[:start_time] if args.key?(:start_time)
end