Class: Google::Apis::ComputeAlpha::ResourcePolicyWorkloadPolicy
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::ResourcePolicyWorkloadPolicy
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Represents the workload policy.
Instance Attribute Summary collapse
-
#accelerator_topology ⇒ String
Specifies the topology required to create a partition for VMs that have interconnected GPUs.
-
#accelerator_topology_mode ⇒ String
Specifies the connection mode for the accelerator topology.
-
#max_topology_distance ⇒ String
Specifies the maximum distance between instances.
-
#type ⇒ String
Specifies the intent of the instance placement in the MIG.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ResourcePolicyWorkloadPolicy
constructor
A new instance of ResourcePolicyWorkloadPolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ResourcePolicyWorkloadPolicy
Returns a new instance of ResourcePolicyWorkloadPolicy.
60705 60706 60707 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 60705 def initialize(**args) update!(**args) end |
Instance Attribute Details
#accelerator_topology ⇒ String
Specifies the topology required to create a partition for VMs that have
interconnected GPUs.
Corresponds to the JSON property acceleratorTopology
60687 60688 60689 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 60687 def accelerator_topology @accelerator_topology end |
#accelerator_topology_mode ⇒ String
Specifies the connection mode for the accelerator topology. If not
specified, the default is AUTO_CONNECT.
Corresponds to the JSON property acceleratorTopologyMode
60693 60694 60695 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 60693 def accelerator_topology_mode @accelerator_topology_mode end |
#max_topology_distance ⇒ String
Specifies the maximum distance between instances.
Corresponds to the JSON property maxTopologyDistance
60698 60699 60700 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 60698 def max_topology_distance @max_topology_distance end |
#type ⇒ String
Specifies the intent of the instance placement in the MIG.
Corresponds to the JSON property type
60703 60704 60705 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 60703 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
60710 60711 60712 60713 60714 60715 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 60710 def update!(**args) @accelerator_topology = args[:accelerator_topology] if args.key?(:accelerator_topology) @accelerator_topology_mode = args[:accelerator_topology_mode] if args.key?(:accelerator_topology_mode) @max_topology_distance = args[:max_topology_distance] if args.key?(:max_topology_distance) @type = args[:type] if args.key?(:type) end |