Class: Google::Apis::ComputeAlpha::ResourceStatus
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::ResourceStatus
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Contains output only fields. Use this sub-message for actual values set on Instance attributes as compared to the value requested by the user (intent) in their instance CRUD calls.
Instance Attribute Summary collapse
-
#accelerator_status ⇒ Array<Google::Apis::ComputeAlpha::ResourceStatusAcceleratorStatus>
Output only.
-
#consumed_reservation ⇒ String
Output only.
-
#consumed_reservation_block ⇒ String
Output only.
-
#effective_instance_metadata ⇒ Google::Apis::ComputeAlpha::ResourceStatusEffectiveInstanceMetadata
Effective values of predefined metadata keys for an instance.
-
#last_instance_termination_details ⇒ Google::Apis::ComputeAlpha::ResourceStatusLastInstanceTerminationDetails
Output only.
-
#physical_host ⇒ String
Output only.
-
#physical_host_topology ⇒ Google::Apis::ComputeAlpha::ResourceStatusPhysicalHostTopology
Represents the physical host topology of the host on which the VM is running.
-
#reservation_consumption_info ⇒ Google::Apis::ComputeAlpha::ResourceStatusReservationConsumptionInfo
Reservation consumption information that the instance is consuming from.
-
#scheduling ⇒ Google::Apis::ComputeAlpha::ResourceStatusScheduling
Corresponds to the JSON property
scheduling. -
#service_integration_statuses ⇒ Hash<String,Google::Apis::ComputeAlpha::ResourceStatusServiceIntegrationStatus>
[Output Only] Represents the status of the service integration specs defined by the user in instance.serviceIntegrationSpecs.
-
#shutdown_details ⇒ Google::Apis::ComputeAlpha::ResourceStatusShutdownDetails
Specifies if the instance is in
PENDING_STOPstate or there is a programmed stop scheduled. -
#upcoming_maintenance ⇒ Google::Apis::ComputeAlpha::UpcomingMaintenance
Upcoming Maintenance notification information.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ResourceStatus
constructor
A new instance of ResourceStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ResourceStatus
Returns a new instance of ResourceStatus.
61583 61584 61585 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61583 def initialize(**args) update!(**args) end |
Instance Attribute Details
#accelerator_status ⇒ Array<Google::Apis::ComputeAlpha::ResourceStatusAcceleratorStatus>
Output only. [Output Only] Accelerators status show results of GPU scans.
These scans
are specialized diagnostic tests designed to uncover latent manufacturing
defects or other issues that could potentially lead to data corruption or
impede the customer's ability to efficiently execute GPU workloads.
Corresponds to the JSON property acceleratorStatus
61514 61515 61516 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61514 def accelerator_status @accelerator_status end |
#consumed_reservation ⇒ String
Output only. [Output Only] The full resource name of the reservation that this
instance
is consuming from.
Corresponds to the JSON property consumedReservation
61521 61522 61523 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61521 def consumed_reservation @consumed_reservation end |
#consumed_reservation_block ⇒ String
Output only. [Output Only] The full resource name of the reservation block
that this
instance is consuming from.
Corresponds to the JSON property consumedReservationBlock
61528 61529 61530 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61528 def consumed_reservation_block @consumed_reservation_block end |
#effective_instance_metadata ⇒ Google::Apis::ComputeAlpha::ResourceStatusEffectiveInstanceMetadata
Effective values of predefined metadata keys for an instance.
Corresponds to the JSON property effectiveInstanceMetadata
61533 61534 61535 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61533 def @effective_instance_metadata end |
#last_instance_termination_details ⇒ Google::Apis::ComputeAlpha::ResourceStatusLastInstanceTerminationDetails
Output only. [Output Only] Contains last termination details why the instance
was
terminated.
Corresponds to the JSON property lastInstanceTerminationDetails
61540 61541 61542 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61540 def last_instance_termination_details @last_instance_termination_details end |
#physical_host ⇒ String
Output only. [Output Only] The precise location of your instance within the
zone's data
center, including the block, sub-block, and host. The field is formatted as
follows: blockId/subBlockId/hostId.
Corresponds to the JSON property physicalHost
61548 61549 61550 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61548 def physical_host @physical_host end |
#physical_host_topology ⇒ Google::Apis::ComputeAlpha::ResourceStatusPhysicalHostTopology
Represents the physical host topology of the host on which the VM is
running.
Corresponds to the JSON property physicalHostTopology
61554 61555 61556 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61554 def physical_host_topology @physical_host_topology end |
#reservation_consumption_info ⇒ Google::Apis::ComputeAlpha::ResourceStatusReservationConsumptionInfo
Reservation consumption information that the instance is consuming from.
Corresponds to the JSON property reservationConsumptionInfo
61559 61560 61561 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61559 def reservation_consumption_info @reservation_consumption_info end |
#scheduling ⇒ Google::Apis::ComputeAlpha::ResourceStatusScheduling
Corresponds to the JSON property scheduling
61564 61565 61566 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61564 def scheduling @scheduling end |
#service_integration_statuses ⇒ Hash<String,Google::Apis::ComputeAlpha::ResourceStatusServiceIntegrationStatus>
[Output Only] Represents the status of the service integration specs
defined by the user in instance.serviceIntegrationSpecs.
Corresponds to the JSON property serviceIntegrationStatuses
61570 61571 61572 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61570 def service_integration_statuses @service_integration_statuses end |
#shutdown_details ⇒ Google::Apis::ComputeAlpha::ResourceStatusShutdownDetails
Specifies if the instance is in PENDING_STOP state or there is a
programmed stop scheduled.
Corresponds to the JSON property shutdownDetails
61576 61577 61578 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61576 def shutdown_details @shutdown_details end |
#upcoming_maintenance ⇒ Google::Apis::ComputeAlpha::UpcomingMaintenance
Upcoming Maintenance notification information.
Corresponds to the JSON property upcomingMaintenance
61581 61582 61583 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61581 def upcoming_maintenance @upcoming_maintenance end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
61588 61589 61590 61591 61592 61593 61594 61595 61596 61597 61598 61599 61600 61601 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61588 def update!(**args) @accelerator_status = args[:accelerator_status] if args.key?(:accelerator_status) @consumed_reservation = args[:consumed_reservation] if args.key?(:consumed_reservation) @consumed_reservation_block = args[:consumed_reservation_block] if args.key?(:consumed_reservation_block) @effective_instance_metadata = args[:effective_instance_metadata] if args.key?(:effective_instance_metadata) @last_instance_termination_details = args[:last_instance_termination_details] if args.key?(:last_instance_termination_details) @physical_host = args[:physical_host] if args.key?(:physical_host) @physical_host_topology = args[:physical_host_topology] if args.key?(:physical_host_topology) @reservation_consumption_info = args[:reservation_consumption_info] if args.key?(:reservation_consumption_info) @scheduling = args[:scheduling] if args.key?(:scheduling) @service_integration_statuses = args[:service_integration_statuses] if args.key?(:service_integration_statuses) @shutdown_details = args[:shutdown_details] if args.key?(:shutdown_details) @upcoming_maintenance = args[:upcoming_maintenance] if args.key?(:upcoming_maintenance) end |