Class: Google::Apis::ComputeAlpha::ResourceStatusAcceleratorStatus
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::ResourceStatusAcceleratorStatus
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
The status of an individual accelerator resource.
Instance Attribute Summary collapse
-
#passed_scans ⇒ Array<Google::Apis::ComputeAlpha::ResourceStatusAcceleratorStatusPassedScan>
The details of scans that passed for an accelerator.
-
#recommended_scans ⇒ Array<Google::Apis::ComputeAlpha::ResourceStatusAcceleratorStatusRecommendedScan>
The details of recommended scans for an accelerator.
-
#serial_number ⇒ String
The serial number of the accelerator.
-
#uuid ⇒ String
The UUID of the accelerator.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ResourceStatusAcceleratorStatus
constructor
A new instance of ResourceStatusAcceleratorStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ResourceStatusAcceleratorStatus
Returns a new instance of ResourceStatusAcceleratorStatus.
63006 63007 63008 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63006 def initialize(**args) update!(**args) end |
Instance Attribute Details
#passed_scans ⇒ Array<Google::Apis::ComputeAlpha::ResourceStatusAcceleratorStatusPassedScan>
The details of scans that passed for an accelerator.
Corresponds to the JSON property passedScans
62989 62990 62991 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 62989 def passed_scans @passed_scans end |
#recommended_scans ⇒ Array<Google::Apis::ComputeAlpha::ResourceStatusAcceleratorStatusRecommendedScan>
The details of recommended scans for an accelerator.
Corresponds to the JSON property recommendedScans
62994 62995 62996 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 62994 def recommended_scans @recommended_scans end |
#serial_number ⇒ String
The serial number of the accelerator.
Corresponds to the JSON property serialNumber
62999 63000 63001 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 62999 def serial_number @serial_number end |
#uuid ⇒ String
The UUID of the accelerator.
Corresponds to the JSON property uuid
63004 63005 63006 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63004 def uuid @uuid end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
63011 63012 63013 63014 63015 63016 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63011 def update!(**args) @passed_scans = args[:passed_scans] if args.key?(:passed_scans) @recommended_scans = args[:recommended_scans] if args.key?(:recommended_scans) @serial_number = args[:serial_number] if args.key?(:serial_number) @uuid = args[:uuid] if args.key?(:uuid) end |