Class: Google::Apis::ComputeAlpha::ResourceStatusAcceleratorStatusRecommendedScan

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ResourceStatusAcceleratorStatusRecommendedScan

Returns a new instance of ResourceStatusAcceleratorStatusRecommendedScan.



61140
61141
61142
# File 'lib/google/apis/compute_alpha/classes.rb', line 61140

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#estimated_durationGoogle::Apis::ComputeAlpha::Duration

A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution. It is independent of any calendar and concepts like "day" or "month". Range is approximately 10,000 years. Corresponds to the JSON property estimatedDuration



61128
61129
61130
# File 'lib/google/apis/compute_alpha/classes.rb', line 61128

def estimated_duration
  @estimated_duration
end

#nameString

Corresponds to the JSON property name

Returns:

  • (String)


61133
61134
61135
# File 'lib/google/apis/compute_alpha/classes.rb', line 61133

def name
  @name
end

#versionString

Corresponds to the JSON property version

Returns:

  • (String)


61138
61139
61140
# File 'lib/google/apis/compute_alpha/classes.rb', line 61138

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



61145
61146
61147
61148
61149
# File 'lib/google/apis/compute_alpha/classes.rb', line 61145

def update!(**args)
  @estimated_duration = args[:estimated_duration] if args.key?(:estimated_duration)
  @name = args[:name] if args.key?(:name)
  @version = args[:version] if args.key?(:version)
end