Class: Google::Apis::ComputeAlpha::ResourceStatusAcceleratorStatusRecommendedScan

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ResourceStatusAcceleratorStatusRecommendedScan

Returns a new instance of ResourceStatusAcceleratorStatusRecommendedScan.



60080
60081
60082
# File 'lib/google/apis/compute_alpha/classes.rb', line 60080

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#estimated_durationGoogle::Apis::ComputeAlpha::Duration

A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution. It is independent of any calendar and concepts like "day" or "month". Range is approximately 10,000 years. Corresponds to the JSON property estimatedDuration



60068
60069
60070
# File 'lib/google/apis/compute_alpha/classes.rb', line 60068

def estimated_duration
  @estimated_duration
end

#nameString

Corresponds to the JSON property name

Returns:

  • (String)


60073
60074
60075
# File 'lib/google/apis/compute_alpha/classes.rb', line 60073

def name
  @name
end

#versionString

Corresponds to the JSON property version

Returns:

  • (String)


60078
60079
60080
# File 'lib/google/apis/compute_alpha/classes.rb', line 60078

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



60085
60086
60087
60088
60089
# File 'lib/google/apis/compute_alpha/classes.rb', line 60085

def update!(**args)
  @estimated_duration = args[:estimated_duration] if args.key?(:estimated_duration)
  @name = args[:name] if args.key?(:name)
  @version = args[:version] if args.key?(:version)
end