Class: Google::Apis::ComputeAlpha::ResourceStatusPhysicalHostTopology

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Represents the physical host topology of the host on which the VM is running.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ResourceStatusPhysicalHostTopology

Returns a new instance of ResourceStatusPhysicalHostTopology.



63505
63506
63507
# File 'lib/google/apis/compute_alpha/classes.rb', line 63505

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#additional_attributesGoogle::Apis::ComputeAlpha::ResourceStatusPhysicalHostTopologyAdditionalAttributes

Additional location information of the running instance. Corresponds to the JSON property additionalAttributes



63477
63478
63479
# File 'lib/google/apis/compute_alpha/classes.rb', line 63477

def additional_attributes
  @additional_attributes
end

#blockString

[Output Only] The ID of the block in which the running instance is located. Instances within the same block experience low network latency. Corresponds to the JSON property block

Returns:

  • (String)


63483
63484
63485
# File 'lib/google/apis/compute_alpha/classes.rb', line 63483

def block
  @block
end

#clusterString

[Output Only] The global name of the Compute Engine cluster where the running instance is located. Corresponds to the JSON property cluster

Returns:

  • (String)


63489
63490
63491
# File 'lib/google/apis/compute_alpha/classes.rb', line 63489

def cluster
  @cluster
end

#hostString

[Output Only] The ID of the host on which the running instance is located. Instances on the same host experience the lowest possible network latency. Corresponds to the JSON property host

Returns:

  • (String)


63496
63497
63498
# File 'lib/google/apis/compute_alpha/classes.rb', line 63496

def host
  @host
end

#subblockString

[Output Only] The ID of the sub-block in which the running instance is located. Instances in the same sub-block experience lower network latency than instances in the same block. Corresponds to the JSON property subblock

Returns:

  • (String)


63503
63504
63505
# File 'lib/google/apis/compute_alpha/classes.rb', line 63503

def subblock
  @subblock
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



63510
63511
63512
63513
63514
63515
63516
# File 'lib/google/apis/compute_alpha/classes.rb', line 63510

def update!(**args)
  @additional_attributes = args[:additional_attributes] if args.key?(:additional_attributes)
  @block = args[:block] if args.key?(:block)
  @cluster = args[:cluster] if args.key?(:cluster)
  @host = args[:host] if args.key?(:host)
  @subblock = args[:subblock] if args.key?(:subblock)
end