Class: Google::Apis::ComputeAlpha::ResourceStatusPhysicalHostTopology
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::ResourceStatusPhysicalHostTopology
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Represents the physical host topology of the host on which the VM is running.
Instance Attribute Summary collapse
-
#additional_attributes ⇒ Google::Apis::ComputeAlpha::ResourceStatusPhysicalHostTopologyAdditionalAttributes
Additional location information of the running instance.
-
#block ⇒ String
[Output Only] The ID of the block in which the running instance is located.
-
#cluster ⇒ String
[Output Only] The global name of the Compute Engine cluster where the running instance is located.
-
#host ⇒ String
[Output Only] The ID of the host on which the running instance is located.
-
#subblock ⇒ String
[Output Only] The ID of the sub-block in which the running instance is located.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ResourceStatusPhysicalHostTopology
constructor
A new instance of ResourceStatusPhysicalHostTopology.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ResourceStatusPhysicalHostTopology
Returns a new instance of ResourceStatusPhysicalHostTopology.
63220 63221 63222 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63220 def initialize(**args) update!(**args) end |
Instance Attribute Details
#additional_attributes ⇒ Google::Apis::ComputeAlpha::ResourceStatusPhysicalHostTopologyAdditionalAttributes
Additional location information of the running instance.
Corresponds to the JSON property additionalAttributes
63192 63193 63194 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63192 def additional_attributes @additional_attributes end |
#block ⇒ String
[Output Only] The ID of the block in which the running instance is
located. Instances within the same block experience low network latency.
Corresponds to the JSON property block
63198 63199 63200 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63198 def block @block end |
#cluster ⇒ String
[Output Only] The global name of the Compute Engine cluster where the
running instance is located.
Corresponds to the JSON property cluster
63204 63205 63206 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63204 def cluster @cluster end |
#host ⇒ String
[Output Only] The ID of the host on which the running instance is located.
Instances on the same host experience the lowest possible network
latency.
Corresponds to the JSON property host
63211 63212 63213 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63211 def host @host end |
#subblock ⇒ String
[Output Only] The ID of the sub-block in which the running instance is
located. Instances in the same sub-block experience lower network latency
than instances in the same block.
Corresponds to the JSON property subblock
63218 63219 63220 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63218 def subblock @subblock end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
63225 63226 63227 63228 63229 63230 63231 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63225 def update!(**args) @additional_attributes = args[:additional_attributes] if args.key?(:additional_attributes) @block = args[:block] if args.key?(:block) @cluster = args[:cluster] if args.key?(:cluster) @host = args[:host] if args.key?(:host) @subblock = args[:subblock] if args.key?(:subblock) end |