Class: Google::Apis::ComputeAlpha::ResourceStatusPhysicalHostTopologyAdditionalAttributes
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::ResourceStatusPhysicalHostTopologyAdditionalAttributes
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Additional location information of the running instance.
Instance Attribute Summary collapse
-
#accelerator_topology_ids ⇒ Hash<String,String>
Output only.
-
#network_topology_ids ⇒ Hash<String,String>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ResourceStatusPhysicalHostTopologyAdditionalAttributes
constructor
A new instance of ResourceStatusPhysicalHostTopologyAdditionalAttributes.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ResourceStatusPhysicalHostTopologyAdditionalAttributes
Returns a new instance of ResourceStatusPhysicalHostTopologyAdditionalAttributes.
63807 63808 63809 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63807 def initialize(**args) update!(**args) end |
Instance Attribute Details
#accelerator_topology_ids ⇒ Hash<String,String>
Output only. The IDs of the accelerator topologies the instance belongs to.
For
example
The key will be topologies like "4x4", "2x2x2" and the value will be
the location ID of the topologies.
Corresponds to the JSON property acceleratorTopologyIds
63797 63798 63799 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63797 def accelerator_topology_ids @accelerator_topology_ids end |
#network_topology_ids ⇒ Hash<String,String>
Output only. Key-value store for arbitrary network topology identifiers
defined by the underlying infrastructure.
The key will be the topology label and the value will be the location
ID for the topology.
Corresponds to the JSON property networkTopologyIds
63805 63806 63807 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63805 def network_topology_ids @network_topology_ids end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
63812 63813 63814 63815 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63812 def update!(**args) @accelerator_topology_ids = args[:accelerator_topology_ids] if args.key?(:accelerator_topology_ids) @network_topology_ids = args[:network_topology_ids] if args.key?(:network_topology_ids) end |