Class: Google::Apis::ComputeAlpha::ResourceStatusReservationConsumptionInfo
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::ResourceStatusReservationConsumptionInfo
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Reservation consumption information that the instance is consuming from.
Instance Attribute Summary collapse
-
#consumed_reservation ⇒ String
Output only.
-
#consumed_reservation_block ⇒ String
Output only.
-
#consumed_reservation_sub_block ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ResourceStatusReservationConsumptionInfo
constructor
A new instance of ResourceStatusReservationConsumptionInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ResourceStatusReservationConsumptionInfo
Returns a new instance of ResourceStatusReservationConsumptionInfo.
61928 61929 61930 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61928 def initialize(**args) update!(**args) end |
Instance Attribute Details
#consumed_reservation ⇒ String
Output only. [Output Only] The full resource name of the reservation that this
instance is consuming from.
Corresponds to the JSON property consumedReservation
61912 61913 61914 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61912 def consumed_reservation @consumed_reservation end |
#consumed_reservation_block ⇒ String
Output only. [Output Only] The full resource name of the reservation block
that this
instance is consuming from.
Corresponds to the JSON property consumedReservationBlock
61919 61920 61921 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61919 def consumed_reservation_block @consumed_reservation_block end |
#consumed_reservation_sub_block ⇒ String
Output only. [Output Only] The full resource name of the reservation sub-block
that
this instance is consuming from.
Corresponds to the JSON property consumedReservationSubBlock
61926 61927 61928 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61926 def consumed_reservation_sub_block @consumed_reservation_sub_block end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
61933 61934 61935 61936 61937 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61933 def update!(**args) @consumed_reservation = args[:consumed_reservation] if args.key?(:consumed_reservation) @consumed_reservation_block = args[:consumed_reservation_block] if args.key?(:consumed_reservation_block) @consumed_reservation_sub_block = args[:consumed_reservation_sub_block] if args.key?(:consumed_reservation_sub_block) end |