Class: Google::Apis::ComputeAlpha::ResourceStatusReservationConsumptionInfo
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::ResourceStatusReservationConsumptionInfo
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Reservation consumption information that the instance is consuming from.
Instance Attribute Summary collapse
-
#consumed_reservation ⇒ String
Output only.
-
#consumed_reservation_block ⇒ String
Output only.
-
#consumed_reservation_sub_block ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ResourceStatusReservationConsumptionInfo
constructor
A new instance of ResourceStatusReservationConsumptionInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ResourceStatusReservationConsumptionInfo
Returns a new instance of ResourceStatusReservationConsumptionInfo.
61903 61904 61905 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61903 def initialize(**args) update!(**args) end |
Instance Attribute Details
#consumed_reservation ⇒ String
Output only. [Output Only] The full resource name of the reservation that this
instance is consuming from.
Corresponds to the JSON property consumedReservation
61887 61888 61889 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61887 def consumed_reservation @consumed_reservation end |
#consumed_reservation_block ⇒ String
Output only. [Output Only] The full resource name of the reservation block
that this
instance is consuming from.
Corresponds to the JSON property consumedReservationBlock
61894 61895 61896 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61894 def consumed_reservation_block @consumed_reservation_block end |
#consumed_reservation_sub_block ⇒ String
Output only. [Output Only] The full resource name of the reservation sub-block
that
this instance is consuming from.
Corresponds to the JSON property consumedReservationSubBlock
61901 61902 61903 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61901 def consumed_reservation_sub_block @consumed_reservation_sub_block end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
61908 61909 61910 61911 61912 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61908 def update!(**args) @consumed_reservation = args[:consumed_reservation] if args.key?(:consumed_reservation) @consumed_reservation_block = args[:consumed_reservation_block] if args.key?(:consumed_reservation_block) @consumed_reservation_sub_block = args[:consumed_reservation_sub_block] if args.key?(:consumed_reservation_sub_block) end |