Class: Google::Apis::ComputeAlpha::ResourceStatusReservationConsumptionInfo

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Reservation consumption information that the instance is consuming from.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ResourceStatusReservationConsumptionInfo

Returns a new instance of ResourceStatusReservationConsumptionInfo.



60254
60255
60256
# File 'lib/google/apis/compute_alpha/classes.rb', line 60254

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#consumed_reservationString

Output only. [Output Only] The full resource name of the reservation that this instance is consuming from. Corresponds to the JSON property consumedReservation

Returns:

  • (String)


60238
60239
60240
# File 'lib/google/apis/compute_alpha/classes.rb', line 60238

def consumed_reservation
  @consumed_reservation
end

#consumed_reservation_blockString

Output only. [Output Only] The full resource name of the reservation block that this instance is consuming from. Corresponds to the JSON property consumedReservationBlock

Returns:

  • (String)


60245
60246
60247
# File 'lib/google/apis/compute_alpha/classes.rb', line 60245

def consumed_reservation_block
  @consumed_reservation_block
end

#consumed_reservation_sub_blockString

Output only. [Output Only] The full resource name of the reservation sub-block that this instance is consuming from. Corresponds to the JSON property consumedReservationSubBlock

Returns:

  • (String)


60252
60253
60254
# File 'lib/google/apis/compute_alpha/classes.rb', line 60252

def consumed_reservation_sub_block
  @consumed_reservation_sub_block
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



60259
60260
60261
60262
60263
# File 'lib/google/apis/compute_alpha/classes.rb', line 60259

def update!(**args)
  @consumed_reservation = args[:consumed_reservation] if args.key?(:consumed_reservation)
  @consumed_reservation_block = args[:consumed_reservation_block] if args.key?(:consumed_reservation_block)
  @consumed_reservation_sub_block = args[:consumed_reservation_sub_block] if args.key?(:consumed_reservation_sub_block)
end