Class: Google::Apis::ComputeAlpha::ResourceStatusScheduling
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::ResourceStatusScheduling
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#availability_domain ⇒ Fixnum
Specifies the availability domain to place the instance in.
-
#graceful_shutdown_timestamp ⇒ String
Output only.
-
#termination_timestamp ⇒ String
Time in future when the instance will be terminated inRFC3339 text format.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ResourceStatusScheduling
constructor
A new instance of ResourceStatusScheduling.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ResourceStatusScheduling
Returns a new instance of ResourceStatusScheduling.
63316 63317 63318 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63316 def initialize(**args) update!(**args) end |
Instance Attribute Details
#availability_domain ⇒ Fixnum
Specifies the availability domain to place the instance in. The value
must be a number between 1 and the number of availability domains
specified in the spread placement policy attached to the instance.
Corresponds to the JSON property availabilityDomain
63302 63303 63304 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63302 def availability_domain @availability_domain end |
#graceful_shutdown_timestamp ⇒ String
Output only. Specifies the timestamp, when the instance will start graceful
shutdown
process, in RFC3339 text format.
Corresponds to the JSON property gracefulShutdownTimestamp
63309 63310 63311 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63309 def @graceful_shutdown_timestamp end |
#termination_timestamp ⇒ String
Time in future when the instance will be terminated inRFC3339 text format.
Corresponds to the JSON property terminationTimestamp
63314 63315 63316 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63314 def @termination_timestamp end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
63321 63322 63323 63324 63325 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63321 def update!(**args) @availability_domain = args[:availability_domain] if args.key?(:availability_domain) @graceful_shutdown_timestamp = args[:graceful_shutdown_timestamp] if args.key?(:graceful_shutdown_timestamp) @termination_timestamp = args[:termination_timestamp] if args.key?(:termination_timestamp) end |