Class: Google::Apis::ComputeAlpha::ResourceStatusServiceIntegrationStatus

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Represents the status of integration between instance and another service. See go/gce-backupdr-design for more details.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ResourceStatusServiceIntegrationStatus

Returns a new instance of ResourceStatusServiceIntegrationStatus.



61954
61955
61956
# File 'lib/google/apis/compute_alpha/classes.rb', line 61954

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backup_drGoogle::Apis::ComputeAlpha::ResourceStatusServiceIntegrationStatusBackupDrStatus

Message defining compute perspective of the result of integration with Backup and DR. FAILED status indicates that the operation specified did not complete correctly and should be retried with the same value. Corresponds to the JSON property backupDr



61952
61953
61954
# File 'lib/google/apis/compute_alpha/classes.rb', line 61952

def backup_dr
  @backup_dr
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



61959
61960
61961
# File 'lib/google/apis/compute_alpha/classes.rb', line 61959

def update!(**args)
  @backup_dr = args[:backup_dr] if args.key?(:backup_dr)
end