Class: Google::Apis::ComputeAlpha::ResourceStatusServiceIntegrationStatus
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::ResourceStatusServiceIntegrationStatus
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Represents the status of integration between instance and another service. See go/gce-backupdr-design for more details.
Instance Attribute Summary collapse
-
#backup_dr ⇒ Google::Apis::ComputeAlpha::ResourceStatusServiceIntegrationStatusBackupDrStatus
Message defining compute perspective of the result of integration with Backup and DR.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ResourceStatusServiceIntegrationStatus
constructor
A new instance of ResourceStatusServiceIntegrationStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ResourceStatusServiceIntegrationStatus
Returns a new instance of ResourceStatusServiceIntegrationStatus.
61142 61143 61144 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61142 def initialize(**args) update!(**args) end |
Instance Attribute Details
#backup_dr ⇒ Google::Apis::ComputeAlpha::ResourceStatusServiceIntegrationStatusBackupDrStatus
Message defining compute perspective of the result of integration with
Backup and DR. FAILED status indicates that the operation specified did
not complete correctly and should be retried with the same value.
Corresponds to the JSON property backupDr
61140 61141 61142 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61140 def backup_dr @backup_dr end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
61147 61148 61149 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61147 def update!(**args) @backup_dr = args[:backup_dr] if args.key?(:backup_dr) end |