Class: Google::Apis::ComputeAlpha::ResourceStatusServiceIntegrationStatusBackupDrStatus
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::ResourceStatusServiceIntegrationStatusBackupDrStatus
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Message defining compute perspective of the result of integration with Backup and DR. FAILED status indicates that the operation specified did not complete correctly and should be retried with the same value.
Instance Attribute Summary collapse
-
#integration_details ⇒ String
The PlanReference object created by Backup and DR to maintain the actual status of backups.
-
#state ⇒ String
Enum representing the registration state of a Backup and DR backup plan for the instance.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ResourceStatusServiceIntegrationStatusBackupDrStatus
constructor
A new instance of ResourceStatusServiceIntegrationStatusBackupDrStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ResourceStatusServiceIntegrationStatusBackupDrStatus
Returns a new instance of ResourceStatusServiceIntegrationStatusBackupDrStatus.
63663 63664 63665 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63663 def initialize(**args) update!(**args) end |
Instance Attribute Details
#integration_details ⇒ String
The PlanReference object created by Backup and DR to maintain the
actual status of backups. May still be present if removing the backup
plan fails.
Corresponds to the JSON property integrationDetails
63655 63656 63657 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63655 def integration_details @integration_details end |
#state ⇒ String
Enum representing the registration state of a Backup and DR backup plan
for the instance.
Corresponds to the JSON property state
63661 63662 63663 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63661 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
63668 63669 63670 63671 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63668 def update!(**args) @integration_details = args[:integration_details] if args.key?(:integration_details) @state = args[:state] if args.key?(:state) end |