Class: Google::Apis::ComputeAlpha::ResourceStatusServiceIntegrationStatusBackupDrStatus

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Message defining compute perspective of the result of integration with Backup and DR. FAILED status indicates that the operation specified did not complete correctly and should be retried with the same value.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ResourceStatusServiceIntegrationStatusBackupDrStatus

Returns a new instance of ResourceStatusServiceIntegrationStatusBackupDrStatus.



63369
63370
63371
# File 'lib/google/apis/compute_alpha/classes.rb', line 63369

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#integration_detailsString

The PlanReference object created by Backup and DR to maintain the actual status of backups. May still be present if removing the backup plan fails. Corresponds to the JSON property integrationDetails

Returns:

  • (String)


63361
63362
63363
# File 'lib/google/apis/compute_alpha/classes.rb', line 63361

def integration_details
  @integration_details
end

#stateString

Enum representing the registration state of a Backup and DR backup plan for the instance. Corresponds to the JSON property state

Returns:

  • (String)


63367
63368
63369
# File 'lib/google/apis/compute_alpha/classes.rb', line 63367

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



63374
63375
63376
63377
# File 'lib/google/apis/compute_alpha/classes.rb', line 63374

def update!(**args)
  @integration_details = args[:integration_details] if args.key?(:integration_details)
  @state = args[:state] if args.key?(:state)
end