Class: Google::Apis::ComputeAlpha::ResourceStatusServiceIntegrationStatusBackupDrStatus
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::ResourceStatusServiceIntegrationStatusBackupDrStatus
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Message defining compute perspective of the result of integration with Backup and DR. FAILED status indicates that the operation specified did not complete correctly and should be retried with the same value.
Instance Attribute Summary collapse
-
#integration_details ⇒ String
The PlanReference object created by Backup and DR to maintain the actual status of backups.
-
#state ⇒ String
Enum representing the registration state of a Backup and DR backup plan for the instance.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ResourceStatusServiceIntegrationStatusBackupDrStatus
constructor
A new instance of ResourceStatusServiceIntegrationStatusBackupDrStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ResourceStatusServiceIntegrationStatusBackupDrStatus
Returns a new instance of ResourceStatusServiceIntegrationStatusBackupDrStatus.
60334 60335 60336 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 60334 def initialize(**args) update!(**args) end |
Instance Attribute Details
#integration_details ⇒ String
The PlanReference object created by Backup and DR to maintain the
actual status of backups. May still be present if removing the backup
plan fails.
Corresponds to the JSON property integrationDetails
60326 60327 60328 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 60326 def integration_details @integration_details end |
#state ⇒ String
Enum representing the registration state of a Backup and DR backup plan
for the instance.
Corresponds to the JSON property state
60332 60333 60334 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 60332 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
60339 60340 60341 60342 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 60339 def update!(**args) @integration_details = args[:integration_details] if args.key?(:integration_details) @state = args[:state] if args.key?(:state) end |