Class: Google::Apis::ComputeAlpha::ResourceStatusShutdownDetails
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::ResourceStatusShutdownDetails
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Specifies if the instance is in PENDING_STOP state or there is a
programmed stop scheduled.
Instance Attribute Summary collapse
-
#max_duration ⇒ Google::Apis::ComputeAlpha::Duration
A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution.
-
#request_timestamp ⇒ String
Past timestamp indicating the beginning of current
stopStatein RFC3339 text format. -
#stop_state ⇒ String
Current stopping state of the instance.
-
#target_state ⇒ String
Target instance state.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ResourceStatusShutdownDetails
constructor
A new instance of ResourceStatusShutdownDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ResourceStatusShutdownDetails
Returns a new instance of ResourceStatusShutdownDetails.
63703 63704 63705 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63703 def initialize(**args) update!(**args) end |
Instance Attribute Details
#max_duration ⇒ Google::Apis::ComputeAlpha::Duration
A Duration represents a fixed-length span of time represented
as a count of seconds and fractions of seconds at nanosecond
resolution. It is independent of any calendar and concepts like "day"
or "month". Range is approximately 10,000 years.
Corresponds to the JSON property maxDuration
63685 63686 63687 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63685 def max_duration @max_duration end |
#request_timestamp ⇒ String
Past timestamp indicating the beginning of current stopState in RFC3339 text
format.
Corresponds to the JSON property requestTimestamp
63691 63692 63693 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63691 def @request_timestamp end |
#stop_state ⇒ String
Current stopping state of the instance.
Corresponds to the JSON property stopState
63696 63697 63698 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63696 def stop_state @stop_state end |
#target_state ⇒ String
Target instance state.
Corresponds to the JSON property targetState
63701 63702 63703 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63701 def target_state @target_state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
63708 63709 63710 63711 63712 63713 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63708 def update!(**args) @max_duration = args[:max_duration] if args.key?(:max_duration) @request_timestamp = args[:request_timestamp] if args.key?(:request_timestamp) @stop_state = args[:stop_state] if args.key?(:stop_state) @target_state = args[:target_state] if args.key?(:target_state) end |