Class: Google::Apis::ComputeAlpha::ResourceStatusShutdownDetails

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Specifies if the instance is in PENDING_STOP state or there is a programmed stop scheduled.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ResourceStatusShutdownDetails

Returns a new instance of ResourceStatusShutdownDetails.



62023
62024
62025
# File 'lib/google/apis/compute_alpha/classes.rb', line 62023

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#max_durationGoogle::Apis::ComputeAlpha::Duration

A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution. It is independent of any calendar and concepts like "day" or "month". Range is approximately 10,000 years. Corresponds to the JSON property maxDuration



62005
62006
62007
# File 'lib/google/apis/compute_alpha/classes.rb', line 62005

def max_duration
  @max_duration
end

#request_timestampString

Past timestamp indicating the beginning of current stopState in RFC3339 text format. Corresponds to the JSON property requestTimestamp

Returns:

  • (String)


62011
62012
62013
# File 'lib/google/apis/compute_alpha/classes.rb', line 62011

def request_timestamp
  @request_timestamp
end

#stop_stateString

Current stopping state of the instance. Corresponds to the JSON property stopState

Returns:

  • (String)


62016
62017
62018
# File 'lib/google/apis/compute_alpha/classes.rb', line 62016

def stop_state
  @stop_state
end

#target_stateString

Target instance state. Corresponds to the JSON property targetState

Returns:

  • (String)


62021
62022
62023
# File 'lib/google/apis/compute_alpha/classes.rb', line 62021

def target_state
  @target_state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



62028
62029
62030
62031
62032
62033
# File 'lib/google/apis/compute_alpha/classes.rb', line 62028

def update!(**args)
  @max_duration = args[:max_duration] if args.key?(:max_duration)
  @request_timestamp = args[:request_timestamp] if args.key?(:request_timestamp)
  @stop_state = args[:stop_state] if args.key?(:stop_state)
  @target_state = args[:target_state] if args.key?(:target_state)
end