Class: Google::Apis::ComputeAlpha::ResourceStatusShutdownDetails

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Specifies if the instance is in PENDING_STOP state or there is a programmed stop scheduled.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ResourceStatusShutdownDetails

Returns a new instance of ResourceStatusShutdownDetails.



61434
61435
61436
# File 'lib/google/apis/compute_alpha/classes.rb', line 61434

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#max_durationGoogle::Apis::ComputeAlpha::Duration

A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution. It is independent of any calendar and concepts like "day" or "month". Range is approximately 10,000 years. Corresponds to the JSON property maxDuration



61416
61417
61418
# File 'lib/google/apis/compute_alpha/classes.rb', line 61416

def max_duration
  @max_duration
end

#request_timestampString

Past timestamp indicating the beginning of current stopState in RFC3339 text format. Corresponds to the JSON property requestTimestamp

Returns:

  • (String)


61422
61423
61424
# File 'lib/google/apis/compute_alpha/classes.rb', line 61422

def request_timestamp
  @request_timestamp
end

#stop_stateString

Current stopping state of the instance. Corresponds to the JSON property stopState

Returns:

  • (String)


61427
61428
61429
# File 'lib/google/apis/compute_alpha/classes.rb', line 61427

def stop_state
  @stop_state
end

#target_stateString

Target instance state. Corresponds to the JSON property targetState

Returns:

  • (String)


61432
61433
61434
# File 'lib/google/apis/compute_alpha/classes.rb', line 61432

def target_state
  @target_state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



61439
61440
61441
61442
61443
61444
# File 'lib/google/apis/compute_alpha/classes.rb', line 61439

def update!(**args)
  @max_duration = args[:max_duration] if args.key?(:max_duration)
  @request_timestamp = args[:request_timestamp] if args.key?(:request_timestamp)
  @stop_state = args[:stop_state] if args.key?(:stop_state)
  @target_state = args[:target_state] if args.key?(:target_state)
end