Class: Google::Apis::ComputeAlpha::RiskDetails
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::RiskDetails
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Detailed insights and metrics about a detected reliability risk.
Instance Attribute Summary collapse
-
#duration ⇒ String
The duration of the risk since it was detected.
-
#global_dns_insight ⇒ Google::Apis::ComputeAlpha::RiskDetailsGlobalDnsInsight
Detailed insights for a global DNS reliability risk.
-
#last_update_timestamp ⇒ String
The last time the risk was updated.
-
#severity ⇒ String
The severity of the risk.
-
#type ⇒ String
The type of risk.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RiskDetails
constructor
A new instance of RiskDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RiskDetails
Returns a new instance of RiskDetails.
63451 63452 63453 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63451 def initialize(**args) update!(**args) end |
Instance Attribute Details
#duration ⇒ String
The duration of the risk since it was detected.
Corresponds to the JSON property duration
63429 63430 63431 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63429 def duration @duration end |
#global_dns_insight ⇒ Google::Apis::ComputeAlpha::RiskDetailsGlobalDnsInsight
Detailed insights for a global DNS reliability risk.
Corresponds to the JSON property globalDnsInsight
63434 63435 63436 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63434 def global_dns_insight @global_dns_insight end |
#last_update_timestamp ⇒ String
The last time the risk was updated.
Corresponds to the JSON property lastUpdateTimestamp
63439 63440 63441 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63439 def @last_update_timestamp end |
#severity ⇒ String
The severity of the risk.
Corresponds to the JSON property severity
63444 63445 63446 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63444 def severity @severity end |
#type ⇒ String
The type of risk.
Corresponds to the JSON property type
63449 63450 63451 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63449 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
63456 63457 63458 63459 63460 63461 63462 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63456 def update!(**args) @duration = args[:duration] if args.key?(:duration) @global_dns_insight = args[:global_dns_insight] if args.key?(:global_dns_insight) @last_update_timestamp = args[:last_update_timestamp] if args.key?(:last_update_timestamp) @severity = args[:severity] if args.key?(:severity) @type = args[:type] if args.key?(:type) end |