Class: Google::Apis::ComputeAlpha::RiskDetails
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::RiskDetails
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Details about a risk.
Instance Attribute Summary collapse
-
#duration ⇒ String
The duration of the risk since it was detected.
-
#global_dns_insight ⇒ Google::Apis::ComputeAlpha::RiskDetailsGlobalDnsInsight
Corresponds to the JSON property
globalDnsInsight. -
#last_update_timestamp ⇒ String
The last time the risk was updated.
-
#severity ⇒ String
The severity of the risk.
-
#type ⇒ String
The type of risk.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RiskDetails
constructor
A new instance of RiskDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RiskDetails
Returns a new instance of RiskDetails.
61476 61477 61478 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61476 def initialize(**args) update!(**args) end |
Instance Attribute Details
#duration ⇒ String
The duration of the risk since it was detected.
Corresponds to the JSON property duration
61454 61455 61456 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61454 def duration @duration end |
#global_dns_insight ⇒ Google::Apis::ComputeAlpha::RiskDetailsGlobalDnsInsight
Corresponds to the JSON property globalDnsInsight
61459 61460 61461 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61459 def global_dns_insight @global_dns_insight end |
#last_update_timestamp ⇒ String
The last time the risk was updated.
Corresponds to the JSON property lastUpdateTimestamp
61464 61465 61466 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61464 def @last_update_timestamp end |
#severity ⇒ String
The severity of the risk.
Corresponds to the JSON property severity
61469 61470 61471 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61469 def severity @severity end |
#type ⇒ String
The type of risk.
Corresponds to the JSON property type
61474 61475 61476 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61474 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
61481 61482 61483 61484 61485 61486 61487 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61481 def update!(**args) @duration = args[:duration] if args.key?(:duration) @global_dns_insight = args[:global_dns_insight] if args.key?(:global_dns_insight) @last_update_timestamp = args[:last_update_timestamp] if args.key?(:last_update_timestamp) @severity = args[:severity] if args.key?(:severity) @type = args[:type] if args.key?(:type) end |