Class: Google::Apis::ComputeAlpha::RiskDetailsGlobalDnsInsight
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::RiskDetailsGlobalDnsInsight
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#project_default_is_global_dns ⇒ Boolean
(also: #project_default_is_global_dns?)
Whether the project default DNS setting is global or not.
-
#query_observation_window ⇒ String
The observation window for the query counts.
-
#risky_query_count ⇒ Fixnum
The number of queries that are risky.
-
#total_query_count ⇒ Fixnum
The total number of queries in the observation window.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RiskDetailsGlobalDnsInsight
constructor
A new instance of RiskDetailsGlobalDnsInsight.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RiskDetailsGlobalDnsInsight
Returns a new instance of RiskDetailsGlobalDnsInsight.
62130 62131 62132 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 62130 def initialize(**args) update!(**args) end |
Instance Attribute Details
#project_default_is_global_dns ⇒ Boolean Also known as: project_default_is_global_dns?
Whether the project default DNS setting is global or not.
Corresponds to the JSON property projectDefaultIsGlobalDns
62111 62112 62113 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 62111 def project_default_is_global_dns @project_default_is_global_dns end |
#query_observation_window ⇒ String
The observation window for the query counts.
Corresponds to the JSON property queryObservationWindow
62117 62118 62119 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 62117 def query_observation_window @query_observation_window end |
#risky_query_count ⇒ Fixnum
The number of queries that are risky. This will always be less than
total_query_count.
Corresponds to the JSON property riskyQueryCount
62123 62124 62125 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 62123 def risky_query_count @risky_query_count end |
#total_query_count ⇒ Fixnum
The total number of queries in the observation window.
Corresponds to the JSON property totalQueryCount
62128 62129 62130 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 62128 def total_query_count @total_query_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
62135 62136 62137 62138 62139 62140 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 62135 def update!(**args) @project_default_is_global_dns = args[:project_default_is_global_dns] if args.key?(:project_default_is_global_dns) @query_observation_window = args[:query_observation_window] if args.key?(:query_observation_window) @risky_query_count = args[:risky_query_count] if args.key?(:risky_query_count) @total_query_count = args[:total_query_count] if args.key?(:total_query_count) end |