Class: Google::Apis::ComputeAlpha::Rollout

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Rollout resource. A Rollout is a specific instance of a RolloutPlan. It represents a single execution of a strategy to roll out a specific resource. It also provides APIs to interact with the rollout.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Rollout

Returns a new instance of Rollout.



62275
62276
62277
# File 'lib/google/apis/compute_alpha/classes.rb', line 62275

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cancellation_timeString

Output only. The timestamp at which the Rollout was cancelled. Corresponds to the JSON property cancellationTime

Returns:

  • (String)


62178
62179
62180
# File 'lib/google/apis/compute_alpha/classes.rb', line 62178

def cancellation_time
  @cancellation_time
end

#completion_timeString

Output only. The timestamp at which the Rollout was completed. Corresponds to the JSON property completionTime

Returns:

  • (String)


62183
62184
62185
# File 'lib/google/apis/compute_alpha/classes.rb', line 62183

def completion_time
  @completion_time
end

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


62189
62190
62191
# File 'lib/google/apis/compute_alpha/classes.rb', line 62189

def creation_timestamp
  @creation_timestamp
end

#current_wave_numberFixnum

Output only. The number of the currently running wave. Ex. 1 Corresponds to the JSON property currentWaveNumber

Returns:

  • (Fixnum)


62195
62196
62197
# File 'lib/google/apis/compute_alpha/classes.rb', line 62195

def current_wave_number
  @current_wave_number
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


62201
62202
62203
# File 'lib/google/apis/compute_alpha/classes.rb', line 62201

def description
  @description
end

#etagString

Output only. etag of the Rollout Ex. abc1234 Corresponds to the JSON property etag

Returns:

  • (String)


62207
62208
62209
# File 'lib/google/apis/compute_alpha/classes.rb', line 62207

def etag
  @etag
end

#idFixnum

Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


62214
62215
62216
# File 'lib/google/apis/compute_alpha/classes.rb', line 62214

def id
  @id
end

#kindString

Output only. [Output Only] Type of the resource. Always compute#rollout for rollouts. Corresponds to the JSON property kind

Returns:

  • (String)


62220
62221
62222
# File 'lib/google/apis/compute_alpha/classes.rb', line 62220

def kind
  @kind
end

#nameString

Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


62231
62232
62233
# File 'lib/google/apis/compute_alpha/classes.rb', line 62231

def name
  @name
end

#pause_timeString

Output only. The timestamp at which the Rollout was paused. Corresponds to the JSON property pauseTime

Returns:

  • (String)


62236
62237
62238
# File 'lib/google/apis/compute_alpha/classes.rb', line 62236

def pause_time
  @pause_time
end

#resume_timeString

Output only. The timestamp at which the Rollout was resumed. Corresponds to the JSON property resumeTime

Returns:

  • (String)


62241
62242
62243
# File 'lib/google/apis/compute_alpha/classes.rb', line 62241

def resume_time
  @resume_time
end

#rollout_entityGoogle::Apis::ComputeAlpha::RolloutRolloutEntity

Specifications of the resource to roll out. Corresponds to the JSON property rolloutEntity



62246
62247
62248
# File 'lib/google/apis/compute_alpha/classes.rb', line 62246

def rollout_entity
  @rollout_entity
end

#rollout_planString

Required. Rollout Plan used to model the Rollout. Ex. compute.googleapis.com/v1/projects/1234/rolloutPlans/rp1 Corresponds to the JSON property rolloutPlan

Returns:

  • (String)


62252
62253
62254
# File 'lib/google/apis/compute_alpha/classes.rb', line 62252

def rollout_plan
  @rollout_plan
end

Output only. [Output Only] Server-defined fully-qualified URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


62258
62259
62260
# File 'lib/google/apis/compute_alpha/classes.rb', line 62258

def self_link
  @self_link
end

Output only. [Output Only] Server-defined URL for this resource's resource id. Corresponds to the JSON property selfLinkWithId

Returns:

  • (String)


62263
62264
62265
# File 'lib/google/apis/compute_alpha/classes.rb', line 62263

def self_link_with_id
  @self_link_with_id
end

#stateString

Output only. The current state of the Rollout. Corresponds to the JSON property state

Returns:

  • (String)


62268
62269
62270
# File 'lib/google/apis/compute_alpha/classes.rb', line 62268

def state
  @state
end

#wave_detailsArray<Google::Apis::ComputeAlpha::RolloutWaveDetails>

Output only. Details about each wave of the rollout. Corresponds to the JSON property waveDetails



62273
62274
62275
# File 'lib/google/apis/compute_alpha/classes.rb', line 62273

def wave_details
  @wave_details
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



62280
62281
62282
62283
62284
62285
62286
62287
62288
62289
62290
62291
62292
62293
62294
62295
62296
62297
62298
# File 'lib/google/apis/compute_alpha/classes.rb', line 62280

def update!(**args)
  @cancellation_time = args[:cancellation_time] if args.key?(:cancellation_time)
  @completion_time = args[:completion_time] if args.key?(:completion_time)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @current_wave_number = args[:current_wave_number] if args.key?(:current_wave_number)
  @description = args[:description] if args.key?(:description)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @pause_time = args[:pause_time] if args.key?(:pause_time)
  @resume_time = args[:resume_time] if args.key?(:resume_time)
  @rollout_entity = args[:rollout_entity] if args.key?(:rollout_entity)
  @rollout_plan = args[:rollout_plan] if args.key?(:rollout_plan)
  @self_link = args[:self_link] if args.key?(:self_link)
  @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id)
  @state = args[:state] if args.key?(:state)
  @wave_details = args[:wave_details] if args.key?(:wave_details)
end