Class: Google::Apis::ComputeAlpha::Rollout
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::Rollout
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Rollout resource. A Rollout is a specific instance of a RolloutPlan. It represents a single execution of a strategy to roll out a specific resource. It also provides APIs to interact with the rollout.
Instance Attribute Summary collapse
-
#cancellation_time ⇒ String
Output only.
-
#completion_time ⇒ String
Output only.
-
#creation_timestamp ⇒ String
Output only.
-
#current_wave_number ⇒ Fixnum
Output only.
-
#description ⇒ String
An optional description of this resource.
-
#etag ⇒ String
Output only.
-
#id ⇒ Fixnum
Output only.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
Name of the resource.
-
#pause_time ⇒ String
Output only.
-
#resume_time ⇒ String
Output only.
-
#rollout_entity ⇒ Google::Apis::ComputeAlpha::RolloutRolloutEntity
Specifications of the resource to roll out.
-
#rollout_plan ⇒ String
Required.
-
#self_link ⇒ String
Output only.
-
#self_link_with_id ⇒ String
Output only.
-
#state ⇒ String
Output only.
-
#wave_details ⇒ Array<Google::Apis::ComputeAlpha::RolloutWaveDetails>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Rollout
constructor
A new instance of Rollout.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Rollout
Returns a new instance of Rollout.
61659 61660 61661 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61659 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cancellation_time ⇒ String
Output only. The timestamp at which the Rollout was cancelled.
Corresponds to the JSON property cancellationTime
61562 61563 61564 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61562 def cancellation_time @cancellation_time end |
#completion_time ⇒ String
Output only. The timestamp at which the Rollout was completed.
Corresponds to the JSON property completionTime
61567 61568 61569 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61567 def completion_time @completion_time end |
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
61573 61574 61575 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61573 def @creation_timestamp end |
#current_wave_number ⇒ Fixnum
Output only. The number of the currently running wave.
Ex. 1
Corresponds to the JSON property currentWaveNumber
61579 61580 61581 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61579 def current_wave_number @current_wave_number end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
61585 61586 61587 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61585 def description @description end |
#etag ⇒ String
Output only. etag of the Rollout
Ex. abc1234
Corresponds to the JSON property etag
61591 61592 61593 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61591 def etag @etag end |
#id ⇒ Fixnum
Output only. [Output Only] The unique identifier for the resource. This
identifier is
defined by the server.
Corresponds to the JSON property id
61598 61599 61600 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61598 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Always compute#rollout
for rollouts.
Corresponds to the JSON property kind
61604 61605 61606 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61604 def kind @kind end |
#name ⇒ String
Name of the resource. Provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])?
which means the first character must be a lowercase letter, and all
following characters must be a dash, lowercase letter, or digit, except
the last character, which cannot be a dash.
Corresponds to the JSON property name
61615 61616 61617 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61615 def name @name end |
#pause_time ⇒ String
Output only. The timestamp at which the Rollout was paused.
Corresponds to the JSON property pauseTime
61620 61621 61622 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61620 def pause_time @pause_time end |
#resume_time ⇒ String
Output only. The timestamp at which the Rollout was resumed.
Corresponds to the JSON property resumeTime
61625 61626 61627 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61625 def resume_time @resume_time end |
#rollout_entity ⇒ Google::Apis::ComputeAlpha::RolloutRolloutEntity
Specifications of the resource to roll out.
Corresponds to the JSON property rolloutEntity
61630 61631 61632 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61630 def rollout_entity @rollout_entity end |
#rollout_plan ⇒ String
Required. Rollout Plan used to model the Rollout.
Ex. compute.googleapis.com/v1/projects/1234/rolloutPlans/rp1
Corresponds to the JSON property rolloutPlan
61636 61637 61638 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61636 def rollout_plan @rollout_plan end |
#self_link ⇒ String
Output only. [Output Only] Server-defined fully-qualified URL for this
resource.
Corresponds to the JSON property selfLink
61642 61643 61644 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61642 def self_link @self_link end |
#self_link_with_id ⇒ String
Output only. [Output Only] Server-defined URL for this resource's resource id.
Corresponds to the JSON property selfLinkWithId
61647 61648 61649 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61647 def self_link_with_id @self_link_with_id end |
#state ⇒ String
Output only. The current state of the Rollout.
Corresponds to the JSON property state
61652 61653 61654 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61652 def state @state end |
#wave_details ⇒ Array<Google::Apis::ComputeAlpha::RolloutWaveDetails>
Output only. Details about each wave of the rollout.
Corresponds to the JSON property waveDetails
61657 61658 61659 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61657 def wave_details @wave_details end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
61664 61665 61666 61667 61668 61669 61670 61671 61672 61673 61674 61675 61676 61677 61678 61679 61680 61681 61682 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61664 def update!(**args) @cancellation_time = args[:cancellation_time] if args.key?(:cancellation_time) @completion_time = args[:completion_time] if args.key?(:completion_time) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @current_wave_number = args[:current_wave_number] if args.key?(:current_wave_number) @description = args[:description] if args.key?(:description) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @pause_time = args[:pause_time] if args.key?(:pause_time) @resume_time = args[:resume_time] if args.key?(:resume_time) @rollout_entity = args[:rollout_entity] if args.key?(:rollout_entity) @rollout_plan = args[:rollout_plan] if args.key?(:rollout_plan) @self_link = args[:self_link] if args.key?(:self_link) @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id) @state = args[:state] if args.key?(:state) @wave_details = args[:wave_details] if args.key?(:wave_details) end |