Class: Google::Apis::ComputeAlpha::Rollout
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::Rollout
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Rollout resource. A Rollout is a specific instance of a RolloutPlan. It represents a single execution of a strategy to roll out a specific resource. It also provides APIs to interact with the rollout.
Instance Attribute Summary collapse
-
#cancellation_time ⇒ String
Output only.
-
#completion_time ⇒ String
Output only.
-
#creation_timestamp ⇒ String
Output only.
-
#current_wave_number ⇒ Fixnum
Output only.
-
#description ⇒ String
An optional description of this resource.
-
#etag ⇒ String
Output only.
-
#id ⇒ Fixnum
Output only.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
Name of the resource.
-
#pause_time ⇒ String
Output only.
-
#resume_time ⇒ String
Output only.
-
#rollout_entity ⇒ Google::Apis::ComputeAlpha::RolloutRolloutEntity
Specifications of the resource to roll out.
-
#rollout_plan ⇒ String
Required.
-
#self_link ⇒ String
Output only.
-
#self_link_with_id ⇒ String
Output only.
-
#state ⇒ String
Output only.
-
#wave_details ⇒ Array<Google::Apis::ComputeAlpha::RolloutWaveDetails>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Rollout
constructor
A new instance of Rollout.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Rollout
Returns a new instance of Rollout.
61438 61439 61440 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61438 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cancellation_time ⇒ String
Output only. The timestamp at which the Rollout was cancelled.
Corresponds to the JSON property cancellationTime
61341 61342 61343 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61341 def cancellation_time @cancellation_time end |
#completion_time ⇒ String
Output only. The timestamp at which the Rollout was completed.
Corresponds to the JSON property completionTime
61346 61347 61348 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61346 def completion_time @completion_time end |
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
61352 61353 61354 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61352 def @creation_timestamp end |
#current_wave_number ⇒ Fixnum
Output only. The number of the currently running wave.
Ex. 1
Corresponds to the JSON property currentWaveNumber
61358 61359 61360 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61358 def current_wave_number @current_wave_number end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
61364 61365 61366 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61364 def description @description end |
#etag ⇒ String
Output only. etag of the Rollout
Ex. abc1234
Corresponds to the JSON property etag
61370 61371 61372 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61370 def etag @etag end |
#id ⇒ Fixnum
Output only. [Output Only] The unique identifier for the resource. This
identifier is
defined by the server.
Corresponds to the JSON property id
61377 61378 61379 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61377 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Always compute#rollout
for rollouts.
Corresponds to the JSON property kind
61383 61384 61385 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61383 def kind @kind end |
#name ⇒ String
Name of the resource. Provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])?
which means the first character must be a lowercase letter, and all
following characters must be a dash, lowercase letter, or digit, except
the last character, which cannot be a dash.
Corresponds to the JSON property name
61394 61395 61396 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61394 def name @name end |
#pause_time ⇒ String
Output only. The timestamp at which the Rollout was paused.
Corresponds to the JSON property pauseTime
61399 61400 61401 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61399 def pause_time @pause_time end |
#resume_time ⇒ String
Output only. The timestamp at which the Rollout was resumed.
Corresponds to the JSON property resumeTime
61404 61405 61406 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61404 def resume_time @resume_time end |
#rollout_entity ⇒ Google::Apis::ComputeAlpha::RolloutRolloutEntity
Specifications of the resource to roll out.
Corresponds to the JSON property rolloutEntity
61409 61410 61411 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61409 def rollout_entity @rollout_entity end |
#rollout_plan ⇒ String
Required. Rollout Plan used to model the Rollout.
Ex. compute.googleapis.com/v1/projects/1234/rolloutPlans/rp1
Corresponds to the JSON property rolloutPlan
61415 61416 61417 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61415 def rollout_plan @rollout_plan end |
#self_link ⇒ String
Output only. [Output Only] Server-defined fully-qualified URL for this
resource.
Corresponds to the JSON property selfLink
61421 61422 61423 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61421 def self_link @self_link end |
#self_link_with_id ⇒ String
Output only. [Output Only] Server-defined URL for this resource's resource id.
Corresponds to the JSON property selfLinkWithId
61426 61427 61428 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61426 def self_link_with_id @self_link_with_id end |
#state ⇒ String
Output only. The current state of the Rollout.
Corresponds to the JSON property state
61431 61432 61433 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61431 def state @state end |
#wave_details ⇒ Array<Google::Apis::ComputeAlpha::RolloutWaveDetails>
Output only. Details about each wave of the rollout.
Corresponds to the JSON property waveDetails
61436 61437 61438 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61436 def wave_details @wave_details end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
61443 61444 61445 61446 61447 61448 61449 61450 61451 61452 61453 61454 61455 61456 61457 61458 61459 61460 61461 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61443 def update!(**args) @cancellation_time = args[:cancellation_time] if args.key?(:cancellation_time) @completion_time = args[:completion_time] if args.key?(:completion_time) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @current_wave_number = args[:current_wave_number] if args.key?(:current_wave_number) @description = args[:description] if args.key?(:description) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @pause_time = args[:pause_time] if args.key?(:pause_time) @resume_time = args[:resume_time] if args.key?(:resume_time) @rollout_entity = args[:rollout_entity] if args.key?(:rollout_entity) @rollout_plan = args[:rollout_plan] if args.key?(:rollout_plan) @self_link = args[:self_link] if args.key?(:self_link) @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id) @state = args[:state] if args.key?(:state) @wave_details = args[:wave_details] if args.key?(:wave_details) end |