Class: Google::Apis::ComputeAlpha::Rollout
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::Rollout
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Rollout resource. A Rollout is a specific instance of a RolloutPlan. It represents a single execution of a strategy to roll out a specific resource. It also provides APIs to interact with the rollout.
Instance Attribute Summary collapse
-
#cancellation_time ⇒ String
Output only.
-
#completion_time ⇒ String
Output only.
-
#creation_timestamp ⇒ String
Output only.
-
#current_wave_number ⇒ Fixnum
Output only.
-
#description ⇒ String
An optional description of this resource.
-
#etag ⇒ String
Output only.
-
#id ⇒ Fixnum
Output only.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
Name of the resource.
-
#rollout_entity ⇒ Google::Apis::ComputeAlpha::RolloutRolloutEntity
Specifications of the resource to roll out.
-
#rollout_plan ⇒ String
Required.
-
#self_link ⇒ String
Output only.
-
#self_link_with_id ⇒ String
Output only.
-
#state ⇒ String
Output only.
-
#wave_details ⇒ Array<Google::Apis::ComputeAlpha::RolloutWaveDetails>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Rollout
constructor
A new instance of Rollout.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Rollout
Returns a new instance of Rollout.
60591 60592 60593 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 60591 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cancellation_time ⇒ String
Output only. The timestamp at which the Rollout was cancelled.
Corresponds to the JSON property cancellationTime
60504 60505 60506 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 60504 def cancellation_time @cancellation_time end |
#completion_time ⇒ String
Output only. The timestamp at which the Rollout was completed.
Corresponds to the JSON property completionTime
60509 60510 60511 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 60509 def completion_time @completion_time end |
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
60515 60516 60517 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 60515 def @creation_timestamp end |
#current_wave_number ⇒ Fixnum
Output only. The number of the currently running wave.
Ex. 1
Corresponds to the JSON property currentWaveNumber
60521 60522 60523 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 60521 def current_wave_number @current_wave_number end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
60527 60528 60529 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 60527 def description @description end |
#etag ⇒ String
Output only. etag of the Rollout
Ex. abc1234
Corresponds to the JSON property etag
60533 60534 60535 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 60533 def etag @etag end |
#id ⇒ Fixnum
Output only. [Output Only] The unique identifier for the resource. This
identifier is
defined by the server.
Corresponds to the JSON property id
60540 60541 60542 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 60540 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Always compute#rollout
for rollouts.
Corresponds to the JSON property kind
60546 60547 60548 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 60546 def kind @kind end |
#name ⇒ String
Name of the resource. Provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])?
which means the first character must be a lowercase letter, and all
following characters must be a dash, lowercase letter, or digit, except
the last character, which cannot be a dash.
Corresponds to the JSON property name
60557 60558 60559 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 60557 def name @name end |
#rollout_entity ⇒ Google::Apis::ComputeAlpha::RolloutRolloutEntity
Specifications of the resource to roll out.
Corresponds to the JSON property rolloutEntity
60562 60563 60564 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 60562 def rollout_entity @rollout_entity end |
#rollout_plan ⇒ String
Required. Rollout Plan used to model the Rollout.
Ex. compute.googleapis.com/v1/projects/1234/rolloutPlans/rp1
Corresponds to the JSON property rolloutPlan
60568 60569 60570 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 60568 def rollout_plan @rollout_plan end |
#self_link ⇒ String
Output only. [Output Only] Server-defined fully-qualified URL for this
resource.
Corresponds to the JSON property selfLink
60574 60575 60576 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 60574 def self_link @self_link end |
#self_link_with_id ⇒ String
Output only. [Output Only] Server-defined URL for this resource's resource id.
Corresponds to the JSON property selfLinkWithId
60579 60580 60581 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 60579 def self_link_with_id @self_link_with_id end |
#state ⇒ String
Output only. The current state of the Rollout.
Corresponds to the JSON property state
60584 60585 60586 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 60584 def state @state end |
#wave_details ⇒ Array<Google::Apis::ComputeAlpha::RolloutWaveDetails>
Output only. Details about each wave of the rollout.
Corresponds to the JSON property waveDetails
60589 60590 60591 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 60589 def wave_details @wave_details end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
60596 60597 60598 60599 60600 60601 60602 60603 60604 60605 60606 60607 60608 60609 60610 60611 60612 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 60596 def update!(**args) @cancellation_time = args[:cancellation_time] if args.key?(:cancellation_time) @completion_time = args[:completion_time] if args.key?(:completion_time) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @current_wave_number = args[:current_wave_number] if args.key?(:current_wave_number) @description = args[:description] if args.key?(:description) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @rollout_entity = args[:rollout_entity] if args.key?(:rollout_entity) @rollout_plan = args[:rollout_plan] if args.key?(:rollout_plan) @self_link = args[:self_link] if args.key?(:self_link) @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id) @state = args[:state] if args.key?(:state) @wave_details = args[:wave_details] if args.key?(:wave_details) end |