Class: Google::Apis::ComputeAlpha::RolloutPlan

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

RolloutPlan resource. A RolloutPlan is the customer-defined strategy to divide a large-scale change into smaller increments, referred to as "waves". Each wave targets a specific portion of the overall affected area and defines criteria that must be met before progressing to the subsequent wave.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RolloutPlan

Returns a new instance of RolloutPlan.



63728
63729
63730
# File 'lib/google/apis/compute_alpha/classes.rb', line 63728

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


63674
63675
63676
# File 'lib/google/apis/compute_alpha/classes.rb', line 63674

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


63680
63681
63682
# File 'lib/google/apis/compute_alpha/classes.rb', line 63680

def description
  @description
end

#idFixnum

Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


63687
63688
63689
# File 'lib/google/apis/compute_alpha/classes.rb', line 63687

def id
  @id
end

#kindString

Output only. [Output Only] Type of the resource. Always compute#rolloutPlan for rolloutPlans. Corresponds to the JSON property kind

Returns:

  • (String)


63693
63694
63695
# File 'lib/google/apis/compute_alpha/classes.rb', line 63693

def kind
  @kind
end

#location_scopeString

The location scope of the rollout plan. If not specified, the location scope is considered as ZONAL. Corresponds to the JSON property locationScope

Returns:

  • (String)


63699
63700
63701
# File 'lib/google/apis/compute_alpha/classes.rb', line 63699

def location_scope
  @location_scope
end

#nameString

Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


63710
63711
63712
# File 'lib/google/apis/compute_alpha/classes.rb', line 63710

def name
  @name
end

Output only. [Output Only] Server-defined fully-qualified URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


63716
63717
63718
# File 'lib/google/apis/compute_alpha/classes.rb', line 63716

def self_link
  @self_link
end

Output only. [Output Only] Server-defined URL for this resource's resource id. Corresponds to the JSON property selfLinkWithId

Returns:

  • (String)


63721
63722
63723
# File 'lib/google/apis/compute_alpha/classes.rb', line 63721

def self_link_with_id
  @self_link_with_id
end

#wavesArray<Google::Apis::ComputeAlpha::RolloutPlanWave>

Required. The waves included in this rollout plan. Corresponds to the JSON property waves



63726
63727
63728
# File 'lib/google/apis/compute_alpha/classes.rb', line 63726

def waves
  @waves
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



63733
63734
63735
63736
63737
63738
63739
63740
63741
63742
63743
# File 'lib/google/apis/compute_alpha/classes.rb', line 63733

def update!(**args)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @location_scope = args[:location_scope] if args.key?(:location_scope)
  @name = args[:name] if args.key?(:name)
  @self_link = args[:self_link] if args.key?(:self_link)
  @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id)
  @waves = args[:waves] if args.key?(:waves)
end