Class: Google::Apis::ComputeAlpha::RolloutPlan
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::RolloutPlan
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
RolloutPlan resource. A RolloutPlan is the customer-defined strategy to divide a large-scale change into smaller increments, referred to as "waves". Each wave targets a specific portion of the overall affected area and defines criteria that must be met before progressing to the subsequent wave.
Instance Attribute Summary collapse
-
#creation_timestamp ⇒ String
Output only.
-
#description ⇒ String
An optional description of this resource.
-
#id ⇒ Fixnum
Output only.
-
#kind ⇒ String
Output only.
-
#location_scope ⇒ String
The location scope of the rollout plan.
-
#name ⇒ String
Name of the resource.
-
#self_link ⇒ String
Output only.
-
#self_link_with_id ⇒ String
Output only.
-
#waves ⇒ Array<Google::Apis::ComputeAlpha::RolloutPlanWave>
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RolloutPlan
constructor
A new instance of RolloutPlan.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RolloutPlan
Returns a new instance of RolloutPlan.
61751 61752 61753 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61751 def initialize(**args) update!(**args) end |
Instance Attribute Details
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
61697 61698 61699 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61697 def @creation_timestamp end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
61703 61704 61705 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61703 def description @description end |
#id ⇒ Fixnum
Output only. [Output Only] The unique identifier for the resource. This
identifier is
defined by the server.
Corresponds to the JSON property id
61710 61711 61712 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61710 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Always compute#rolloutPlan
for rolloutPlans.
Corresponds to the JSON property kind
61716 61717 61718 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61716 def kind @kind end |
#location_scope ⇒ String
The location scope of the rollout plan. If not specified, the location
scope is considered as ZONAL.
Corresponds to the JSON property locationScope
61722 61723 61724 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61722 def location_scope @location_scope end |
#name ⇒ String
Name of the resource. Provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])?
which means the first character must be a lowercase letter, and all
following characters must be a dash, lowercase letter, or digit, except
the last character, which cannot be a dash.
Corresponds to the JSON property name
61733 61734 61735 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61733 def name @name end |
#self_link ⇒ String
Output only. [Output Only] Server-defined fully-qualified URL for this
resource.
Corresponds to the JSON property selfLink
61739 61740 61741 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61739 def self_link @self_link end |
#self_link_with_id ⇒ String
Output only. [Output Only] Server-defined URL for this resource's resource id.
Corresponds to the JSON property selfLinkWithId
61744 61745 61746 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61744 def self_link_with_id @self_link_with_id end |
#waves ⇒ Array<Google::Apis::ComputeAlpha::RolloutPlanWave>
Required. The waves included in this rollout plan.
Corresponds to the JSON property waves
61749 61750 61751 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61749 def waves @waves end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
61756 61757 61758 61759 61760 61761 61762 61763 61764 61765 61766 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61756 def update!(**args) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @location_scope = args[:location_scope] if args.key?(:location_scope) @name = args[:name] if args.key?(:name) @self_link = args[:self_link] if args.key?(:self_link) @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id) @waves = args[:waves] if args.key?(:waves) end |