Class: Google::Apis::ComputeAlpha::RolloutPlan
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::RolloutPlan
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
RolloutPlan resource. A RolloutPlan is the customer-defined strategy to divide a large-scale change into smaller increments, referred to as "waves". Each wave targets a specific portion of the overall affected area and defines criteria that must be met before progressing to the subsequent wave.
Instance Attribute Summary collapse
-
#creation_timestamp ⇒ String
Output only.
-
#description ⇒ String
An optional description of this resource.
-
#id ⇒ Fixnum
Output only.
-
#kind ⇒ String
Output only.
-
#location_scope ⇒ String
The location scope of the rollout plan.
-
#name ⇒ String
Name of the resource.
-
#self_link ⇒ String
Output only.
-
#self_link_with_id ⇒ String
Output only.
-
#waves ⇒ Array<Google::Apis::ComputeAlpha::RolloutPlanWave>
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RolloutPlan
constructor
A new instance of RolloutPlan.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RolloutPlan
Returns a new instance of RolloutPlan.
61530 61531 61532 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61530 def initialize(**args) update!(**args) end |
Instance Attribute Details
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
61476 61477 61478 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61476 def @creation_timestamp end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
61482 61483 61484 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61482 def description @description end |
#id ⇒ Fixnum
Output only. [Output Only] The unique identifier for the resource. This
identifier is
defined by the server.
Corresponds to the JSON property id
61489 61490 61491 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61489 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Always compute#rolloutPlan
for rolloutPlans.
Corresponds to the JSON property kind
61495 61496 61497 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61495 def kind @kind end |
#location_scope ⇒ String
The location scope of the rollout plan. If not specified, the location
scope is considered as ZONAL.
Corresponds to the JSON property locationScope
61501 61502 61503 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61501 def location_scope @location_scope end |
#name ⇒ String
Name of the resource. Provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])?
which means the first character must be a lowercase letter, and all
following characters must be a dash, lowercase letter, or digit, except
the last character, which cannot be a dash.
Corresponds to the JSON property name
61512 61513 61514 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61512 def name @name end |
#self_link ⇒ String
Output only. [Output Only] Server-defined fully-qualified URL for this
resource.
Corresponds to the JSON property selfLink
61518 61519 61520 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61518 def self_link @self_link end |
#self_link_with_id ⇒ String
Output only. [Output Only] Server-defined URL for this resource's resource id.
Corresponds to the JSON property selfLinkWithId
61523 61524 61525 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61523 def self_link_with_id @self_link_with_id end |
#waves ⇒ Array<Google::Apis::ComputeAlpha::RolloutPlanWave>
Required. The waves included in this rollout plan.
Corresponds to the JSON property waves
61528 61529 61530 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61528 def waves @waves end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
61535 61536 61537 61538 61539 61540 61541 61542 61543 61544 61545 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 61535 def update!(**args) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @location_scope = args[:location_scope] if args.key?(:location_scope) @name = args[:name] if args.key?(:name) @self_link = args[:self_link] if args.key?(:self_link) @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id) @waves = args[:waves] if args.key?(:waves) end |