Class: Google::Apis::ComputeAlpha::RolloutPlan

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

RolloutPlan resource. A RolloutPlan is the customer-defined strategy to divide a large-scale change into smaller increments, referred to as "waves". Each wave targets a specific portion of the overall affected area and defines criteria that must be met before progressing to the subsequent wave.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RolloutPlan

Returns a new instance of RolloutPlan.



60681
60682
60683
# File 'lib/google/apis/compute_alpha/classes.rb', line 60681

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


60627
60628
60629
# File 'lib/google/apis/compute_alpha/classes.rb', line 60627

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


60633
60634
60635
# File 'lib/google/apis/compute_alpha/classes.rb', line 60633

def description
  @description
end

#idFixnum

Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


60640
60641
60642
# File 'lib/google/apis/compute_alpha/classes.rb', line 60640

def id
  @id
end

#kindString

Output only. [Output Only] Type of the resource. Always compute#rolloutPlan for rolloutPlans. Corresponds to the JSON property kind

Returns:

  • (String)


60646
60647
60648
# File 'lib/google/apis/compute_alpha/classes.rb', line 60646

def kind
  @kind
end

#location_scopeString

The location scope of the rollout plan. If not specified, the location scope is considered as ZONAL. Corresponds to the JSON property locationScope

Returns:

  • (String)


60652
60653
60654
# File 'lib/google/apis/compute_alpha/classes.rb', line 60652

def location_scope
  @location_scope
end

#nameString

Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


60663
60664
60665
# File 'lib/google/apis/compute_alpha/classes.rb', line 60663

def name
  @name
end

Output only. [Output Only] Server-defined fully-qualified URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


60669
60670
60671
# File 'lib/google/apis/compute_alpha/classes.rb', line 60669

def self_link
  @self_link
end

Output only. [Output Only] Server-defined URL for this resource's resource id. Corresponds to the JSON property selfLinkWithId

Returns:

  • (String)


60674
60675
60676
# File 'lib/google/apis/compute_alpha/classes.rb', line 60674

def self_link_with_id
  @self_link_with_id
end

#wavesArray<Google::Apis::ComputeAlpha::RolloutPlanWave>

Required. The waves included in this rollout plan. Corresponds to the JSON property waves



60679
60680
60681
# File 'lib/google/apis/compute_alpha/classes.rb', line 60679

def waves
  @waves
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



60686
60687
60688
60689
60690
60691
60692
60693
60694
60695
60696
# File 'lib/google/apis/compute_alpha/classes.rb', line 60686

def update!(**args)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @location_scope = args[:location_scope] if args.key?(:location_scope)
  @name = args[:name] if args.key?(:name)
  @self_link = args[:self_link] if args.key?(:self_link)
  @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id)
  @waves = args[:waves] if args.key?(:waves)
end