Class: Google::Apis::ComputeAlpha::RolloutPlanWave

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

A single wave in a rollout plan.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RolloutPlanWave

Returns a new instance of RolloutPlanWave.



62394
62395
62396
# File 'lib/google/apis/compute_alpha/classes.rb', line 62394

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

Optional. The display name of this wave of the rollout plan. Corresponds to the JSON property displayName

Returns:

  • (String)


62367
62368
62369
# File 'lib/google/apis/compute_alpha/classes.rb', line 62367

def display_name
  @display_name
end

#numberFixnum

Output only. The wave number. Corresponds to the JSON property number

Returns:

  • (Fixnum)


62372
62373
62374
# File 'lib/google/apis/compute_alpha/classes.rb', line 62372

def number
  @number
end

#orchestration_optionsGoogle::Apis::ComputeAlpha::RolloutPlanWaveOrchestrationOptions

Options to control the pace of orchestration of a wave. These options are required only if the resource being rolled out follows the Orchestrated pattern. Corresponds to the JSON property orchestrationOptions



62379
62380
62381
# File 'lib/google/apis/compute_alpha/classes.rb', line 62379

def orchestration_options
  @orchestration_options
end

#selectorsArray<Google::Apis::ComputeAlpha::RolloutPlanWaveSelector>

Required. The selectors for this wave. There is a logical AND between each selector defined in a wave, so a resource must satisfy the criteria of all the specified selectors to be in scope for the wave. Corresponds to the JSON property selectors



62387
62388
62389
# File 'lib/google/apis/compute_alpha/classes.rb', line 62387

def selectors
  @selectors
end

#validationGoogle::Apis::ComputeAlpha::RolloutPlanWaveValidation

The validation to be performed before progressing to the next wave. Corresponds to the JSON property validation



62392
62393
62394
# File 'lib/google/apis/compute_alpha/classes.rb', line 62392

def validation
  @validation
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



62399
62400
62401
62402
62403
62404
62405
# File 'lib/google/apis/compute_alpha/classes.rb', line 62399

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @number = args[:number] if args.key?(:number)
  @orchestration_options = args[:orchestration_options] if args.key?(:orchestration_options)
  @selectors = args[:selectors] if args.key?(:selectors)
  @validation = args[:validation] if args.key?(:validation)
end