Class: Google::Apis::ComputeAlpha::RolloutPlanWave

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

A single wave in a rollout plan.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RolloutPlanWave

Returns a new instance of RolloutPlanWave.



61805
61806
61807
# File 'lib/google/apis/compute_alpha/classes.rb', line 61805

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

Optional. The display name of this wave of the rollout plan. Corresponds to the JSON property displayName

Returns:

  • (String)


61778
61779
61780
# File 'lib/google/apis/compute_alpha/classes.rb', line 61778

def display_name
  @display_name
end

#numberFixnum

Output only. The wave number. Corresponds to the JSON property number

Returns:

  • (Fixnum)


61783
61784
61785
# File 'lib/google/apis/compute_alpha/classes.rb', line 61783

def number
  @number
end

#orchestration_optionsGoogle::Apis::ComputeAlpha::RolloutPlanWaveOrchestrationOptions

Options to control the pace of orchestration of a wave. These options are required only if the resource being rolled out follows the Orchestrated pattern. Corresponds to the JSON property orchestrationOptions



61790
61791
61792
# File 'lib/google/apis/compute_alpha/classes.rb', line 61790

def orchestration_options
  @orchestration_options
end

#selectorsArray<Google::Apis::ComputeAlpha::RolloutPlanWaveSelector>

Required. The selectors for this wave. There is a logical AND between each selector defined in a wave, so a resource must satisfy the criteria of all the specified selectors to be in scope for the wave. Corresponds to the JSON property selectors



61798
61799
61800
# File 'lib/google/apis/compute_alpha/classes.rb', line 61798

def selectors
  @selectors
end

#validationGoogle::Apis::ComputeAlpha::RolloutPlanWaveValidation

The validation to be performed before progressing to the next wave. Corresponds to the JSON property validation



61803
61804
61805
# File 'lib/google/apis/compute_alpha/classes.rb', line 61803

def validation
  @validation
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



61810
61811
61812
61813
61814
61815
61816
# File 'lib/google/apis/compute_alpha/classes.rb', line 61810

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @number = args[:number] if args.key?(:number)
  @orchestration_options = args[:orchestration_options] if args.key?(:orchestration_options)
  @selectors = args[:selectors] if args.key?(:selectors)
  @validation = args[:validation] if args.key?(:validation)
end