Class: Google::Apis::ComputeAlpha::RolloutPlanWave

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

A single wave in a rollout plan.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RolloutPlanWave

Returns a new instance of RolloutPlanWave.



60733
60734
60735
# File 'lib/google/apis/compute_alpha/classes.rb', line 60733

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

Optional. The display name of this wave of the rollout plan. Corresponds to the JSON property displayName

Returns:

  • (String)


60706
60707
60708
# File 'lib/google/apis/compute_alpha/classes.rb', line 60706

def display_name
  @display_name
end

#numberFixnum

Output only. The wave number. Corresponds to the JSON property number

Returns:

  • (Fixnum)


60711
60712
60713
# File 'lib/google/apis/compute_alpha/classes.rb', line 60711

def number
  @number
end

#orchestration_optionsGoogle::Apis::ComputeAlpha::RolloutPlanWaveOrchestrationOptions

Options to control the pace of orchestration of a wave. These options are required only if the resource being rolled out follows the Orchestrated pattern. Corresponds to the JSON property orchestrationOptions



60718
60719
60720
# File 'lib/google/apis/compute_alpha/classes.rb', line 60718

def orchestration_options
  @orchestration_options
end

#selectorsArray<Google::Apis::ComputeAlpha::RolloutPlanWaveSelector>

Required. The selectors for this wave. There is a logical AND between each selector defined in a wave, so a resource must satisfy the criteria of all the specified selectors to be in scope for the wave. Corresponds to the JSON property selectors



60726
60727
60728
# File 'lib/google/apis/compute_alpha/classes.rb', line 60726

def selectors
  @selectors
end

#validationGoogle::Apis::ComputeAlpha::RolloutPlanWaveValidation

The validation to be performed before progressing to the next wave. Corresponds to the JSON property validation



60731
60732
60733
# File 'lib/google/apis/compute_alpha/classes.rb', line 60731

def validation
  @validation
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



60738
60739
60740
60741
60742
60743
60744
# File 'lib/google/apis/compute_alpha/classes.rb', line 60738

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @number = args[:number] if args.key?(:number)
  @orchestration_options = args[:orchestration_options] if args.key?(:orchestration_options)
  @selectors = args[:selectors] if args.key?(:selectors)
  @validation = args[:validation] if args.key?(:validation)
end