Class: Google::Apis::ComputeAlpha::RolloutPlanWaveOrchestrationOptions

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Options to control the pace of orchestration of a wave. These options are required only if the resource being rolled out follows the Orchestrated pattern.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RolloutPlanWaveOrchestrationOptions

Returns a new instance of RolloutPlanWaveOrchestrationOptions.



62458
62459
62460
# File 'lib/google/apis/compute_alpha/classes.rb', line 62458

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#delaysArray<Google::Apis::ComputeAlpha::RolloutPlanWaveOrchestrationOptionsDelay>

Optional. Delays, if any, to be added between batches of projects. We allow multiple Delays to be specified, letting users set separate delays between batches of projects corresponding to different locations and batches of projects corresponding to the same location. Corresponds to the JSON property delays



62445
62446
62447
# File 'lib/google/apis/compute_alpha/classes.rb', line 62445

def delays
  @delays
end

#max_concurrent_locationsFixnum

Optional. Maximum number of locations to be orchestrated in parallel. Corresponds to the JSON property maxConcurrentLocations

Returns:

  • (Fixnum)


62450
62451
62452
# File 'lib/google/apis/compute_alpha/classes.rb', line 62450

def max_concurrent_locations
  @max_concurrent_locations
end

#max_concurrent_resources_per_locationFixnum

Optional. Maximum number of resources to be orchestrated per location in parallel. Corresponds to the JSON property maxConcurrentResourcesPerLocation

Returns:

  • (Fixnum)


62456
62457
62458
# File 'lib/google/apis/compute_alpha/classes.rb', line 62456

def max_concurrent_resources_per_location
  @max_concurrent_resources_per_location
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



62463
62464
62465
62466
62467
# File 'lib/google/apis/compute_alpha/classes.rb', line 62463

def update!(**args)
  @delays = args[:delays] if args.key?(:delays)
  @max_concurrent_locations = args[:max_concurrent_locations] if args.key?(:max_concurrent_locations)
  @max_concurrent_resources_per_location = args[:max_concurrent_resources_per_location] if args.key?(:max_concurrent_resources_per_location)
end