Class: Google::Apis::ComputeAlpha::RolloutPlanWaveOrchestrationOptions

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Options to control the pace of orchestration of a wave. These options are required only if the resource being rolled out follows the Orchestrated pattern.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RolloutPlanWaveOrchestrationOptions

Returns a new instance of RolloutPlanWaveOrchestrationOptions.



62433
62434
62435
# File 'lib/google/apis/compute_alpha/classes.rb', line 62433

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#delaysArray<Google::Apis::ComputeAlpha::RolloutPlanWaveOrchestrationOptionsDelay>

Optional. Delays, if any, to be added between batches of projects. We allow multiple Delays to be specified, letting users set separate delays between batches of projects corresponding to different locations and batches of projects corresponding to the same location. Corresponds to the JSON property delays



62420
62421
62422
# File 'lib/google/apis/compute_alpha/classes.rb', line 62420

def delays
  @delays
end

#max_concurrent_locationsFixnum

Optional. Maximum number of locations to be orchestrated in parallel. Corresponds to the JSON property maxConcurrentLocations

Returns:

  • (Fixnum)


62425
62426
62427
# File 'lib/google/apis/compute_alpha/classes.rb', line 62425

def max_concurrent_locations
  @max_concurrent_locations
end

#max_concurrent_resources_per_locationFixnum

Optional. Maximum number of resources to be orchestrated per location in parallel. Corresponds to the JSON property maxConcurrentResourcesPerLocation

Returns:

  • (Fixnum)


62431
62432
62433
# File 'lib/google/apis/compute_alpha/classes.rb', line 62431

def max_concurrent_resources_per_location
  @max_concurrent_resources_per_location
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



62438
62439
62440
62441
62442
# File 'lib/google/apis/compute_alpha/classes.rb', line 62438

def update!(**args)
  @delays = args[:delays] if args.key?(:delays)
  @max_concurrent_locations = args[:max_concurrent_locations] if args.key?(:max_concurrent_locations)
  @max_concurrent_resources_per_location = args[:max_concurrent_resources_per_location] if args.key?(:max_concurrent_resources_per_location)
end