Class: Google::Apis::ComputeAlpha::RolloutPlanWaveSelector
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::RolloutPlanWaveSelector
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
A selector which specifies what resource(s) are included in a given wave.
Instance Attribute Summary collapse
-
#location_selector ⇒ Google::Apis::ComputeAlpha::RolloutPlanWaveSelectorLocationSelector
Roll out to resources by location.
-
#resource_hierarchy_selector ⇒ Google::Apis::ComputeAlpha::RolloutPlanWaveSelectorResourceHierarchySelector
Roll out to resources by Cloud Resource Manager resource hierarchy nodes such as projects, folders, orgs.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RolloutPlanWaveSelector
constructor
A new instance of RolloutPlanWaveSelector.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RolloutPlanWaveSelector
Returns a new instance of RolloutPlanWaveSelector.
60837 60838 60839 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 60837 def initialize(**args) update!(**args) end |
Instance Attribute Details
#location_selector ⇒ Google::Apis::ComputeAlpha::RolloutPlanWaveSelectorLocationSelector
Roll out to resources by location.
Corresponds to the JSON property locationSelector
60829 60830 60831 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 60829 def location_selector @location_selector end |
#resource_hierarchy_selector ⇒ Google::Apis::ComputeAlpha::RolloutPlanWaveSelectorResourceHierarchySelector
Roll out to resources by Cloud Resource Manager resource hierarchy
nodes such as projects, folders, orgs.
Corresponds to the JSON property resourceHierarchySelector
60835 60836 60837 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 60835 def resource_hierarchy_selector @resource_hierarchy_selector end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
60842 60843 60844 60845 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 60842 def update!(**args) @location_selector = args[:location_selector] if args.key?(:location_selector) @resource_hierarchy_selector = args[:resource_hierarchy_selector] if args.key?(:resource_hierarchy_selector) end |