Class: Google::Apis::ComputeAlpha::RolloutPlanWaveValidationTimeBasedValidationMetadata
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::RolloutPlanWaveValidationTimeBasedValidationMetadata
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Metadata required if type = "time".
Instance Attribute Summary collapse
-
#wait_duration ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RolloutPlanWaveValidationTimeBasedValidationMetadata
constructor
A new instance of RolloutPlanWaveValidationTimeBasedValidationMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RolloutPlanWaveValidationTimeBasedValidationMetadata
Returns a new instance of RolloutPlanWaveValidationTimeBasedValidationMetadata.
62013 62014 62015 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 62013 def initialize(**args) update!(**args) end |
Instance Attribute Details
#wait_duration ⇒ String
Optional. The duration that the system waits in between waves. This wait
starts
after all changes in the wave are rolled out.
Corresponds to the JSON property waitDuration
62011 62012 62013 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 62011 def wait_duration @wait_duration end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
62018 62019 62020 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 62018 def update!(**args) @wait_duration = args[:wait_duration] if args.key?(:wait_duration) end |