Class: Google::Apis::ComputeAlpha::RolloutPlanWaveValidationTimeBasedValidationMetadata

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Metadata required if type = "time".

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RolloutPlanWaveValidationTimeBasedValidationMetadata

Returns a new instance of RolloutPlanWaveValidationTimeBasedValidationMetadata.



60943
60944
60945
# File 'lib/google/apis/compute_alpha/classes.rb', line 60943

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#wait_durationString

Optional. The duration that the system waits in between waves. This wait starts after all changes in the wave are rolled out. Corresponds to the JSON property waitDuration

Returns:

  • (String)


60941
60942
60943
# File 'lib/google/apis/compute_alpha/classes.rb', line 60941

def wait_duration
  @wait_duration
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



60948
60949
60950
# File 'lib/google/apis/compute_alpha/classes.rb', line 60948

def update!(**args)
  @wait_duration = args[:wait_duration] if args.key?(:wait_duration)
end