Class: Google::Apis::ComputeAlpha::RolloutPlansListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of RolloutPlan resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RolloutPlansListResponse

Returns a new instance of RolloutPlansListResponse.



64045
64046
64047
# File 'lib/google/apis/compute_alpha/classes.rb', line 64045

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


64007
64008
64009
# File 'lib/google/apis/compute_alpha/classes.rb', line 64007

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


64012
64013
64014
# File 'lib/google/apis/compute_alpha/classes.rb', line 64012

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::RolloutPlan>

A list of RolloutPlan resources. Corresponds to the JSON property items



64017
64018
64019
# File 'lib/google/apis/compute_alpha/classes.rb', line 64017

def items
  @items
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


64027
64028
64029
# File 'lib/google/apis/compute_alpha/classes.rb', line 64027

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


64032
64033
64034
# File 'lib/google/apis/compute_alpha/classes.rb', line 64032

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


64038
64039
64040
# File 'lib/google/apis/compute_alpha/classes.rb', line 64038

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::RolloutPlansListResponse::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



64043
64044
64045
# File 'lib/google/apis/compute_alpha/classes.rb', line 64043

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



64050
64051
64052
64053
64054
64055
64056
64057
64058
# File 'lib/google/apis/compute_alpha/classes.rb', line 64050

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end