Class: Google::Apis::ComputeAlpha::RolloutPlansListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of RolloutPlan resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RolloutPlansListResponse

Returns a new instance of RolloutPlansListResponse.



62659
62660
62661
# File 'lib/google/apis/compute_alpha/classes.rb', line 62659

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


62621
62622
62623
# File 'lib/google/apis/compute_alpha/classes.rb', line 62621

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


62626
62627
62628
# File 'lib/google/apis/compute_alpha/classes.rb', line 62626

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::RolloutPlan>

A list of RolloutPlan resources. Corresponds to the JSON property items



62631
62632
62633
# File 'lib/google/apis/compute_alpha/classes.rb', line 62631

def items
  @items
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


62641
62642
62643
# File 'lib/google/apis/compute_alpha/classes.rb', line 62641

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


62646
62647
62648
# File 'lib/google/apis/compute_alpha/classes.rb', line 62646

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


62652
62653
62654
# File 'lib/google/apis/compute_alpha/classes.rb', line 62652

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::RolloutPlansListResponse::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



62657
62658
62659
# File 'lib/google/apis/compute_alpha/classes.rb', line 62657

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



62664
62665
62666
62667
62668
62669
62670
62671
62672
# File 'lib/google/apis/compute_alpha/classes.rb', line 62664

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end