Class: Google::Apis::ComputeAlpha::RolloutPlansListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of RolloutPlan resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RolloutPlansListResponse

Returns a new instance of RolloutPlansListResponse.



61847
61848
61849
# File 'lib/google/apis/compute_alpha/classes.rb', line 61847

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


61809
61810
61811
# File 'lib/google/apis/compute_alpha/classes.rb', line 61809

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


61814
61815
61816
# File 'lib/google/apis/compute_alpha/classes.rb', line 61814

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::RolloutPlan>

A list of RolloutPlan resources. Corresponds to the JSON property items



61819
61820
61821
# File 'lib/google/apis/compute_alpha/classes.rb', line 61819

def items
  @items
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


61829
61830
61831
# File 'lib/google/apis/compute_alpha/classes.rb', line 61829

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


61834
61835
61836
# File 'lib/google/apis/compute_alpha/classes.rb', line 61834

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


61840
61841
61842
# File 'lib/google/apis/compute_alpha/classes.rb', line 61840

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::RolloutPlansListResponse::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



61845
61846
61847
# File 'lib/google/apis/compute_alpha/classes.rb', line 61845

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



61852
61853
61854
61855
61856
61857
61858
61859
61860
# File 'lib/google/apis/compute_alpha/classes.rb', line 61852

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end