Class: Google::Apis::ComputeAlpha::RolloutPlansListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of RolloutPlan resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RolloutPlansListResponse

Returns a new instance of RolloutPlansListResponse.



60998
60999
61000
# File 'lib/google/apis/compute_alpha/classes.rb', line 60998

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


60960
60961
60962
# File 'lib/google/apis/compute_alpha/classes.rb', line 60960

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


60965
60966
60967
# File 'lib/google/apis/compute_alpha/classes.rb', line 60965

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::RolloutPlan>

A list of RolloutPlan resources. Corresponds to the JSON property items



60970
60971
60972
# File 'lib/google/apis/compute_alpha/classes.rb', line 60970

def items
  @items
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


60980
60981
60982
# File 'lib/google/apis/compute_alpha/classes.rb', line 60980

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


60985
60986
60987
# File 'lib/google/apis/compute_alpha/classes.rb', line 60985

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


60991
60992
60993
# File 'lib/google/apis/compute_alpha/classes.rb', line 60991

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::RolloutPlansListResponse::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



60996
60997
60998
# File 'lib/google/apis/compute_alpha/classes.rb', line 60996

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



61003
61004
61005
61006
61007
61008
61009
61010
61011
# File 'lib/google/apis/compute_alpha/classes.rb', line 61003

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end