Class: Google::Apis::ComputeAlpha::RolloutPolicy
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::RolloutPolicy
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
A rollout policy configuration.
Instance Attribute Summary collapse
-
#default_rollout_time ⇒ String
An optional RFC3339 timestamp on or after which the update is considered rolled out to any zone that is not explicitly stated.
-
#location_rollout_policies ⇒ Hash<String,String>
Location based rollout policies to apply to the resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RolloutPolicy
constructor
A new instance of RolloutPolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RolloutPolicy
Returns a new instance of RolloutPolicy.
64444 64445 64446 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64444 def initialize(**args) update!(**args) end |
Instance Attribute Details
#default_rollout_time ⇒ String
An optional RFC3339 timestamp on or after which the update is
considered rolled out to any zone that is not explicitly stated.
Corresponds to the JSON property defaultRolloutTime
64433 64434 64435 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64433 def default_rollout_time @default_rollout_time end |
#location_rollout_policies ⇒ Hash<String,String>
Location based rollout policies to apply to the resource.
Currently only zone names are supported and must be represented
as valid URLs, like: zones/us-central1-a.
The value expects an RFC3339 timestamp on or after which the update is
considered rolled out to the specified location.
Corresponds to the JSON property locationRolloutPolicies
64442 64443 64444 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64442 def location_rollout_policies @location_rollout_policies end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
64449 64450 64451 64452 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64449 def update!(**args) @default_rollout_time = args[:default_rollout_time] if args.key?(:default_rollout_time) @location_rollout_policies = args[:location_rollout_policies] if args.key?(:location_rollout_policies) end |