Class: Google::Apis::ComputeAlpha::RolloutPolicy

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

A rollout policy configuration.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RolloutPolicy

Returns a new instance of RolloutPolicy.



62789
62790
62791
# File 'lib/google/apis/compute_alpha/classes.rb', line 62789

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#default_rollout_timeString

An optional RFC3339 timestamp on or after which the update is considered rolled out to any zone that is not explicitly stated. Corresponds to the JSON property defaultRolloutTime

Returns:

  • (String)


62778
62779
62780
# File 'lib/google/apis/compute_alpha/classes.rb', line 62778

def default_rollout_time
  @default_rollout_time
end

#location_rollout_policiesHash<String,String>

Location based rollout policies to apply to the resource. Currently only zone names are supported and must be represented as valid URLs, like: zones/us-central1-a. The value expects an RFC3339 timestamp on or after which the update is considered rolled out to the specified location. Corresponds to the JSON property locationRolloutPolicies

Returns:

  • (Hash<String,String>)


62787
62788
62789
# File 'lib/google/apis/compute_alpha/classes.rb', line 62787

def location_rollout_policies
  @location_rollout_policies
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



62794
62795
62796
62797
# File 'lib/google/apis/compute_alpha/classes.rb', line 62794

def update!(**args)
  @default_rollout_time = args[:default_rollout_time] if args.key?(:default_rollout_time)
  @location_rollout_policies = args[:location_rollout_policies] if args.key?(:location_rollout_policies)
end