Class: Google::Apis::ComputeAlpha::RolloutWaveDetails
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::RolloutWaveDetails
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Additional metadata about the status of each wave provided by the server.
Instance Attribute Summary collapse
-
#orchestrated_wave_details ⇒ Google::Apis::ComputeAlpha::RolloutWaveDetailsOrchestratedWaveDetails
Details of the wave for products using the Orchestrated integration model.
-
#wave_display_name ⇒ String
Output only.
-
#wave_number ⇒ Fixnum
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RolloutWaveDetails
constructor
A new instance of RolloutWaveDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RolloutWaveDetails
Returns a new instance of RolloutWaveDetails.
62277 62278 62279 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 62277 def initialize(**args) update!(**args) end |
Instance Attribute Details
#orchestrated_wave_details ⇒ Google::Apis::ComputeAlpha::RolloutWaveDetailsOrchestratedWaveDetails
Details of the wave for products using the Orchestrated integration
model.
Corresponds to the JSON property orchestratedWaveDetails
62264 62265 62266 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 62264 def orchestrated_wave_details @orchestrated_wave_details end |
#wave_display_name ⇒ String
Output only. Wave name.
Ex. wave1
Corresponds to the JSON property waveDisplayName
62270 62271 62272 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 62270 def wave_display_name @wave_display_name end |
#wave_number ⇒ Fixnum
Output only. System generated number for the wave.
Corresponds to the JSON property waveNumber
62275 62276 62277 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 62275 def wave_number @wave_number end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
62282 62283 62284 62285 62286 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 62282 def update!(**args) @orchestrated_wave_details = args[:orchestrated_wave_details] if args.key?(:orchestrated_wave_details) @wave_display_name = args[:wave_display_name] if args.key?(:wave_display_name) @wave_number = args[:wave_number] if args.key?(:wave_number) end |