Class: Google::Apis::ComputeAlpha::RolloutWaveDetails
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::RolloutWaveDetails
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Additional metadata about the status of each wave provided by the server.
Instance Attribute Summary collapse
-
#orchestrated_wave_details ⇒ Google::Apis::ComputeAlpha::RolloutWaveDetailsOrchestratedWaveDetails
Details of the wave for products using the Orchestrated integration model.
-
#wave_display_name ⇒ String
Output only.
-
#wave_number ⇒ Fixnum
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RolloutWaveDetails
constructor
A new instance of RolloutWaveDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RolloutWaveDetails
Returns a new instance of RolloutWaveDetails.
62275 62276 62277 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 62275 def initialize(**args) update!(**args) end |
Instance Attribute Details
#orchestrated_wave_details ⇒ Google::Apis::ComputeAlpha::RolloutWaveDetailsOrchestratedWaveDetails
Details of the wave for products using the Orchestrated integration
model.
Corresponds to the JSON property orchestratedWaveDetails
62262 62263 62264 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 62262 def orchestrated_wave_details @orchestrated_wave_details end |
#wave_display_name ⇒ String
Output only. Wave name.
Ex. wave1
Corresponds to the JSON property waveDisplayName
62268 62269 62270 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 62268 def wave_display_name @wave_display_name end |
#wave_number ⇒ Fixnum
Output only. System generated number for the wave.
Corresponds to the JSON property waveNumber
62273 62274 62275 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 62273 def wave_number @wave_number end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
62280 62281 62282 62283 62284 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 62280 def update!(**args) @orchestrated_wave_details = args[:orchestrated_wave_details] if args.key?(:orchestrated_wave_details) @wave_display_name = args[:wave_display_name] if args.key?(:wave_display_name) @wave_number = args[:wave_number] if args.key?(:wave_number) end |