Class: Google::Apis::ComputeAlpha::RolloutWaveDetails

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Additional metadata about the status of each wave provided by the server.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RolloutWaveDetails

Returns a new instance of RolloutWaveDetails.



61205
61206
61207
# File 'lib/google/apis/compute_alpha/classes.rb', line 61205

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#orchestrated_wave_detailsGoogle::Apis::ComputeAlpha::RolloutWaveDetailsOrchestratedWaveDetails

Details of the wave for products using the Orchestrated integration model. Corresponds to the JSON property orchestratedWaveDetails



61192
61193
61194
# File 'lib/google/apis/compute_alpha/classes.rb', line 61192

def orchestrated_wave_details
  @orchestrated_wave_details
end

#wave_display_nameString

Output only. Wave name. Ex. wave1 Corresponds to the JSON property waveDisplayName

Returns:

  • (String)


61198
61199
61200
# File 'lib/google/apis/compute_alpha/classes.rb', line 61198

def wave_display_name
  @wave_display_name
end

#wave_numberFixnum

Output only. System generated number for the wave. Corresponds to the JSON property waveNumber

Returns:

  • (Fixnum)


61203
61204
61205
# File 'lib/google/apis/compute_alpha/classes.rb', line 61203

def wave_number
  @wave_number
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



61210
61211
61212
61213
61214
# File 'lib/google/apis/compute_alpha/classes.rb', line 61210

def update!(**args)
  @orchestrated_wave_details = args[:orchestrated_wave_details] if args.key?(:orchestrated_wave_details)
  @wave_display_name = args[:wave_display_name] if args.key?(:wave_display_name)
  @wave_number = args[:wave_number] if args.key?(:wave_number)
end