Class: Google::Apis::ComputeAlpha::RolloutWaveDetailsOrchestratedWaveDetails

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Details of the wave for products using the Orchestrated integration model.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RolloutWaveDetailsOrchestratedWaveDetails

Returns a new instance of RolloutWaveDetailsOrchestratedWaveDetails.



64305
64306
64307
# File 'lib/google/apis/compute_alpha/classes.rb', line 64305

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#completed_resources_countFixnum

Output only. Resource completed so far. Corresponds to the JSON property completedResourcesCount

Returns:

  • (Fixnum)


64272
64273
64274
# File 'lib/google/apis/compute_alpha/classes.rb', line 64272

def completed_resources_count
  @completed_resources_count
end

#estimated_completion_timeString

Output only. Estimated timestamp at which the wave will complete. Extrapolated from current progress. Corresponds to the JSON property estimatedCompletionTime

Returns:

  • (String)


64279
64280
64281
# File 'lib/google/apis/compute_alpha/classes.rb', line 64279

def estimated_completion_time
  @estimated_completion_time
end

#estimated_total_resources_countFixnum

Output only. Estimated total count of resources. Corresponds to the JSON property estimatedTotalResourcesCount

Returns:

  • (Fixnum)


64284
64285
64286
# File 'lib/google/apis/compute_alpha/classes.rb', line 64284

def estimated_total_resources_count
  @estimated_total_resources_count
end

#failed_locationsArray<String>

Output only. Locations that failed during orchestration, and ProgressiveRollout stopped retrying. There may be some successful resources rolled out in the wave as the location may have failed later in the Rollout. Corresponds to the JSON property failedLocations

Returns:

  • (Array<String>)


64292
64293
64294
# File 'lib/google/apis/compute_alpha/classes.rb', line 64292

def failed_locations
  @failed_locations
end

#failed_resources_countFixnum

Output only. Resources failed. Corresponds to the JSON property failedResourcesCount

Returns:

  • (Fixnum)


64297
64298
64299
# File 'lib/google/apis/compute_alpha/classes.rb', line 64297

def failed_resources_count
  @failed_resources_count
end

#location_statusHash<String,Google::Apis::ComputeAlpha::RolloutWaveDetailsOrchestratedWaveDetailsLocationStatus>

Output only. Status of each location in the wave. Map keys (locations) must be specified like "us-east1" or "asia-west1-a". Corresponds to the JSON property locationStatus



64303
64304
64305
# File 'lib/google/apis/compute_alpha/classes.rb', line 64303

def location_status
  @location_status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



64310
64311
64312
64313
64314
64315
64316
64317
# File 'lib/google/apis/compute_alpha/classes.rb', line 64310

def update!(**args)
  @completed_resources_count = args[:completed_resources_count] if args.key?(:completed_resources_count)
  @estimated_completion_time = args[:estimated_completion_time] if args.key?(:estimated_completion_time)
  @estimated_total_resources_count = args[:estimated_total_resources_count] if args.key?(:estimated_total_resources_count)
  @failed_locations = args[:failed_locations] if args.key?(:failed_locations)
  @failed_resources_count = args[:failed_resources_count] if args.key?(:failed_resources_count)
  @location_status = args[:location_status] if args.key?(:location_status)
end