Class: Google::Apis::ComputeAlpha::RolloutWaveDetailsOrchestratedWaveDetails
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::RolloutWaveDetailsOrchestratedWaveDetails
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Details of the wave for products using the Orchestrated integration model.
Instance Attribute Summary collapse
-
#completed_resources_count ⇒ Fixnum
Output only.
-
#estimated_completion_time ⇒ String
Output only.
-
#estimated_total_resources_count ⇒ Fixnum
Output only.
-
#failed_locations ⇒ Array<String>
Output only.
-
#failed_resources_count ⇒ Fixnum
Output only.
-
#location_status ⇒ Hash<String,Google::Apis::ComputeAlpha::RolloutWaveDetailsOrchestratedWaveDetailsLocationStatus>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RolloutWaveDetailsOrchestratedWaveDetails
constructor
A new instance of RolloutWaveDetailsOrchestratedWaveDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RolloutWaveDetailsOrchestratedWaveDetails
Returns a new instance of RolloutWaveDetailsOrchestratedWaveDetails.
62330 62331 62332 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 62330 def initialize(**args) update!(**args) end |
Instance Attribute Details
#completed_resources_count ⇒ Fixnum
Output only. Resource completed so far.
Corresponds to the JSON property completedResourcesCount
62297 62298 62299 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 62297 def completed_resources_count @completed_resources_count end |
#estimated_completion_time ⇒ String
Output only. Estimated timestamp at which the wave will complete. Extrapolated
from
current progress.
Corresponds to the JSON property estimatedCompletionTime
62304 62305 62306 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 62304 def estimated_completion_time @estimated_completion_time end |
#estimated_total_resources_count ⇒ Fixnum
Output only. Estimated total count of resources.
Corresponds to the JSON property estimatedTotalResourcesCount
62309 62310 62311 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 62309 def estimated_total_resources_count @estimated_total_resources_count end |
#failed_locations ⇒ Array<String>
Output only. Locations that failed during orchestration, and
ProgressiveRollout
stopped retrying. There may be some successful resources rolled out in
the wave as the location may have failed later in the Rollout.
Corresponds to the JSON property failedLocations
62317 62318 62319 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 62317 def failed_locations @failed_locations end |
#failed_resources_count ⇒ Fixnum
Output only. Resources failed.
Corresponds to the JSON property failedResourcesCount
62322 62323 62324 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 62322 def failed_resources_count @failed_resources_count end |
#location_status ⇒ Hash<String,Google::Apis::ComputeAlpha::RolloutWaveDetailsOrchestratedWaveDetailsLocationStatus>
Output only. Status of each location in the wave. Map keys (locations) must be
specified like "us-east1" or "asia-west1-a".
Corresponds to the JSON property locationStatus
62328 62329 62330 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 62328 def location_status @location_status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
62335 62336 62337 62338 62339 62340 62341 62342 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 62335 def update!(**args) @completed_resources_count = args[:completed_resources_count] if args.key?(:completed_resources_count) @estimated_completion_time = args[:estimated_completion_time] if args.key?(:estimated_completion_time) @estimated_total_resources_count = args[:estimated_total_resources_count] if args.key?(:estimated_total_resources_count) @failed_locations = args[:failed_locations] if args.key?(:failed_locations) @failed_resources_count = args[:failed_resources_count] if args.key?(:failed_resources_count) @location_status = args[:location_status] if args.key?(:location_status) end |