Class: Google::Apis::ComputeAlpha::RolloutsListResponse
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::RolloutsListResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::Rollout>
A list of Rollout resources.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::RolloutsListResponse::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RolloutsListResponse
constructor
A new instance of RolloutsListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RolloutsListResponse
Returns a new instance of RolloutsListResponse.
64678 64679 64680 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64678 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
64640 64641 64642 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64640 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
64645 64646 64647 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64645 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::Rollout>
A list of Rollout resources.
Corresponds to the JSON property items
64650 64651 64652 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64650 def items @items end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
64660 64661 64662 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64660 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
64665 64666 64667 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64665 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
end_interface: MixerListResponseWithEtagBuilder
Corresponds to the JSON property unreachables
64671 64672 64673 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64671 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::RolloutsListResponse::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
64676 64677 64678 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64676 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
64683 64684 64685 64686 64687 64688 64689 64690 64691 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64683 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |