Class: Google::Apis::ComputeAlpha::RolloutsListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RolloutsListResponse

Returns a new instance of RolloutsListResponse.



64384
64385
64386
# File 'lib/google/apis/compute_alpha/classes.rb', line 64384

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


64346
64347
64348
# File 'lib/google/apis/compute_alpha/classes.rb', line 64346

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


64351
64352
64353
# File 'lib/google/apis/compute_alpha/classes.rb', line 64351

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::Rollout>

A list of Rollout resources. Corresponds to the JSON property items



64356
64357
64358
# File 'lib/google/apis/compute_alpha/classes.rb', line 64356

def items
  @items
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


64366
64367
64368
# File 'lib/google/apis/compute_alpha/classes.rb', line 64366

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


64371
64372
64373
# File 'lib/google/apis/compute_alpha/classes.rb', line 64371

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


64377
64378
64379
# File 'lib/google/apis/compute_alpha/classes.rb', line 64377

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::RolloutsListResponse::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



64382
64383
64384
# File 'lib/google/apis/compute_alpha/classes.rb', line 64382

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



64389
64390
64391
64392
64393
64394
64395
64396
64397
# File 'lib/google/apis/compute_alpha/classes.rb', line 64389

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end