Class: Google::Apis::ComputeAlpha::RolloutsListResponse
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::RolloutsListResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::Rollout>
A list of Rollout resources.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::RolloutsListResponse::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RolloutsListResponse
constructor
A new instance of RolloutsListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RolloutsListResponse
Returns a new instance of RolloutsListResponse.
63023 63024 63025 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63023 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
62985 62986 62987 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 62985 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
62990 62991 62992 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 62990 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::Rollout>
A list of Rollout resources.
Corresponds to the JSON property items
62995 62996 62997 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 62995 def items @items end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
63005 63006 63007 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63005 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
63010 63011 63012 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63010 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
end_interface: MixerListResponseWithEtagBuilder
Corresponds to the JSON property unreachables
63016 63017 63018 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63016 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::RolloutsListResponse::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
63021 63022 63023 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63021 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
63028 63029 63030 63031 63032 63033 63034 63035 63036 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63028 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |