Class: Google::Apis::ComputeAlpha::RolloutsListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RolloutsListResponse

Returns a new instance of RolloutsListResponse.



62407
62408
62409
# File 'lib/google/apis/compute_alpha/classes.rb', line 62407

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


62369
62370
62371
# File 'lib/google/apis/compute_alpha/classes.rb', line 62369

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


62374
62375
62376
# File 'lib/google/apis/compute_alpha/classes.rb', line 62374

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::Rollout>

A list of Rollout resources. Corresponds to the JSON property items



62379
62380
62381
# File 'lib/google/apis/compute_alpha/classes.rb', line 62379

def items
  @items
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


62389
62390
62391
# File 'lib/google/apis/compute_alpha/classes.rb', line 62389

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


62394
62395
62396
# File 'lib/google/apis/compute_alpha/classes.rb', line 62394

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


62400
62401
62402
# File 'lib/google/apis/compute_alpha/classes.rb', line 62400

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::RolloutsListResponse::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



62405
62406
62407
# File 'lib/google/apis/compute_alpha/classes.rb', line 62405

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



62412
62413
62414
62415
62416
62417
62418
62419
62420
# File 'lib/google/apis/compute_alpha/classes.rb', line 62412

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end