Class: Google::Apis::ComputeAlpha::RolloutsListResponse
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::RolloutsListResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::Rollout>
A list of Rollout resources.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::RolloutsListResponse::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RolloutsListResponse
constructor
A new instance of RolloutsListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RolloutsListResponse
Returns a new instance of RolloutsListResponse.
62186 62187 62188 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 62186 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
62148 62149 62150 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 62148 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
62153 62154 62155 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 62153 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::Rollout>
A list of Rollout resources.
Corresponds to the JSON property items
62158 62159 62160 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 62158 def items @items end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
62168 62169 62170 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 62168 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
62173 62174 62175 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 62173 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
end_interface: MixerListResponseWithEtagBuilder
Corresponds to the JSON property unreachables
62179 62180 62181 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 62179 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::RolloutsListResponse::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
62184 62185 62186 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 62184 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
62191 62192 62193 62194 62195 62196 62197 62198 62199 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 62191 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |