Class: Google::Apis::ComputeAlpha::RolloutsListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RolloutsListResponse

Returns a new instance of RolloutsListResponse.



61303
61304
61305
# File 'lib/google/apis/compute_alpha/classes.rb', line 61303

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


61265
61266
61267
# File 'lib/google/apis/compute_alpha/classes.rb', line 61265

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


61270
61271
61272
# File 'lib/google/apis/compute_alpha/classes.rb', line 61270

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::Rollout>

A list of Rollout resources. Corresponds to the JSON property items



61275
61276
61277
# File 'lib/google/apis/compute_alpha/classes.rb', line 61275

def items
  @items
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


61285
61286
61287
# File 'lib/google/apis/compute_alpha/classes.rb', line 61285

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


61290
61291
61292
# File 'lib/google/apis/compute_alpha/classes.rb', line 61290

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


61296
61297
61298
# File 'lib/google/apis/compute_alpha/classes.rb', line 61296

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::RolloutsListResponse::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



61301
61302
61303
# File 'lib/google/apis/compute_alpha/classes.rb', line 61301

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



61308
61309
61310
61311
61312
61313
61314
61315
61316
# File 'lib/google/apis/compute_alpha/classes.rb', line 61308

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end