Class: Google::Apis::ComputeAlpha::RouteList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::RouteList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Contains a list of Route resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::Route>
A list of Route resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::RouteList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RouteList
constructor
A new instance of RouteList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RouteList
Returns a new instance of RouteList.
65452 65453 65454 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 65452 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
65420 65421 65422 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 65420 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::Route>
A list of Route resources.
Corresponds to the JSON property items
65425 65426 65427 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 65425 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
65430 65431 65432 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 65430 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
65440 65441 65442 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 65440 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
65445 65446 65447 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 65445 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::RouteList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
65450 65451 65452 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 65450 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
65457 65458 65459 65460 65461 65462 65463 65464 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 65457 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |