Class: Google::Apis::ComputeAlpha::RouteList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of Route resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RouteList

Returns a new instance of RouteList.



64891
64892
64893
# File 'lib/google/apis/compute_alpha/classes.rb', line 64891

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


64859
64860
64861
# File 'lib/google/apis/compute_alpha/classes.rb', line 64859

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::Route>

A list of Route resources. Corresponds to the JSON property items



64864
64865
64866
# File 'lib/google/apis/compute_alpha/classes.rb', line 64864

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


64869
64870
64871
# File 'lib/google/apis/compute_alpha/classes.rb', line 64869

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


64879
64880
64881
# File 'lib/google/apis/compute_alpha/classes.rb', line 64879

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


64884
64885
64886
# File 'lib/google/apis/compute_alpha/classes.rb', line 64884

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::RouteList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



64889
64890
64891
# File 'lib/google/apis/compute_alpha/classes.rb', line 64889

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



64896
64897
64898
64899
64900
64901
64902
64903
# File 'lib/google/apis/compute_alpha/classes.rb', line 64896

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end