Class: Google::Apis::ComputeAlpha::RouteList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::RouteList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Contains a list of Route resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::Route>
A list of Route resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::RouteList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RouteList
constructor
A new instance of RouteList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RouteList
Returns a new instance of RouteList.
63530 63531 63532 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63530 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
63498 63499 63500 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63498 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::Route>
A list of Route resources.
Corresponds to the JSON property items
63503 63504 63505 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63503 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
63508 63509 63510 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63508 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
63518 63519 63520 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63518 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
63523 63524 63525 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63523 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::RouteList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
63528 63529 63530 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63528 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
63535 63536 63537 63538 63539 63540 63541 63542 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63535 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |