Class: Google::Apis::ComputeAlpha::RouteList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::RouteList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Contains a list of Route resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::Route>
A list of Route resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::RouteList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RouteList
constructor
A new instance of RouteList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RouteList
Returns a new instance of RouteList.
62916 62917 62918 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 62916 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
62884 62885 62886 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 62884 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::Route>
A list of Route resources.
Corresponds to the JSON property items
62889 62890 62891 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 62889 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
62894 62895 62896 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 62894 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
62904 62905 62906 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 62904 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
62909 62910 62911 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 62909 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::RouteList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
62914 62915 62916 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 62914 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
62921 62922 62923 62924 62925 62926 62927 62928 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 62921 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |