Class: Google::Apis::ComputeAlpha::RoutePolicy

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RoutePolicy

Returns a new instance of RoutePolicy.



65046
65047
65048
# File 'lib/google/apis/compute_alpha/classes.rb', line 65046

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

An optional description of route policy. Corresponds to the JSON property description

Returns:

  • (String)


65013
65014
65015
# File 'lib/google/apis/compute_alpha/classes.rb', line 65013

def description
  @description
end

#fingerprintString

A fingerprint for the Route Policy being applied to this Router, which is essentially a hash of the Route Policy used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update Route Policy. You must always provide an up-to-date fingerprint hash in order to update or change labels. To see the latest fingerprint, make a getRoutePolicy() request to retrieve a Route Policy. Corresponds to the JSON property fingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


65026
65027
65028
# File 'lib/google/apis/compute_alpha/classes.rb', line 65026

def fingerprint
  @fingerprint
end

#nameString

Route Policy name, which must be a resource ID segment and unique within all the router's Route Policies. Name should conform to RFC1035. Corresponds to the JSON property name

Returns:

  • (String)


65032
65033
65034
# File 'lib/google/apis/compute_alpha/classes.rb', line 65032

def name
  @name
end

#termsArray<Google::Apis::ComputeAlpha::RoutePolicyPolicyTerm>

List of terms (the order in the list is not important, they are evaluated in order of priority). Order of policies is not retained and might change when getting policy later. Corresponds to the JSON property terms



65039
65040
65041
# File 'lib/google/apis/compute_alpha/classes.rb', line 65039

def terms
  @terms
end

#typeString

Corresponds to the JSON property type

Returns:

  • (String)


65044
65045
65046
# File 'lib/google/apis/compute_alpha/classes.rb', line 65044

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



65051
65052
65053
65054
65055
65056
65057
# File 'lib/google/apis/compute_alpha/classes.rb', line 65051

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @fingerprint = args[:fingerprint] if args.key?(:fingerprint)
  @name = args[:name] if args.key?(:name)
  @terms = args[:terms] if args.key?(:terms)
  @type = args[:type] if args.key?(:type)
end