Class: Google::Apis::ComputeAlpha::RoutePolicy
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::RoutePolicy
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#description ⇒ String
An optional description of route policy.
-
#fingerprint ⇒ String
A fingerprint for the Route Policy being applied to this Router, which is essentially a hash of the Route Policy used for optimistic locking.
-
#name ⇒ String
Route Policy name, which must be a resource ID segment and unique within all the router's Route Policies.
-
#terms ⇒ Array<Google::Apis::ComputeAlpha::RoutePolicyPolicyTerm>
List of terms (the order in the list is not important, they are evaluated in order of priority).
-
#type ⇒ String
Corresponds to the JSON property
type.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RoutePolicy
constructor
A new instance of RoutePolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RoutePolicy
Returns a new instance of RoutePolicy.
63660 63661 63662 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63660 def initialize(**args) update!(**args) end |
Instance Attribute Details
#description ⇒ String
An optional description of route policy.
Corresponds to the JSON property description
63627 63628 63629 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63627 def description @description end |
#fingerprint ⇒ String
A fingerprint for the Route Policy being applied to this Router, which is
essentially a hash of the Route Policy used for optimistic locking.
The fingerprint is initially generated by Compute Engine and changes
after every request to modify or update Route Policy. You must always
provide an up-to-date fingerprint hash in order to update or change
labels.
To see the latest fingerprint, make a getRoutePolicy() request
to retrieve a Route Policy.
Corresponds to the JSON property fingerprint
NOTE: Values are automatically base64 encoded/decoded in the client library.
63640 63641 63642 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63640 def fingerprint @fingerprint end |
#name ⇒ String
Route Policy name, which must be a resource ID segment and unique
within all the router's Route Policies. Name should conform to RFC1035.
Corresponds to the JSON property name
63646 63647 63648 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63646 def name @name end |
#terms ⇒ Array<Google::Apis::ComputeAlpha::RoutePolicyPolicyTerm>
List of terms (the order in the list is not important, they are evaluated
in order of priority). Order of policies is not retained and might change
when getting policy later.
Corresponds to the JSON property terms
63653 63654 63655 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63653 def terms @terms end |
#type ⇒ String
Corresponds to the JSON property type
63658 63659 63660 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63658 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
63665 63666 63667 63668 63669 63670 63671 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63665 def update!(**args) @description = args[:description] if args.key?(:description) @fingerprint = args[:fingerprint] if args.key?(:fingerprint) @name = args[:name] if args.key?(:name) @terms = args[:terms] if args.key?(:terms) @type = args[:type] if args.key?(:type) end |