Class: Google::Apis::ComputeAlpha::RoutePolicy

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RoutePolicy

Returns a new instance of RoutePolicy.



63069
63070
63071
# File 'lib/google/apis/compute_alpha/classes.rb', line 63069

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

An optional description of route policy. Corresponds to the JSON property description

Returns:

  • (String)


63036
63037
63038
# File 'lib/google/apis/compute_alpha/classes.rb', line 63036

def description
  @description
end

#fingerprintString

A fingerprint for the Route Policy being applied to this Router, which is essentially a hash of the Route Policy used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update Route Policy. You must always provide an up-to-date fingerprint hash in order to update or change labels. To see the latest fingerprint, make a getRoutePolicy() request to retrieve a Route Policy. Corresponds to the JSON property fingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


63049
63050
63051
# File 'lib/google/apis/compute_alpha/classes.rb', line 63049

def fingerprint
  @fingerprint
end

#nameString

Route Policy name, which must be a resource ID segment and unique within all the router's Route Policies. Name should conform to RFC1035. Corresponds to the JSON property name

Returns:

  • (String)


63055
63056
63057
# File 'lib/google/apis/compute_alpha/classes.rb', line 63055

def name
  @name
end

#termsArray<Google::Apis::ComputeAlpha::RoutePolicyPolicyTerm>

List of terms (the order in the list is not important, they are evaluated in order of priority). Order of policies is not retained and might change when getting policy later. Corresponds to the JSON property terms



63062
63063
63064
# File 'lib/google/apis/compute_alpha/classes.rb', line 63062

def terms
  @terms
end

#typeString

Corresponds to the JSON property type

Returns:

  • (String)


63067
63068
63069
# File 'lib/google/apis/compute_alpha/classes.rb', line 63067

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



63074
63075
63076
63077
63078
63079
63080
# File 'lib/google/apis/compute_alpha/classes.rb', line 63074

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @fingerprint = args[:fingerprint] if args.key?(:fingerprint)
  @name = args[:name] if args.key?(:name)
  @terms = args[:terms] if args.key?(:terms)
  @type = args[:type] if args.key?(:type)
end