Class: Google::Apis::ComputeAlpha::Router

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Represents a Cloud Router resource. For more information about Cloud Router, read theCloud Router overview.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Router

Returns a new instance of Router.



65524
65525
65526
# File 'lib/google/apis/compute_alpha/classes.rb', line 65524

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bgpGoogle::Apis::ComputeAlpha::RouterBgp

BGP information specific to this router. Corresponds to the JSON property bgp



65416
65417
65418
# File 'lib/google/apis/compute_alpha/classes.rb', line 65416

def bgp
  @bgp
end

#bgp_peersArray<Google::Apis::ComputeAlpha::RouterBgpPeer>

BGP information that must be configured into the routing stack to establish BGP peering. This information must specify the peer ASN and either the interface name, IP address, or peer IP address. Please refer toRFC4273. Corresponds to the JSON property bgpPeers



65424
65425
65426
# File 'lib/google/apis/compute_alpha/classes.rb', line 65424

def bgp_peers
  @bgp_peers
end

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


65430
65431
65432
# File 'lib/google/apis/compute_alpha/classes.rb', line 65430

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


65436
65437
65438
# File 'lib/google/apis/compute_alpha/classes.rb', line 65436

def description
  @description
end

#encrypted_interconnect_routerBoolean Also known as: encrypted_interconnect_router?

Indicates if a router is dedicated for use with encrypted VLAN attachments (interconnectAttachments). Corresponds to the JSON property encryptedInterconnectRouter

Returns:

  • (Boolean)


65442
65443
65444
# File 'lib/google/apis/compute_alpha/classes.rb', line 65442

def encrypted_interconnect_router
  @encrypted_interconnect_router
end

#idFixnum

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


65449
65450
65451
# File 'lib/google/apis/compute_alpha/classes.rb', line 65449

def id
  @id
end

#interfacesArray<Google::Apis::ComputeAlpha::RouterInterface>

Router interfaces. To create a BGP peer that uses a router interface, the interface must have one of the following fields specified:

  • linkedVpnTunnel
  • linkedInterconnectAttachment
  • subnetwork You can create a router interface without any of these fields specified. However, you cannot create a BGP peer that uses that interface. Corresponds to the JSON property interfaces


65462
65463
65464
# File 'lib/google/apis/compute_alpha/classes.rb', line 65462

def interfaces
  @interfaces
end

#kindString

Output only. [Output Only] Type of resource. Always compute#router for routers. Corresponds to the JSON property kind

Returns:

  • (String)


65468
65469
65470
# File 'lib/google/apis/compute_alpha/classes.rb', line 65468

def kind
  @kind
end

#md5_authentication_keysArray<Google::Apis::ComputeAlpha::RouterMd5AuthenticationKey>

Keys used for MD5 authentication. Corresponds to the JSON property md5AuthenticationKeys



65473
65474
65475
# File 'lib/google/apis/compute_alpha/classes.rb', line 65473

def md5_authentication_keys
  @md5_authentication_keys
end

#nameString

Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


65484
65485
65486
# File 'lib/google/apis/compute_alpha/classes.rb', line 65484

def name
  @name
end

#natsArray<Google::Apis::ComputeAlpha::RouterNat>

A list of NAT services created in this router. Corresponds to the JSON property nats



65489
65490
65491
# File 'lib/google/apis/compute_alpha/classes.rb', line 65489

def nats
  @nats
end

#ncc_gatewayString

URI of the ncc_gateway to which this router associated. Corresponds to the JSON property nccGateway

Returns:

  • (String)


65494
65495
65496
# File 'lib/google/apis/compute_alpha/classes.rb', line 65494

def ncc_gateway
  @ncc_gateway
end

#networkString

URI of the network to which this router belongs. Corresponds to the JSON property network

Returns:

  • (String)


65499
65500
65501
# File 'lib/google/apis/compute_alpha/classes.rb', line 65499

def network
  @network
end

#paramsGoogle::Apis::ComputeAlpha::RouterParams

Additional router parameters. Corresponds to the JSON property params



65504
65505
65506
# File 'lib/google/apis/compute_alpha/classes.rb', line 65504

def params
  @params
end

#regionString

[Output Only] URI of the region where the router resides. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body. Corresponds to the JSON property region

Returns:

  • (String)


65511
65512
65513
# File 'lib/google/apis/compute_alpha/classes.rb', line 65511

def region
  @region
end

[Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


65516
65517
65518
# File 'lib/google/apis/compute_alpha/classes.rb', line 65516

def self_link
  @self_link
end

Output only. [Output Only] Server-defined URL for this resource with the resource id. Corresponds to the JSON property selfLinkWithId

Returns:

  • (String)


65522
65523
65524
# File 'lib/google/apis/compute_alpha/classes.rb', line 65522

def self_link_with_id
  @self_link_with_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



65529
65530
65531
65532
65533
65534
65535
65536
65537
65538
65539
65540
65541
65542
65543
65544
65545
65546
65547
# File 'lib/google/apis/compute_alpha/classes.rb', line 65529

def update!(**args)
  @bgp = args[:bgp] if args.key?(:bgp)
  @bgp_peers = args[:bgp_peers] if args.key?(:bgp_peers)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @encrypted_interconnect_router = args[:encrypted_interconnect_router] if args.key?(:encrypted_interconnect_router)
  @id = args[:id] if args.key?(:id)
  @interfaces = args[:interfaces] if args.key?(:interfaces)
  @kind = args[:kind] if args.key?(:kind)
  @md5_authentication_keys = args[:md5_authentication_keys] if args.key?(:md5_authentication_keys)
  @name = args[:name] if args.key?(:name)
  @nats = args[:nats] if args.key?(:nats)
  @ncc_gateway = args[:ncc_gateway] if args.key?(:ncc_gateway)
  @network = args[:network] if args.key?(:network)
  @params = args[:params] if args.key?(:params)
  @region = args[:region] if args.key?(:region)
  @self_link = args[:self_link] if args.key?(:self_link)
  @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id)
end