Class: Google::Apis::ComputeAlpha::Router

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Represents a Cloud Router resource. For more information about Cloud Router, read theCloud Router overview.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Router

Returns a new instance of Router.



63844
63845
63846
# File 'lib/google/apis/compute_alpha/classes.rb', line 63844

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bgpGoogle::Apis::ComputeAlpha::RouterBgp

BGP information specific to this router. Corresponds to the JSON property bgp



63736
63737
63738
# File 'lib/google/apis/compute_alpha/classes.rb', line 63736

def bgp
  @bgp
end

#bgp_peersArray<Google::Apis::ComputeAlpha::RouterBgpPeer>

BGP information that must be configured into the routing stack to establish BGP peering. This information must specify the peer ASN and either the interface name, IP address, or peer IP address. Please refer toRFC4273. Corresponds to the JSON property bgpPeers



63744
63745
63746
# File 'lib/google/apis/compute_alpha/classes.rb', line 63744

def bgp_peers
  @bgp_peers
end

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


63750
63751
63752
# File 'lib/google/apis/compute_alpha/classes.rb', line 63750

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


63756
63757
63758
# File 'lib/google/apis/compute_alpha/classes.rb', line 63756

def description
  @description
end

#encrypted_interconnect_routerBoolean Also known as: encrypted_interconnect_router?

Indicates if a router is dedicated for use with encrypted VLAN attachments (interconnectAttachments). Corresponds to the JSON property encryptedInterconnectRouter

Returns:

  • (Boolean)


63762
63763
63764
# File 'lib/google/apis/compute_alpha/classes.rb', line 63762

def encrypted_interconnect_router
  @encrypted_interconnect_router
end

#idFixnum

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


63769
63770
63771
# File 'lib/google/apis/compute_alpha/classes.rb', line 63769

def id
  @id
end

#interfacesArray<Google::Apis::ComputeAlpha::RouterInterface>

Router interfaces. To create a BGP peer that uses a router interface, the interface must have one of the following fields specified:

  • linkedVpnTunnel
  • linkedInterconnectAttachment
  • subnetwork You can create a router interface without any of these fields specified. However, you cannot create a BGP peer that uses that interface. Corresponds to the JSON property interfaces


63782
63783
63784
# File 'lib/google/apis/compute_alpha/classes.rb', line 63782

def interfaces
  @interfaces
end

#kindString

Output only. [Output Only] Type of resource. Always compute#router for routers. Corresponds to the JSON property kind

Returns:

  • (String)


63788
63789
63790
# File 'lib/google/apis/compute_alpha/classes.rb', line 63788

def kind
  @kind
end

#md5_authentication_keysArray<Google::Apis::ComputeAlpha::RouterMd5AuthenticationKey>

Keys used for MD5 authentication. Corresponds to the JSON property md5AuthenticationKeys



63793
63794
63795
# File 'lib/google/apis/compute_alpha/classes.rb', line 63793

def md5_authentication_keys
  @md5_authentication_keys
end

#nameString

Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


63804
63805
63806
# File 'lib/google/apis/compute_alpha/classes.rb', line 63804

def name
  @name
end

#natsArray<Google::Apis::ComputeAlpha::RouterNat>

A list of NAT services created in this router. Corresponds to the JSON property nats



63809
63810
63811
# File 'lib/google/apis/compute_alpha/classes.rb', line 63809

def nats
  @nats
end

#ncc_gatewayString

URI of the ncc_gateway to which this router associated. Corresponds to the JSON property nccGateway

Returns:

  • (String)


63814
63815
63816
# File 'lib/google/apis/compute_alpha/classes.rb', line 63814

def ncc_gateway
  @ncc_gateway
end

#networkString

URI of the network to which this router belongs. Corresponds to the JSON property network

Returns:

  • (String)


63819
63820
63821
# File 'lib/google/apis/compute_alpha/classes.rb', line 63819

def network
  @network
end

#paramsGoogle::Apis::ComputeAlpha::RouterParams

Additional router parameters. Corresponds to the JSON property params



63824
63825
63826
# File 'lib/google/apis/compute_alpha/classes.rb', line 63824

def params
  @params
end

#regionString

[Output Only] URI of the region where the router resides. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body. Corresponds to the JSON property region

Returns:

  • (String)


63831
63832
63833
# File 'lib/google/apis/compute_alpha/classes.rb', line 63831

def region
  @region
end

[Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


63836
63837
63838
# File 'lib/google/apis/compute_alpha/classes.rb', line 63836

def self_link
  @self_link
end

Output only. [Output Only] Server-defined URL for this resource with the resource id. Corresponds to the JSON property selfLinkWithId

Returns:

  • (String)


63842
63843
63844
# File 'lib/google/apis/compute_alpha/classes.rb', line 63842

def self_link_with_id
  @self_link_with_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



63849
63850
63851
63852
63853
63854
63855
63856
63857
63858
63859
63860
63861
63862
63863
63864
63865
63866
63867
# File 'lib/google/apis/compute_alpha/classes.rb', line 63849

def update!(**args)
  @bgp = args[:bgp] if args.key?(:bgp)
  @bgp_peers = args[:bgp_peers] if args.key?(:bgp_peers)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @encrypted_interconnect_router = args[:encrypted_interconnect_router] if args.key?(:encrypted_interconnect_router)
  @id = args[:id] if args.key?(:id)
  @interfaces = args[:interfaces] if args.key?(:interfaces)
  @kind = args[:kind] if args.key?(:kind)
  @md5_authentication_keys = args[:md5_authentication_keys] if args.key?(:md5_authentication_keys)
  @name = args[:name] if args.key?(:name)
  @nats = args[:nats] if args.key?(:nats)
  @ncc_gateway = args[:ncc_gateway] if args.key?(:ncc_gateway)
  @network = args[:network] if args.key?(:network)
  @params = args[:params] if args.key?(:params)
  @region = args[:region] if args.key?(:region)
  @self_link = args[:self_link] if args.key?(:self_link)
  @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id)
end