Class: Google::Apis::ComputeAlpha::Router

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Represents a Cloud Router resource. For more information about Cloud Router, read theCloud Router overview.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Router

Returns a new instance of Router.



63255
63256
63257
# File 'lib/google/apis/compute_alpha/classes.rb', line 63255

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bgpGoogle::Apis::ComputeAlpha::RouterBgp

BGP information specific to this router. Corresponds to the JSON property bgp



63147
63148
63149
# File 'lib/google/apis/compute_alpha/classes.rb', line 63147

def bgp
  @bgp
end

#bgp_peersArray<Google::Apis::ComputeAlpha::RouterBgpPeer>

BGP information that must be configured into the routing stack to establish BGP peering. This information must specify the peer ASN and either the interface name, IP address, or peer IP address. Please refer toRFC4273. Corresponds to the JSON property bgpPeers



63155
63156
63157
# File 'lib/google/apis/compute_alpha/classes.rb', line 63155

def bgp_peers
  @bgp_peers
end

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


63161
63162
63163
# File 'lib/google/apis/compute_alpha/classes.rb', line 63161

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


63167
63168
63169
# File 'lib/google/apis/compute_alpha/classes.rb', line 63167

def description
  @description
end

#encrypted_interconnect_routerBoolean Also known as: encrypted_interconnect_router?

Indicates if a router is dedicated for use with encrypted VLAN attachments (interconnectAttachments). Corresponds to the JSON property encryptedInterconnectRouter

Returns:

  • (Boolean)


63173
63174
63175
# File 'lib/google/apis/compute_alpha/classes.rb', line 63173

def encrypted_interconnect_router
  @encrypted_interconnect_router
end

#idFixnum

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


63180
63181
63182
# File 'lib/google/apis/compute_alpha/classes.rb', line 63180

def id
  @id
end

#interfacesArray<Google::Apis::ComputeAlpha::RouterInterface>

Router interfaces. To create a BGP peer that uses a router interface, the interface must have one of the following fields specified:

  • linkedVpnTunnel
  • linkedInterconnectAttachment
  • subnetwork You can create a router interface without any of these fields specified. However, you cannot create a BGP peer that uses that interface. Corresponds to the JSON property interfaces


63193
63194
63195
# File 'lib/google/apis/compute_alpha/classes.rb', line 63193

def interfaces
  @interfaces
end

#kindString

Output only. [Output Only] Type of resource. Always compute#router for routers. Corresponds to the JSON property kind

Returns:

  • (String)


63199
63200
63201
# File 'lib/google/apis/compute_alpha/classes.rb', line 63199

def kind
  @kind
end

#md5_authentication_keysArray<Google::Apis::ComputeAlpha::RouterMd5AuthenticationKey>

Keys used for MD5 authentication. Corresponds to the JSON property md5AuthenticationKeys



63204
63205
63206
# File 'lib/google/apis/compute_alpha/classes.rb', line 63204

def md5_authentication_keys
  @md5_authentication_keys
end

#nameString

Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


63215
63216
63217
# File 'lib/google/apis/compute_alpha/classes.rb', line 63215

def name
  @name
end

#natsArray<Google::Apis::ComputeAlpha::RouterNat>

A list of NAT services created in this router. Corresponds to the JSON property nats



63220
63221
63222
# File 'lib/google/apis/compute_alpha/classes.rb', line 63220

def nats
  @nats
end

#ncc_gatewayString

URI of the ncc_gateway to which this router associated. Corresponds to the JSON property nccGateway

Returns:

  • (String)


63225
63226
63227
# File 'lib/google/apis/compute_alpha/classes.rb', line 63225

def ncc_gateway
  @ncc_gateway
end

#networkString

URI of the network to which this router belongs. Corresponds to the JSON property network

Returns:

  • (String)


63230
63231
63232
# File 'lib/google/apis/compute_alpha/classes.rb', line 63230

def network
  @network
end

#paramsGoogle::Apis::ComputeAlpha::RouterParams

Additional router parameters. Corresponds to the JSON property params



63235
63236
63237
# File 'lib/google/apis/compute_alpha/classes.rb', line 63235

def params
  @params
end

#regionString

[Output Only] URI of the region where the router resides. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body. Corresponds to the JSON property region

Returns:

  • (String)


63242
63243
63244
# File 'lib/google/apis/compute_alpha/classes.rb', line 63242

def region
  @region
end

[Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


63247
63248
63249
# File 'lib/google/apis/compute_alpha/classes.rb', line 63247

def self_link
  @self_link
end

Output only. [Output Only] Server-defined URL for this resource with the resource id. Corresponds to the JSON property selfLinkWithId

Returns:

  • (String)


63253
63254
63255
# File 'lib/google/apis/compute_alpha/classes.rb', line 63253

def self_link_with_id
  @self_link_with_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



63260
63261
63262
63263
63264
63265
63266
63267
63268
63269
63270
63271
63272
63273
63274
63275
63276
63277
63278
# File 'lib/google/apis/compute_alpha/classes.rb', line 63260

def update!(**args)
  @bgp = args[:bgp] if args.key?(:bgp)
  @bgp_peers = args[:bgp_peers] if args.key?(:bgp_peers)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @encrypted_interconnect_router = args[:encrypted_interconnect_router] if args.key?(:encrypted_interconnect_router)
  @id = args[:id] if args.key?(:id)
  @interfaces = args[:interfaces] if args.key?(:interfaces)
  @kind = args[:kind] if args.key?(:kind)
  @md5_authentication_keys = args[:md5_authentication_keys] if args.key?(:md5_authentication_keys)
  @name = args[:name] if args.key?(:name)
  @nats = args[:nats] if args.key?(:nats)
  @ncc_gateway = args[:ncc_gateway] if args.key?(:ncc_gateway)
  @network = args[:network] if args.key?(:network)
  @params = args[:params] if args.key?(:params)
  @region = args[:region] if args.key?(:region)
  @self_link = args[:self_link] if args.key?(:self_link)
  @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id)
end