Class: Google::Apis::ComputeAlpha::Router
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::Router
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Represents a Cloud Router resource. For more information about Cloud Router, read theCloud Router overview.
Instance Attribute Summary collapse
-
#bgp ⇒ Google::Apis::ComputeAlpha::RouterBgp
BGP information specific to this router.
-
#bgp_peers ⇒ Array<Google::Apis::ComputeAlpha::RouterBgpPeer>
BGP information that must be configured into the routing stack to establish BGP peering.
-
#creation_timestamp ⇒ String
Output only.
-
#description ⇒ String
An optional description of this resource.
-
#encrypted_interconnect_router ⇒ Boolean
(also: #encrypted_interconnect_router?)
Indicates if a router is dedicated for use with encrypted VLAN attachments (interconnectAttachments).
-
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource.
-
#interfaces ⇒ Array<Google::Apis::ComputeAlpha::RouterInterface>
Router interfaces.
-
#kind ⇒ String
Output only.
-
#md5_authentication_keys ⇒ Array<Google::Apis::ComputeAlpha::RouterMd5AuthenticationKey>
Keys used for MD5 authentication.
-
#name ⇒ String
Name of the resource.
-
#nats ⇒ Array<Google::Apis::ComputeAlpha::RouterNat>
A list of NAT services created in this router.
-
#ncc_gateway ⇒ String
URI of the ncc_gateway to which this router associated.
-
#network ⇒ String
URI of the network to which this router belongs.
-
#params ⇒ Google::Apis::ComputeAlpha::RouterParams
Additional router parameters.
-
#region ⇒ String
[Output Only] URI of the region where the router resides.
-
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
-
#self_link_with_id ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Router
constructor
A new instance of Router.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Router
Returns a new instance of Router.
63253 63254 63255 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63253 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bgp ⇒ Google::Apis::ComputeAlpha::RouterBgp
BGP information specific to this router.
Corresponds to the JSON property bgp
63145 63146 63147 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63145 def bgp @bgp end |
#bgp_peers ⇒ Array<Google::Apis::ComputeAlpha::RouterBgpPeer>
BGP information that must be configured into the routing stack to
establish BGP peering. This information must specify the peer ASN and
either the interface name, IP address, or peer IP address. Please refer
toRFC4273.
Corresponds to the JSON property bgpPeers
63153 63154 63155 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63153 def bgp_peers @bgp_peers end |
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
63159 63160 63161 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63159 def @creation_timestamp end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
63165 63166 63167 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63165 def description @description end |
#encrypted_interconnect_router ⇒ Boolean Also known as: encrypted_interconnect_router?
Indicates if a router is dedicated for use with encrypted VLAN
attachments (interconnectAttachments).
Corresponds to the JSON property encryptedInterconnectRouter
63171 63172 63173 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63171 def encrypted_interconnect_router @encrypted_interconnect_router end |
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
63178 63179 63180 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63178 def id @id end |
#interfaces ⇒ Array<Google::Apis::ComputeAlpha::RouterInterface>
Router interfaces. To create a BGP peer that uses a router interface, the interface must have one of the following fields specified:
- linkedVpnTunnel
- linkedInterconnectAttachment
- subnetwork
You can create a router interface without any of these fields specified.
However, you cannot create a BGP peer that uses that interface.
Corresponds to the JSON property
interfaces
63191 63192 63193 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63191 def interfaces @interfaces end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#router for
routers.
Corresponds to the JSON property kind
63197 63198 63199 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63197 def kind @kind end |
#md5_authentication_keys ⇒ Array<Google::Apis::ComputeAlpha::RouterMd5AuthenticationKey>
Keys used for MD5 authentication.
Corresponds to the JSON property md5AuthenticationKeys
63202 63203 63204 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63202 def md5_authentication_keys @md5_authentication_keys end |
#name ⇒ String
Name of the resource. Provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must
be a dash, lowercase letter, or digit, except the last character, which
cannot be a dash.
Corresponds to the JSON property name
63213 63214 63215 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63213 def name @name end |
#nats ⇒ Array<Google::Apis::ComputeAlpha::RouterNat>
A list of NAT services created in this router.
Corresponds to the JSON property nats
63218 63219 63220 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63218 def nats @nats end |
#ncc_gateway ⇒ String
URI of the ncc_gateway to which this router associated.
Corresponds to the JSON property nccGateway
63223 63224 63225 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63223 def ncc_gateway @ncc_gateway end |
#network ⇒ String
URI of the network to which this router belongs.
Corresponds to the JSON property network
63228 63229 63230 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63228 def network @network end |
#params ⇒ Google::Apis::ComputeAlpha::RouterParams
Additional router parameters.
Corresponds to the JSON property params
63233 63234 63235 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63233 def params @params end |
#region ⇒ String
[Output Only] URI of the region where the router resides.
You must specify this field as part of the HTTP request URL. It is
not settable as a field in the request body.
Corresponds to the JSON property region
63240 63241 63242 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63240 def region @region end |
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
63245 63246 63247 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63245 def self_link @self_link end |
#self_link_with_id ⇒ String
Output only. [Output Only] Server-defined URL for this resource with the
resource id.
Corresponds to the JSON property selfLinkWithId
63251 63252 63253 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63251 def self_link_with_id @self_link_with_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
63258 63259 63260 63261 63262 63263 63264 63265 63266 63267 63268 63269 63270 63271 63272 63273 63274 63275 63276 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63258 def update!(**args) @bgp = args[:bgp] if args.key?(:bgp) @bgp_peers = args[:bgp_peers] if args.key?(:bgp_peers) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @encrypted_interconnect_router = args[:encrypted_interconnect_router] if args.key?(:encrypted_interconnect_router) @id = args[:id] if args.key?(:id) @interfaces = args[:interfaces] if args.key?(:interfaces) @kind = args[:kind] if args.key?(:kind) @md5_authentication_keys = args[:md5_authentication_keys] if args.key?(:md5_authentication_keys) @name = args[:name] if args.key?(:name) @nats = args[:nats] if args.key?(:nats) @ncc_gateway = args[:ncc_gateway] if args.key?(:ncc_gateway) @network = args[:network] if args.key?(:network) @params = args[:params] if args.key?(:params) @region = args[:region] if args.key?(:region) @self_link = args[:self_link] if args.key?(:self_link) @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id) end |