Class: Google::Apis::ComputeAlpha::RouterAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of routers.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RouterAggregatedList

Returns a new instance of RouterAggregatedList.



63964
63965
63966
# File 'lib/google/apis/compute_alpha/classes.rb', line 63964

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


63927
63928
63929
# File 'lib/google/apis/compute_alpha/classes.rb', line 63927

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::RoutersScopedList>

A list of Router resources. Corresponds to the JSON property items



63932
63933
63934
# File 'lib/google/apis/compute_alpha/classes.rb', line 63932

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


63937
63938
63939
# File 'lib/google/apis/compute_alpha/classes.rb', line 63937

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


63947
63948
63949
# File 'lib/google/apis/compute_alpha/classes.rb', line 63947

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


63952
63953
63954
# File 'lib/google/apis/compute_alpha/classes.rb', line 63952

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


63957
63958
63959
# File 'lib/google/apis/compute_alpha/classes.rb', line 63957

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::RouterAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



63962
63963
63964
# File 'lib/google/apis/compute_alpha/classes.rb', line 63962

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



63969
63970
63971
63972
63973
63974
63975
63976
63977
# File 'lib/google/apis/compute_alpha/classes.rb', line 63969

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end