Class: Google::Apis::ComputeAlpha::RouterAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::RouterAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Contains a list of routers.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::RoutersScopedList>
A list of Router resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::RouterAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RouterAggregatedList
constructor
A new instance of RouterAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RouterAggregatedList
Returns a new instance of RouterAggregatedList.
63348 63349 63350 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63348 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
63311 63312 63313 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63311 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::RoutersScopedList>
A list of Router resources.
Corresponds to the JSON property items
63316 63317 63318 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63316 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
63321 63322 63323 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63321 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
63331 63332 63333 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63331 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
63336 63337 63338 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63336 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
63341 63342 63343 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63341 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::RouterAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
63346 63347 63348 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63346 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
63353 63354 63355 63356 63357 63358 63359 63360 63361 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63353 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |