Class: Google::Apis::ComputeAlpha::RouterAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::RouterAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Contains a list of routers.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::RoutersScopedList>
A list of Router resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::RouterAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RouterAggregatedList
constructor
A new instance of RouterAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RouterAggregatedList
Returns a new instance of RouterAggregatedList.
63127 63128 63129 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63127 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
63090 63091 63092 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63090 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::RoutersScopedList>
A list of Router resources.
Corresponds to the JSON property items
63095 63096 63097 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63095 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
63100 63101 63102 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63100 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
63110 63111 63112 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63110 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
63115 63116 63117 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63115 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
63120 63121 63122 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63120 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::RouterAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
63125 63126 63127 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63125 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
63132 63133 63134 63135 63136 63137 63138 63139 63140 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63132 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |