Class: Google::Apis::ComputeAlpha::RouterAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::RouterAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Contains a list of routers.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::RoutersScopedList>
A list of Router resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::RouterAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RouterAggregatedList
constructor
A new instance of RouterAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RouterAggregatedList
Returns a new instance of RouterAggregatedList.
62244 62245 62246 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 62244 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
62207 62208 62209 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 62207 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::RoutersScopedList>
A list of Router resources.
Corresponds to the JSON property items
62212 62213 62214 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 62212 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
62217 62218 62219 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 62217 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
62227 62228 62229 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 62227 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
62232 62233 62234 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 62232 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
62237 62238 62239 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 62237 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::RouterAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
62242 62243 62244 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 62242 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
62249 62250 62251 62252 62253 62254 62255 62256 62257 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 62249 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |