Class: Google::Apis::ComputeAlpha::RouterBgp
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::RouterBgp
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#advertise_mode ⇒ String
User-specified flag to indicate which mode to use for advertisement.
-
#advertised_groups ⇒ Array<String>
User-specified list of prefix groups to advertise in custom mode.
-
#advertised_ip_ranges ⇒ Array<Google::Apis::ComputeAlpha::RouterAdvertisedIpRange>
User-specified list of individual IP ranges to advertise in custom mode.
-
#asn ⇒ Fixnum
Local BGP Autonomous System Number (ASN).
-
#identifier_range ⇒ String
Explicitly specifies a range of valid BGP Identifiers for this Router.
-
#keepalive_interval ⇒ Fixnum
The interval in seconds between BGP keepalive messages that are sent to the peer.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RouterBgp
constructor
A new instance of RouterBgp.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RouterBgp
Returns a new instance of RouterBgp.
63493 63494 63495 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63493 def initialize(**args) update!(**args) end |
Instance Attribute Details
#advertise_mode ⇒ String
User-specified flag to indicate which mode to use for advertisement.
The options are DEFAULT or CUSTOM.
Corresponds to the JSON property advertiseMode
63442 63443 63444 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63442 def advertise_mode @advertise_mode end |
#advertised_groups ⇒ Array<String>
User-specified list of prefix groups to advertise in custom mode.
This field can only be populated if advertise_mode is CUSTOM and
is advertised to all peers of the router.
These groups will be advertised in addition to any specified prefixes.
Leave this field blank to advertise no custom groups.
Corresponds to the JSON property advertisedGroups
63451 63452 63453 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63451 def advertised_groups @advertised_groups end |
#advertised_ip_ranges ⇒ Array<Google::Apis::ComputeAlpha::RouterAdvertisedIpRange>
User-specified list of individual IP ranges to advertise in custom mode.
This field can only be populated if advertise_mode is CUSTOM and
is advertised to all peers of the router.
These IP ranges will be advertised in addition to any specified groups.
Leave this field blank to advertise no custom IP ranges.
Corresponds to the JSON property advertisedIpRanges
63460 63461 63462 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63460 def advertised_ip_ranges @advertised_ip_ranges end |
#asn ⇒ Fixnum
Local BGP Autonomous System Number (ASN).
Must be anRFC6996 private ASN, either 16-bit or 32-bit. The
value will be fixed for this router resource. All VPN tunnels that link
to this router will have the same local ASN.
Corresponds to the JSON property asn
63468 63469 63470 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63468 def asn @asn end |
#identifier_range ⇒ String
Explicitly specifies a range of valid BGP Identifiers for this Router. It
is provided as a link-local IPv4 range (from 169.254.0.0/16), of size at
least /30, even if the BGP sessions are over IPv6. It must not overlap
with any IPv4 BGP session ranges.
Other vendors commonly call this "router ID".
Corresponds to the JSON property identifierRange
63477 63478 63479 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63477 def identifier_range @identifier_range end |
#keepalive_interval ⇒ Fixnum
The interval in seconds between BGP keepalive messages that are
sent to the peer.
Hold time is three times the interval at which keepalive messages are
sent, and the hold time is the maximum number of seconds allowed to
elapse between successive keepalive messages that BGP receives from a
peer.
BGP will use the smaller of either the local hold time value or the
peer's hold time value as the hold time for the BGP connection between
the two peers.
If set, this value must be between 20 and 60. The default is 20.
Corresponds to the JSON property keepaliveInterval
63491 63492 63493 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63491 def keepalive_interval @keepalive_interval end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
63498 63499 63500 63501 63502 63503 63504 63505 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63498 def update!(**args) @advertise_mode = args[:advertise_mode] if args.key?(:advertise_mode) @advertised_groups = args[:advertised_groups] if args.key?(:advertised_groups) @advertised_ip_ranges = args[:advertised_ip_ranges] if args.key?(:advertised_ip_ranges) @asn = args[:asn] if args.key?(:asn) @identifier_range = args[:identifier_range] if args.key?(:identifier_range) @keepalive_interval = args[:keepalive_interval] if args.key?(:keepalive_interval) end |