Class: Google::Apis::ComputeAlpha::RouterBgpPeerBfd
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::RouterBgpPeerBfd
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#min_receive_interval ⇒ Fixnum
The minimum interval, in milliseconds, between BFD control packets received from the peer router.
-
#min_transmit_interval ⇒ Fixnum
The minimum interval, in milliseconds, between BFD control packets transmitted to the peer router.
-
#mode ⇒ String
The BFD session initialization mode for this BGP peer.
-
#multiplier ⇒ Fixnum
The number of consecutive BFD packets that must be missed before BFD declares that a peer is unavailable.
-
#packet_mode ⇒ String
The BFD packet mode for this BGP peer.
-
#session_initialization_mode ⇒ String
The BFD session initialization mode for this BGP peer.
-
#slow_timer_interval ⇒ Fixnum
The minimum interval, in milliseconds, between BFD control packets transmitted to and received from the peer router when BFD echo mode is enabled on both routers.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RouterBgpPeerBfd
constructor
A new instance of RouterBgpPeerBfd.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RouterBgpPeerBfd
Returns a new instance of RouterBgpPeerBfd.
63581 63582 63583 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63581 def initialize(**args) update!(**args) end |
Instance Attribute Details
#min_receive_interval ⇒ Fixnum
The minimum interval, in milliseconds, between BFD control packets
received from the peer router. The actual value is negotiated between
the two routers and is equal to the greater of this value and the
transmit interval of the other router.
If set, this value must be between 1000 and 30000.
The default is 1000.
Corresponds to the JSON property minReceiveInterval
63519 63520 63521 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63519 def min_receive_interval @min_receive_interval end |
#min_transmit_interval ⇒ Fixnum
The minimum interval, in milliseconds, between BFD control packets
transmitted to the peer router. The actual value is negotiated between
the two routers and is equal to the greater of this value and the
corresponding receive interval of the other router.
If set, this value must be between 1000 and 30000.
The default is 1000.
Corresponds to the JSON property minTransmitInterval
63529 63530 63531 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63529 def min_transmit_interval @min_transmit_interval end |
#mode ⇒ String
The BFD session initialization mode for this BGP peer.
If set to ACTIVE, the Cloud Router will initiate the BFD session for
this BGP peer. If set to PASSIVE, the Cloud Router will wait for the
peer router to initiate the BFD session for this BGP peer. If set to
DISABLED, BFD is disabled for this BGP peer. The default is PASSIVE.
Corresponds to the JSON property mode
63538 63539 63540 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63538 def mode @mode end |
#multiplier ⇒ Fixnum
The number of consecutive BFD packets that must be missed
before BFD declares that a peer is unavailable.
If set, the value must be a value between 5 and 16.
The default is 5.
Corresponds to the JSON property multiplier
63546 63547 63548 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63546 def multiplier @multiplier end |
#packet_mode ⇒ String
The BFD packet mode for this BGP peer.
If set to CONTROL_AND_ECHO, BFD echo mode is enabled for this BGP peer.
In this mode, if the peer router also has BFD echo mode enabled, BFD
echo packets will be sent to the other router. If the peer router does
not have BFD echo mode enabled, only control packets will be sent. If
set to CONTROL_ONLY, BFD echo mode is disabled for this BGP peer. If
this router and the peer router have a multihop connection, this should
be set to CONTROL_ONLY as BFD echo mode is only supported on singlehop
connections. The default is CONTROL_AND_ECHO.
Corresponds to the JSON property packetMode
63559 63560 63561 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63559 def packet_mode @packet_mode end |
#session_initialization_mode ⇒ String
The BFD session initialization mode for this BGP peer.
If set to ACTIVE, the Cloud Router will initiate the BFD session for
this BGP peer. If set to PASSIVE, the Cloud Router will wait for the
peer router to initiate the BFD session for this BGP peer. If set to
DISABLED, BFD is disabled for this BGP peer. The default is DISABLED.
Corresponds to the JSON property sessionInitializationMode
63568 63569 63570 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63568 def session_initialization_mode @session_initialization_mode end |
#slow_timer_interval ⇒ Fixnum
The minimum interval, in milliseconds, between BFD control packets
transmitted to and received from the peer router when BFD echo mode is
enabled on both routers. The actual transmit and receive intervals are
negotiated between the two routers and are equal to the greater of this
value and the corresponding interval on the other router.
If set, this value must be between 1000 and 30000.
The default is 5000.
Corresponds to the JSON property slowTimerInterval
63579 63580 63581 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63579 def slow_timer_interval @slow_timer_interval end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
63586 63587 63588 63589 63590 63591 63592 63593 63594 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63586 def update!(**args) @min_receive_interval = args[:min_receive_interval] if args.key?(:min_receive_interval) @min_transmit_interval = args[:min_transmit_interval] if args.key?(:min_transmit_interval) @mode = args[:mode] if args.key?(:mode) @multiplier = args[:multiplier] if args.key?(:multiplier) @packet_mode = args[:packet_mode] if args.key?(:packet_mode) @session_initialization_mode = args[:session_initialization_mode] if args.key?(:session_initialization_mode) @slow_timer_interval = args[:slow_timer_interval] if args.key?(:slow_timer_interval) end |