Class: Google::Apis::ComputeAlpha::RouterList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::RouterList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Contains a list of Router resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::Router>
A list of Router resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::RouterList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RouterList
constructor
A new instance of RouterList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RouterList
Returns a new instance of RouterList.
66266 66267 66268 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 66266 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
66233 66234 66235 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 66233 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::Router>
A list of Router resources.
Corresponds to the JSON property items
66238 66239 66240 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 66238 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#router for
routers.
Corresponds to the JSON property kind
66244 66245 66246 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 66244 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
66254 66255 66256 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 66254 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
66259 66260 66261 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 66259 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::RouterList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
66264 66265 66266 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 66264 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
66271 66272 66273 66274 66275 66276 66277 66278 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 66271 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |