Class: Google::Apis::ComputeAlpha::RouterList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of Router resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RouterList

Returns a new instance of RouterList.



64586
64587
64588
# File 'lib/google/apis/compute_alpha/classes.rb', line 64586

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


64553
64554
64555
# File 'lib/google/apis/compute_alpha/classes.rb', line 64553

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::Router>

A list of Router resources. Corresponds to the JSON property items



64558
64559
64560
# File 'lib/google/apis/compute_alpha/classes.rb', line 64558

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#router for routers. Corresponds to the JSON property kind

Returns:

  • (String)


64564
64565
64566
# File 'lib/google/apis/compute_alpha/classes.rb', line 64564

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


64574
64575
64576
# File 'lib/google/apis/compute_alpha/classes.rb', line 64574

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


64579
64580
64581
# File 'lib/google/apis/compute_alpha/classes.rb', line 64579

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::RouterList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



64584
64585
64586
# File 'lib/google/apis/compute_alpha/classes.rb', line 64584

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



64591
64592
64593
64594
64595
64596
64597
64598
# File 'lib/google/apis/compute_alpha/classes.rb', line 64591

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end