Class: Google::Apis::ComputeAlpha::RouterList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::RouterList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Contains a list of Router resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::Router>
A list of Router resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::RouterList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RouterList
constructor
A new instance of RouterList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RouterList
Returns a new instance of RouterList.
63997 63998 63999 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63997 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
63964 63965 63966 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63964 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::Router>
A list of Router resources.
Corresponds to the JSON property items
63969 63970 63971 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63969 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#router for
routers.
Corresponds to the JSON property kind
63975 63976 63977 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63975 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
63985 63986 63987 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63985 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
63990 63991 63992 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63990 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::RouterList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
63995 63996 63997 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63995 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
64002 64003 64004 64005 64006 64007 64008 64009 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64002 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |