Class: Google::Apis::ComputeAlpha::RouterMd5AuthenticationKey
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::RouterMd5AuthenticationKey
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#key ⇒ String
[Input only] Value of the key.
-
#name ⇒ String
Name used to identify the key.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RouterMd5AuthenticationKey
constructor
A new instance of RouterMd5AuthenticationKey.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RouterMd5AuthenticationKey
Returns a new instance of RouterMd5AuthenticationKey.
64102 64103 64104 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64102 def initialize(**args) update!(**args) end |
Instance Attribute Details
#key ⇒ String
[Input only] Value of the key.
For patch and update calls, it can be skipped to
copy the value from the previous configuration. This is allowed if the
key with the same name existed before the operation. Maximum length is 80
characters. Can only contain printable ASCII characters.
Corresponds to the JSON property key
64093 64094 64095 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64093 def key @key end |
#name ⇒ String
Name used to identify the key.
Must be unique within a router. Must be referenced by exactly
one bgpPeer. Must comply withRFC1035.
Corresponds to the JSON property name
64100 64101 64102 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64100 def name @name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
64107 64108 64109 64110 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64107 def update!(**args) @key = args[:key] if args.key?(:key) @name = args[:name] if args.key?(:name) end |