Class: Google::Apis::ComputeAlpha::RouterMd5AuthenticationKey

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RouterMd5AuthenticationKey

Returns a new instance of RouterMd5AuthenticationKey.



63879
63880
63881
# File 'lib/google/apis/compute_alpha/classes.rb', line 63879

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#keyString

[Input only] Value of the key. For patch and update calls, it can be skipped to copy the value from the previous configuration. This is allowed if the key with the same name existed before the operation. Maximum length is 80 characters. Can only contain printable ASCII characters. Corresponds to the JSON property key

Returns:

  • (String)


63870
63871
63872
# File 'lib/google/apis/compute_alpha/classes.rb', line 63870

def key
  @key
end

#nameString

Name used to identify the key. Must be unique within a router. Must be referenced by exactly one bgpPeer. Must comply withRFC1035. Corresponds to the JSON property name

Returns:

  • (String)


63877
63878
63879
# File 'lib/google/apis/compute_alpha/classes.rb', line 63877

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



63884
63885
63886
63887
# File 'lib/google/apis/compute_alpha/classes.rb', line 63884

def update!(**args)
  @key = args[:key] if args.key?(:key)
  @name = args[:name] if args.key?(:name)
end