Class: Google::Apis::ComputeAlpha::RouterMd5AuthenticationKey
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::RouterMd5AuthenticationKey
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#key ⇒ String
[Input only] Value of the key.
-
#name ⇒ String
Name used to identify the key.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RouterMd5AuthenticationKey
constructor
A new instance of RouterMd5AuthenticationKey.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RouterMd5AuthenticationKey
Returns a new instance of RouterMd5AuthenticationKey.
63879 63880 63881 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63879 def initialize(**args) update!(**args) end |
Instance Attribute Details
#key ⇒ String
[Input only] Value of the key.
For patch and update calls, it can be skipped to
copy the value from the previous configuration. This is allowed if the
key with the same name existed before the operation. Maximum length is 80
characters. Can only contain printable ASCII characters.
Corresponds to the JSON property key
63870 63871 63872 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63870 def key @key end |
#name ⇒ String
Name used to identify the key.
Must be unique within a router. Must be referenced by exactly
one bgpPeer. Must comply withRFC1035.
Corresponds to the JSON property name
63877 63878 63879 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63877 def name @name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
63884 63885 63886 63887 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 63884 def update!(**args) @key = args[:key] if args.key?(:key) @name = args[:name] if args.key?(:name) end |