Class: Google::Apis::ComputeAlpha::RouterStatus
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::RouterStatus
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#best_routes ⇒ Array<Google::Apis::ComputeAlpha::Route>
A list of the best dynamic routes for this Cloud Router's Virtual Private Cloud (VPC) network in the same region as this Cloud Router.
-
#best_routes_for_router ⇒ Array<Google::Apis::ComputeAlpha::Route>
A list of the best BGP routes learned by this Cloud Router.
-
#bgp_peer_status ⇒ Array<Google::Apis::ComputeAlpha::RouterStatusBgpPeerStatus>
Corresponds to the JSON property
bgpPeerStatus. -
#nat_status ⇒ Array<Google::Apis::ComputeAlpha::RouterStatusNatStatus>
Corresponds to the JSON property
natStatus. -
#ncc_gateway ⇒ String
URI of the ncc_gateway to which this router associated.
-
#network ⇒ String
URI of the network to which this router belongs.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RouterStatus
constructor
A new instance of RouterStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RouterStatus
Returns a new instance of RouterStatus.
65225 65226 65227 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 65225 def initialize(**args) update!(**args) end |
Instance Attribute Details
#best_routes ⇒ Array<Google::Apis::ComputeAlpha::Route>
A list of the best dynamic routes for this Cloud Router's Virtual Private
Cloud (VPC) network in the same region as this Cloud Router.
Lists all of the best routes per prefix that are programmed into this
region's VPC data plane.
When global dynamic routing mode is turned on in the VPC network, this list
can include cross-region dynamic routes from Cloud Routers in other
regions.
Corresponds to the JSON property bestRoutes
65195 65196 65197 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 65195 def best_routes @best_routes end |
#best_routes_for_router ⇒ Array<Google::Apis::ComputeAlpha::Route>
A list of the best BGP routes learned by this Cloud Router.
It is possible that routes listed might not be programmed into the data
plane, if the Google Cloud control plane finds a more optimal route for a
prefix than a route learned by this Cloud Router.
Corresponds to the JSON property bestRoutesForRouter
65203 65204 65205 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 65203 def best_routes_for_router @best_routes_for_router end |
#bgp_peer_status ⇒ Array<Google::Apis::ComputeAlpha::RouterStatusBgpPeerStatus>
Corresponds to the JSON property bgpPeerStatus
65208 65209 65210 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 65208 def bgp_peer_status @bgp_peer_status end |
#nat_status ⇒ Array<Google::Apis::ComputeAlpha::RouterStatusNatStatus>
Corresponds to the JSON property natStatus
65213 65214 65215 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 65213 def nat_status @nat_status end |
#ncc_gateway ⇒ String
URI of the ncc_gateway to which this router associated.
Corresponds to the JSON property nccGateway
65218 65219 65220 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 65218 def ncc_gateway @ncc_gateway end |
#network ⇒ String
URI of the network to which this router belongs.
Corresponds to the JSON property network
65223 65224 65225 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 65223 def network @network end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
65230 65231 65232 65233 65234 65235 65236 65237 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 65230 def update!(**args) @best_routes = args[:best_routes] if args.key?(:best_routes) @best_routes_for_router = args[:best_routes_for_router] if args.key?(:best_routes_for_router) @bgp_peer_status = args[:bgp_peer_status] if args.key?(:bgp_peer_status) @nat_status = args[:nat_status] if args.key?(:nat_status) @ncc_gateway = args[:ncc_gateway] if args.key?(:ncc_gateway) @network = args[:network] if args.key?(:network) end |