Class: Google::Apis::ComputeAlpha::RouterStatus

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RouterStatus

Returns a new instance of RouterStatus.



65193
65194
65195
# File 'lib/google/apis/compute_alpha/classes.rb', line 65193

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#best_routesArray<Google::Apis::ComputeAlpha::Route>

A list of the best dynamic routes for this Cloud Router's Virtual Private Cloud (VPC) network in the same region as this Cloud Router. Lists all of the best routes per prefix that are programmed into this region's VPC data plane. When global dynamic routing mode is turned on in the VPC network, this list can include cross-region dynamic routes from Cloud Routers in other regions. Corresponds to the JSON property bestRoutes



65163
65164
65165
# File 'lib/google/apis/compute_alpha/classes.rb', line 65163

def best_routes
  @best_routes
end

#best_routes_for_routerArray<Google::Apis::ComputeAlpha::Route>

A list of the best BGP routes learned by this Cloud Router. It is possible that routes listed might not be programmed into the data plane, if the Google Cloud control plane finds a more optimal route for a prefix than a route learned by this Cloud Router. Corresponds to the JSON property bestRoutesForRouter



65171
65172
65173
# File 'lib/google/apis/compute_alpha/classes.rb', line 65171

def best_routes_for_router
  @best_routes_for_router
end

#bgp_peer_statusArray<Google::Apis::ComputeAlpha::RouterStatusBgpPeerStatus>

Corresponds to the JSON property bgpPeerStatus



65176
65177
65178
# File 'lib/google/apis/compute_alpha/classes.rb', line 65176

def bgp_peer_status
  @bgp_peer_status
end

#nat_statusArray<Google::Apis::ComputeAlpha::RouterStatusNatStatus>

Corresponds to the JSON property natStatus



65181
65182
65183
# File 'lib/google/apis/compute_alpha/classes.rb', line 65181

def nat_status
  @nat_status
end

#ncc_gatewayString

URI of the ncc_gateway to which this router associated. Corresponds to the JSON property nccGateway

Returns:

  • (String)


65186
65187
65188
# File 'lib/google/apis/compute_alpha/classes.rb', line 65186

def ncc_gateway
  @ncc_gateway
end

#networkString

URI of the network to which this router belongs. Corresponds to the JSON property network

Returns:

  • (String)


65191
65192
65193
# File 'lib/google/apis/compute_alpha/classes.rb', line 65191

def network
  @network
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



65198
65199
65200
65201
65202
65203
65204
65205
# File 'lib/google/apis/compute_alpha/classes.rb', line 65198

def update!(**args)
  @best_routes = args[:best_routes] if args.key?(:best_routes)
  @best_routes_for_router = args[:best_routes_for_router] if args.key?(:best_routes_for_router)
  @bgp_peer_status = args[:bgp_peer_status] if args.key?(:bgp_peer_status)
  @nat_status = args[:nat_status] if args.key?(:nat_status)
  @ncc_gateway = args[:ncc_gateway] if args.key?(:ncc_gateway)
  @network = args[:network] if args.key?(:network)
end