Class: Google::Apis::ComputeAlpha::RouterStatus
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::RouterStatus
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#best_routes ⇒ Array<Google::Apis::ComputeAlpha::Route>
A list of the best dynamic routes for this Cloud Router's Virtual Private Cloud (VPC) network in the same region as this Cloud Router.
-
#best_routes_for_router ⇒ Array<Google::Apis::ComputeAlpha::Route>
A list of the best BGP routes learned by this Cloud Router.
-
#bgp_peer_status ⇒ Array<Google::Apis::ComputeAlpha::RouterStatusBgpPeerStatus>
Corresponds to the JSON property
bgpPeerStatus. -
#nat_status ⇒ Array<Google::Apis::ComputeAlpha::RouterStatusNatStatus>
Corresponds to the JSON property
natStatus. -
#ncc_gateway ⇒ String
URI of the ncc_gateway to which this router associated.
-
#network ⇒ String
URI of the network to which this router belongs.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RouterStatus
constructor
A new instance of RouterStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RouterStatus
Returns a new instance of RouterStatus.
64372 64373 64374 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64372 def initialize(**args) update!(**args) end |
Instance Attribute Details
#best_routes ⇒ Array<Google::Apis::ComputeAlpha::Route>
A list of the best dynamic routes for this Cloud Router's Virtual Private
Cloud (VPC) network in the same region as this Cloud Router.
Lists all of the best routes per prefix that are programmed into this
region's VPC data plane.
When global dynamic routing mode is turned on in the VPC network, this list
can include cross-region dynamic routes from Cloud Routers in other
regions.
Corresponds to the JSON property bestRoutes
64342 64343 64344 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64342 def best_routes @best_routes end |
#best_routes_for_router ⇒ Array<Google::Apis::ComputeAlpha::Route>
A list of the best BGP routes learned by this Cloud Router.
It is possible that routes listed might not be programmed into the data
plane, if the Google Cloud control plane finds a more optimal route for a
prefix than a route learned by this Cloud Router.
Corresponds to the JSON property bestRoutesForRouter
64350 64351 64352 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64350 def best_routes_for_router @best_routes_for_router end |
#bgp_peer_status ⇒ Array<Google::Apis::ComputeAlpha::RouterStatusBgpPeerStatus>
Corresponds to the JSON property bgpPeerStatus
64355 64356 64357 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64355 def bgp_peer_status @bgp_peer_status end |
#nat_status ⇒ Array<Google::Apis::ComputeAlpha::RouterStatusNatStatus>
Corresponds to the JSON property natStatus
64360 64361 64362 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64360 def nat_status @nat_status end |
#ncc_gateway ⇒ String
URI of the ncc_gateway to which this router associated.
Corresponds to the JSON property nccGateway
64365 64366 64367 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64365 def ncc_gateway @ncc_gateway end |
#network ⇒ String
URI of the network to which this router belongs.
Corresponds to the JSON property network
64370 64371 64372 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64370 def network @network end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
64377 64378 64379 64380 64381 64382 64383 64384 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64377 def update!(**args) @best_routes = args[:best_routes] if args.key?(:best_routes) @best_routes_for_router = args[:best_routes_for_router] if args.key?(:best_routes_for_router) @bgp_peer_status = args[:bgp_peer_status] if args.key?(:bgp_peer_status) @nat_status = args[:nat_status] if args.key?(:nat_status) @ncc_gateway = args[:ncc_gateway] if args.key?(:ncc_gateway) @network = args[:network] if args.key?(:network) end |