Class: Google::Apis::ComputeAlpha::RouterStatusBgpPeerStatus

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RouterStatusBgpPeerStatus

Returns a new instance of RouterStatusBgpPeerStatus.



67028
67029
67030
# File 'lib/google/apis/compute_alpha/classes.rb', line 67028

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#advertised_routesArray<Google::Apis::ComputeAlpha::Route>

Routes that were advertised to the remote BGP peer Corresponds to the JSON property advertisedRoutes



66902
66903
66904
# File 'lib/google/apis/compute_alpha/classes.rb', line 66902

def advertised_routes
  @advertised_routes
end

#bfd_statusGoogle::Apis::ComputeAlpha::BfdStatus

Next free: 15 Corresponds to the JSON property bfdStatus



66907
66908
66909
# File 'lib/google/apis/compute_alpha/classes.rb', line 66907

def bfd_status
  @bfd_status
end

#depreferencedBoolean Also known as: depreferenced?

Output only. [Output Only] Indicates whether the BGP peer is in a depreferenced state. Corresponds to the JSON property depreferenced

Returns:

  • (Boolean)


66913
66914
66915
# File 'lib/google/apis/compute_alpha/classes.rb', line 66913

def depreferenced
  @depreferenced
end

#enable_ipv4Boolean Also known as: enable_ipv4?

Output only. Enable IPv4 traffic over BGP Peer. It is enabled by default if the peerIpAddress is version 4. Corresponds to the JSON property enableIpv4

Returns:

  • (Boolean)


66920
66921
66922
# File 'lib/google/apis/compute_alpha/classes.rb', line 66920

def enable_ipv4
  @enable_ipv4
end

#enable_ipv6Boolean Also known as: enable_ipv6?

Output only. Enable IPv6 traffic over BGP Peer. It is enabled by default if the peerIpAddress is version 6. Corresponds to the JSON property enableIpv6

Returns:

  • (Boolean)


66927
66928
66929
# File 'lib/google/apis/compute_alpha/classes.rb', line 66927

def enable_ipv6
  @enable_ipv6
end

#ip_addressString

Output only. IP address of the local BGP interface. Corresponds to the JSON property ipAddress

Returns:

  • (String)


66933
66934
66935
# File 'lib/google/apis/compute_alpha/classes.rb', line 66933

def ip_address
  @ip_address
end

#ipv4_nexthop_addressString

Output only. IPv4 address of the local BGP interface. Corresponds to the JSON property ipv4NexthopAddress

Returns:

  • (String)


66938
66939
66940
# File 'lib/google/apis/compute_alpha/classes.rb', line 66938

def ipv4_nexthop_address
  @ipv4_nexthop_address
end

#ipv6_nexthop_addressString

Output only. IPv6 address of the local BGP interface. Corresponds to the JSON property ipv6NexthopAddress

Returns:

  • (String)


66943
66944
66945
# File 'lib/google/apis/compute_alpha/classes.rb', line 66943

def ipv6_nexthop_address
  @ipv6_nexthop_address
end

#linked_custom_hardwareString

Output only. The URI of the linked custom hardware resource, CustomHardwareLinkAttachment. This CustomHardwareLinkAttachment resource is the one that will establish the BGP session from the Cloud Router. Corresponds to the JSON property linkedCustomHardware

Returns:

  • (String)


66950
66951
66952
# File 'lib/google/apis/compute_alpha/classes.rb', line 66950

def linked_custom_hardware
  @linked_custom_hardware
end

#linked_vpn_tunnelString

Output only. URL of the VPN tunnel that this BGP peer controls. Corresponds to the JSON property linkedVpnTunnel

Returns:

  • (String)


66955
66956
66957
# File 'lib/google/apis/compute_alpha/classes.rb', line 66955

def linked_vpn_tunnel
  @linked_vpn_tunnel
end

#md5_auth_enabledBoolean Also known as: md5_auth_enabled?

Informs whether MD5 authentication is enabled on this BGP peer. Corresponds to the JSON property md5AuthEnabled

Returns:

  • (Boolean)


66960
66961
66962
# File 'lib/google/apis/compute_alpha/classes.rb', line 66960

def md5_auth_enabled
  @md5_auth_enabled
end

#nameString

Output only. Name of this BGP peer. Unique within the Routers resource. Corresponds to the JSON property name

Returns:

  • (String)


66966
66967
66968
# File 'lib/google/apis/compute_alpha/classes.rb', line 66966

def name
  @name
end

#num_learned_routesFixnum

Output only. Number of routes learned from the remote BGP Peer. Corresponds to the JSON property numLearnedRoutes

Returns:

  • (Fixnum)


66971
66972
66973
# File 'lib/google/apis/compute_alpha/classes.rb', line 66971

def num_learned_routes
  @num_learned_routes
end

#peer_ip_addressString

Output only. IP address of the remote BGP interface. Corresponds to the JSON property peerIpAddress

Returns:

  • (String)


66976
66977
66978
# File 'lib/google/apis/compute_alpha/classes.rb', line 66976

def peer_ip_address
  @peer_ip_address
end

#peer_ipv4_nexthop_addressString

Output only. IPv4 address of the remote BGP interface. Corresponds to the JSON property peerIpv4NexthopAddress

Returns:

  • (String)


66981
66982
66983
# File 'lib/google/apis/compute_alpha/classes.rb', line 66981

def peer_ipv4_nexthop_address
  @peer_ipv4_nexthop_address
end

#peer_ipv6_nexthop_addressString

Output only. IPv6 address of the remote BGP interface. Corresponds to the JSON property peerIpv6NexthopAddress

Returns:

  • (String)


66986
66987
66988
# File 'lib/google/apis/compute_alpha/classes.rb', line 66986

def peer_ipv6_nexthop_address
  @peer_ipv6_nexthop_address
end

#router_appliance_instanceString

Output only. [Output only] URI of the VM instance that is used as third-party router appliances such as Next Gen Firewalls, Virtual Routers, or Router Appliances. The VM instance is the peer side of the BGP session. Corresponds to the JSON property routerApplianceInstance

Returns:

  • (String)


66995
66996
66997
# File 'lib/google/apis/compute_alpha/classes.rb', line 66995

def router_appliance_instance
  @router_appliance_instance
end

#stateString

Output only. The state of the BGP session. For a list of possible values for this field, seeBGP session states. Corresponds to the JSON property state

Returns:

  • (String)


67002
67003
67004
# File 'lib/google/apis/compute_alpha/classes.rb', line 67002

def state
  @state
end

#statusString

Output only. Status of the BGP peer: UP, DOWN Corresponds to the JSON property status

Returns:

  • (String)


67007
67008
67009
# File 'lib/google/apis/compute_alpha/classes.rb', line 67007

def status
  @status
end

#status_reasonString

Indicates why particular status was returned. Corresponds to the JSON property statusReason

Returns:

  • (String)


67012
67013
67014
# File 'lib/google/apis/compute_alpha/classes.rb', line 67012

def status_reason
  @status_reason
end

#uptimeString

Output only. Time this session has been up. Format: 14 years, 51 weeks, 6 days, 23 hours, 59 minutes, 59 seconds Corresponds to the JSON property uptime

Returns:

  • (String)


67019
67020
67021
# File 'lib/google/apis/compute_alpha/classes.rb', line 67019

def uptime
  @uptime
end

#uptime_secondsString

Output only. Time this session has been up, in seconds. Format: 145 Corresponds to the JSON property uptimeSeconds

Returns:

  • (String)


67026
67027
67028
# File 'lib/google/apis/compute_alpha/classes.rb', line 67026

def uptime_seconds
  @uptime_seconds
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



67033
67034
67035
67036
67037
67038
67039
67040
67041
67042
67043
67044
67045
67046
67047
67048
67049
67050
67051
67052
67053
67054
67055
67056
# File 'lib/google/apis/compute_alpha/classes.rb', line 67033

def update!(**args)
  @advertised_routes = args[:advertised_routes] if args.key?(:advertised_routes)
  @bfd_status = args[:bfd_status] if args.key?(:bfd_status)
  @depreferenced = args[:depreferenced] if args.key?(:depreferenced)
  @enable_ipv4 = args[:enable_ipv4] if args.key?(:enable_ipv4)
  @enable_ipv6 = args[:enable_ipv6] if args.key?(:enable_ipv6)
  @ip_address = args[:ip_address] if args.key?(:ip_address)
  @ipv4_nexthop_address = args[:ipv4_nexthop_address] if args.key?(:ipv4_nexthop_address)
  @ipv6_nexthop_address = args[:ipv6_nexthop_address] if args.key?(:ipv6_nexthop_address)
  @linked_custom_hardware = args[:linked_custom_hardware] if args.key?(:linked_custom_hardware)
  @linked_vpn_tunnel = args[:linked_vpn_tunnel] if args.key?(:linked_vpn_tunnel)
  @md5_auth_enabled = args[:md5_auth_enabled] if args.key?(:md5_auth_enabled)
  @name = args[:name] if args.key?(:name)
  @num_learned_routes = args[:num_learned_routes] if args.key?(:num_learned_routes)
  @peer_ip_address = args[:peer_ip_address] if args.key?(:peer_ip_address)
  @peer_ipv4_nexthop_address = args[:peer_ipv4_nexthop_address] if args.key?(:peer_ipv4_nexthop_address)
  @peer_ipv6_nexthop_address = args[:peer_ipv6_nexthop_address] if args.key?(:peer_ipv6_nexthop_address)
  @router_appliance_instance = args[:router_appliance_instance] if args.key?(:router_appliance_instance)
  @state = args[:state] if args.key?(:state)
  @status = args[:status] if args.key?(:status)
  @status_reason = args[:status_reason] if args.key?(:status_reason)
  @uptime = args[:uptime] if args.key?(:uptime)
  @uptime_seconds = args[:uptime_seconds] if args.key?(:uptime_seconds)
end