Class: Google::Apis::ComputeAlpha::RouterStatusBgpPeerStatus
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::RouterStatusBgpPeerStatus
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#advertised_routes ⇒ Array<Google::Apis::ComputeAlpha::Route>
Routes that were advertised to the remote BGP peer Corresponds to the JSON property
advertisedRoutes. -
#bfd_status ⇒ Google::Apis::ComputeAlpha::BfdStatus
Next free: 15 Corresponds to the JSON property
bfdStatus. -
#enable_ipv4 ⇒ Boolean
(also: #enable_ipv4?)
Output only.
-
#enable_ipv6 ⇒ Boolean
(also: #enable_ipv6?)
Output only.
-
#ip_address ⇒ String
Output only.
-
#ipv4_nexthop_address ⇒ String
Output only.
-
#ipv6_nexthop_address ⇒ String
Output only.
-
#linked_custom_hardware ⇒ String
Output only.
-
#linked_vpn_tunnel ⇒ String
Output only.
-
#md5_auth_enabled ⇒ Boolean
(also: #md5_auth_enabled?)
Informs whether MD5 authentication is enabled on this BGP peer.
-
#name ⇒ String
Output only.
-
#num_learned_routes ⇒ Fixnum
Output only.
-
#peer_ip_address ⇒ String
Output only.
-
#peer_ipv4_nexthop_address ⇒ String
Output only.
-
#peer_ipv6_nexthop_address ⇒ String
Output only.
-
#router_appliance_instance ⇒ String
Output only.
-
#state ⇒ String
Output only.
-
#status ⇒ String
Output only.
-
#status_reason ⇒ String
Indicates why particular status was returned.
-
#uptime ⇒ String
Output only.
-
#uptime_seconds ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RouterStatusBgpPeerStatus
constructor
A new instance of RouterStatusBgpPeerStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RouterStatusBgpPeerStatus
Returns a new instance of RouterStatusBgpPeerStatus.
64736 64737 64738 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64736 def initialize(**args) update!(**args) end |
Instance Attribute Details
#advertised_routes ⇒ Array<Google::Apis::ComputeAlpha::Route>
Routes that were advertised to the remote BGP peer
Corresponds to the JSON property advertisedRoutes
64617 64618 64619 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64617 def advertised_routes @advertised_routes end |
#bfd_status ⇒ Google::Apis::ComputeAlpha::BfdStatus
Next free: 15
Corresponds to the JSON property bfdStatus
64622 64623 64624 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64622 def bfd_status @bfd_status end |
#enable_ipv4 ⇒ Boolean Also known as: enable_ipv4?
Output only. Enable IPv4 traffic over BGP Peer.
It is enabled by default if the peerIpAddress is version 4.
Corresponds to the JSON property enableIpv4
64628 64629 64630 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64628 def enable_ipv4 @enable_ipv4 end |
#enable_ipv6 ⇒ Boolean Also known as: enable_ipv6?
Output only. Enable IPv6 traffic over BGP Peer.
It is enabled by default if the peerIpAddress is version 6.
Corresponds to the JSON property enableIpv6
64635 64636 64637 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64635 def enable_ipv6 @enable_ipv6 end |
#ip_address ⇒ String
Output only. IP address of the local BGP interface.
Corresponds to the JSON property ipAddress
64641 64642 64643 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64641 def ip_address @ip_address end |
#ipv4_nexthop_address ⇒ String
Output only. IPv4 address of the local BGP interface.
Corresponds to the JSON property ipv4NexthopAddress
64646 64647 64648 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64646 def ipv4_nexthop_address @ipv4_nexthop_address end |
#ipv6_nexthop_address ⇒ String
Output only. IPv6 address of the local BGP interface.
Corresponds to the JSON property ipv6NexthopAddress
64651 64652 64653 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64651 def ipv6_nexthop_address @ipv6_nexthop_address end |
#linked_custom_hardware ⇒ String
Output only. The URI of the linked custom hardware resource,
CustomHardwareLinkAttachment. This CustomHardwareLinkAttachment resource
is the one that will establish the BGP session from the Cloud Router.
Corresponds to the JSON property linkedCustomHardware
64658 64659 64660 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64658 def linked_custom_hardware @linked_custom_hardware end |
#linked_vpn_tunnel ⇒ String
Output only. URL of the VPN tunnel that this BGP peer controls.
Corresponds to the JSON property linkedVpnTunnel
64663 64664 64665 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64663 def linked_vpn_tunnel @linked_vpn_tunnel end |
#md5_auth_enabled ⇒ Boolean Also known as: md5_auth_enabled?
Informs whether MD5 authentication is enabled on this BGP peer.
Corresponds to the JSON property md5AuthEnabled
64668 64669 64670 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64668 def md5_auth_enabled @md5_auth_enabled end |
#name ⇒ String
Output only. Name of this BGP peer. Unique within the Routers resource.
Corresponds to the JSON property name
64674 64675 64676 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64674 def name @name end |
#num_learned_routes ⇒ Fixnum
Output only. Number of routes learned from the remote BGP Peer.
Corresponds to the JSON property numLearnedRoutes
64679 64680 64681 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64679 def num_learned_routes @num_learned_routes end |
#peer_ip_address ⇒ String
Output only. IP address of the remote BGP interface.
Corresponds to the JSON property peerIpAddress
64684 64685 64686 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64684 def peer_ip_address @peer_ip_address end |
#peer_ipv4_nexthop_address ⇒ String
Output only. IPv4 address of the remote BGP interface.
Corresponds to the JSON property peerIpv4NexthopAddress
64689 64690 64691 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64689 def peer_ipv4_nexthop_address @peer_ipv4_nexthop_address end |
#peer_ipv6_nexthop_address ⇒ String
Output only. IPv6 address of the remote BGP interface.
Corresponds to the JSON property peerIpv6NexthopAddress
64694 64695 64696 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64694 def peer_ipv6_nexthop_address @peer_ipv6_nexthop_address end |
#router_appliance_instance ⇒ String
Output only. [Output only] URI of the VM instance that is used as third-party
router
appliances such as Next Gen Firewalls, Virtual Routers, or Router
Appliances.
The VM instance is the peer side of the BGP session.
Corresponds to the JSON property routerApplianceInstance
64703 64704 64705 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64703 def router_appliance_instance @router_appliance_instance end |
#state ⇒ String
Output only. The state of the BGP session. For a list of possible values for
this
field, seeBGP session states.
Corresponds to the JSON property state
64710 64711 64712 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64710 def state @state end |
#status ⇒ String
Output only. Status of the BGP peer: UP, DOWN
Corresponds to the JSON property status
64715 64716 64717 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64715 def status @status end |
#status_reason ⇒ String
Indicates why particular status was returned.
Corresponds to the JSON property statusReason
64720 64721 64722 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64720 def status_reason @status_reason end |
#uptime ⇒ String
Output only. Time this session has been up.
Format:
14 years, 51 weeks, 6 days, 23 hours, 59 minutes, 59 seconds
Corresponds to the JSON property uptime
64727 64728 64729 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64727 def uptime @uptime end |
#uptime_seconds ⇒ String
Output only. Time this session has been up, in seconds.
Format:
145
Corresponds to the JSON property uptimeSeconds
64734 64735 64736 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64734 def uptime_seconds @uptime_seconds end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
64741 64742 64743 64744 64745 64746 64747 64748 64749 64750 64751 64752 64753 64754 64755 64756 64757 64758 64759 64760 64761 64762 64763 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64741 def update!(**args) @advertised_routes = args[:advertised_routes] if args.key?(:advertised_routes) @bfd_status = args[:bfd_status] if args.key?(:bfd_status) @enable_ipv4 = args[:enable_ipv4] if args.key?(:enable_ipv4) @enable_ipv6 = args[:enable_ipv6] if args.key?(:enable_ipv6) @ip_address = args[:ip_address] if args.key?(:ip_address) @ipv4_nexthop_address = args[:ipv4_nexthop_address] if args.key?(:ipv4_nexthop_address) @ipv6_nexthop_address = args[:ipv6_nexthop_address] if args.key?(:ipv6_nexthop_address) @linked_custom_hardware = args[:linked_custom_hardware] if args.key?(:linked_custom_hardware) @linked_vpn_tunnel = args[:linked_vpn_tunnel] if args.key?(:linked_vpn_tunnel) @md5_auth_enabled = args[:md5_auth_enabled] if args.key?(:md5_auth_enabled) @name = args[:name] if args.key?(:name) @num_learned_routes = args[:num_learned_routes] if args.key?(:num_learned_routes) @peer_ip_address = args[:peer_ip_address] if args.key?(:peer_ip_address) @peer_ipv4_nexthop_address = args[:peer_ipv4_nexthop_address] if args.key?(:peer_ipv4_nexthop_address) @peer_ipv6_nexthop_address = args[:peer_ipv6_nexthop_address] if args.key?(:peer_ipv6_nexthop_address) @router_appliance_instance = args[:router_appliance_instance] if args.key?(:router_appliance_instance) @state = args[:state] if args.key?(:state) @status = args[:status] if args.key?(:status) @status_reason = args[:status_reason] if args.key?(:status_reason) @uptime = args[:uptime] if args.key?(:uptime) @uptime_seconds = args[:uptime_seconds] if args.key?(:uptime_seconds) end |