Class: Google::Apis::ComputeAlpha::RouterStatusBgpPeerStatus
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::RouterStatusBgpPeerStatus
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#advertised_routes ⇒ Array<Google::Apis::ComputeAlpha::Route>
Routes that were advertised to the remote BGP peer Corresponds to the JSON property
advertisedRoutes. -
#bfd_status ⇒ Google::Apis::ComputeAlpha::BfdStatus
Next free: 15 Corresponds to the JSON property
bfdStatus. -
#enable_ipv4 ⇒ Boolean
(also: #enable_ipv4?)
Output only.
-
#enable_ipv6 ⇒ Boolean
(also: #enable_ipv6?)
Output only.
-
#ip_address ⇒ String
Output only.
-
#ipv4_nexthop_address ⇒ String
Output only.
-
#ipv6_nexthop_address ⇒ String
Output only.
-
#linked_custom_hardware ⇒ String
Output only.
-
#linked_vpn_tunnel ⇒ String
Output only.
-
#md5_auth_enabled ⇒ Boolean
(also: #md5_auth_enabled?)
Informs whether MD5 authentication is enabled on this BGP peer.
-
#name ⇒ String
Output only.
-
#num_learned_routes ⇒ Fixnum
Output only.
-
#peer_ip_address ⇒ String
Output only.
-
#peer_ipv4_nexthop_address ⇒ String
Output only.
-
#peer_ipv6_nexthop_address ⇒ String
Output only.
-
#router_appliance_instance ⇒ String
Output only.
-
#state ⇒ String
Output only.
-
#status ⇒ String
Output only.
-
#status_reason ⇒ String
Indicates why particular status was returned.
-
#uptime ⇒ String
Output only.
-
#uptime_seconds ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RouterStatusBgpPeerStatus
constructor
A new instance of RouterStatusBgpPeerStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RouterStatusBgpPeerStatus
Returns a new instance of RouterStatusBgpPeerStatus.
64513 64514 64515 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64513 def initialize(**args) update!(**args) end |
Instance Attribute Details
#advertised_routes ⇒ Array<Google::Apis::ComputeAlpha::Route>
Routes that were advertised to the remote BGP peer
Corresponds to the JSON property advertisedRoutes
64394 64395 64396 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64394 def advertised_routes @advertised_routes end |
#bfd_status ⇒ Google::Apis::ComputeAlpha::BfdStatus
Next free: 15
Corresponds to the JSON property bfdStatus
64399 64400 64401 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64399 def bfd_status @bfd_status end |
#enable_ipv4 ⇒ Boolean Also known as: enable_ipv4?
Output only. Enable IPv4 traffic over BGP Peer.
It is enabled by default if the peerIpAddress is version 4.
Corresponds to the JSON property enableIpv4
64405 64406 64407 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64405 def enable_ipv4 @enable_ipv4 end |
#enable_ipv6 ⇒ Boolean Also known as: enable_ipv6?
Output only. Enable IPv6 traffic over BGP Peer.
It is enabled by default if the peerIpAddress is version 6.
Corresponds to the JSON property enableIpv6
64412 64413 64414 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64412 def enable_ipv6 @enable_ipv6 end |
#ip_address ⇒ String
Output only. IP address of the local BGP interface.
Corresponds to the JSON property ipAddress
64418 64419 64420 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64418 def ip_address @ip_address end |
#ipv4_nexthop_address ⇒ String
Output only. IPv4 address of the local BGP interface.
Corresponds to the JSON property ipv4NexthopAddress
64423 64424 64425 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64423 def ipv4_nexthop_address @ipv4_nexthop_address end |
#ipv6_nexthop_address ⇒ String
Output only. IPv6 address of the local BGP interface.
Corresponds to the JSON property ipv6NexthopAddress
64428 64429 64430 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64428 def ipv6_nexthop_address @ipv6_nexthop_address end |
#linked_custom_hardware ⇒ String
Output only. The URI of the linked custom hardware resource,
CustomHardwareLinkAttachment. This CustomHardwareLinkAttachment resource
is the one that will establish the BGP session from the Cloud Router.
Corresponds to the JSON property linkedCustomHardware
64435 64436 64437 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64435 def linked_custom_hardware @linked_custom_hardware end |
#linked_vpn_tunnel ⇒ String
Output only. URL of the VPN tunnel that this BGP peer controls.
Corresponds to the JSON property linkedVpnTunnel
64440 64441 64442 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64440 def linked_vpn_tunnel @linked_vpn_tunnel end |
#md5_auth_enabled ⇒ Boolean Also known as: md5_auth_enabled?
Informs whether MD5 authentication is enabled on this BGP peer.
Corresponds to the JSON property md5AuthEnabled
64445 64446 64447 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64445 def md5_auth_enabled @md5_auth_enabled end |
#name ⇒ String
Output only. Name of this BGP peer. Unique within the Routers resource.
Corresponds to the JSON property name
64451 64452 64453 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64451 def name @name end |
#num_learned_routes ⇒ Fixnum
Output only. Number of routes learned from the remote BGP Peer.
Corresponds to the JSON property numLearnedRoutes
64456 64457 64458 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64456 def num_learned_routes @num_learned_routes end |
#peer_ip_address ⇒ String
Output only. IP address of the remote BGP interface.
Corresponds to the JSON property peerIpAddress
64461 64462 64463 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64461 def peer_ip_address @peer_ip_address end |
#peer_ipv4_nexthop_address ⇒ String
Output only. IPv4 address of the remote BGP interface.
Corresponds to the JSON property peerIpv4NexthopAddress
64466 64467 64468 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64466 def peer_ipv4_nexthop_address @peer_ipv4_nexthop_address end |
#peer_ipv6_nexthop_address ⇒ String
Output only. IPv6 address of the remote BGP interface.
Corresponds to the JSON property peerIpv6NexthopAddress
64471 64472 64473 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64471 def peer_ipv6_nexthop_address @peer_ipv6_nexthop_address end |
#router_appliance_instance ⇒ String
Output only. [Output only] URI of the VM instance that is used as third-party
router
appliances such as Next Gen Firewalls, Virtual Routers, or Router
Appliances.
The VM instance is the peer side of the BGP session.
Corresponds to the JSON property routerApplianceInstance
64480 64481 64482 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64480 def router_appliance_instance @router_appliance_instance end |
#state ⇒ String
Output only. The state of the BGP session. For a list of possible values for
this
field, seeBGP session states.
Corresponds to the JSON property state
64487 64488 64489 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64487 def state @state end |
#status ⇒ String
Output only. Status of the BGP peer: UP, DOWN
Corresponds to the JSON property status
64492 64493 64494 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64492 def status @status end |
#status_reason ⇒ String
Indicates why particular status was returned.
Corresponds to the JSON property statusReason
64497 64498 64499 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64497 def status_reason @status_reason end |
#uptime ⇒ String
Output only. Time this session has been up.
Format:
14 years, 51 weeks, 6 days, 23 hours, 59 minutes, 59 seconds
Corresponds to the JSON property uptime
64504 64505 64506 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64504 def uptime @uptime end |
#uptime_seconds ⇒ String
Output only. Time this session has been up, in seconds.
Format:
145
Corresponds to the JSON property uptimeSeconds
64511 64512 64513 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64511 def uptime_seconds @uptime_seconds end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
64518 64519 64520 64521 64522 64523 64524 64525 64526 64527 64528 64529 64530 64531 64532 64533 64534 64535 64536 64537 64538 64539 64540 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64518 def update!(**args) @advertised_routes = args[:advertised_routes] if args.key?(:advertised_routes) @bfd_status = args[:bfd_status] if args.key?(:bfd_status) @enable_ipv4 = args[:enable_ipv4] if args.key?(:enable_ipv4) @enable_ipv6 = args[:enable_ipv6] if args.key?(:enable_ipv6) @ip_address = args[:ip_address] if args.key?(:ip_address) @ipv4_nexthop_address = args[:ipv4_nexthop_address] if args.key?(:ipv4_nexthop_address) @ipv6_nexthop_address = args[:ipv6_nexthop_address] if args.key?(:ipv6_nexthop_address) @linked_custom_hardware = args[:linked_custom_hardware] if args.key?(:linked_custom_hardware) @linked_vpn_tunnel = args[:linked_vpn_tunnel] if args.key?(:linked_vpn_tunnel) @md5_auth_enabled = args[:md5_auth_enabled] if args.key?(:md5_auth_enabled) @name = args[:name] if args.key?(:name) @num_learned_routes = args[:num_learned_routes] if args.key?(:num_learned_routes) @peer_ip_address = args[:peer_ip_address] if args.key?(:peer_ip_address) @peer_ipv4_nexthop_address = args[:peer_ipv4_nexthop_address] if args.key?(:peer_ipv4_nexthop_address) @peer_ipv6_nexthop_address = args[:peer_ipv6_nexthop_address] if args.key?(:peer_ipv6_nexthop_address) @router_appliance_instance = args[:router_appliance_instance] if args.key?(:router_appliance_instance) @state = args[:state] if args.key?(:state) @status = args[:status] if args.key?(:status) @status_reason = args[:status_reason] if args.key?(:status_reason) @uptime = args[:uptime] if args.key?(:uptime) @uptime_seconds = args[:uptime_seconds] if args.key?(:uptime_seconds) end |