Class: Google::Apis::ComputeAlpha::RoutersListBgpRoutes
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::RoutersListBgpRoutes
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] The unique identifier for the resource.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#result ⇒ Array<Google::Apis::ComputeAlpha::BgpRoute>
[Output Only] A list of bgp routes.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::RoutersListBgpRoutes::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RoutersListBgpRoutes
constructor
A new instance of RoutersListBgpRoutes.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RoutersListBgpRoutes
Returns a new instance of RoutersListBgpRoutes.
67016 67017 67018 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 67016 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
66972 66973 66974 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 66972 def etag @etag end |
#id ⇒ String
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
66978 66979 66980 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 66978 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
routersListBgpRoutes for lists of bgp routes.
Corresponds to the JSON property kind
66984 66985 66986 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 66984 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
66994 66995 66996 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 66994 def next_page_token @next_page_token end |
#result ⇒ Array<Google::Apis::ComputeAlpha::BgpRoute>
[Output Only] A list of bgp routes.
Corresponds to the JSON property result
66999 67000 67001 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 66999 def result @result end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
67004 67005 67006 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 67004 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
67009 67010 67011 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 67009 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::RoutersListBgpRoutes::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
67014 67015 67016 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 67014 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
67021 67022 67023 67024 67025 67026 67027 67028 67029 67030 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 67021 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @result = args[:result] if args.key?(:result) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |