Class: Google::Apis::ComputeAlpha::RoutersListBgpRoutes

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RoutersListBgpRoutes

Returns a new instance of RoutersListBgpRoutes.



65647
65648
65649
# File 'lib/google/apis/compute_alpha/classes.rb', line 65647

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


65603
65604
65605
# File 'lib/google/apis/compute_alpha/classes.rb', line 65603

def etag
  @etag
end

#idString

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


65609
65610
65611
# File 'lib/google/apis/compute_alpha/classes.rb', line 65609

def id
  @id
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# routersListBgpRoutes for lists of bgp routes. Corresponds to the JSON property kind

Returns:

  • (String)


65615
65616
65617
# File 'lib/google/apis/compute_alpha/classes.rb', line 65615

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


65625
65626
65627
# File 'lib/google/apis/compute_alpha/classes.rb', line 65625

def next_page_token
  @next_page_token
end

#resultArray<Google::Apis::ComputeAlpha::BgpRoute>

[Output Only] A list of bgp routes. Corresponds to the JSON property result



65630
65631
65632
# File 'lib/google/apis/compute_alpha/classes.rb', line 65630

def result
  @result
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


65635
65636
65637
# File 'lib/google/apis/compute_alpha/classes.rb', line 65635

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


65640
65641
65642
# File 'lib/google/apis/compute_alpha/classes.rb', line 65640

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::RoutersListBgpRoutes::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



65645
65646
65647
# File 'lib/google/apis/compute_alpha/classes.rb', line 65645

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



65652
65653
65654
65655
65656
65657
65658
65659
65660
65661
# File 'lib/google/apis/compute_alpha/classes.rb', line 65652

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @result = args[:result] if args.key?(:result)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end