Class: Google::Apis::ComputeAlpha::RoutersListBgpRoutes
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::RoutersListBgpRoutes
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] The unique identifier for the resource.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#result ⇒ Array<Google::Apis::ComputeAlpha::BgpRoute>
[Output Only] A list of bgp routes.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::RoutersListBgpRoutes::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RoutersListBgpRoutes
constructor
A new instance of RoutersListBgpRoutes.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RoutersListBgpRoutes
Returns a new instance of RoutersListBgpRoutes.
65615 65616 65617 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 65615 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
65571 65572 65573 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 65571 def etag @etag end |
#id ⇒ String
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
65577 65578 65579 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 65577 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
routersListBgpRoutes for lists of bgp routes.
Corresponds to the JSON property kind
65583 65584 65585 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 65583 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
65593 65594 65595 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 65593 def next_page_token @next_page_token end |
#result ⇒ Array<Google::Apis::ComputeAlpha::BgpRoute>
[Output Only] A list of bgp routes.
Corresponds to the JSON property result
65598 65599 65600 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 65598 def result @result end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
65603 65604 65605 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 65603 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
65608 65609 65610 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 65608 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::RoutersListBgpRoutes::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
65613 65614 65615 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 65613 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
65620 65621 65622 65623 65624 65625 65626 65627 65628 65629 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 65620 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @result = args[:result] if args.key?(:result) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |