Class: Google::Apis::ComputeAlpha::RoutersListBgpRoutes

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RoutersListBgpRoutes

Returns a new instance of RoutersListBgpRoutes.



65017
65018
65019
# File 'lib/google/apis/compute_alpha/classes.rb', line 65017

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


64973
64974
64975
# File 'lib/google/apis/compute_alpha/classes.rb', line 64973

def etag
  @etag
end

#idString

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


64979
64980
64981
# File 'lib/google/apis/compute_alpha/classes.rb', line 64979

def id
  @id
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# routersListBgpRoutes for lists of bgp routes. Corresponds to the JSON property kind

Returns:

  • (String)


64985
64986
64987
# File 'lib/google/apis/compute_alpha/classes.rb', line 64985

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


64995
64996
64997
# File 'lib/google/apis/compute_alpha/classes.rb', line 64995

def next_page_token
  @next_page_token
end

#resultArray<Google::Apis::ComputeAlpha::BgpRoute>

[Output Only] A list of bgp routes. Corresponds to the JSON property result



65000
65001
65002
# File 'lib/google/apis/compute_alpha/classes.rb', line 65000

def result
  @result
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


65005
65006
65007
# File 'lib/google/apis/compute_alpha/classes.rb', line 65005

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


65010
65011
65012
# File 'lib/google/apis/compute_alpha/classes.rb', line 65010

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::RoutersListBgpRoutes::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



65015
65016
65017
# File 'lib/google/apis/compute_alpha/classes.rb', line 65015

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



65022
65023
65024
65025
65026
65027
65028
65029
65030
65031
# File 'lib/google/apis/compute_alpha/classes.rb', line 65022

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @result = args[:result] if args.key?(:result)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end