Class: Google::Apis::ComputeAlpha::RoutersListBgpRoutes
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::RoutersListBgpRoutes
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] The unique identifier for the resource.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#result ⇒ Array<Google::Apis::ComputeAlpha::BgpRoute>
[Output Only] A list of bgp routes.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::RoutersListBgpRoutes::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RoutersListBgpRoutes
constructor
A new instance of RoutersListBgpRoutes.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RoutersListBgpRoutes
Returns a new instance of RoutersListBgpRoutes.
65015 65016 65017 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 65015 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
64971 64972 64973 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64971 def etag @etag end |
#id ⇒ String
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
64977 64978 64979 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64977 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
routersListBgpRoutes for lists of bgp routes.
Corresponds to the JSON property kind
64983 64984 64985 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64983 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
64993 64994 64995 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64993 def next_page_token @next_page_token end |
#result ⇒ Array<Google::Apis::ComputeAlpha::BgpRoute>
[Output Only] A list of bgp routes.
Corresponds to the JSON property result
64998 64999 65000 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64998 def result @result end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
65003 65004 65005 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 65003 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
65008 65009 65010 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 65008 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::RoutersListBgpRoutes::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
65013 65014 65015 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 65013 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
65020 65021 65022 65023 65024 65025 65026 65027 65028 65029 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 65020 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @result = args[:result] if args.key?(:result) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |