Class: Google::Apis::ComputeAlpha::RoutersListBgpRoutes
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::RoutersListBgpRoutes
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] The unique identifier for the resource.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#result ⇒ Array<Google::Apis::ComputeAlpha::BgpRoute>
[Output Only] A list of bgp routes.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::RoutersListBgpRoutes::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RoutersListBgpRoutes
constructor
A new instance of RoutersListBgpRoutes.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RoutersListBgpRoutes
Returns a new instance of RoutersListBgpRoutes.
64794 64795 64796 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64794 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
64750 64751 64752 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64750 def etag @etag end |
#id ⇒ String
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
64756 64757 64758 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64756 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
routersListBgpRoutes for lists of bgp routes.
Corresponds to the JSON property kind
64762 64763 64764 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64762 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
64772 64773 64774 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64772 def next_page_token @next_page_token end |
#result ⇒ Array<Google::Apis::ComputeAlpha::BgpRoute>
[Output Only] A list of bgp routes.
Corresponds to the JSON property result
64777 64778 64779 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64777 def result @result end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
64782 64783 64784 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64782 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
64787 64788 64789 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64787 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::RoutersListBgpRoutes::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
64792 64793 64794 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64792 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
64799 64800 64801 64802 64803 64804 64805 64806 64807 64808 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64799 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @result = args[:result] if args.key?(:result) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |