Class: Google::Apis::ComputeAlpha::RoutersListBgpRoutes

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RoutersListBgpRoutes

Returns a new instance of RoutersListBgpRoutes.



63911
63912
63913
# File 'lib/google/apis/compute_alpha/classes.rb', line 63911

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


63867
63868
63869
# File 'lib/google/apis/compute_alpha/classes.rb', line 63867

def etag
  @etag
end

#idString

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


63873
63874
63875
# File 'lib/google/apis/compute_alpha/classes.rb', line 63873

def id
  @id
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# routersListBgpRoutes for lists of bgp routes. Corresponds to the JSON property kind

Returns:

  • (String)


63879
63880
63881
# File 'lib/google/apis/compute_alpha/classes.rb', line 63879

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


63889
63890
63891
# File 'lib/google/apis/compute_alpha/classes.rb', line 63889

def next_page_token
  @next_page_token
end

#resultArray<Google::Apis::ComputeAlpha::BgpRoute>

[Output Only] A list of bgp routes. Corresponds to the JSON property result



63894
63895
63896
# File 'lib/google/apis/compute_alpha/classes.rb', line 63894

def result
  @result
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


63899
63900
63901
# File 'lib/google/apis/compute_alpha/classes.rb', line 63899

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


63904
63905
63906
# File 'lib/google/apis/compute_alpha/classes.rb', line 63904

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::RoutersListBgpRoutes::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



63909
63910
63911
# File 'lib/google/apis/compute_alpha/classes.rb', line 63909

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



63916
63917
63918
63919
63920
63921
63922
63923
63924
63925
# File 'lib/google/apis/compute_alpha/classes.rb', line 63916

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @result = args[:result] if args.key?(:result)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end