Class: Google::Apis::ComputeAlpha::RoutersListNamedSets
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::RoutersListNamedSets
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] The unique identifier for the resource.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#result ⇒ Array<Google::Apis::ComputeAlpha::NamedSet>
[Output Only] A list of named sets.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::RoutersListNamedSets::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RoutersListNamedSets
constructor
A new instance of RoutersListNamedSets.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RoutersListNamedSets
Returns a new instance of RoutersListNamedSets.
67724 67725 67726 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 67724 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
67680 67681 67682 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 67680 def etag @etag end |
#id ⇒ String
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
67686 67687 67688 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 67686 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
routersListNamedSets for lists of named sets.
Corresponds to the JSON property kind
67692 67693 67694 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 67692 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
67702 67703 67704 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 67702 def next_page_token @next_page_token end |
#result ⇒ Array<Google::Apis::ComputeAlpha::NamedSet>
[Output Only] A list of named sets.
Corresponds to the JSON property result
67707 67708 67709 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 67707 def result @result end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
67712 67713 67714 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 67712 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
67717 67718 67719 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 67717 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::RoutersListNamedSets::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
67722 67723 67724 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 67722 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
67729 67730 67731 67732 67733 67734 67735 67736 67737 67738 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 67729 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @result = args[:result] if args.key?(:result) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |