Class: Google::Apis::ComputeAlpha::RoutersListNamedSets

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RoutersListNamedSets

Returns a new instance of RoutersListNamedSets.



67448
67449
67450
# File 'lib/google/apis/compute_alpha/classes.rb', line 67448

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


67404
67405
67406
# File 'lib/google/apis/compute_alpha/classes.rb', line 67404

def etag
  @etag
end

#idString

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


67410
67411
67412
# File 'lib/google/apis/compute_alpha/classes.rb', line 67410

def id
  @id
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# routersListNamedSets for lists of named sets. Corresponds to the JSON property kind

Returns:

  • (String)


67416
67417
67418
# File 'lib/google/apis/compute_alpha/classes.rb', line 67416

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


67426
67427
67428
# File 'lib/google/apis/compute_alpha/classes.rb', line 67426

def next_page_token
  @next_page_token
end

#resultArray<Google::Apis::ComputeAlpha::NamedSet>

[Output Only] A list of named sets. Corresponds to the JSON property result



67431
67432
67433
# File 'lib/google/apis/compute_alpha/classes.rb', line 67431

def result
  @result
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


67436
67437
67438
# File 'lib/google/apis/compute_alpha/classes.rb', line 67436

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


67441
67442
67443
# File 'lib/google/apis/compute_alpha/classes.rb', line 67441

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::RoutersListNamedSets::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



67446
67447
67448
# File 'lib/google/apis/compute_alpha/classes.rb', line 67446

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



67453
67454
67455
67456
67457
67458
67459
67460
67461
67462
# File 'lib/google/apis/compute_alpha/classes.rb', line 67453

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @result = args[:result] if args.key?(:result)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end