Class: Google::Apis::ComputeAlpha::RoutersListNamedSets

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RoutersListNamedSets

Returns a new instance of RoutersListNamedSets.



67154
67155
67156
# File 'lib/google/apis/compute_alpha/classes.rb', line 67154

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


67110
67111
67112
# File 'lib/google/apis/compute_alpha/classes.rb', line 67110

def etag
  @etag
end

#idString

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


67116
67117
67118
# File 'lib/google/apis/compute_alpha/classes.rb', line 67116

def id
  @id
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# routersListNamedSets for lists of named sets. Corresponds to the JSON property kind

Returns:

  • (String)


67122
67123
67124
# File 'lib/google/apis/compute_alpha/classes.rb', line 67122

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


67132
67133
67134
# File 'lib/google/apis/compute_alpha/classes.rb', line 67132

def next_page_token
  @next_page_token
end

#resultArray<Google::Apis::ComputeAlpha::NamedSet>

[Output Only] A list of named sets. Corresponds to the JSON property result



67137
67138
67139
# File 'lib/google/apis/compute_alpha/classes.rb', line 67137

def result
  @result
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


67142
67143
67144
# File 'lib/google/apis/compute_alpha/classes.rb', line 67142

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


67147
67148
67149
# File 'lib/google/apis/compute_alpha/classes.rb', line 67147

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::RoutersListNamedSets::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



67152
67153
67154
# File 'lib/google/apis/compute_alpha/classes.rb', line 67152

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



67159
67160
67161
67162
67163
67164
67165
67166
67167
67168
# File 'lib/google/apis/compute_alpha/classes.rb', line 67159

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @result = args[:result] if args.key?(:result)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end