Class: Google::Apis::ComputeAlpha::RoutersListNamedSets

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RoutersListNamedSets

Returns a new instance of RoutersListNamedSets.



65753
65754
65755
# File 'lib/google/apis/compute_alpha/classes.rb', line 65753

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


65709
65710
65711
# File 'lib/google/apis/compute_alpha/classes.rb', line 65709

def etag
  @etag
end

#idString

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


65715
65716
65717
# File 'lib/google/apis/compute_alpha/classes.rb', line 65715

def id
  @id
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# routersListNamedSets for lists of named sets. Corresponds to the JSON property kind

Returns:

  • (String)


65721
65722
65723
# File 'lib/google/apis/compute_alpha/classes.rb', line 65721

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


65731
65732
65733
# File 'lib/google/apis/compute_alpha/classes.rb', line 65731

def next_page_token
  @next_page_token
end

#resultArray<Google::Apis::ComputeAlpha::NamedSet>

[Output Only] A list of named sets. Corresponds to the JSON property result



65736
65737
65738
# File 'lib/google/apis/compute_alpha/classes.rb', line 65736

def result
  @result
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


65741
65742
65743
# File 'lib/google/apis/compute_alpha/classes.rb', line 65741

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


65746
65747
65748
# File 'lib/google/apis/compute_alpha/classes.rb', line 65746

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::RoutersListNamedSets::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



65751
65752
65753
# File 'lib/google/apis/compute_alpha/classes.rb', line 65751

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



65758
65759
65760
65761
65762
65763
65764
65765
65766
65767
# File 'lib/google/apis/compute_alpha/classes.rb', line 65758

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @result = args[:result] if args.key?(:result)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end