Class: Google::Apis::ComputeAlpha::RoutersListNamedSets

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RoutersListNamedSets

Returns a new instance of RoutersListNamedSets.



65153
65154
65155
# File 'lib/google/apis/compute_alpha/classes.rb', line 65153

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


65109
65110
65111
# File 'lib/google/apis/compute_alpha/classes.rb', line 65109

def etag
  @etag
end

#idString

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


65115
65116
65117
# File 'lib/google/apis/compute_alpha/classes.rb', line 65115

def id
  @id
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# routersListNamedSets for lists of named sets. Corresponds to the JSON property kind

Returns:

  • (String)


65121
65122
65123
# File 'lib/google/apis/compute_alpha/classes.rb', line 65121

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


65131
65132
65133
# File 'lib/google/apis/compute_alpha/classes.rb', line 65131

def next_page_token
  @next_page_token
end

#resultArray<Google::Apis::ComputeAlpha::NamedSet>

[Output Only] A list of named sets. Corresponds to the JSON property result



65136
65137
65138
# File 'lib/google/apis/compute_alpha/classes.rb', line 65136

def result
  @result
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


65141
65142
65143
# File 'lib/google/apis/compute_alpha/classes.rb', line 65141

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


65146
65147
65148
# File 'lib/google/apis/compute_alpha/classes.rb', line 65146

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::RoutersListNamedSets::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



65151
65152
65153
# File 'lib/google/apis/compute_alpha/classes.rb', line 65151

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



65158
65159
65160
65161
65162
65163
65164
65165
65166
65167
# File 'lib/google/apis/compute_alpha/classes.rb', line 65158

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @result = args[:result] if args.key?(:result)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end