Class: Google::Apis::ComputeAlpha::RoutersListNamedSets
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::RoutersListNamedSets
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] The unique identifier for the resource.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#result ⇒ Array<Google::Apis::ComputeAlpha::NamedSet>
[Output Only] A list of named sets.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::RoutersListNamedSets::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RoutersListNamedSets
constructor
A new instance of RoutersListNamedSets.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RoutersListNamedSets
Returns a new instance of RoutersListNamedSets.
64932 64933 64934 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64932 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
64888 64889 64890 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64888 def etag @etag end |
#id ⇒ String
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
64894 64895 64896 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64894 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
routersListNamedSets for lists of named sets.
Corresponds to the JSON property kind
64900 64901 64902 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64900 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
64910 64911 64912 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64910 def next_page_token @next_page_token end |
#result ⇒ Array<Google::Apis::ComputeAlpha::NamedSet>
[Output Only] A list of named sets.
Corresponds to the JSON property result
64915 64916 64917 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64915 def result @result end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
64920 64921 64922 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64920 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
64925 64926 64927 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64925 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::RoutersListNamedSets::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
64930 64931 64932 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64930 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
64937 64938 64939 64940 64941 64942 64943 64944 64945 64946 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64937 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @result = args[:result] if args.key?(:result) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |