Class: Google::Apis::ComputeAlpha::RoutersListNamedSets

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RoutersListNamedSets

Returns a new instance of RoutersListNamedSets.



64049
64050
64051
# File 'lib/google/apis/compute_alpha/classes.rb', line 64049

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


64005
64006
64007
# File 'lib/google/apis/compute_alpha/classes.rb', line 64005

def etag
  @etag
end

#idString

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


64011
64012
64013
# File 'lib/google/apis/compute_alpha/classes.rb', line 64011

def id
  @id
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# routersListNamedSets for lists of named sets. Corresponds to the JSON property kind

Returns:

  • (String)


64017
64018
64019
# File 'lib/google/apis/compute_alpha/classes.rb', line 64017

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


64027
64028
64029
# File 'lib/google/apis/compute_alpha/classes.rb', line 64027

def next_page_token
  @next_page_token
end

#resultArray<Google::Apis::ComputeAlpha::NamedSet>

[Output Only] A list of named sets. Corresponds to the JSON property result



64032
64033
64034
# File 'lib/google/apis/compute_alpha/classes.rb', line 64032

def result
  @result
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


64037
64038
64039
# File 'lib/google/apis/compute_alpha/classes.rb', line 64037

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


64042
64043
64044
# File 'lib/google/apis/compute_alpha/classes.rb', line 64042

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::RoutersListNamedSets::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



64047
64048
64049
# File 'lib/google/apis/compute_alpha/classes.rb', line 64047

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



64054
64055
64056
64057
64058
64059
64060
64061
64062
64063
# File 'lib/google/apis/compute_alpha/classes.rb', line 64054

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @result = args[:result] if args.key?(:result)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end