Class: Google::Apis::ComputeAlpha::RoutersListRoutePolicies
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::RoutersListRoutePolicies
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] The unique identifier for the resource.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#result ⇒ Array<Google::Apis::ComputeAlpha::RoutePolicy>
[Output Only] A list of route policies.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::RoutersListRoutePolicies::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RoutersListRoutePolicies
constructor
A new instance of RoutersListRoutePolicies.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RoutersListRoutePolicies
Returns a new instance of RoutersListRoutePolicies.
67586 67587 67588 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 67586 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
67542 67543 67544 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 67542 def etag @etag end |
#id ⇒ String
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
67548 67549 67550 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 67548 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
routersListRoutePolicies for lists of route policies.
Corresponds to the JSON property kind
67554 67555 67556 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 67554 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
67564 67565 67566 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 67564 def next_page_token @next_page_token end |
#result ⇒ Array<Google::Apis::ComputeAlpha::RoutePolicy>
[Output Only] A list of route policies.
Corresponds to the JSON property result
67569 67570 67571 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 67569 def result @result end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
67574 67575 67576 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 67574 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
67579 67580 67581 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 67579 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::RoutersListRoutePolicies::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
67584 67585 67586 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 67584 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
67591 67592 67593 67594 67595 67596 67597 67598 67599 67600 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 67591 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @result = args[:result] if args.key?(:result) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |