Class: Google::Apis::ComputeAlpha::RoutersListRoutePolicies

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RoutersListRoutePolicies

Returns a new instance of RoutersListRoutePolicies.



67292
67293
67294
# File 'lib/google/apis/compute_alpha/classes.rb', line 67292

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


67248
67249
67250
# File 'lib/google/apis/compute_alpha/classes.rb', line 67248

def etag
  @etag
end

#idString

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


67254
67255
67256
# File 'lib/google/apis/compute_alpha/classes.rb', line 67254

def id
  @id
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# routersListRoutePolicies for lists of route policies. Corresponds to the JSON property kind

Returns:

  • (String)


67260
67261
67262
# File 'lib/google/apis/compute_alpha/classes.rb', line 67260

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


67270
67271
67272
# File 'lib/google/apis/compute_alpha/classes.rb', line 67270

def next_page_token
  @next_page_token
end

#resultArray<Google::Apis::ComputeAlpha::RoutePolicy>

[Output Only] A list of route policies. Corresponds to the JSON property result



67275
67276
67277
# File 'lib/google/apis/compute_alpha/classes.rb', line 67275

def result
  @result
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


67280
67281
67282
# File 'lib/google/apis/compute_alpha/classes.rb', line 67280

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


67285
67286
67287
# File 'lib/google/apis/compute_alpha/classes.rb', line 67285

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::RoutersListRoutePolicies::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



67290
67291
67292
# File 'lib/google/apis/compute_alpha/classes.rb', line 67290

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



67297
67298
67299
67300
67301
67302
67303
67304
67305
67306
# File 'lib/google/apis/compute_alpha/classes.rb', line 67297

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @result = args[:result] if args.key?(:result)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end