Class: Google::Apis::ComputeAlpha::RoutersListRoutePolicies

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RoutersListRoutePolicies

Returns a new instance of RoutersListRoutePolicies.



65923
65924
65925
# File 'lib/google/apis/compute_alpha/classes.rb', line 65923

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


65879
65880
65881
# File 'lib/google/apis/compute_alpha/classes.rb', line 65879

def etag
  @etag
end

#idString

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


65885
65886
65887
# File 'lib/google/apis/compute_alpha/classes.rb', line 65885

def id
  @id
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# routersListRoutePolicies for lists of route policies. Corresponds to the JSON property kind

Returns:

  • (String)


65891
65892
65893
# File 'lib/google/apis/compute_alpha/classes.rb', line 65891

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


65901
65902
65903
# File 'lib/google/apis/compute_alpha/classes.rb', line 65901

def next_page_token
  @next_page_token
end

#resultArray<Google::Apis::ComputeAlpha::RoutePolicy>

[Output Only] A list of route policies. Corresponds to the JSON property result



65906
65907
65908
# File 'lib/google/apis/compute_alpha/classes.rb', line 65906

def result
  @result
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


65911
65912
65913
# File 'lib/google/apis/compute_alpha/classes.rb', line 65911

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


65916
65917
65918
# File 'lib/google/apis/compute_alpha/classes.rb', line 65916

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::RoutersListRoutePolicies::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



65921
65922
65923
# File 'lib/google/apis/compute_alpha/classes.rb', line 65921

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



65928
65929
65930
65931
65932
65933
65934
65935
65936
65937
# File 'lib/google/apis/compute_alpha/classes.rb', line 65928

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @result = args[:result] if args.key?(:result)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end