Class: Google::Apis::ComputeAlpha::RoutersListRoutePolicies
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::RoutersListRoutePolicies
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] The unique identifier for the resource.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#result ⇒ Array<Google::Apis::ComputeAlpha::RoutePolicy>
[Output Only] A list of route policies.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::RoutersListRoutePolicies::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RoutersListRoutePolicies
constructor
A new instance of RoutersListRoutePolicies.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RoutersListRoutePolicies
Returns a new instance of RoutersListRoutePolicies.
65891 65892 65893 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 65891 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
65847 65848 65849 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 65847 def etag @etag end |
#id ⇒ String
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
65853 65854 65855 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 65853 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
routersListRoutePolicies for lists of route policies.
Corresponds to the JSON property kind
65859 65860 65861 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 65859 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
65869 65870 65871 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 65869 def next_page_token @next_page_token end |
#result ⇒ Array<Google::Apis::ComputeAlpha::RoutePolicy>
[Output Only] A list of route policies.
Corresponds to the JSON property result
65874 65875 65876 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 65874 def result @result end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
65879 65880 65881 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 65879 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
65884 65885 65886 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 65884 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::RoutersListRoutePolicies::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
65889 65890 65891 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 65889 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
65896 65897 65898 65899 65900 65901 65902 65903 65904 65905 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 65896 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @result = args[:result] if args.key?(:result) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |