Class: Google::Apis::ComputeAlpha::RoutersListRoutePolicies

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RoutersListRoutePolicies

Returns a new instance of RoutersListRoutePolicies.



65293
65294
65295
# File 'lib/google/apis/compute_alpha/classes.rb', line 65293

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


65249
65250
65251
# File 'lib/google/apis/compute_alpha/classes.rb', line 65249

def etag
  @etag
end

#idString

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


65255
65256
65257
# File 'lib/google/apis/compute_alpha/classes.rb', line 65255

def id
  @id
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# routersListRoutePolicies for lists of route policies. Corresponds to the JSON property kind

Returns:

  • (String)


65261
65262
65263
# File 'lib/google/apis/compute_alpha/classes.rb', line 65261

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


65271
65272
65273
# File 'lib/google/apis/compute_alpha/classes.rb', line 65271

def next_page_token
  @next_page_token
end

#resultArray<Google::Apis::ComputeAlpha::RoutePolicy>

[Output Only] A list of route policies. Corresponds to the JSON property result



65276
65277
65278
# File 'lib/google/apis/compute_alpha/classes.rb', line 65276

def result
  @result
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


65281
65282
65283
# File 'lib/google/apis/compute_alpha/classes.rb', line 65281

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


65286
65287
65288
# File 'lib/google/apis/compute_alpha/classes.rb', line 65286

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::RoutersListRoutePolicies::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



65291
65292
65293
# File 'lib/google/apis/compute_alpha/classes.rb', line 65291

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



65298
65299
65300
65301
65302
65303
65304
65305
65306
65307
# File 'lib/google/apis/compute_alpha/classes.rb', line 65298

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @result = args[:result] if args.key?(:result)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end