Class: Google::Apis::ComputeAlpha::RoutersListRoutePolicies

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RoutersListRoutePolicies

Returns a new instance of RoutersListRoutePolicies.



65291
65292
65293
# File 'lib/google/apis/compute_alpha/classes.rb', line 65291

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


65247
65248
65249
# File 'lib/google/apis/compute_alpha/classes.rb', line 65247

def etag
  @etag
end

#idString

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


65253
65254
65255
# File 'lib/google/apis/compute_alpha/classes.rb', line 65253

def id
  @id
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# routersListRoutePolicies for lists of route policies. Corresponds to the JSON property kind

Returns:

  • (String)


65259
65260
65261
# File 'lib/google/apis/compute_alpha/classes.rb', line 65259

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


65269
65270
65271
# File 'lib/google/apis/compute_alpha/classes.rb', line 65269

def next_page_token
  @next_page_token
end

#resultArray<Google::Apis::ComputeAlpha::RoutePolicy>

[Output Only] A list of route policies. Corresponds to the JSON property result



65274
65275
65276
# File 'lib/google/apis/compute_alpha/classes.rb', line 65274

def result
  @result
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


65279
65280
65281
# File 'lib/google/apis/compute_alpha/classes.rb', line 65279

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


65284
65285
65286
# File 'lib/google/apis/compute_alpha/classes.rb', line 65284

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::RoutersListRoutePolicies::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



65289
65290
65291
# File 'lib/google/apis/compute_alpha/classes.rb', line 65289

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



65296
65297
65298
65299
65300
65301
65302
65303
65304
65305
# File 'lib/google/apis/compute_alpha/classes.rb', line 65296

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @result = args[:result] if args.key?(:result)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end