Class: Google::Apis::ComputeAlpha::SavedAttachedDisk
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::SavedAttachedDisk
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
DEPRECATED: Please use compute#savedDisk instead. An instance-attached disk resource.
Instance Attribute Summary collapse
-
#auto_delete ⇒ Boolean
(also: #auto_delete?)
Specifies whether the disk will be auto-deleted when the instance is deleted (but not when the disk is detached from the instance).
-
#boot ⇒ Boolean
(also: #boot?)
Indicates that this is a boot disk.
-
#device_name ⇒ String
Specifies the name of the disk attached to the source instance.
-
#disk_encryption_key ⇒ Google::Apis::ComputeAlpha::CustomerEncryptionKey
The encryption key for the disk.
-
#disk_size_gb ⇒ Fixnum
The size of the disk in base-2 GB.
-
#disk_type ⇒ String
Output only.
-
#guest_os_features ⇒ Array<Google::Apis::ComputeAlpha::GuestOsFeature>
A list of features to enable on the guest operating system.
-
#index ⇒ Fixnum
Output only.
-
#interface ⇒ String
Specifies the disk interface to use for attaching this disk, which is either SCSI or NVME.
-
#kind ⇒ String
Output only.
-
#licenses ⇒ Array<String>
Output only.
-
#mode ⇒ String
The mode in which this disk is attached to the source instance, eitherREAD_WRITE or READ_ONLY.
-
#source ⇒ String
Specifies a URL of the disk attached to the source instance.
-
#storage_bytes ⇒ Fixnum
Output only.
-
#storage_bytes_status ⇒ String
Output only.
-
#type ⇒ String
Specifies the type of the attached disk, either SCRATCH orPERSISTENT.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SavedAttachedDisk
constructor
A new instance of SavedAttachedDisk.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SavedAttachedDisk
Returns a new instance of SavedAttachedDisk.
64578 64579 64580 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64578 def initialize(**args) update!(**args) end |
Instance Attribute Details
#auto_delete ⇒ Boolean Also known as: auto_delete?
Specifies whether the disk will be auto-deleted when the instance is
deleted (but not when the disk is detached from the instance).
Corresponds to the JSON property autoDelete
64482 64483 64484 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64482 def auto_delete @auto_delete end |
#boot ⇒ Boolean Also known as: boot?
Indicates that this is a boot disk. The virtual machine will use the first
partition of the disk for its root filesystem.
Corresponds to the JSON property boot
64489 64490 64491 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64489 def boot @boot end |
#device_name ⇒ String
Specifies the name of the disk attached to the source instance.
Corresponds to the JSON property deviceName
64495 64496 64497 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64495 def device_name @device_name end |
#disk_encryption_key ⇒ Google::Apis::ComputeAlpha::CustomerEncryptionKey
The encryption key for the disk.
Corresponds to the JSON property diskEncryptionKey
64500 64501 64502 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64500 def disk_encryption_key @disk_encryption_key end |
#disk_size_gb ⇒ Fixnum
The size of the disk in base-2 GB.
Corresponds to the JSON property diskSizeGb
64505 64506 64507 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64505 def disk_size_gb @disk_size_gb end |
#disk_type ⇒ String
Output only. [Output Only] URL of the disk type resource. For example:projects/
project/zones/zone/diskTypes/pd-standard or
pd-ssd
Corresponds to the JSON property diskType
64512 64513 64514 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64512 def disk_type @disk_type end |
#guest_os_features ⇒ Array<Google::Apis::ComputeAlpha::GuestOsFeature>
A list of features to enable on the guest operating system. Applicable only
for bootable images. Read
Enabling guest operating system features to see a list of available
options.
Corresponds to the JSON property guestOsFeatures
64520 64521 64522 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64520 def guest_os_features @guest_os_features end |
#index ⇒ Fixnum
Output only. Specifies zero-based index of the disk that is attached to the
source
instance.
Corresponds to the JSON property index
64527 64528 64529 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64527 def index @index end |
#interface ⇒ String
Specifies the disk interface to use for attaching this disk, which is
either SCSI or NVME.
Corresponds to the JSON property interface
64533 64534 64535 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64533 def interface @interface end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#attachedDisk
for attached disks.
Corresponds to the JSON property kind
64539 64540 64541 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64539 def kind @kind end |
#licenses ⇒ Array<String>
Output only. [Output Only] Any valid publicly visible licenses.
Corresponds to the JSON property licenses
64544 64545 64546 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64544 def licenses @licenses end |
#mode ⇒ String
The mode in which this disk is attached to the source instance,
eitherREAD_WRITE or READ_ONLY.
Corresponds to the JSON property mode
64550 64551 64552 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64550 def mode @mode end |
#source ⇒ String
Specifies a URL of the disk attached to the source instance.
Corresponds to the JSON property source
64555 64556 64557 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64555 def source @source end |
#storage_bytes ⇒ Fixnum
Output only. [Output Only] A size of the storage used by the disk's snapshot
by this
machine image.
Corresponds to the JSON property storageBytes
64562 64563 64564 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64562 def storage_bytes @storage_bytes end |
#storage_bytes_status ⇒ String
Output only. [Output Only] An indicator whether storageBytes is in a
stable state or it is being adjusted as a result of shared storage
reallocation. This status can either be UPDATING, meaning
the size of the snapshot is being updated, or UP_TO_DATE,
meaning the size of the snapshot is up-to-date.
Corresponds to the JSON property storageBytesStatus
64571 64572 64573 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64571 def storage_bytes_status @storage_bytes_status end |
#type ⇒ String
Specifies the type of the attached disk, either SCRATCH orPERSISTENT.
Corresponds to the JSON property type
64576 64577 64578 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64576 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
64583 64584 64585 64586 64587 64588 64589 64590 64591 64592 64593 64594 64595 64596 64597 64598 64599 64600 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64583 def update!(**args) @auto_delete = args[:auto_delete] if args.key?(:auto_delete) @boot = args[:boot] if args.key?(:boot) @device_name = args[:device_name] if args.key?(:device_name) @disk_encryption_key = args[:disk_encryption_key] if args.key?(:disk_encryption_key) @disk_size_gb = args[:disk_size_gb] if args.key?(:disk_size_gb) @disk_type = args[:disk_type] if args.key?(:disk_type) @guest_os_features = args[:guest_os_features] if args.key?(:guest_os_features) @index = args[:index] if args.key?(:index) @interface = args[:interface] if args.key?(:interface) @kind = args[:kind] if args.key?(:kind) @licenses = args[:licenses] if args.key?(:licenses) @mode = args[:mode] if args.key?(:mode) @source = args[:source] if args.key?(:source) @storage_bytes = args[:storage_bytes] if args.key?(:storage_bytes) @storage_bytes_status = args[:storage_bytes_status] if args.key?(:storage_bytes_status) @type = args[:type] if args.key?(:type) end |