Class: Google::Apis::ComputeAlpha::SavedDisk
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::SavedDisk
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
An instance-attached disk resource.
Instance Attribute Summary collapse
-
#architecture ⇒ String
Output only.
-
#kind ⇒ String
Output only.
-
#source_disk ⇒ String
Output only.
-
#storage_bytes ⇒ Fixnum
Output only.
-
#storage_bytes_status ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SavedDisk
constructor
A new instance of SavedDisk.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SavedDisk
Returns a new instance of SavedDisk.
66343 66344 66345 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 66343 def initialize(**args) update!(**args) end |
Instance Attribute Details
#architecture ⇒ String
Output only. [Output Only] The architecture of the attached disk.
Corresponds to the JSON property architecture
66314 66315 66316 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 66314 def architecture @architecture end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Always compute#savedDisk
for attached disks.
Corresponds to the JSON property kind
66320 66321 66322 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 66320 def kind @kind end |
#source_disk ⇒ String
Output only. Specifies a URL of the disk attached to the source instance.
Corresponds to the JSON property sourceDisk
66325 66326 66327 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 66325 def source_disk @source_disk end |
#storage_bytes ⇒ Fixnum
Output only. [Output Only] Size of the individual disk snapshot used by this
machine
image.
Corresponds to the JSON property storageBytes
66332 66333 66334 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 66332 def storage_bytes @storage_bytes end |
#storage_bytes_status ⇒ String
Output only. [Output Only] An indicator whether storageBytes is in a
stable state or it is being adjusted as a result of shared storage
reallocation. This status can either be UPDATING, meaning
the size of the snapshot is being updated, or UP_TO_DATE,
meaning the size of the snapshot is up-to-date.
Corresponds to the JSON property storageBytesStatus
66341 66342 66343 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 66341 def storage_bytes_status @storage_bytes_status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
66348 66349 66350 66351 66352 66353 66354 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 66348 def update!(**args) @architecture = args[:architecture] if args.key?(:architecture) @kind = args[:kind] if args.key?(:kind) @source_disk = args[:source_disk] if args.key?(:source_disk) @storage_bytes = args[:storage_bytes] if args.key?(:storage_bytes) @storage_bytes_status = args[:storage_bytes_status] if args.key?(:storage_bytes_status) end |