Class: Google::Apis::ComputeAlpha::SavedDisk

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

An instance-attached disk resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SavedDisk

Returns a new instance of SavedDisk.



65745
65746
65747
# File 'lib/google/apis/compute_alpha/classes.rb', line 65745

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#architectureString

Output only. [Output Only] The architecture of the attached disk. Corresponds to the JSON property architecture

Returns:

  • (String)


65716
65717
65718
# File 'lib/google/apis/compute_alpha/classes.rb', line 65716

def architecture
  @architecture
end

#kindString

Output only. [Output Only] Type of the resource. Always compute#savedDisk for attached disks. Corresponds to the JSON property kind

Returns:

  • (String)


65722
65723
65724
# File 'lib/google/apis/compute_alpha/classes.rb', line 65722

def kind
  @kind
end

#source_diskString

Output only. Specifies a URL of the disk attached to the source instance. Corresponds to the JSON property sourceDisk

Returns:

  • (String)


65727
65728
65729
# File 'lib/google/apis/compute_alpha/classes.rb', line 65727

def source_disk
  @source_disk
end

#storage_bytesFixnum

Output only. [Output Only] Size of the individual disk snapshot used by this machine image. Corresponds to the JSON property storageBytes

Returns:

  • (Fixnum)


65734
65735
65736
# File 'lib/google/apis/compute_alpha/classes.rb', line 65734

def storage_bytes
  @storage_bytes
end

#storage_bytes_statusString

Output only. [Output Only] An indicator whether storageBytes is in a stable state or it is being adjusted as a result of shared storage reallocation. This status can either be UPDATING, meaning the size of the snapshot is being updated, or UP_TO_DATE, meaning the size of the snapshot is up-to-date. Corresponds to the JSON property storageBytesStatus

Returns:

  • (String)


65743
65744
65745
# File 'lib/google/apis/compute_alpha/classes.rb', line 65743

def storage_bytes_status
  @storage_bytes_status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



65750
65751
65752
65753
65754
65755
65756
# File 'lib/google/apis/compute_alpha/classes.rb', line 65750

def update!(**args)
  @architecture = args[:architecture] if args.key?(:architecture)
  @kind = args[:kind] if args.key?(:kind)
  @source_disk = args[:source_disk] if args.key?(:source_disk)
  @storage_bytes = args[:storage_bytes] if args.key?(:storage_bytes)
  @storage_bytes_status = args[:storage_bytes_status] if args.key?(:storage_bytes_status)
end