Class: Google::Apis::ComputeAlpha::Scheduling

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Sets the scheduling options for an Instance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Scheduling

Returns a new instance of Scheduling.



68278
68279
68280
# File 'lib/google/apis/compute_alpha/classes.rb', line 68278

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#automatic_restartBoolean Also known as: automatic_restart?

Specifies whether the instance should be automatically restarted if it is terminated by Compute Engine (not terminated by a user). You can only set the automatic restart option for standard instances.Preemptible instances cannot be automatically restarted. By default, this is set to true so an instance is automatically restarted if it is terminated by Compute Engine. Corresponds to the JSON property automaticRestart

Returns:

  • (Boolean)


68103
68104
68105
# File 'lib/google/apis/compute_alpha/classes.rb', line 68103

def automatic_restart
  @automatic_restart
end

#availability_domainFixnum

Specifies the availability domain to place the instance in. The value must be a number between 1 and the number of availability domains specified in the spread placement policy attached to the instance. Corresponds to the JSON property availabilityDomain

Returns:

  • (Fixnum)


68111
68112
68113
# File 'lib/google/apis/compute_alpha/classes.rb', line 68111

def availability_domain
  @availability_domain
end

#current_cpusFixnum

Current number of vCPUs available for VM. 0 or unset means default vCPUs of the current machine type. Corresponds to the JSON property currentCpus

Returns:

  • (Fixnum)


68117
68118
68119
# File 'lib/google/apis/compute_alpha/classes.rb', line 68117

def current_cpus
  @current_cpus
end

#current_memory_mbFixnum

Current amount of memory (in MB) available for VM. 0 or unset means default amount of memory of the current machine type. Corresponds to the JSON property currentMemoryMb

Returns:

  • (Fixnum)


68123
68124
68125
# File 'lib/google/apis/compute_alpha/classes.rb', line 68123

def current_memory_mb
  @current_memory_mb
end

#expose_host_topologyBoolean Also known as: expose_host_topology?

This optional flag exposes the hashed physical host ID in the ResourceStatus resource of the VM. Corresponds to the JSON property exposeHostTopology

Returns:

  • (Boolean)


68129
68130
68131
# File 'lib/google/apis/compute_alpha/classes.rb', line 68129

def expose_host_topology
  @expose_host_topology
end

#graceful_shutdownGoogle::Apis::ComputeAlpha::SchedulingGracefulShutdown

The configuration for gracefully shutting down the instance. Corresponds to the JSON property gracefulShutdown



68135
68136
68137
# File 'lib/google/apis/compute_alpha/classes.rb', line 68135

def graceful_shutdown
  @graceful_shutdown
end

#host_error_timeout_secondsFixnum

Specify the time in seconds for host error detection, the value must be within the range of [90, 330] with the increment of 30, if unset, the default behavior of host error recovery will be used. Corresponds to the JSON property hostErrorTimeoutSeconds

Returns:

  • (Fixnum)


68142
68143
68144
# File 'lib/google/apis/compute_alpha/classes.rb', line 68142

def host_error_timeout_seconds
  @host_error_timeout_seconds
end

#instance_termination_actionString

Specifies the termination action for the instance. Corresponds to the JSON property instanceTerminationAction

Returns:

  • (String)


68147
68148
68149
# File 'lib/google/apis/compute_alpha/classes.rb', line 68147

def instance_termination_action
  @instance_termination_action
end

#latency_tolerantBoolean Also known as: latency_tolerant?

Defines whether the instance is tolerant of higher cpu latency. This can only be set during instance creation, or when the instance is not currently running. It must not be set if thepreemptible option is also set. Corresponds to the JSON property latencyTolerant

Returns:

  • (Boolean)


68155
68156
68157
# File 'lib/google/apis/compute_alpha/classes.rb', line 68155

def latency_tolerant
  @latency_tolerant
end

#local_ssd_recovery_timeoutGoogle::Apis::ComputeAlpha::Duration

A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution. It is independent of any calendar and concepts like "day" or "month". Range is approximately 10,000 years. Corresponds to the JSON property localSsdRecoveryTimeout



68164
68165
68166
# File 'lib/google/apis/compute_alpha/classes.rb', line 68164

def local_ssd_recovery_timeout
  @local_ssd_recovery_timeout
end

#location_hintString

An opaque location hint used to place the instance close to other resources. This field is for use by internal tools that use the public API. Corresponds to the JSON property locationHint

Returns:

  • (String)


68171
68172
68173
# File 'lib/google/apis/compute_alpha/classes.rb', line 68171

def location_hint
  @location_hint
end

#maintenance_freeze_duration_hoursFixnum

Specifies the number of hours after VM instance creation where the VM won't be scheduled for maintenance. Corresponds to the JSON property maintenanceFreezeDurationHours

Returns:

  • (Fixnum)


68177
68178
68179
# File 'lib/google/apis/compute_alpha/classes.rb', line 68177

def maintenance_freeze_duration_hours
  @maintenance_freeze_duration_hours
end

#maintenance_intervalString

Specifies the frequency of planned maintenance events. The accepted values are: PERIODIC. Corresponds to the JSON property maintenanceInterval

Returns:

  • (String)


68183
68184
68185
# File 'lib/google/apis/compute_alpha/classes.rb', line 68183

def maintenance_interval
  @maintenance_interval
end

#max_run_durationGoogle::Apis::ComputeAlpha::Duration

A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution. It is independent of any calendar and concepts like "day" or "month". Range is approximately 10,000 years. Corresponds to the JSON property maxRunDuration



68191
68192
68193
# File 'lib/google/apis/compute_alpha/classes.rb', line 68191

def max_run_duration
  @max_run_duration
end

#min_node_cpusFixnum

The minimum number of virtual CPUs this instance will consume when running on a sole-tenant node. Corresponds to the JSON property minNodeCpus

Returns:

  • (Fixnum)


68197
68198
68199
# File 'lib/google/apis/compute_alpha/classes.rb', line 68197

def min_node_cpus
  @min_node_cpus
end

#node_affinitiesArray<Google::Apis::ComputeAlpha::SchedulingNodeAffinity>

A set of node affinity and anti-affinity configurations. Refer toConfiguring node affinity for more information. Overrides reservationAffinity. Corresponds to the JSON property nodeAffinities



68205
68206
68207
# File 'lib/google/apis/compute_alpha/classes.rb', line 68205

def node_affinities
  @node_affinities
end

#on_host_maintenanceString

Defines the maintenance behavior for this instance. For standard instances, the default behavior is MIGRATE. Forpreemptible instances, the default and only possible behavior is TERMINATE. For more information, see Set VM host maintenance policy. Corresponds to the JSON property onHostMaintenance

Returns:

  • (String)


68215
68216
68217
# File 'lib/google/apis/compute_alpha/classes.rb', line 68215

def on_host_maintenance
  @on_host_maintenance
end

#on_instance_stop_actionGoogle::Apis::ComputeAlpha::SchedulingOnInstanceStopAction

Defines the behaviour for instances with the instance_termination_actionSTOP. Corresponds to the JSON property onInstanceStopAction



68220
68221
68222
# File 'lib/google/apis/compute_alpha/classes.rb', line 68220

def on_instance_stop_action
  @on_instance_stop_action
end

#preemptibleBoolean Also known as: preemptible?

Defines whether the instance is preemptible. This can only be set during instance creation or while the instance isstopped and therefore, in a TERMINATED state. SeeInstance Life Cycle for more information on the possible instance states. Corresponds to the JSON property preemptible

Returns:

  • (Boolean)


68228
68229
68230
# File 'lib/google/apis/compute_alpha/classes.rb', line 68228

def preemptible
  @preemptible
end

#preemption_notice_durationGoogle::Apis::ComputeAlpha::Duration

A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution. It is independent of any calendar and concepts like "day" or "month". Range is approximately 10,000 years. Corresponds to the JSON property preemptionNoticeDuration



68237
68238
68239
# File 'lib/google/apis/compute_alpha/classes.rb', line 68237

def preemption_notice_duration
  @preemption_notice_duration
end

#provisioning_modelString

Specifies the provisioning model of the instance. Corresponds to the JSON property provisioningModel

Returns:

  • (String)


68242
68243
68244
# File 'lib/google/apis/compute_alpha/classes.rb', line 68242

def provisioning_model
  @provisioning_model
end

#shutdown_timeoutGoogle::Apis::ComputeAlpha::Duration

A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution. It is independent of any calendar and concepts like "day" or "month". Range is approximately 10,000 years. Corresponds to the JSON property shutdownTimeout



68250
68251
68252
# File 'lib/google/apis/compute_alpha/classes.rb', line 68250

def shutdown_timeout
  @shutdown_timeout
end

#skip_guest_os_shutdownBoolean Also known as: skip_guest_os_shutdown?

Default is false and there will be 120 seconds between GCE ACPI G2 Soft Off and ACPI G3 Mechanical Off for Standard VMs and 30 seconds for Spot VMs. Corresponds to the JSON property skipGuestOsShutdown

Returns:

  • (Boolean)


68257
68258
68259
# File 'lib/google/apis/compute_alpha/classes.rb', line 68257

def skip_guest_os_shutdown
  @skip_guest_os_shutdown
end

#termination_timeString

Specifies the timestamp, when the instance will be terminated, inRFC3339 text format. If specified, the instance termination action will be performed at the termination time. Corresponds to the JSON property terminationTime

Returns:

  • (String)


68265
68266
68267
# File 'lib/google/apis/compute_alpha/classes.rb', line 68265

def termination_time
  @termination_time
end

#vsock_modeGoogle::Apis::ComputeAlpha::SchedulingVsockMode

Message to control the enablement of the vsock device. Corresponds to the JSON property vsockMode



68270
68271
68272
# File 'lib/google/apis/compute_alpha/classes.rb', line 68270

def vsock_mode
  @vsock_mode
end

#windows_license_optimization_modeString

Represents the Windows Server License Optimization Mode of the VM. If unspecified, the default mode is OFF. Corresponds to the JSON property windowsLicenseOptimizationMode

Returns:

  • (String)


68276
68277
68278
# File 'lib/google/apis/compute_alpha/classes.rb', line 68276

def windows_license_optimization_mode
  @windows_license_optimization_mode
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



68283
68284
68285
68286
68287
68288
68289
68290
68291
68292
68293
68294
68295
68296
68297
68298
68299
68300
68301
68302
68303
68304
68305
68306
68307
68308
68309
68310
# File 'lib/google/apis/compute_alpha/classes.rb', line 68283

def update!(**args)
  @automatic_restart = args[:automatic_restart] if args.key?(:automatic_restart)
  @availability_domain = args[:availability_domain] if args.key?(:availability_domain)
  @current_cpus = args[:current_cpus] if args.key?(:current_cpus)
  @current_memory_mb = args[:current_memory_mb] if args.key?(:current_memory_mb)
  @expose_host_topology = args[:expose_host_topology] if args.key?(:expose_host_topology)
  @graceful_shutdown = args[:graceful_shutdown] if args.key?(:graceful_shutdown)
  @host_error_timeout_seconds = args[:host_error_timeout_seconds] if args.key?(:host_error_timeout_seconds)
  @instance_termination_action = args[:instance_termination_action] if args.key?(:instance_termination_action)
  @latency_tolerant = args[:latency_tolerant] if args.key?(:latency_tolerant)
  @local_ssd_recovery_timeout = args[:local_ssd_recovery_timeout] if args.key?(:local_ssd_recovery_timeout)
  @location_hint = args[:location_hint] if args.key?(:location_hint)
  @maintenance_freeze_duration_hours = args[:maintenance_freeze_duration_hours] if args.key?(:maintenance_freeze_duration_hours)
  @maintenance_interval = args[:maintenance_interval] if args.key?(:maintenance_interval)
  @max_run_duration = args[:max_run_duration] if args.key?(:max_run_duration)
  @min_node_cpus = args[:min_node_cpus] if args.key?(:min_node_cpus)
  @node_affinities = args[:node_affinities] if args.key?(:node_affinities)
  @on_host_maintenance = args[:on_host_maintenance] if args.key?(:on_host_maintenance)
  @on_instance_stop_action = args[:on_instance_stop_action] if args.key?(:on_instance_stop_action)
  @preemptible = args[:preemptible] if args.key?(:preemptible)
  @preemption_notice_duration = args[:preemption_notice_duration] if args.key?(:preemption_notice_duration)
  @provisioning_model = args[:provisioning_model] if args.key?(:provisioning_model)
  @shutdown_timeout = args[:shutdown_timeout] if args.key?(:shutdown_timeout)
  @skip_guest_os_shutdown = args[:skip_guest_os_shutdown] if args.key?(:skip_guest_os_shutdown)
  @termination_time = args[:termination_time] if args.key?(:termination_time)
  @vsock_mode = args[:vsock_mode] if args.key?(:vsock_mode)
  @windows_license_optimization_mode = args[:windows_license_optimization_mode] if args.key?(:windows_license_optimization_mode)
end