Class: Google::Apis::ComputeAlpha::Scheduling
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::Scheduling
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Sets the scheduling options for an Instance.
Instance Attribute Summary collapse
-
#automatic_restart ⇒ Boolean
(also: #automatic_restart?)
Specifies whether the instance should be automatically restarted if it is terminated by Compute Engine (not terminated by a user).
-
#availability_domain ⇒ Fixnum
Specifies the availability domain to place the instance in.
-
#current_cpus ⇒ Fixnum
Current number of vCPUs available for VM.
-
#current_memory_mb ⇒ Fixnum
Current amount of memory (in MB) available for VM.
-
#graceful_shutdown ⇒ Google::Apis::ComputeAlpha::SchedulingGracefulShutdown
The configuration for gracefully shutting down the instance.
-
#host_error_timeout_seconds ⇒ Fixnum
Specify the time in seconds for host error detection, the value must be within the range of [90, 330] with the increment of 30, if unset, the default behavior of host error recovery will be used.
-
#instance_termination_action ⇒ String
Specifies the termination action for the instance.
-
#latency_tolerant ⇒ Boolean
(also: #latency_tolerant?)
Defines whether the instance is tolerant of higher cpu latency.
-
#local_ssd_recovery_timeout ⇒ Google::Apis::ComputeAlpha::Duration
A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution.
-
#location_hint ⇒ String
An opaque location hint used to place the instance close to other resources.
-
#maintenance_freeze_duration_hours ⇒ Fixnum
Specifies the number of hours after VM instance creation where the VM won't be scheduled for maintenance.
-
#maintenance_interval ⇒ String
Specifies the frequency of planned maintenance events.
-
#max_run_duration ⇒ Google::Apis::ComputeAlpha::Duration
A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution.
-
#min_node_cpus ⇒ Fixnum
The minimum number of virtual CPUs this instance will consume when running on a sole-tenant node.
-
#node_affinities ⇒ Array<Google::Apis::ComputeAlpha::SchedulingNodeAffinity>
A set of node affinity and anti-affinity configurations.
-
#on_host_maintenance ⇒ String
Defines the maintenance behavior for this instance.
-
#on_instance_stop_action ⇒ Google::Apis::ComputeAlpha::SchedulingOnInstanceStopAction
Defines the behaviour for instances with the instance_termination_actionSTOP.
-
#preemptible ⇒ Boolean
(also: #preemptible?)
Defines whether the instance is preemptible.
-
#preemption_notice_duration ⇒ Google::Apis::ComputeAlpha::Duration
A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution.
-
#provisioning_model ⇒ String
Specifies the provisioning model of the instance.
-
#shutdown_timeout ⇒ Google::Apis::ComputeAlpha::Duration
A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution.
-
#skip_guest_os_shutdown ⇒ Boolean
(also: #skip_guest_os_shutdown?)
Default is false and there will be 120 seconds between GCE ACPI G2 Soft Off and ACPI G3 Mechanical Off for Standard VMs and 30 seconds for Spot VMs.
-
#termination_time ⇒ String
Specifies the timestamp, when the instance will be terminated, inRFC3339 text format.
-
#windows_license_optimization_mode ⇒ String
Represents the Windows Server License Optimization Mode of the VM.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Scheduling
constructor
A new instance of Scheduling.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Scheduling
Returns a new instance of Scheduling.
65973 65974 65975 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 65973 def initialize(**args) update!(**args) end |
Instance Attribute Details
#automatic_restart ⇒ Boolean Also known as: automatic_restart?
Specifies whether the instance should be automatically restarted if it is
terminated by Compute Engine (not terminated by a user). You can only set
the automatic restart option for standard instances.Preemptible instances
cannot be automatically restarted.
By default, this is set to true so an instance is
automatically restarted if it is terminated by Compute Engine.
Corresponds to the JSON property automaticRestart
65810 65811 65812 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 65810 def automatic_restart @automatic_restart end |
#availability_domain ⇒ Fixnum
Specifies the availability domain to place the instance in. The value
must be a number between 1 and the number of availability domains
specified in the spread placement policy attached to the instance.
Corresponds to the JSON property availabilityDomain
65818 65819 65820 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 65818 def availability_domain @availability_domain end |
#current_cpus ⇒ Fixnum
Current number of vCPUs available for VM.
0 or unset means default vCPUs of the current machine type.
Corresponds to the JSON property currentCpus
65824 65825 65826 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 65824 def current_cpus @current_cpus end |
#current_memory_mb ⇒ Fixnum
Current amount of memory (in MB) available for VM.
0 or unset means default amount of memory of the current machine type.
Corresponds to the JSON property currentMemoryMb
65830 65831 65832 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 65830 def current_memory_mb @current_memory_mb end |
#graceful_shutdown ⇒ Google::Apis::ComputeAlpha::SchedulingGracefulShutdown
The configuration for gracefully shutting down the instance.
Corresponds to the JSON property gracefulShutdown
65835 65836 65837 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 65835 def graceful_shutdown @graceful_shutdown end |
#host_error_timeout_seconds ⇒ Fixnum
Specify the time in seconds for host error detection, the value must be
within the range of [90, 330] with the increment of 30, if unset, the
default behavior of host error recovery will be used.
Corresponds to the JSON property hostErrorTimeoutSeconds
65842 65843 65844 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 65842 def host_error_timeout_seconds @host_error_timeout_seconds end |
#instance_termination_action ⇒ String
Specifies the termination action for the instance.
Corresponds to the JSON property instanceTerminationAction
65847 65848 65849 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 65847 def instance_termination_action @instance_termination_action end |
#latency_tolerant ⇒ Boolean Also known as: latency_tolerant?
Defines whether the instance is tolerant of higher cpu latency. This can
only be set during instance creation, or when the instance is not currently
running. It must not be set if thepreemptible option is
also set.
Corresponds to the JSON property latencyTolerant
65855 65856 65857 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 65855 def latency_tolerant @latency_tolerant end |
#local_ssd_recovery_timeout ⇒ Google::Apis::ComputeAlpha::Duration
A Duration represents a fixed-length span of time represented
as a count of seconds and fractions of seconds at nanosecond
resolution. It is independent of any calendar and concepts like "day"
or "month". Range is approximately 10,000 years.
Corresponds to the JSON property localSsdRecoveryTimeout
65864 65865 65866 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 65864 def local_ssd_recovery_timeout @local_ssd_recovery_timeout end |
#location_hint ⇒ String
An opaque location hint used to place the instance close to other
resources.
This field is for use by internal tools that use the public API.
Corresponds to the JSON property locationHint
65871 65872 65873 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 65871 def location_hint @location_hint end |
#maintenance_freeze_duration_hours ⇒ Fixnum
Specifies the number of hours after VM instance creation where the VM won't
be scheduled for maintenance.
Corresponds to the JSON property maintenanceFreezeDurationHours
65877 65878 65879 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 65877 def maintenance_freeze_duration_hours @maintenance_freeze_duration_hours end |
#maintenance_interval ⇒ String
Specifies the frequency of planned maintenance events. The accepted values
are: PERIODIC.
Corresponds to the JSON property maintenanceInterval
65883 65884 65885 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 65883 def maintenance_interval @maintenance_interval end |
#max_run_duration ⇒ Google::Apis::ComputeAlpha::Duration
A Duration represents a fixed-length span of time represented
as a count of seconds and fractions of seconds at nanosecond
resolution. It is independent of any calendar and concepts like "day"
or "month". Range is approximately 10,000 years.
Corresponds to the JSON property maxRunDuration
65891 65892 65893 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 65891 def max_run_duration @max_run_duration end |
#min_node_cpus ⇒ Fixnum
The minimum number of virtual CPUs this instance will consume when running
on a sole-tenant node.
Corresponds to the JSON property minNodeCpus
65897 65898 65899 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 65897 def min_node_cpus @min_node_cpus end |
#node_affinities ⇒ Array<Google::Apis::ComputeAlpha::SchedulingNodeAffinity>
A set of node affinity and anti-affinity configurations. Refer toConfiguring
node
affinity for more information.
Overrides reservationAffinity.
Corresponds to the JSON property nodeAffinities
65905 65906 65907 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 65905 def node_affinities @node_affinities end |
#on_host_maintenance ⇒ String
Defines the maintenance behavior for this instance. For standard instances,
the default behavior is MIGRATE. Forpreemptible instances,
the default and only possible behavior is TERMINATE. For more
information, see
Set
VM host maintenance policy.
Corresponds to the JSON property onHostMaintenance
65915 65916 65917 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 65915 def on_host_maintenance @on_host_maintenance end |
#on_instance_stop_action ⇒ Google::Apis::ComputeAlpha::SchedulingOnInstanceStopAction
Defines the behaviour for instances with the instance_termination_actionSTOP.
Corresponds to the JSON property onInstanceStopAction
65920 65921 65922 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 65920 def on_instance_stop_action @on_instance_stop_action end |
#preemptible ⇒ Boolean Also known as: preemptible?
Defines whether the instance is preemptible. This can only be set during
instance creation or while the instance isstopped and
therefore, in a TERMINATED state. SeeInstance Life
Cycle for more information on the possible instance states.
Corresponds to the JSON property preemptible
65928 65929 65930 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 65928 def preemptible @preemptible end |
#preemption_notice_duration ⇒ Google::Apis::ComputeAlpha::Duration
A Duration represents a fixed-length span of time represented
as a count of seconds and fractions of seconds at nanosecond
resolution. It is independent of any calendar and concepts like "day"
or "month". Range is approximately 10,000 years.
Corresponds to the JSON property preemptionNoticeDuration
65937 65938 65939 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 65937 def preemption_notice_duration @preemption_notice_duration end |
#provisioning_model ⇒ String
Specifies the provisioning model of the instance.
Corresponds to the JSON property provisioningModel
65942 65943 65944 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 65942 def provisioning_model @provisioning_model end |
#shutdown_timeout ⇒ Google::Apis::ComputeAlpha::Duration
A Duration represents a fixed-length span of time represented
as a count of seconds and fractions of seconds at nanosecond
resolution. It is independent of any calendar and concepts like "day"
or "month". Range is approximately 10,000 years.
Corresponds to the JSON property shutdownTimeout
65950 65951 65952 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 65950 def shutdown_timeout @shutdown_timeout end |
#skip_guest_os_shutdown ⇒ Boolean Also known as: skip_guest_os_shutdown?
Default is false and there will be 120 seconds between GCE ACPI G2 Soft
Off and ACPI G3 Mechanical
Off for Standard VMs and 30 seconds for Spot VMs.
Corresponds to the JSON property skipGuestOsShutdown
65957 65958 65959 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 65957 def skip_guest_os_shutdown @skip_guest_os_shutdown end |
#termination_time ⇒ String
Specifies the timestamp, when the instance will be terminated, inRFC3339 text
format. If specified, the instance
termination action will be performed at the termination time.
Corresponds to the JSON property terminationTime
65965 65966 65967 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 65965 def termination_time @termination_time end |
#windows_license_optimization_mode ⇒ String
Represents the Windows Server License Optimization Mode of the VM. If
unspecified, the default mode is OFF.
Corresponds to the JSON property windowsLicenseOptimizationMode
65971 65972 65973 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 65971 def windows_license_optimization_mode @windows_license_optimization_mode end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
65978 65979 65980 65981 65982 65983 65984 65985 65986 65987 65988 65989 65990 65991 65992 65993 65994 65995 65996 65997 65998 65999 66000 66001 66002 66003 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 65978 def update!(**args) @automatic_restart = args[:automatic_restart] if args.key?(:automatic_restart) @availability_domain = args[:availability_domain] if args.key?(:availability_domain) @current_cpus = args[:current_cpus] if args.key?(:current_cpus) @current_memory_mb = args[:current_memory_mb] if args.key?(:current_memory_mb) @graceful_shutdown = args[:graceful_shutdown] if args.key?(:graceful_shutdown) @host_error_timeout_seconds = args[:host_error_timeout_seconds] if args.key?(:host_error_timeout_seconds) @instance_termination_action = args[:instance_termination_action] if args.key?(:instance_termination_action) @latency_tolerant = args[:latency_tolerant] if args.key?(:latency_tolerant) @local_ssd_recovery_timeout = args[:local_ssd_recovery_timeout] if args.key?(:local_ssd_recovery_timeout) @location_hint = args[:location_hint] if args.key?(:location_hint) @maintenance_freeze_duration_hours = args[:maintenance_freeze_duration_hours] if args.key?(:maintenance_freeze_duration_hours) @maintenance_interval = args[:maintenance_interval] if args.key?(:maintenance_interval) @max_run_duration = args[:max_run_duration] if args.key?(:max_run_duration) @min_node_cpus = args[:min_node_cpus] if args.key?(:min_node_cpus) @node_affinities = args[:node_affinities] if args.key?(:node_affinities) @on_host_maintenance = args[:on_host_maintenance] if args.key?(:on_host_maintenance) @on_instance_stop_action = args[:on_instance_stop_action] if args.key?(:on_instance_stop_action) @preemptible = args[:preemptible] if args.key?(:preemptible) @preemption_notice_duration = args[:preemption_notice_duration] if args.key?(:preemption_notice_duration) @provisioning_model = args[:provisioning_model] if args.key?(:provisioning_model) @shutdown_timeout = args[:shutdown_timeout] if args.key?(:shutdown_timeout) @skip_guest_os_shutdown = args[:skip_guest_os_shutdown] if args.key?(:skip_guest_os_shutdown) @termination_time = args[:termination_time] if args.key?(:termination_time) @windows_license_optimization_mode = args[:windows_license_optimization_mode] if args.key?(:windows_license_optimization_mode) end |