Class: Google::Apis::ComputeAlpha::Scheduling

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Sets the scheduling options for an Instance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Scheduling

Returns a new instance of Scheduling.



64867
64868
64869
# File 'lib/google/apis/compute_alpha/classes.rb', line 64867

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#automatic_restartBoolean Also known as: automatic_restart?

Specifies whether the instance should be automatically restarted if it is terminated by Compute Engine (not terminated by a user). You can only set the automatic restart option for standard instances.Preemptible instances cannot be automatically restarted. By default, this is set to true so an instance is automatically restarted if it is terminated by Compute Engine. Corresponds to the JSON property automaticRestart

Returns:

  • (Boolean)


64704
64705
64706
# File 'lib/google/apis/compute_alpha/classes.rb', line 64704

def automatic_restart
  @automatic_restart
end

#availability_domainFixnum

Specifies the availability domain to place the instance in. The value must be a number between 1 and the number of availability domains specified in the spread placement policy attached to the instance. Corresponds to the JSON property availabilityDomain

Returns:

  • (Fixnum)


64712
64713
64714
# File 'lib/google/apis/compute_alpha/classes.rb', line 64712

def availability_domain
  @availability_domain
end

#current_cpusFixnum

Current number of vCPUs available for VM. 0 or unset means default vCPUs of the current machine type. Corresponds to the JSON property currentCpus

Returns:

  • (Fixnum)


64718
64719
64720
# File 'lib/google/apis/compute_alpha/classes.rb', line 64718

def current_cpus
  @current_cpus
end

#current_memory_mbFixnum

Current amount of memory (in MB) available for VM. 0 or unset means default amount of memory of the current machine type. Corresponds to the JSON property currentMemoryMb

Returns:

  • (Fixnum)


64724
64725
64726
# File 'lib/google/apis/compute_alpha/classes.rb', line 64724

def current_memory_mb
  @current_memory_mb
end

#graceful_shutdownGoogle::Apis::ComputeAlpha::SchedulingGracefulShutdown

The configuration for gracefully shutting down the instance. Corresponds to the JSON property gracefulShutdown



64729
64730
64731
# File 'lib/google/apis/compute_alpha/classes.rb', line 64729

def graceful_shutdown
  @graceful_shutdown
end

#host_error_timeout_secondsFixnum

Specify the time in seconds for host error detection, the value must be within the range of [90, 330] with the increment of 30, if unset, the default behavior of host error recovery will be used. Corresponds to the JSON property hostErrorTimeoutSeconds

Returns:

  • (Fixnum)


64736
64737
64738
# File 'lib/google/apis/compute_alpha/classes.rb', line 64736

def host_error_timeout_seconds
  @host_error_timeout_seconds
end

#instance_termination_actionString

Specifies the termination action for the instance. Corresponds to the JSON property instanceTerminationAction

Returns:

  • (String)


64741
64742
64743
# File 'lib/google/apis/compute_alpha/classes.rb', line 64741

def instance_termination_action
  @instance_termination_action
end

#latency_tolerantBoolean Also known as: latency_tolerant?

Defines whether the instance is tolerant of higher cpu latency. This can only be set during instance creation, or when the instance is not currently running. It must not be set if thepreemptible option is also set. Corresponds to the JSON property latencyTolerant

Returns:

  • (Boolean)


64749
64750
64751
# File 'lib/google/apis/compute_alpha/classes.rb', line 64749

def latency_tolerant
  @latency_tolerant
end

#local_ssd_recovery_timeoutGoogle::Apis::ComputeAlpha::Duration

A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution. It is independent of any calendar and concepts like "day" or "month". Range is approximately 10,000 years. Corresponds to the JSON property localSsdRecoveryTimeout



64758
64759
64760
# File 'lib/google/apis/compute_alpha/classes.rb', line 64758

def local_ssd_recovery_timeout
  @local_ssd_recovery_timeout
end

#location_hintString

An opaque location hint used to place the instance close to other resources. This field is for use by internal tools that use the public API. Corresponds to the JSON property locationHint

Returns:

  • (String)


64765
64766
64767
# File 'lib/google/apis/compute_alpha/classes.rb', line 64765

def location_hint
  @location_hint
end

#maintenance_freeze_duration_hoursFixnum

Specifies the number of hours after VM instance creation where the VM won't be scheduled for maintenance. Corresponds to the JSON property maintenanceFreezeDurationHours

Returns:

  • (Fixnum)


64771
64772
64773
# File 'lib/google/apis/compute_alpha/classes.rb', line 64771

def maintenance_freeze_duration_hours
  @maintenance_freeze_duration_hours
end

#maintenance_intervalString

Specifies the frequency of planned maintenance events. The accepted values are: PERIODIC. Corresponds to the JSON property maintenanceInterval

Returns:

  • (String)


64777
64778
64779
# File 'lib/google/apis/compute_alpha/classes.rb', line 64777

def maintenance_interval
  @maintenance_interval
end

#max_run_durationGoogle::Apis::ComputeAlpha::Duration

A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution. It is independent of any calendar and concepts like "day" or "month". Range is approximately 10,000 years. Corresponds to the JSON property maxRunDuration



64785
64786
64787
# File 'lib/google/apis/compute_alpha/classes.rb', line 64785

def max_run_duration
  @max_run_duration
end

#min_node_cpusFixnum

The minimum number of virtual CPUs this instance will consume when running on a sole-tenant node. Corresponds to the JSON property minNodeCpus

Returns:

  • (Fixnum)


64791
64792
64793
# File 'lib/google/apis/compute_alpha/classes.rb', line 64791

def min_node_cpus
  @min_node_cpus
end

#node_affinitiesArray<Google::Apis::ComputeAlpha::SchedulingNodeAffinity>

A set of node affinity and anti-affinity configurations. Refer toConfiguring node affinity for more information. Overrides reservationAffinity. Corresponds to the JSON property nodeAffinities



64799
64800
64801
# File 'lib/google/apis/compute_alpha/classes.rb', line 64799

def node_affinities
  @node_affinities
end

#on_host_maintenanceString

Defines the maintenance behavior for this instance. For standard instances, the default behavior is MIGRATE. Forpreemptible instances, the default and only possible behavior is TERMINATE. For more information, see Set VM host maintenance policy. Corresponds to the JSON property onHostMaintenance

Returns:

  • (String)


64809
64810
64811
# File 'lib/google/apis/compute_alpha/classes.rb', line 64809

def on_host_maintenance
  @on_host_maintenance
end

#on_instance_stop_actionGoogle::Apis::ComputeAlpha::SchedulingOnInstanceStopAction

Defines the behaviour for instances with the instance_termination_actionSTOP. Corresponds to the JSON property onInstanceStopAction



64814
64815
64816
# File 'lib/google/apis/compute_alpha/classes.rb', line 64814

def on_instance_stop_action
  @on_instance_stop_action
end

#preemptibleBoolean Also known as: preemptible?

Defines whether the instance is preemptible. This can only be set during instance creation or while the instance isstopped and therefore, in a TERMINATED state. SeeInstance Life Cycle for more information on the possible instance states. Corresponds to the JSON property preemptible

Returns:

  • (Boolean)


64822
64823
64824
# File 'lib/google/apis/compute_alpha/classes.rb', line 64822

def preemptible
  @preemptible
end

#preemption_notice_durationGoogle::Apis::ComputeAlpha::Duration

A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution. It is independent of any calendar and concepts like "day" or "month". Range is approximately 10,000 years. Corresponds to the JSON property preemptionNoticeDuration



64831
64832
64833
# File 'lib/google/apis/compute_alpha/classes.rb', line 64831

def preemption_notice_duration
  @preemption_notice_duration
end

#provisioning_modelString

Specifies the provisioning model of the instance. Corresponds to the JSON property provisioningModel

Returns:

  • (String)


64836
64837
64838
# File 'lib/google/apis/compute_alpha/classes.rb', line 64836

def provisioning_model
  @provisioning_model
end

#shutdown_timeoutGoogle::Apis::ComputeAlpha::Duration

A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution. It is independent of any calendar and concepts like "day" or "month". Range is approximately 10,000 years. Corresponds to the JSON property shutdownTimeout



64844
64845
64846
# File 'lib/google/apis/compute_alpha/classes.rb', line 64844

def shutdown_timeout
  @shutdown_timeout
end

#skip_guest_os_shutdownBoolean Also known as: skip_guest_os_shutdown?

Default is false and there will be 120 seconds between GCE ACPI G2 Soft Off and ACPI G3 Mechanical Off for Standard VMs and 30 seconds for Spot VMs. Corresponds to the JSON property skipGuestOsShutdown

Returns:

  • (Boolean)


64851
64852
64853
# File 'lib/google/apis/compute_alpha/classes.rb', line 64851

def skip_guest_os_shutdown
  @skip_guest_os_shutdown
end

#termination_timeString

Specifies the timestamp, when the instance will be terminated, inRFC3339 text format. If specified, the instance termination action will be performed at the termination time. Corresponds to the JSON property terminationTime

Returns:

  • (String)


64859
64860
64861
# File 'lib/google/apis/compute_alpha/classes.rb', line 64859

def termination_time
  @termination_time
end

#windows_license_optimization_modeString

Represents the Windows Server License Optimization Mode of the VM. If unspecified, the default mode is OFF. Corresponds to the JSON property windowsLicenseOptimizationMode

Returns:

  • (String)


64865
64866
64867
# File 'lib/google/apis/compute_alpha/classes.rb', line 64865

def windows_license_optimization_mode
  @windows_license_optimization_mode
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



64872
64873
64874
64875
64876
64877
64878
64879
64880
64881
64882
64883
64884
64885
64886
64887
64888
64889
64890
64891
64892
64893
64894
64895
64896
64897
# File 'lib/google/apis/compute_alpha/classes.rb', line 64872

def update!(**args)
  @automatic_restart = args[:automatic_restart] if args.key?(:automatic_restart)
  @availability_domain = args[:availability_domain] if args.key?(:availability_domain)
  @current_cpus = args[:current_cpus] if args.key?(:current_cpus)
  @current_memory_mb = args[:current_memory_mb] if args.key?(:current_memory_mb)
  @graceful_shutdown = args[:graceful_shutdown] if args.key?(:graceful_shutdown)
  @host_error_timeout_seconds = args[:host_error_timeout_seconds] if args.key?(:host_error_timeout_seconds)
  @instance_termination_action = args[:instance_termination_action] if args.key?(:instance_termination_action)
  @latency_tolerant = args[:latency_tolerant] if args.key?(:latency_tolerant)
  @local_ssd_recovery_timeout = args[:local_ssd_recovery_timeout] if args.key?(:local_ssd_recovery_timeout)
  @location_hint = args[:location_hint] if args.key?(:location_hint)
  @maintenance_freeze_duration_hours = args[:maintenance_freeze_duration_hours] if args.key?(:maintenance_freeze_duration_hours)
  @maintenance_interval = args[:maintenance_interval] if args.key?(:maintenance_interval)
  @max_run_duration = args[:max_run_duration] if args.key?(:max_run_duration)
  @min_node_cpus = args[:min_node_cpus] if args.key?(:min_node_cpus)
  @node_affinities = args[:node_affinities] if args.key?(:node_affinities)
  @on_host_maintenance = args[:on_host_maintenance] if args.key?(:on_host_maintenance)
  @on_instance_stop_action = args[:on_instance_stop_action] if args.key?(:on_instance_stop_action)
  @preemptible = args[:preemptible] if args.key?(:preemptible)
  @preemption_notice_duration = args[:preemption_notice_duration] if args.key?(:preemption_notice_duration)
  @provisioning_model = args[:provisioning_model] if args.key?(:provisioning_model)
  @shutdown_timeout = args[:shutdown_timeout] if args.key?(:shutdown_timeout)
  @skip_guest_os_shutdown = args[:skip_guest_os_shutdown] if args.key?(:skip_guest_os_shutdown)
  @termination_time = args[:termination_time] if args.key?(:termination_time)
  @windows_license_optimization_mode = args[:windows_license_optimization_mode] if args.key?(:windows_license_optimization_mode)
end