Class: Google::Apis::ComputeAlpha::SchedulingGracefulShutdown

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

The configuration for gracefully shutting down the instance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SchedulingGracefulShutdown

Returns a new instance of SchedulingGracefulShutdown.



66622
66623
66624
# File 'lib/google/apis/compute_alpha/classes.rb', line 66622

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enabledBoolean Also known as: enabled?

Opts-in for graceful shutdown. Corresponds to the JSON property enabled

Returns:

  • (Boolean)


66611
66612
66613
# File 'lib/google/apis/compute_alpha/classes.rb', line 66611

def enabled
  @enabled
end

#max_durationGoogle::Apis::ComputeAlpha::Duration

A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution. It is independent of any calendar and concepts like "day" or "month". Range is approximately 10,000 years. Corresponds to the JSON property maxDuration



66620
66621
66622
# File 'lib/google/apis/compute_alpha/classes.rb', line 66620

def max_duration
  @max_duration
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



66627
66628
66629
66630
# File 'lib/google/apis/compute_alpha/classes.rb', line 66627

def update!(**args)
  @enabled = args[:enabled] if args.key?(:enabled)
  @max_duration = args[:max_duration] if args.key?(:max_duration)
end