Class: Google::Apis::ComputeAlpha::SchedulingGracefulShutdown
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::SchedulingGracefulShutdown
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
The configuration for gracefully shutting down the instance.
Instance Attribute Summary collapse
-
#enabled ⇒ Boolean
(also: #enabled?)
Opts-in for graceful shutdown.
-
#max_duration ⇒ Google::Apis::ComputeAlpha::Duration
A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SchedulingGracefulShutdown
constructor
A new instance of SchedulingGracefulShutdown.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SchedulingGracefulShutdown
Returns a new instance of SchedulingGracefulShutdown.
66024 66025 66026 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 66024 def initialize(**args) update!(**args) end |
Instance Attribute Details
#enabled ⇒ Boolean Also known as: enabled?
Opts-in for graceful shutdown.
Corresponds to the JSON property enabled
66013 66014 66015 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 66013 def enabled @enabled end |
#max_duration ⇒ Google::Apis::ComputeAlpha::Duration
A Duration represents a fixed-length span of time represented
as a count of seconds and fractions of seconds at nanosecond
resolution. It is independent of any calendar and concepts like "day"
or "month". Range is approximately 10,000 years.
Corresponds to the JSON property maxDuration
66022 66023 66024 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 66022 def max_duration @max_duration end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
66029 66030 66031 66032 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 66029 def update!(**args) @enabled = args[:enabled] if args.key?(:enabled) @max_duration = args[:max_duration] if args.key?(:max_duration) end |