Class: Google::Apis::ComputeAlpha::SchedulingOnInstanceStopAction

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Defines the behaviour for instances with the instance_termination_actionSTOP.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SchedulingOnInstanceStopAction

Returns a new instance of SchedulingOnInstanceStopAction.



68387
68388
68389
# File 'lib/google/apis/compute_alpha/classes.rb', line 68387

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#discard_local_ssdBoolean Also known as: discard_local_ssd?

If true, the contents of any attached Local SSD disks will be discarded else, the Local SSD data will be preserved when the instance is stopped at the end of the run duration/termination time. Corresponds to the JSON property discardLocalSsd

Returns:

  • (Boolean)


68384
68385
68386
# File 'lib/google/apis/compute_alpha/classes.rb', line 68384

def discard_local_ssd
  @discard_local_ssd
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



68392
68393
68394
# File 'lib/google/apis/compute_alpha/classes.rb', line 68392

def update!(**args)
  @discard_local_ssd = args[:discard_local_ssd] if args.key?(:discard_local_ssd)
end