Class: Google::Apis::ComputeAlpha::SchedulingOnInstanceStopAction
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::SchedulingOnInstanceStopAction
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Defines the behaviour for instances with the instance_termination_actionSTOP.
Instance Attribute Summary collapse
-
#discard_local_ssd ⇒ Boolean
(also: #discard_local_ssd?)
If true, the contents of any attached Local SSD disks will be discarded else, the Local SSD data will be preserved when the instance is stopped at the end of the run duration/termination time.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SchedulingOnInstanceStopAction
constructor
A new instance of SchedulingOnInstanceStopAction.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SchedulingOnInstanceStopAction
Returns a new instance of SchedulingOnInstanceStopAction.
68085 68086 68087 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 68085 def initialize(**args) update!(**args) end |
Instance Attribute Details
#discard_local_ssd ⇒ Boolean Also known as: discard_local_ssd?
If true, the contents of any attached Local SSD disks will be discarded
else, the Local SSD data will be preserved when the instance is stopped
at the end of the run duration/termination time.
Corresponds to the JSON property discardLocalSsd
68082 68083 68084 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 68082 def discard_local_ssd @discard_local_ssd end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
68090 68091 68092 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 68090 def update!(**args) @discard_local_ssd = args[:discard_local_ssd] if args.key?(:discard_local_ssd) end |