Class: Google::Apis::ComputeAlpha::SecurityPoliciesAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SecurityPoliciesAggregatedList

Returns a new instance of SecurityPoliciesAggregatedList.



68514
68515
68516
# File 'lib/google/apis/compute_alpha/classes.rb', line 68514

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


68470
68471
68472
# File 'lib/google/apis/compute_alpha/classes.rb', line 68470

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


68475
68476
68477
# File 'lib/google/apis/compute_alpha/classes.rb', line 68475

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::SecurityPoliciesScopedList>

A list of SecurityPoliciesScopedList resources. Corresponds to the JSON property items



68480
68481
68482
# File 'lib/google/apis/compute_alpha/classes.rb', line 68480

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# securityPolicyAggregatedList for lists of Security Policies. Corresponds to the JSON property kind

Returns:

  • (String)


68487
68488
68489
# File 'lib/google/apis/compute_alpha/classes.rb', line 68487

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


68497
68498
68499
# File 'lib/google/apis/compute_alpha/classes.rb', line 68497

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


68502
68503
68504
# File 'lib/google/apis/compute_alpha/classes.rb', line 68502

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


68507
68508
68509
# File 'lib/google/apis/compute_alpha/classes.rb', line 68507

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::SecurityPoliciesAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



68512
68513
68514
# File 'lib/google/apis/compute_alpha/classes.rb', line 68512

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



68519
68520
68521
68522
68523
68524
68525
68526
68527
68528
# File 'lib/google/apis/compute_alpha/classes.rb', line 68519

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end