Class: Google::Apis::ComputeAlpha::SecurityPoliciesAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::SecurityPoliciesAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::SecurityPoliciesScopedList>
A list of SecurityPoliciesScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::SecurityPoliciesAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SecurityPoliciesAggregatedList
constructor
A new instance of SecurityPoliciesAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SecurityPoliciesAggregatedList
Returns a new instance of SecurityPoliciesAggregatedList.
68212 68213 68214 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 68212 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
68168 68169 68170 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 68168 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
68173 68174 68175 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 68173 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::SecurityPoliciesScopedList>
A list of SecurityPoliciesScopedList resources.
Corresponds to the JSON property items
68178 68179 68180 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 68178 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
securityPolicyAggregatedList for lists of Security
Policies.
Corresponds to the JSON property kind
68185 68186 68187 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 68185 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
68195 68196 68197 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 68195 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
68200 68201 68202 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 68200 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
68205 68206 68207 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 68205 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::SecurityPoliciesAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
68210 68211 68212 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 68210 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
68217 68218 68219 68220 68221 68222 68223 68224 68225 68226 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 68217 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |