Class: Google::Apis::ComputeAlpha::SecurityPoliciesAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SecurityPoliciesAggregatedList

Returns a new instance of SecurityPoliciesAggregatedList.



66843
66844
66845
# File 'lib/google/apis/compute_alpha/classes.rb', line 66843

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


66799
66800
66801
# File 'lib/google/apis/compute_alpha/classes.rb', line 66799

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


66804
66805
66806
# File 'lib/google/apis/compute_alpha/classes.rb', line 66804

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::SecurityPoliciesScopedList>

A list of SecurityPoliciesScopedList resources. Corresponds to the JSON property items



66809
66810
66811
# File 'lib/google/apis/compute_alpha/classes.rb', line 66809

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# securityPolicyAggregatedList for lists of Security Policies. Corresponds to the JSON property kind

Returns:

  • (String)


66816
66817
66818
# File 'lib/google/apis/compute_alpha/classes.rb', line 66816

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


66826
66827
66828
# File 'lib/google/apis/compute_alpha/classes.rb', line 66826

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


66831
66832
66833
# File 'lib/google/apis/compute_alpha/classes.rb', line 66831

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


66836
66837
66838
# File 'lib/google/apis/compute_alpha/classes.rb', line 66836

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::SecurityPoliciesAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



66841
66842
66843
# File 'lib/google/apis/compute_alpha/classes.rb', line 66841

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



66848
66849
66850
66851
66852
66853
66854
66855
66856
66857
# File 'lib/google/apis/compute_alpha/classes.rb', line 66848

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end