Class: Google::Apis::ComputeAlpha::SecurityPoliciesAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::SecurityPoliciesAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::SecurityPoliciesScopedList>
A list of SecurityPoliciesScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::SecurityPoliciesAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SecurityPoliciesAggregatedList
constructor
A new instance of SecurityPoliciesAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SecurityPoliciesAggregatedList
Returns a new instance of SecurityPoliciesAggregatedList.
66786 66787 66788 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 66786 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
66742 66743 66744 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 66742 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
66747 66748 66749 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 66747 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::SecurityPoliciesScopedList>
A list of SecurityPoliciesScopedList resources.
Corresponds to the JSON property items
66752 66753 66754 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 66752 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
securityPolicyAggregatedList for lists of Security
Policies.
Corresponds to the JSON property kind
66759 66760 66761 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 66759 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
66769 66770 66771 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 66769 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
66774 66775 66776 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 66774 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
66779 66780 66781 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 66779 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::SecurityPoliciesAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
66784 66785 66786 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 66784 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
66791 66792 66793 66794 66795 66796 66797 66798 66799 66800 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 66791 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |