Class: Google::Apis::ComputeAlpha::SecurityPoliciesAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SecurityPoliciesAggregatedList

Returns a new instance of SecurityPoliciesAggregatedList.



65965
65966
65967
# File 'lib/google/apis/compute_alpha/classes.rb', line 65965

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


65921
65922
65923
# File 'lib/google/apis/compute_alpha/classes.rb', line 65921

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


65926
65927
65928
# File 'lib/google/apis/compute_alpha/classes.rb', line 65926

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::SecurityPoliciesScopedList>

A list of SecurityPoliciesScopedList resources. Corresponds to the JSON property items



65931
65932
65933
# File 'lib/google/apis/compute_alpha/classes.rb', line 65931

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# securityPolicyAggregatedList for lists of Security Policies. Corresponds to the JSON property kind

Returns:

  • (String)


65938
65939
65940
# File 'lib/google/apis/compute_alpha/classes.rb', line 65938

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


65948
65949
65950
# File 'lib/google/apis/compute_alpha/classes.rb', line 65948

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


65953
65954
65955
# File 'lib/google/apis/compute_alpha/classes.rb', line 65953

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


65958
65959
65960
# File 'lib/google/apis/compute_alpha/classes.rb', line 65958

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::SecurityPoliciesAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



65963
65964
65965
# File 'lib/google/apis/compute_alpha/classes.rb', line 65963

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



65970
65971
65972
65973
65974
65975
65976
65977
65978
65979
# File 'lib/google/apis/compute_alpha/classes.rb', line 65970

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end