Class: Google::Apis::ComputeAlpha::SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfig
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Configuration options for L7 DDoS detection. This field is only supported in Global Security Policies of type CLOUD_ARMOR.
Instance Attribute Summary collapse
-
#enable ⇒ Boolean
(also: #enable?)
If set to true, enables CAAP for L7 DDoS detection.
-
#rule_visibility ⇒ String
Rule visibility can be one of the following: STANDARD - opaque rules.
-
#threshold_configs ⇒ Array<Google::Apis::ComputeAlpha::SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfig>
Configuration options for layer7 adaptive protection for various customizable thresholds.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfig
constructor
A new instance of SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfig
Returns a new instance of SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfig.
65641 65642 65643 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 65641 def initialize(**args) update!(**args) end |
Instance Attribute Details
#enable ⇒ Boolean Also known as: enable?
If set to true, enables CAAP for L7 DDoS detection.
This field is only supported in Global Security Policies of type
CLOUD_ARMOR.
Corresponds to the JSON property enable
65623 65624 65625 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 65623 def enable @enable end |
#rule_visibility ⇒ String
Rule visibility can be one of the following:
STANDARD - opaque rules. (default)
PREMIUM - transparent rules.
This field is only supported in Global Security Policies of type
CLOUD_ARMOR.
Corresponds to the JSON property ruleVisibility
65633 65634 65635 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 65633 def rule_visibility @rule_visibility end |
#threshold_configs ⇒ Array<Google::Apis::ComputeAlpha::SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfig>
Configuration options for layer7 adaptive protection for various
customizable thresholds.
Corresponds to the JSON property thresholdConfigs
65639 65640 65641 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 65639 def threshold_configs @threshold_configs end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
65646 65647 65648 65649 65650 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 65646 def update!(**args) @enable = args[:enable] if args.key?(:enable) @rule_visibility = args[:rule_visibility] if args.key?(:rule_visibility) @threshold_configs = args[:threshold_configs] if args.key?(:threshold_configs) end |