Class: Google::Apis::ComputeAlpha::SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfig

Returns a new instance of SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfig.



68834
68835
68836
# File 'lib/google/apis/compute_alpha/classes.rb', line 68834

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#auto_deploy_confidence_thresholdFloat

Corresponds to the JSON property autoDeployConfidenceThreshold

Returns:

  • (Float)


68790
68791
68792
# File 'lib/google/apis/compute_alpha/classes.rb', line 68790

def auto_deploy_confidence_threshold
  @auto_deploy_confidence_threshold
end

#auto_deploy_expiration_secFixnum

Corresponds to the JSON property autoDeployExpirationSec

Returns:

  • (Fixnum)


68795
68796
68797
# File 'lib/google/apis/compute_alpha/classes.rb', line 68795

def auto_deploy_expiration_sec
  @auto_deploy_expiration_sec
end

#auto_deploy_impacted_baseline_thresholdFloat

Corresponds to the JSON property autoDeployImpactedBaselineThreshold

Returns:

  • (Float)


68800
68801
68802
# File 'lib/google/apis/compute_alpha/classes.rb', line 68800

def auto_deploy_impacted_baseline_threshold
  @auto_deploy_impacted_baseline_threshold
end

#auto_deploy_load_thresholdFloat

Corresponds to the JSON property autoDeployLoadThreshold

Returns:

  • (Float)


68805
68806
68807
# File 'lib/google/apis/compute_alpha/classes.rb', line 68805

def auto_deploy_load_threshold
  @auto_deploy_load_threshold
end

#detection_absolute_qpsFloat

Corresponds to the JSON property detectionAbsoluteQps

Returns:

  • (Float)


68810
68811
68812
# File 'lib/google/apis/compute_alpha/classes.rb', line 68810

def detection_absolute_qps
  @detection_absolute_qps
end

#detection_load_thresholdFloat

Corresponds to the JSON property detectionLoadThreshold

Returns:

  • (Float)


68815
68816
68817
# File 'lib/google/apis/compute_alpha/classes.rb', line 68815

def detection_load_threshold
  @detection_load_threshold
end

#detection_relative_to_baseline_qpsFloat

Corresponds to the JSON property detectionRelativeToBaselineQps

Returns:

  • (Float)


68820
68821
68822
# File 'lib/google/apis/compute_alpha/classes.rb', line 68820

def detection_relative_to_baseline_qps
  @detection_relative_to_baseline_qps
end

#nameString

The name must be 1-63 characters long, and comply withRFC1035. The name must be unique within the security policy. Corresponds to the JSON property name

Returns:

  • (String)


68826
68827
68828
# File 'lib/google/apis/compute_alpha/classes.rb', line 68826

def name
  @name
end

#traffic_granularity_configsArray<Google::Apis::ComputeAlpha::SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfigTrafficGranularityConfig>

Configuration options for enabling Adaptive Protection to operate on specified granular traffic units. Corresponds to the JSON property trafficGranularityConfigs



68832
68833
68834
# File 'lib/google/apis/compute_alpha/classes.rb', line 68832

def traffic_granularity_configs
  @traffic_granularity_configs
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



68839
68840
68841
68842
68843
68844
68845
68846
68847
68848
68849
# File 'lib/google/apis/compute_alpha/classes.rb', line 68839

def update!(**args)
  @auto_deploy_confidence_threshold = args[:auto_deploy_confidence_threshold] if args.key?(:auto_deploy_confidence_threshold)
  @auto_deploy_expiration_sec = args[:auto_deploy_expiration_sec] if args.key?(:auto_deploy_expiration_sec)
  @auto_deploy_impacted_baseline_threshold = args[:auto_deploy_impacted_baseline_threshold] if args.key?(:auto_deploy_impacted_baseline_threshold)
  @auto_deploy_load_threshold = args[:auto_deploy_load_threshold] if args.key?(:auto_deploy_load_threshold)
  @detection_absolute_qps = args[:detection_absolute_qps] if args.key?(:detection_absolute_qps)
  @detection_load_threshold = args[:detection_load_threshold] if args.key?(:detection_load_threshold)
  @detection_relative_to_baseline_qps = args[:detection_relative_to_baseline_qps] if args.key?(:detection_relative_to_baseline_qps)
  @name = args[:name] if args.key?(:name)
  @traffic_granularity_configs = args[:traffic_granularity_configs] if args.key?(:traffic_granularity_configs)
end