Class: Google::Apis::ComputeAlpha::SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfig

Returns a new instance of SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfig.



66808
66809
66810
# File 'lib/google/apis/compute_alpha/classes.rb', line 66808

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#auto_deploy_confidence_thresholdFloat

Corresponds to the JSON property autoDeployConfidenceThreshold

Returns:

  • (Float)


66764
66765
66766
# File 'lib/google/apis/compute_alpha/classes.rb', line 66764

def auto_deploy_confidence_threshold
  @auto_deploy_confidence_threshold
end

#auto_deploy_expiration_secFixnum

Corresponds to the JSON property autoDeployExpirationSec

Returns:

  • (Fixnum)


66769
66770
66771
# File 'lib/google/apis/compute_alpha/classes.rb', line 66769

def auto_deploy_expiration_sec
  @auto_deploy_expiration_sec
end

#auto_deploy_impacted_baseline_thresholdFloat

Corresponds to the JSON property autoDeployImpactedBaselineThreshold

Returns:

  • (Float)


66774
66775
66776
# File 'lib/google/apis/compute_alpha/classes.rb', line 66774

def auto_deploy_impacted_baseline_threshold
  @auto_deploy_impacted_baseline_threshold
end

#auto_deploy_load_thresholdFloat

Corresponds to the JSON property autoDeployLoadThreshold

Returns:

  • (Float)


66779
66780
66781
# File 'lib/google/apis/compute_alpha/classes.rb', line 66779

def auto_deploy_load_threshold
  @auto_deploy_load_threshold
end

#detection_absolute_qpsFloat

Corresponds to the JSON property detectionAbsoluteQps

Returns:

  • (Float)


66784
66785
66786
# File 'lib/google/apis/compute_alpha/classes.rb', line 66784

def detection_absolute_qps
  @detection_absolute_qps
end

#detection_load_thresholdFloat

Corresponds to the JSON property detectionLoadThreshold

Returns:

  • (Float)


66789
66790
66791
# File 'lib/google/apis/compute_alpha/classes.rb', line 66789

def detection_load_threshold
  @detection_load_threshold
end

#detection_relative_to_baseline_qpsFloat

Corresponds to the JSON property detectionRelativeToBaselineQps

Returns:

  • (Float)


66794
66795
66796
# File 'lib/google/apis/compute_alpha/classes.rb', line 66794

def detection_relative_to_baseline_qps
  @detection_relative_to_baseline_qps
end

#nameString

The name must be 1-63 characters long, and comply withRFC1035. The name must be unique within the security policy. Corresponds to the JSON property name

Returns:

  • (String)


66800
66801
66802
# File 'lib/google/apis/compute_alpha/classes.rb', line 66800

def name
  @name
end

#traffic_granularity_configsArray<Google::Apis::ComputeAlpha::SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfigTrafficGranularityConfig>

Configuration options for enabling Adaptive Protection to operate on specified granular traffic units. Corresponds to the JSON property trafficGranularityConfigs



66806
66807
66808
# File 'lib/google/apis/compute_alpha/classes.rb', line 66806

def traffic_granularity_configs
  @traffic_granularity_configs
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



66813
66814
66815
66816
66817
66818
66819
66820
66821
66822
66823
# File 'lib/google/apis/compute_alpha/classes.rb', line 66813

def update!(**args)
  @auto_deploy_confidence_threshold = args[:auto_deploy_confidence_threshold] if args.key?(:auto_deploy_confidence_threshold)
  @auto_deploy_expiration_sec = args[:auto_deploy_expiration_sec] if args.key?(:auto_deploy_expiration_sec)
  @auto_deploy_impacted_baseline_threshold = args[:auto_deploy_impacted_baseline_threshold] if args.key?(:auto_deploy_impacted_baseline_threshold)
  @auto_deploy_load_threshold = args[:auto_deploy_load_threshold] if args.key?(:auto_deploy_load_threshold)
  @detection_absolute_qps = args[:detection_absolute_qps] if args.key?(:detection_absolute_qps)
  @detection_load_threshold = args[:detection_load_threshold] if args.key?(:detection_load_threshold)
  @detection_relative_to_baseline_qps = args[:detection_relative_to_baseline_qps] if args.key?(:detection_relative_to_baseline_qps)
  @name = args[:name] if args.key?(:name)
  @traffic_granularity_configs = args[:traffic_granularity_configs] if args.key?(:traffic_granularity_configs)
end