Class: Google::Apis::ComputeAlpha::SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfigTrafficGranularityConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Configurations to specifc granular traffic units processed by Adaptive Protection.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfigTrafficGranularityConfig

Returns a new instance of SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfigTrafficGranularityConfig.



67506
67507
67508
# File 'lib/google/apis/compute_alpha/classes.rb', line 67506

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enable_each_unique_valueBoolean Also known as: enable_each_unique_value?

If enabled, traffic matching each unique value for the specified type constitutes a separate traffic unit. It can only be set to true if value is empty. Corresponds to the JSON property enableEachUniqueValue

Returns:

  • (Boolean)


67493
67494
67495
# File 'lib/google/apis/compute_alpha/classes.rb', line 67493

def enable_each_unique_value
  @enable_each_unique_value
end

#typeString

Type of this configuration. Corresponds to the JSON property type

Returns:

  • (String)


67499
67500
67501
# File 'lib/google/apis/compute_alpha/classes.rb', line 67499

def type
  @type
end

#valueString

Requests that match this value constitute a granular traffic unit. Corresponds to the JSON property value

Returns:

  • (String)


67504
67505
67506
# File 'lib/google/apis/compute_alpha/classes.rb', line 67504

def value
  @value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



67511
67512
67513
67514
67515
# File 'lib/google/apis/compute_alpha/classes.rb', line 67511

def update!(**args)
  @enable_each_unique_value = args[:enable_each_unique_value] if args.key?(:enable_each_unique_value)
  @type = args[:type] if args.key?(:type)
  @value = args[:value] if args.key?(:value)
end