Class: Google::Apis::ComputeAlpha::SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfigTrafficGranularityConfig
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfigTrafficGranularityConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Configurations to specifc granular traffic units processed by Adaptive Protection.
Instance Attribute Summary collapse
-
#enable_each_unique_value ⇒ Boolean
(also: #enable_each_unique_value?)
If enabled, traffic matching each unique value for the specified type constitutes a separate traffic unit.
-
#type ⇒ String
Type of this configuration.
-
#value ⇒ String
Requests that match this value constitute a granular traffic unit.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfigTrafficGranularityConfig
constructor
A new instance of SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfigTrafficGranularityConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfigTrafficGranularityConfig
Returns a new instance of SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfigTrafficGranularityConfig.
66849 66850 66851 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 66849 def initialize(**args) update!(**args) end |
Instance Attribute Details
#enable_each_unique_value ⇒ Boolean Also known as: enable_each_unique_value?
If enabled, traffic matching each unique value for the specified
type constitutes a separate traffic unit.
It can only be set to true if value is empty.
Corresponds to the JSON property enableEachUniqueValue
66836 66837 66838 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 66836 def enable_each_unique_value @enable_each_unique_value end |
#type ⇒ String
Type of this configuration.
Corresponds to the JSON property type
66842 66843 66844 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 66842 def type @type end |
#value ⇒ String
Requests that match this value constitute a granular traffic unit.
Corresponds to the JSON property value
66847 66848 66849 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 66847 def value @value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
66854 66855 66856 66857 66858 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 66854 def update!(**args) @enable_each_unique_value = args[:enable_each_unique_value] if args.key?(:enable_each_unique_value) @type = args[:type] if args.key?(:type) @value = args[:value] if args.key?(:value) end |