Class: Google::Apis::ComputeAlpha::SecurityPolicyAdvancedOptionsConfig
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::SecurityPolicyAdvancedOptionsConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#json_custom_config ⇒ Google::Apis::ComputeAlpha::SecurityPolicyAdvancedOptionsConfigJsonCustomConfig
Custom configuration to apply the JSON parsing.
-
#json_parsing ⇒ String
Corresponds to the JSON property
jsonParsing. -
#log_level ⇒ String
Corresponds to the JSON property
logLevel. -
#request_body_inspection_size ⇒ String
The maximum request size chosen by the customer with Waf enabled.
-
#user_ip_request_headers ⇒ Array<String>
An optional list of case-insensitive request header names to use for resolving the callers client IP address.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SecurityPolicyAdvancedOptionsConfig
constructor
A new instance of SecurityPolicyAdvancedOptionsConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SecurityPolicyAdvancedOptionsConfig
Returns a new instance of SecurityPolicyAdvancedOptionsConfig.
67494 67495 67496 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 67494 def initialize(**args) update!(**args) end |
Instance Attribute Details
#json_custom_config ⇒ Google::Apis::ComputeAlpha::SecurityPolicyAdvancedOptionsConfigJsonCustomConfig
Custom configuration to apply the JSON parsing. Only applicable when
json_parsing is set to STANDARD.
Corresponds to the JSON property jsonCustomConfig
67469 67470 67471 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 67469 def json_custom_config @json_custom_config end |
#json_parsing ⇒ String
Corresponds to the JSON property jsonParsing
67474 67475 67476 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 67474 def json_parsing @json_parsing end |
#log_level ⇒ String
Corresponds to the JSON property logLevel
67479 67480 67481 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 67479 def log_level @log_level end |
#request_body_inspection_size ⇒ String
The maximum request size chosen by the customer with Waf enabled.
Values supported are "8KB", "16KB, "32KB", "48KB" and "64KB".
Values are case insensitive.
Corresponds to the JSON property requestBodyInspectionSize
67486 67487 67488 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 67486 def request_body_inspection_size @request_body_inspection_size end |
#user_ip_request_headers ⇒ Array<String>
An optional list of case-insensitive request header names to use for
resolving the callers client IP address.
Corresponds to the JSON property userIpRequestHeaders
67492 67493 67494 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 67492 def user_ip_request_headers @user_ip_request_headers end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
67499 67500 67501 67502 67503 67504 67505 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 67499 def update!(**args) @json_custom_config = args[:json_custom_config] if args.key?(:json_custom_config) @json_parsing = args[:json_parsing] if args.key?(:json_parsing) @log_level = args[:log_level] if args.key?(:log_level) @request_body_inspection_size = args[:request_body_inspection_size] if args.key?(:request_body_inspection_size) @user_ip_request_headers = args[:user_ip_request_headers] if args.key?(:user_ip_request_headers) end |