Class: Google::Apis::ComputeAlpha::SecurityPolicyAdvancedOptionsConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SecurityPolicyAdvancedOptionsConfig

Returns a new instance of SecurityPolicyAdvancedOptionsConfig.



66673
66674
66675
# File 'lib/google/apis/compute_alpha/classes.rb', line 66673

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#json_custom_configGoogle::Apis::ComputeAlpha::SecurityPolicyAdvancedOptionsConfigJsonCustomConfig

Custom configuration to apply the JSON parsing. Only applicable when json_parsing is set to STANDARD. Corresponds to the JSON property jsonCustomConfig



66648
66649
66650
# File 'lib/google/apis/compute_alpha/classes.rb', line 66648

def json_custom_config
  @json_custom_config
end

#json_parsingString

Corresponds to the JSON property jsonParsing

Returns:

  • (String)


66653
66654
66655
# File 'lib/google/apis/compute_alpha/classes.rb', line 66653

def json_parsing
  @json_parsing
end

#log_levelString

Corresponds to the JSON property logLevel

Returns:

  • (String)


66658
66659
66660
# File 'lib/google/apis/compute_alpha/classes.rb', line 66658

def log_level
  @log_level
end

#request_body_inspection_sizeString

The maximum request size chosen by the customer with Waf enabled. Values supported are "8KB", "16KB, "32KB", "48KB" and "64KB". Values are case insensitive. Corresponds to the JSON property requestBodyInspectionSize

Returns:

  • (String)


66665
66666
66667
# File 'lib/google/apis/compute_alpha/classes.rb', line 66665

def request_body_inspection_size
  @request_body_inspection_size
end

#user_ip_request_headersArray<String>

An optional list of case-insensitive request header names to use for resolving the callers client IP address. Corresponds to the JSON property userIpRequestHeaders

Returns:

  • (Array<String>)


66671
66672
66673
# File 'lib/google/apis/compute_alpha/classes.rb', line 66671

def user_ip_request_headers
  @user_ip_request_headers
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



66678
66679
66680
66681
66682
66683
66684
# File 'lib/google/apis/compute_alpha/classes.rb', line 66678

def update!(**args)
  @json_custom_config = args[:json_custom_config] if args.key?(:json_custom_config)
  @json_parsing = args[:json_parsing] if args.key?(:json_parsing)
  @log_level = args[:log_level] if args.key?(:log_level)
  @request_body_inspection_size = args[:request_body_inspection_size] if args.key?(:request_body_inspection_size)
  @user_ip_request_headers = args[:user_ip_request_headers] if args.key?(:user_ip_request_headers)
end