Class: Google::Apis::ComputeAlpha::SecurityPolicyAssociation
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::SecurityPolicyAssociation
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#attachment_id ⇒ String
The resource that the security policy is attached to.
-
#display_name ⇒ String
Output only.
-
#excluded_folders ⇒ Array<String>
A list of folders to exclude from the security policy.
-
#excluded_projects ⇒ Array<String>
A list of projects to exclude from the security policy.
-
#name ⇒ String
The name for an association.
-
#security_policy_id ⇒ String
Output only.
-
#short_name ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SecurityPolicyAssociation
constructor
A new instance of SecurityPolicyAssociation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SecurityPolicyAssociation
Returns a new instance of SecurityPolicyAssociation.
66973 66974 66975 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 66973 def initialize(**args) update!(**args) end |
Instance Attribute Details
#attachment_id ⇒ String
The resource that the security policy is attached to.
Corresponds to the JSON property attachmentId
66939 66940 66941 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 66939 def @attachment_id end |
#display_name ⇒ String
Output only. [Output Only] The display name of the security policy of the
association.
Corresponds to the JSON property displayName
66945 66946 66947 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 66945 def display_name @display_name end |
#excluded_folders ⇒ Array<String>
A list of folders to exclude from the security policy.
Corresponds to the JSON property excludedFolders
66950 66951 66952 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 66950 def excluded_folders @excluded_folders end |
#excluded_projects ⇒ Array<String>
A list of projects to exclude from the security policy.
Corresponds to the JSON property excludedProjects
66955 66956 66957 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 66955 def excluded_projects @excluded_projects end |
#name ⇒ String
The name for an association.
Corresponds to the JSON property name
66960 66961 66962 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 66960 def name @name end |
#security_policy_id ⇒ String
Output only. [Output Only] The security policy ID of the association.
Corresponds to the JSON property securityPolicyId
66965 66966 66967 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 66965 def security_policy_id @security_policy_id end |
#short_name ⇒ String
Output only. [Output Only] The short name of the security policy of the
association.
Corresponds to the JSON property shortName
66971 66972 66973 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 66971 def short_name @short_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
66978 66979 66980 66981 66982 66983 66984 66985 66986 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 66978 def update!(**args) @attachment_id = args[:attachment_id] if args.key?(:attachment_id) @display_name = args[:display_name] if args.key?(:display_name) @excluded_folders = args[:excluded_folders] if args.key?(:excluded_folders) @excluded_projects = args[:excluded_projects] if args.key?(:excluded_projects) @name = args[:name] if args.key?(:name) @security_policy_id = args[:security_policy_id] if args.key?(:security_policy_id) @short_name = args[:short_name] if args.key?(:short_name) end |