Class: Google::Apis::ComputeAlpha::SecurityPolicyList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SecurityPolicyList

Returns a new instance of SecurityPolicyList.



69426
69427
69428
# File 'lib/google/apis/compute_alpha/classes.rb', line 69426

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


69388
69389
69390
# File 'lib/google/apis/compute_alpha/classes.rb', line 69388

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


69393
69394
69395
# File 'lib/google/apis/compute_alpha/classes.rb', line 69393

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::SecurityPolicy>

A list of SecurityPolicy resources. Corresponds to the JSON property items



69398
69399
69400
# File 'lib/google/apis/compute_alpha/classes.rb', line 69398

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute#securityPolicyList for listsof securityPolicies Corresponds to the JSON property kind

Returns:

  • (String)


69404
69405
69406
# File 'lib/google/apis/compute_alpha/classes.rb', line 69404

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


69414
69415
69416
# File 'lib/google/apis/compute_alpha/classes.rb', line 69414

def next_page_token
  @next_page_token
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


69419
69420
69421
# File 'lib/google/apis/compute_alpha/classes.rb', line 69419

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::SecurityPolicyList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



69424
69425
69426
# File 'lib/google/apis/compute_alpha/classes.rb', line 69424

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



69431
69432
69433
69434
69435
69436
69437
69438
69439
# File 'lib/google/apis/compute_alpha/classes.rb', line 69431

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end