Class: Google::Apis::ComputeAlpha::SecurityPolicyList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::SecurityPolicyList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::SecurityPolicy>
A list of SecurityPolicy resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::SecurityPolicyList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SecurityPolicyList
constructor
A new instance of SecurityPolicyList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SecurityPolicyList
Returns a new instance of SecurityPolicyList.
69124 69125 69126 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 69124 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
69086 69087 69088 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 69086 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
69091 69092 69093 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 69091 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::SecurityPolicy>
A list of SecurityPolicy resources.
Corresponds to the JSON property items
69096 69097 69098 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 69096 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#securityPolicyList
for listsof securityPolicies
Corresponds to the JSON property kind
69102 69103 69104 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 69102 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
69112 69113 69114 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 69112 def next_page_token @next_page_token end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
69117 69118 69119 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 69117 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::SecurityPolicyList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
69122 69123 69124 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 69122 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
69129 69130 69131 69132 69133 69134 69135 69136 69137 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 69129 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |