Class: Google::Apis::ComputeAlpha::SecurityPolicyList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SecurityPolicyList

Returns a new instance of SecurityPolicyList.



67698
67699
67700
# File 'lib/google/apis/compute_alpha/classes.rb', line 67698

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


67660
67661
67662
# File 'lib/google/apis/compute_alpha/classes.rb', line 67660

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


67665
67666
67667
# File 'lib/google/apis/compute_alpha/classes.rb', line 67665

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::SecurityPolicy>

A list of SecurityPolicy resources. Corresponds to the JSON property items



67670
67671
67672
# File 'lib/google/apis/compute_alpha/classes.rb', line 67670

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute#securityPolicyList for listsof securityPolicies Corresponds to the JSON property kind

Returns:

  • (String)


67676
67677
67678
# File 'lib/google/apis/compute_alpha/classes.rb', line 67676

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


67686
67687
67688
# File 'lib/google/apis/compute_alpha/classes.rb', line 67686

def next_page_token
  @next_page_token
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


67691
67692
67693
# File 'lib/google/apis/compute_alpha/classes.rb', line 67691

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::SecurityPolicyList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



67696
67697
67698
# File 'lib/google/apis/compute_alpha/classes.rb', line 67696

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



67703
67704
67705
67706
67707
67708
67709
67710
67711
# File 'lib/google/apis/compute_alpha/classes.rb', line 67703

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end