Class: Google::Apis::ComputeAlpha::SecurityPolicyList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::SecurityPolicyList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::SecurityPolicy>
A list of SecurityPolicy resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::SecurityPolicyList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SecurityPolicyList
constructor
A new instance of SecurityPolicyList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SecurityPolicyList
Returns a new instance of SecurityPolicyList.
67100 67101 67102 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 67100 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
67062 67063 67064 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 67062 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
67067 67068 67069 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 67067 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::SecurityPolicy>
A list of SecurityPolicy resources.
Corresponds to the JSON property items
67072 67073 67074 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 67072 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#securityPolicyList
for listsof securityPolicies
Corresponds to the JSON property kind
67078 67079 67080 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 67078 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
67088 67089 67090 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 67088 def next_page_token @next_page_token end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
67093 67094 67095 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 67093 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::SecurityPolicyList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
67098 67099 67100 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 67098 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
67105 67106 67107 67108 67109 67110 67111 67112 67113 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 67105 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |