Class: Google::Apis::ComputeAlpha::SecurityPolicyList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SecurityPolicyList

Returns a new instance of SecurityPolicyList.



67098
67099
67100
# File 'lib/google/apis/compute_alpha/classes.rb', line 67098

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


67060
67061
67062
# File 'lib/google/apis/compute_alpha/classes.rb', line 67060

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


67065
67066
67067
# File 'lib/google/apis/compute_alpha/classes.rb', line 67065

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::SecurityPolicy>

A list of SecurityPolicy resources. Corresponds to the JSON property items



67070
67071
67072
# File 'lib/google/apis/compute_alpha/classes.rb', line 67070

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute#securityPolicyList for listsof securityPolicies Corresponds to the JSON property kind

Returns:

  • (String)


67076
67077
67078
# File 'lib/google/apis/compute_alpha/classes.rb', line 67076

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


67086
67087
67088
# File 'lib/google/apis/compute_alpha/classes.rb', line 67086

def next_page_token
  @next_page_token
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


67091
67092
67093
# File 'lib/google/apis/compute_alpha/classes.rb', line 67091

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::SecurityPolicyList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



67096
67097
67098
# File 'lib/google/apis/compute_alpha/classes.rb', line 67096

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



67103
67104
67105
67106
67107
67108
67109
67110
67111
# File 'lib/google/apis/compute_alpha/classes.rb', line 67103

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end