Class: Google::Apis::ComputeAlpha::SecurityPolicyList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SecurityPolicyList

Returns a new instance of SecurityPolicyList.



65994
65995
65996
# File 'lib/google/apis/compute_alpha/classes.rb', line 65994

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


65956
65957
65958
# File 'lib/google/apis/compute_alpha/classes.rb', line 65956

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


65961
65962
65963
# File 'lib/google/apis/compute_alpha/classes.rb', line 65961

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::SecurityPolicy>

A list of SecurityPolicy resources. Corresponds to the JSON property items



65966
65967
65968
# File 'lib/google/apis/compute_alpha/classes.rb', line 65966

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute#securityPolicyList for listsof securityPolicies Corresponds to the JSON property kind

Returns:

  • (String)


65972
65973
65974
# File 'lib/google/apis/compute_alpha/classes.rb', line 65972

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


65982
65983
65984
# File 'lib/google/apis/compute_alpha/classes.rb', line 65982

def next_page_token
  @next_page_token
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


65987
65988
65989
# File 'lib/google/apis/compute_alpha/classes.rb', line 65987

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::SecurityPolicyList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



65992
65993
65994
# File 'lib/google/apis/compute_alpha/classes.rb', line 65992

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



65999
66000
66001
66002
66003
66004
66005
66006
66007
# File 'lib/google/apis/compute_alpha/classes.rb', line 65999

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end