Class: Google::Apis::ComputeAlpha::SecurityPolicyList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::SecurityPolicyList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::SecurityPolicy>
A list of SecurityPolicy resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::SecurityPolicyList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SecurityPolicyList
constructor
A new instance of SecurityPolicyList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SecurityPolicyList
Returns a new instance of SecurityPolicyList.
65994 65995 65996 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 65994 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
65956 65957 65958 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 65956 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
65961 65962 65963 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 65961 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::SecurityPolicy>
A list of SecurityPolicy resources.
Corresponds to the JSON property items
65966 65967 65968 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 65966 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#securityPolicyList
for listsof securityPolicies
Corresponds to the JSON property kind
65972 65973 65974 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 65972 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
65982 65983 65984 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 65982 def next_page_token @next_page_token end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
65987 65988 65989 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 65987 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::SecurityPolicyList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
65992 65993 65994 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 65992 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
65999 66000 66001 66002 66003 66004 66005 66006 66007 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 65999 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |