Class: Google::Apis::ComputeAlpha::SecurityPolicyRecaptchaOptionsConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SecurityPolicyRecaptchaOptionsConfig

Returns a new instance of SecurityPolicyRecaptchaOptionsConfig.



66095
66096
66097
# File 'lib/google/apis/compute_alpha/classes.rb', line 66095

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#redirect_site_keyString

An optional field to supply a reCAPTCHA site key to be used for all the rules using the redirect action with the type of GOOGLE_RECAPTCHA under the security policy. The specified site key needs to be created from the reCAPTCHA API. The user is responsible for the validity of the specified site key. If not specified, a Google-managed site key is used. This field is only supported in Global Security Policies of type CLOUD_ARMOR. Corresponds to the JSON property redirectSiteKey

Returns:

  • (String)


66093
66094
66095
# File 'lib/google/apis/compute_alpha/classes.rb', line 66093

def redirect_site_key
  @redirect_site_key
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



66100
66101
66102
# File 'lib/google/apis/compute_alpha/classes.rb', line 66100

def update!(**args)
  @redirect_site_key = args[:redirect_site_key] if args.key?(:redirect_site_key)
end