Class: Google::Apis::ComputeAlpha::SecurityPolicyRule
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::SecurityPolicyRule
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Represents a rule that describes one or more match conditions along with the action to be taken when traffic matches this condition (allow or deny).
Instance Attribute Summary collapse
-
#action ⇒ String
The Action to perform when the rule is matched.
-
#description ⇒ String
An optional description of this resource.
-
#direction ⇒ String
The direction in which this rule applies.
-
#enable_logging ⇒ Boolean
(also: #enable_logging?)
Denotes whether to enable logging for a particular rule.
-
#header_action ⇒ Google::Apis::ComputeAlpha::SecurityPolicyRuleHttpHeaderAction
Optional, additional actions that are performed on headers.
-
#kind ⇒ String
Output only.
-
#match ⇒ Google::Apis::ComputeAlpha::SecurityPolicyRuleMatcher
Represents a match condition that incoming traffic is evaluated against.
-
#network_match ⇒ Google::Apis::ComputeAlpha::SecurityPolicyRuleNetworkMatcher
Represents a match condition that incoming network traffic is evaluated against.
-
#preconfigured_waf_config ⇒ Google::Apis::ComputeAlpha::SecurityPolicyRulePreconfiguredWafConfig
Preconfigured WAF configuration to be applied for the rule.
-
#preview ⇒ Boolean
(also: #preview?)
If set to true, the specified action is not enforced.
-
#priority ⇒ Fixnum
An integer indicating the priority of a rule in the list.
-
#rate_limit_options ⇒ Google::Apis::ComputeAlpha::SecurityPolicyRuleRateLimitOptions
Must be specified if the action is "rate_based_ban" or "throttle" or "fairshare".
-
#redirect_options ⇒ Google::Apis::ComputeAlpha::SecurityPolicyRuleRedirectOptions
Parameters defining the redirect action.
-
#redirect_target ⇒ String
This must be specified for redirect actions.
-
#rule_managed_protection_tier ⇒ String
Output only.
-
#rule_number ⇒ Fixnum
Identifier for the rule.
-
#rule_tuple_count ⇒ Fixnum
Output only.
-
#target_resources ⇒ Array<String>
A list of network resource URLs to which this rule applies.
-
#target_service_accounts ⇒ Array<String>
A list of service accounts indicating the sets of instances that are applied with this rule.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SecurityPolicyRule
constructor
A new instance of SecurityPolicyRule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SecurityPolicyRule
Returns a new instance of SecurityPolicyRule.
66282 66283 66284 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 66282 def initialize(**args) update!(**args) end |
Instance Attribute Details
#action ⇒ String
The Action to perform when the rule is matched. The following are the valid actions:
- allow: allow access to target.
- deny(STATUS): deny access to target, returns the
HTTP response code specified. Valid values for
STATUSare 403, 404, and 502. - rate_based_ban: limit client traffic to the configured threshold and ban the client if the traffic exceeds the threshold. Configure parameters for this action in RateLimitOptions. Requires rate_limit_options to be set.
- redirect: redirect to a different target. This can either be an internal reCAPTCHA redirect, or an external URL-based redirect via a 302 response. Parameters for this action can be configured via redirectOptions. This action is only supported in Global Security Policies of type CLOUD_ARMOR.
- throttle: limit client traffic to the configured threshold. Configure parameters for this action in rateLimitOptions. Requires rate_limit_options to be set for this.
- fairshare (preview only): when traffic reaches the
threshold limit, requests from the clients matching this rule begin to be
rate-limited using the Fair Share algorithm. This action is only allowed
in security policies of type
CLOUD_ARMOR_INTERNAL_SERVICE. Corresponds to the JSON propertyaction
66155 66156 66157 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 66155 def action @action end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
66161 66162 66163 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 66161 def description @description end |
#direction ⇒ String
The direction in which this rule applies. This field may only be
specified when versioned_expr is set to FIREWALL.
Corresponds to the JSON property direction
66167 66168 66169 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 66167 def direction @direction end |
#enable_logging ⇒ Boolean Also known as: enable_logging?
Denotes whether to enable logging for a particular rule. If logging is
enabled, logs will be exported to the configured export destination in
Stackdriver. Logs may be exported to BigQuery or Pub/Sub. Note: you
cannot enable logging on "goto_next" rules.
This field may only be specified when the versioned_expr is set to
FIREWALL.
Corresponds to the JSON property enableLogging
66177 66178 66179 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 66177 def enable_logging @enable_logging end |
#header_action ⇒ Google::Apis::ComputeAlpha::SecurityPolicyRuleHttpHeaderAction
Optional, additional actions that are performed on headers.
This field is only supported in Global Security Policies of type
CLOUD_ARMOR.
Corresponds to the JSON property headerAction
66185 66186 66187 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 66185 def header_action @header_action end |
#kind ⇒ String
Output only. [Output only] Type of the resource. Alwayscompute#
securityPolicyRule for security policy rules
Corresponds to the JSON property kind
66191 66192 66193 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 66191 def kind @kind end |
#match ⇒ Google::Apis::ComputeAlpha::SecurityPolicyRuleMatcher
Represents a match condition that incoming traffic is evaluated against.
Exactly one field must be specified.
Corresponds to the JSON property match
66197 66198 66199 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 66197 def match @match end |
#network_match ⇒ Google::Apis::ComputeAlpha::SecurityPolicyRuleNetworkMatcher
Represents a match condition that incoming network traffic is evaluated
against.
Corresponds to the JSON property networkMatch
66203 66204 66205 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 66203 def network_match @network_match end |
#preconfigured_waf_config ⇒ Google::Apis::ComputeAlpha::SecurityPolicyRulePreconfiguredWafConfig
Preconfigured WAF configuration to be applied for the rule. If the rule
does not evaluate preconfigured WAF rules, i.e., if
evaluatePreconfiguredWaf() is not used, this field will have no effect.
Corresponds to the JSON property preconfiguredWafConfig
66210 66211 66212 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 66210 def preconfigured_waf_config @preconfigured_waf_config end |
#preview ⇒ Boolean Also known as: preview?
If set to true, the specified action is not enforced.
Corresponds to the JSON property preview
66215 66216 66217 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 66215 def preview @preview end |
#priority ⇒ Fixnum
An integer indicating the priority of a rule in the list. The priority
must be a positive value between 0 and 2147483647.
Rules are evaluated from highest to lowest priority where 0 is the
highest priority and 2147483647 is the lowest priority.
Corresponds to the JSON property priority
66224 66225 66226 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 66224 def priority @priority end |
#rate_limit_options ⇒ Google::Apis::ComputeAlpha::SecurityPolicyRuleRateLimitOptions
Must be specified if the action is "rate_based_ban" or "throttle" or
"fairshare". Cannot be specified for any other actions.
Corresponds to the JSON property rateLimitOptions
66230 66231 66232 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 66230 def @rate_limit_options end |
#redirect_options ⇒ Google::Apis::ComputeAlpha::SecurityPolicyRuleRedirectOptions
Parameters defining the redirect action. Cannot be specified for any
other actions.
This field is only supported in Global Security Policies of type
CLOUD_ARMOR.
Corresponds to the JSON property redirectOptions
66238 66239 66240 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 66238 def @redirect_options end |
#redirect_target ⇒ String
This must be specified for redirect actions. Cannot be specified for any
other actions.
Corresponds to the JSON property redirectTarget
66244 66245 66246 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 66244 def redirect_target @redirect_target end |
#rule_managed_protection_tier ⇒ String
Output only. [Output Only] The minimum Cloud Armor subscription required for
this
rule.
[Deprecated] Use requiredManagedProtectionTiers instead.
Corresponds to the JSON property ruleManagedProtectionTier
66252 66253 66254 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 66252 def rule_managed_protection_tier @rule_managed_protection_tier end |
#rule_number ⇒ Fixnum
Identifier for the rule. This is only unique within the given security
policy. This can only be set during rule creation, if rule number is not
specified it will be generated by the server.
Corresponds to the JSON property ruleNumber
66259 66260 66261 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 66259 def rule_number @rule_number end |
#rule_tuple_count ⇒ Fixnum
Output only. [Output Only] Calculation of the complexity of a single firewall
security
policy rule.
Corresponds to the JSON property ruleTupleCount
66266 66267 66268 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 66266 def rule_tuple_count @rule_tuple_count end |
#target_resources ⇒ Array<String>
A list of network resource URLs to which this rule applies. This field
allows you to control which network's VMs get this rule. If this field
is left blank, all VMs within the organization will receive the rule.
This field may only be specified when versioned_expr is set to FIREWALL.
Corresponds to the JSON property targetResources
66274 66275 66276 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 66274 def target_resources @target_resources end |
#target_service_accounts ⇒ Array<String>
A list of service accounts indicating the sets of instances that are
applied with this rule.
Corresponds to the JSON property targetServiceAccounts
66280 66281 66282 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 66280 def target_service_accounts @target_service_accounts end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
66287 66288 66289 66290 66291 66292 66293 66294 66295 66296 66297 66298 66299 66300 66301 66302 66303 66304 66305 66306 66307 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 66287 def update!(**args) @action = args[:action] if args.key?(:action) @description = args[:description] if args.key?(:description) @direction = args[:direction] if args.key?(:direction) @enable_logging = args[:enable_logging] if args.key?(:enable_logging) @header_action = args[:header_action] if args.key?(:header_action) @kind = args[:kind] if args.key?(:kind) @match = args[:match] if args.key?(:match) @network_match = args[:network_match] if args.key?(:network_match) @preconfigured_waf_config = args[:preconfigured_waf_config] if args.key?(:preconfigured_waf_config) @preview = args[:preview] if args.key?(:preview) @priority = args[:priority] if args.key?(:priority) @rate_limit_options = args[:rate_limit_options] if args.key?(:rate_limit_options) @redirect_options = args[:redirect_options] if args.key?(:redirect_options) @redirect_target = args[:redirect_target] if args.key?(:redirect_target) @rule_managed_protection_tier = args[:rule_managed_protection_tier] if args.key?(:rule_managed_protection_tier) @rule_number = args[:rule_number] if args.key?(:rule_number) @rule_tuple_count = args[:rule_tuple_count] if args.key?(:rule_tuple_count) @target_resources = args[:target_resources] if args.key?(:target_resources) @target_service_accounts = args[:target_service_accounts] if args.key?(:target_service_accounts) end |