Class: Google::Apis::ComputeAlpha::SecurityPolicyRuleMatcherConfig
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::SecurityPolicyRuleMatcherConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#dest_ip_ranges ⇒ Array<String>
CIDR IP address range.
-
#dest_ports ⇒ Array<Google::Apis::ComputeAlpha::SecurityPolicyRuleMatcherConfigDestinationPort>
Pairs of IP protocols and ports that the rule should match.
-
#layer4_configs ⇒ Array<Google::Apis::ComputeAlpha::SecurityPolicyRuleMatcherConfigLayer4Config>
Pairs of IP protocols and ports that the rule should match.
-
#src_ip_ranges ⇒ Array<String>
CIDR IP address range.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SecurityPolicyRuleMatcherConfig
constructor
A new instance of SecurityPolicyRuleMatcherConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SecurityPolicyRuleMatcherConfig
Returns a new instance of SecurityPolicyRuleMatcherConfig.
69884 69885 69886 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 69884 def initialize(**args) update!(**args) end |
Instance Attribute Details
#dest_ip_ranges ⇒ Array<String>
CIDR IP address range.
This field may only be specified when versioned_expr is set to
FIREWALL.
Corresponds to the JSON property destIpRanges
69862 69863 69864 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 69862 def dest_ip_ranges @dest_ip_ranges end |
#dest_ports ⇒ Array<Google::Apis::ComputeAlpha::SecurityPolicyRuleMatcherConfigDestinationPort>
Pairs of IP protocols and ports that the rule should match.
This field may only be specified when versioned_expr is set to
FIREWALL.
Corresponds to the JSON property destPorts
69869 69870 69871 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 69869 def dest_ports @dest_ports end |
#layer4_configs ⇒ Array<Google::Apis::ComputeAlpha::SecurityPolicyRuleMatcherConfigLayer4Config>
Pairs of IP protocols and ports that the rule should match.
This field may only be specified when versioned_expr is set to
FIREWALL.
Corresponds to the JSON property layer4Configs
69876 69877 69878 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 69876 def layer4_configs @layer4_configs end |
#src_ip_ranges ⇒ Array<String>
CIDR IP address range.
Maximum number of src_ip_ranges allowed is 10.
Corresponds to the JSON property srcIpRanges
69882 69883 69884 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 69882 def src_ip_ranges @src_ip_ranges end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
69889 69890 69891 69892 69893 69894 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 69889 def update!(**args) @dest_ip_ranges = args[:dest_ip_ranges] if args.key?(:dest_ip_ranges) @dest_ports = args[:dest_ports] if args.key?(:dest_ports) @layer4_configs = args[:layer4_configs] if args.key?(:layer4_configs) @src_ip_ranges = args[:src_ip_ranges] if args.key?(:src_ip_ranges) end |