Class: Google::Apis::ComputeAlpha::SecurityPolicyRuleMatcherConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SecurityPolicyRuleMatcherConfig

Returns a new instance of SecurityPolicyRuleMatcherConfig.



68213
68214
68215
# File 'lib/google/apis/compute_alpha/classes.rb', line 68213

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dest_ip_rangesArray<String>

CIDR IP address range. This field may only be specified when versioned_expr is set to FIREWALL. Corresponds to the JSON property destIpRanges

Returns:

  • (Array<String>)


68191
68192
68193
# File 'lib/google/apis/compute_alpha/classes.rb', line 68191

def dest_ip_ranges
  @dest_ip_ranges
end

#dest_portsArray<Google::Apis::ComputeAlpha::SecurityPolicyRuleMatcherConfigDestinationPort>

Pairs of IP protocols and ports that the rule should match. This field may only be specified when versioned_expr is set to FIREWALL. Corresponds to the JSON property destPorts



68198
68199
68200
# File 'lib/google/apis/compute_alpha/classes.rb', line 68198

def dest_ports
  @dest_ports
end

#layer4_configsArray<Google::Apis::ComputeAlpha::SecurityPolicyRuleMatcherConfigLayer4Config>

Pairs of IP protocols and ports that the rule should match. This field may only be specified when versioned_expr is set to FIREWALL. Corresponds to the JSON property layer4Configs



68205
68206
68207
# File 'lib/google/apis/compute_alpha/classes.rb', line 68205

def layer4_configs
  @layer4_configs
end

#src_ip_rangesArray<String>

CIDR IP address range. Maximum number of src_ip_ranges allowed is 10. Corresponds to the JSON property srcIpRanges

Returns:

  • (Array<String>)


68211
68212
68213
# File 'lib/google/apis/compute_alpha/classes.rb', line 68211

def src_ip_ranges
  @src_ip_ranges
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



68218
68219
68220
68221
68222
68223
# File 'lib/google/apis/compute_alpha/classes.rb', line 68218

def update!(**args)
  @dest_ip_ranges = args[:dest_ip_ranges] if args.key?(:dest_ip_ranges)
  @dest_ports = args[:dest_ports] if args.key?(:dest_ports)
  @layer4_configs = args[:layer4_configs] if args.key?(:layer4_configs)
  @src_ip_ranges = args[:src_ip_ranges] if args.key?(:src_ip_ranges)
end