Class: Google::Apis::ComputeAlpha::SecurityPolicyRuleMatcherConfig
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::SecurityPolicyRuleMatcherConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#dest_ip_ranges ⇒ Array<String>
CIDR IP address range.
-
#dest_ports ⇒ Array<Google::Apis::ComputeAlpha::SecurityPolicyRuleMatcherConfigDestinationPort>
Pairs of IP protocols and ports that the rule should match.
-
#layer4_configs ⇒ Array<Google::Apis::ComputeAlpha::SecurityPolicyRuleMatcherConfigLayer4Config>
Pairs of IP protocols and ports that the rule should match.
-
#src_ip_ranges ⇒ Array<String>
CIDR IP address range.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SecurityPolicyRuleMatcherConfig
constructor
A new instance of SecurityPolicyRuleMatcherConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SecurityPolicyRuleMatcherConfig
Returns a new instance of SecurityPolicyRuleMatcherConfig.
66452 66453 66454 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 66452 def initialize(**args) update!(**args) end |
Instance Attribute Details
#dest_ip_ranges ⇒ Array<String>
CIDR IP address range.
This field may only be specified when versioned_expr is set to
FIREWALL.
Corresponds to the JSON property destIpRanges
66430 66431 66432 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 66430 def dest_ip_ranges @dest_ip_ranges end |
#dest_ports ⇒ Array<Google::Apis::ComputeAlpha::SecurityPolicyRuleMatcherConfigDestinationPort>
Pairs of IP protocols and ports that the rule should match.
This field may only be specified when versioned_expr is set to
FIREWALL.
Corresponds to the JSON property destPorts
66437 66438 66439 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 66437 def dest_ports @dest_ports end |
#layer4_configs ⇒ Array<Google::Apis::ComputeAlpha::SecurityPolicyRuleMatcherConfigLayer4Config>
Pairs of IP protocols and ports that the rule should match.
This field may only be specified when versioned_expr is set to
FIREWALL.
Corresponds to the JSON property layer4Configs
66444 66445 66446 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 66444 def layer4_configs @layer4_configs end |
#src_ip_ranges ⇒ Array<String>
CIDR IP address range.
Maximum number of src_ip_ranges allowed is 10.
Corresponds to the JSON property srcIpRanges
66450 66451 66452 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 66450 def src_ip_ranges @src_ip_ranges end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
66457 66458 66459 66460 66461 66462 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 66457 def update!(**args) @dest_ip_ranges = args[:dest_ip_ranges] if args.key?(:dest_ip_ranges) @dest_ports = args[:dest_ports] if args.key?(:dest_ports) @layer4_configs = args[:layer4_configs] if args.key?(:layer4_configs) @src_ip_ranges = args[:src_ip_ranges] if args.key?(:src_ip_ranges) end |