Class: Google::Apis::ComputeAlpha::SecurityPolicyRuleMatcherConfigDestinationPort
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::SecurityPolicyRuleMatcherConfigDestinationPort
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#ip_protocol ⇒ String
The IP protocol to which this rule applies.
-
#ports ⇒ Array<String>
An optional list of ports to which this rule applies.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SecurityPolicyRuleMatcherConfigDestinationPort
constructor
A new instance of SecurityPolicyRuleMatcherConfigDestinationPort.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SecurityPolicyRuleMatcherConfigDestinationPort
Returns a new instance of SecurityPolicyRuleMatcherConfigDestinationPort.
67595 67596 67597 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 67595 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ip_protocol ⇒ String
The IP protocol to which this rule applies. The protocol type is
required when creating a firewall rule. This value can either be
one of the following well known protocol strings (tcp,udp, icmp, esp,ah, ipip,
sctp), or the IP
protocol number.
Corresponds to the JSON property ipProtocol
67582 67583 67584 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 67582 def ip_protocol @ip_protocol end |
#ports ⇒ Array<String>
An optional list of ports to which this rule applies. This field is
only applicable for UDP or TCP protocol. Each entry must be either
an integer or a range. If not specified, this rule applies to
connections through any port.
Example inputs include: ["22"],["80","443"], and ["12345-12349"].
This field may only be specified when versioned_expr is set to
FIREWALL.
Corresponds to the JSON property ports
67593 67594 67595 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 67593 def ports @ports end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
67600 67601 67602 67603 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 67600 def update!(**args) @ip_protocol = args[:ip_protocol] if args.key?(:ip_protocol) @ports = args[:ports] if args.key?(:ports) end |