Class: Google::Apis::ComputeAlpha::SecurityPolicyRuleMatcherConfigLayer4Config

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SecurityPolicyRuleMatcherConfigLayer4Config

Returns a new instance of SecurityPolicyRuleMatcherConfigLayer4Config.



67630
67631
67632
# File 'lib/google/apis/compute_alpha/classes.rb', line 67630

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ip_protocolString

The IP protocol to which this rule applies. The protocol type is required when creating a firewall rule. This value can either be one of the following well known protocol strings (tcp,udp, icmp, esp,ah, ipip, sctp), or the IP protocol number. Corresponds to the JSON property ipProtocol

Returns:

  • (String)


67617
67618
67619
# File 'lib/google/apis/compute_alpha/classes.rb', line 67617

def ip_protocol
  @ip_protocol
end

#portsArray<String>

An optional list of ports to which this rule applies. This field is only applicable for UDP or TCP protocol. Each entry must be either an integer or a range. If not specified, this rule applies to connections through any port. Example inputs include: ["22"],["80","443"], and ["12345-12349"]. This field may only be specified when versioned_expr is set to FIREWALL. Corresponds to the JSON property ports

Returns:

  • (Array<String>)


67628
67629
67630
# File 'lib/google/apis/compute_alpha/classes.rb', line 67628

def ports
  @ports
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



67635
67636
67637
67638
# File 'lib/google/apis/compute_alpha/classes.rb', line 67635

def update!(**args)
  @ip_protocol = args[:ip_protocol] if args.key?(:ip_protocol)
  @ports = args[:ports] if args.key?(:ports)
end