Class: Google::Apis::ComputeAlpha::SecurityPolicyRuleMatcherExprOptions
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::SecurityPolicyRuleMatcherExprOptions
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#recaptcha_options ⇒ Google::Apis::ComputeAlpha::SecurityPolicyRuleMatcherExprOptionsRecaptchaOptions
reCAPTCHA configuration options to be applied for the rule.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SecurityPolicyRuleMatcherExprOptions
constructor
A new instance of SecurityPolicyRuleMatcherExprOptions.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SecurityPolicyRuleMatcherExprOptions
Returns a new instance of SecurityPolicyRuleMatcherExprOptions.
69675 69676 69677 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 69675 def initialize(**args) update!(**args) end |
Instance Attribute Details
#recaptcha_options ⇒ Google::Apis::ComputeAlpha::SecurityPolicyRuleMatcherExprOptionsRecaptchaOptions
reCAPTCHA configuration options to be applied for the rule. If the
rule does not evaluate reCAPTCHA tokens, this field has no effect.
Corresponds to the JSON property recaptchaOptions
69673 69674 69675 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 69673 def @recaptcha_options end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
69680 69681 69682 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 69680 def update!(**args) @recaptcha_options = args[:recaptcha_options] if args.key?(:recaptcha_options) end |