Class: Google::Apis::ComputeAlpha::SecurityPolicyRuleMatcherExprOptionsRecaptchaOptions
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::SecurityPolicyRuleMatcherExprOptionsRecaptchaOptions
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#action_token_site_keys ⇒ Array<String>
A list of site keys to be used during the validation of reCAPTCHA action-tokens.
-
#session_token_site_keys ⇒ Array<String>
A list of site keys to be used during the validation of reCAPTCHA session-tokens.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SecurityPolicyRuleMatcherExprOptionsRecaptchaOptions
constructor
A new instance of SecurityPolicyRuleMatcherExprOptionsRecaptchaOptions.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SecurityPolicyRuleMatcherExprOptionsRecaptchaOptions
Returns a new instance of SecurityPolicyRuleMatcherExprOptionsRecaptchaOptions.
67458 67459 67460 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 67458 def initialize(**args) update!(**args) end |
Instance Attribute Details
#action_token_site_keys ⇒ Array<String>
A list of site keys to be used during the validation of reCAPTCHA
action-tokens. The provided site keys need to be created from
reCAPTCHA API under the same project where the security policy is
created.
Corresponds to the JSON property actionTokenSiteKeys
67448 67449 67450 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 67448 def action_token_site_keys @action_token_site_keys end |
#session_token_site_keys ⇒ Array<String>
A list of site keys to be used during the validation of reCAPTCHA
session-tokens. The provided site keys need to be created from
reCAPTCHA API under the same project where the security policy is
created.
Corresponds to the JSON property sessionTokenSiteKeys
67456 67457 67458 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 67456 def session_token_site_keys @session_token_site_keys end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
67463 67464 67465 67466 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 67463 def update!(**args) @action_token_site_keys = args[:action_token_site_keys] if args.key?(:action_token_site_keys) @session_token_site_keys = args[:session_token_site_keys] if args.key?(:session_token_site_keys) end |