Class: Google::Apis::ComputeAlpha::SecurityPolicyRuleNetworkMatcher
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::SecurityPolicyRuleNetworkMatcher
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Represents a match condition that incoming network traffic is evaluated against.
Instance Attribute Summary collapse
-
#dest_ip_ranges ⇒ Array<String>
Destination IPv4/IPv6 addresses or CIDR prefixes, in standard text format.
-
#dest_ports ⇒ Array<String>
Destination port numbers for TCP/UDP/SCTP.
-
#ip_protocols ⇒ Array<String>
IPv4 protocol / IPv6 next header (after extension headers).
-
#src_asns ⇒ Array<Fixnum>
BGP Autonomous System Number associated with the source IP address.
-
#src_ip_ranges ⇒ Array<String>
Source IPv4/IPv6 addresses or CIDR prefixes, in standard text format.
-
#src_ports ⇒ Array<String>
Source port numbers for TCP/UDP/SCTP.
-
#src_region_codes ⇒ Array<String>
Two-letter ISO 3166-1 alpha-2 country code associated with the source IP address.
-
#user_defined_fields ⇒ Array<Google::Apis::ComputeAlpha::SecurityPolicyRuleNetworkMatcherUserDefinedFieldMatch>
User-defined fields.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SecurityPolicyRuleNetworkMatcher
constructor
A new instance of SecurityPolicyRuleNetworkMatcher.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SecurityPolicyRuleNetworkMatcher
Returns a new instance of SecurityPolicyRuleNetworkMatcher.
67522 67523 67524 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 67522 def initialize(**args) update!(**args) end |
Instance Attribute Details
#dest_ip_ranges ⇒ Array<String>
Destination IPv4/IPv6 addresses or CIDR prefixes, in standard text
format.
Corresponds to the JSON property destIpRanges
67478 67479 67480 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 67478 def dest_ip_ranges @dest_ip_ranges end |
#dest_ports ⇒ Array<String>
Destination port numbers for TCP/UDP/SCTP. Each element can be a 16-bit
unsigned decimal number (e.g. "80") or range (e.g. "0-1023").
Corresponds to the JSON property destPorts
67484 67485 67486 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 67484 def dest_ports @dest_ports end |
#ip_protocols ⇒ Array<String>
IPv4 protocol / IPv6 next header (after extension headers). Each
element can be an 8-bit unsigned decimal number (e.g. "6"), range (e.g.
"253-254"), or one of the following protocol names: "tcp", "udp",
"icmp", "esp", "ah", "ipip", or "sctp".
Corresponds to the JSON property ipProtocols
67492 67493 67494 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 67492 def ip_protocols @ip_protocols end |
#src_asns ⇒ Array<Fixnum>
BGP Autonomous System Number associated with the source IP address.
Corresponds to the JSON property srcAsns
67497 67498 67499 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 67497 def src_asns @src_asns end |
#src_ip_ranges ⇒ Array<String>
Source IPv4/IPv6 addresses or CIDR prefixes, in standard text format.
Corresponds to the JSON property srcIpRanges
67502 67503 67504 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 67502 def src_ip_ranges @src_ip_ranges end |
#src_ports ⇒ Array<String>
Source port numbers for TCP/UDP/SCTP. Each element can be a 16-bit
unsigned decimal number (e.g. "80") or range (e.g. "0-1023").
Corresponds to the JSON property srcPorts
67508 67509 67510 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 67508 def src_ports @src_ports end |
#src_region_codes ⇒ Array<String>
Two-letter ISO 3166-1 alpha-2 country code associated with the source
IP address.
Corresponds to the JSON property srcRegionCodes
67514 67515 67516 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 67514 def src_region_codes @src_region_codes end |
#user_defined_fields ⇒ Array<Google::Apis::ComputeAlpha::SecurityPolicyRuleNetworkMatcherUserDefinedFieldMatch>
User-defined fields. Each element names a defined field and lists the
matching values for that field.
Corresponds to the JSON property userDefinedFields
67520 67521 67522 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 67520 def user_defined_fields @user_defined_fields end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
67527 67528 67529 67530 67531 67532 67533 67534 67535 67536 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 67527 def update!(**args) @dest_ip_ranges = args[:dest_ip_ranges] if args.key?(:dest_ip_ranges) @dest_ports = args[:dest_ports] if args.key?(:dest_ports) @ip_protocols = args[:ip_protocols] if args.key?(:ip_protocols) @src_asns = args[:src_asns] if args.key?(:src_asns) @src_ip_ranges = args[:src_ip_ranges] if args.key?(:src_ip_ranges) @src_ports = args[:src_ports] if args.key?(:src_ports) @src_region_codes = args[:src_region_codes] if args.key?(:src_region_codes) @user_defined_fields = args[:user_defined_fields] if args.key?(:user_defined_fields) end |