Class: Google::Apis::ComputeAlpha::SecurityPolicyRulePreconfiguredWafConfigExclusion
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::SecurityPolicyRulePreconfiguredWafConfigExclusion
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#request_bodies_to_exclude ⇒ Array<Google::Apis::ComputeAlpha::SecurityPolicyRulePreconfiguredWafConfigExclusionFieldParams>
A list of request body fields to be excluded from inspection during preconfigured WAF evaluation.
-
#request_cookies_to_exclude ⇒ Array<Google::Apis::ComputeAlpha::SecurityPolicyRulePreconfiguredWafConfigExclusionFieldParams>
A list of request cookie names whose value will be excluded from inspection during preconfigured WAF evaluation.
-
#request_headers_to_exclude ⇒ Array<Google::Apis::ComputeAlpha::SecurityPolicyRulePreconfiguredWafConfigExclusionFieldParams>
A list of request header names whose value will be excluded from inspection during preconfigured WAF evaluation.
-
#request_query_params_to_exclude ⇒ Array<Google::Apis::ComputeAlpha::SecurityPolicyRulePreconfiguredWafConfigExclusionFieldParams>
A list of request query parameter names whose value will be excluded from inspection during preconfigured WAF evaluation.
-
#request_uris_to_exclude ⇒ Array<Google::Apis::ComputeAlpha::SecurityPolicyRulePreconfiguredWafConfigExclusionFieldParams>
A list of request URIs from the request line to be excluded from inspection during preconfigured WAF evaluation.
-
#target_rule_ids ⇒ Array<String>
A list of target rule IDs under the WAF rule set to apply the preconfigured WAF exclusion.
-
#target_rule_set ⇒ String
Target WAF rule set to apply the preconfigured WAF exclusion.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SecurityPolicyRulePreconfiguredWafConfigExclusion
constructor
A new instance of SecurityPolicyRulePreconfiguredWafConfigExclusion.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SecurityPolicyRulePreconfiguredWafConfigExclusion
Returns a new instance of SecurityPolicyRulePreconfiguredWafConfigExclusion.
68454 68455 68456 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 68454 def initialize(**args) update!(**args) end |
Instance Attribute Details
#request_bodies_to_exclude ⇒ Array<Google::Apis::ComputeAlpha::SecurityPolicyRulePreconfiguredWafConfigExclusionFieldParams>
A list of request body fields to be excluded from inspection during
preconfigured WAF evaluation.
Corresponds to the JSON property requestBodiesToExclude
68414 68415 68416 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 68414 def request_bodies_to_exclude @request_bodies_to_exclude end |
#request_cookies_to_exclude ⇒ Array<Google::Apis::ComputeAlpha::SecurityPolicyRulePreconfiguredWafConfigExclusionFieldParams>
A list of request cookie names whose value will be excluded from
inspection during preconfigured WAF evaluation.
Corresponds to the JSON property requestCookiesToExclude
68420 68421 68422 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 68420 def @request_cookies_to_exclude end |
#request_headers_to_exclude ⇒ Array<Google::Apis::ComputeAlpha::SecurityPolicyRulePreconfiguredWafConfigExclusionFieldParams>
A list of request header names whose value will be excluded from
inspection during preconfigured WAF evaluation.
Corresponds to the JSON property requestHeadersToExclude
68426 68427 68428 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 68426 def request_headers_to_exclude @request_headers_to_exclude end |
#request_query_params_to_exclude ⇒ Array<Google::Apis::ComputeAlpha::SecurityPolicyRulePreconfiguredWafConfigExclusionFieldParams>
A list of request query parameter names whose value will be excluded
from inspection during preconfigured WAF evaluation. Note that the
parameter can be in the query string or in the POST body.
Corresponds to the JSON property requestQueryParamsToExclude
68433 68434 68435 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 68433 def request_query_params_to_exclude @request_query_params_to_exclude end |
#request_uris_to_exclude ⇒ Array<Google::Apis::ComputeAlpha::SecurityPolicyRulePreconfiguredWafConfigExclusionFieldParams>
A list of request URIs from the request line to be excluded from
inspection during preconfigured WAF evaluation. When specifying this
field, the query or fragment part should be excluded.
Corresponds to the JSON property requestUrisToExclude
68440 68441 68442 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 68440 def request_uris_to_exclude @request_uris_to_exclude end |
#target_rule_ids ⇒ Array<String>
A list of target rule IDs under the WAF rule set to apply the
preconfigured WAF exclusion. If omitted, it refers to all the rule
IDs under the WAF rule set.
Corresponds to the JSON property targetRuleIds
68447 68448 68449 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 68447 def target_rule_ids @target_rule_ids end |
#target_rule_set ⇒ String
Target WAF rule set to apply the preconfigured WAF exclusion.
Corresponds to the JSON property targetRuleSet
68452 68453 68454 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 68452 def target_rule_set @target_rule_set end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
68459 68460 68461 68462 68463 68464 68465 68466 68467 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 68459 def update!(**args) @request_bodies_to_exclude = args[:request_bodies_to_exclude] if args.key?(:request_bodies_to_exclude) @request_cookies_to_exclude = args[:request_cookies_to_exclude] if args.key?(:request_cookies_to_exclude) @request_headers_to_exclude = args[:request_headers_to_exclude] if args.key?(:request_headers_to_exclude) @request_query_params_to_exclude = args[:request_query_params_to_exclude] if args.key?(:request_query_params_to_exclude) @request_uris_to_exclude = args[:request_uris_to_exclude] if args.key?(:request_uris_to_exclude) @target_rule_ids = args[:target_rule_ids] if args.key?(:target_rule_ids) @target_rule_set = args[:target_rule_set] if args.key?(:target_rule_set) end |