Class: Google::Apis::ComputeAlpha::SecurityPolicyRulePreconfiguredWafConfigExclusion
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::SecurityPolicyRulePreconfiguredWafConfigExclusion
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#request_bodies_to_exclude ⇒ Array<Google::Apis::ComputeAlpha::SecurityPolicyRulePreconfiguredWafConfigExclusionFieldParams>
A list of request body fields to be excluded from inspection during preconfigured WAF evaluation.
-
#request_cookies_to_exclude ⇒ Array<Google::Apis::ComputeAlpha::SecurityPolicyRulePreconfiguredWafConfigExclusionFieldParams>
A list of request cookie names whose value will be excluded from inspection during preconfigured WAF evaluation.
-
#request_headers_to_exclude ⇒ Array<Google::Apis::ComputeAlpha::SecurityPolicyRulePreconfiguredWafConfigExclusionFieldParams>
A list of request header names whose value will be excluded from inspection during preconfigured WAF evaluation.
-
#request_query_params_to_exclude ⇒ Array<Google::Apis::ComputeAlpha::SecurityPolicyRulePreconfiguredWafConfigExclusionFieldParams>
A list of request query parameter names whose value will be excluded from inspection during preconfigured WAF evaluation.
-
#request_uris_to_exclude ⇒ Array<Google::Apis::ComputeAlpha::SecurityPolicyRulePreconfiguredWafConfigExclusionFieldParams>
A list of request URIs from the request line to be excluded from inspection during preconfigured WAF evaluation.
-
#target_rule_ids ⇒ Array<String>
A list of target rule IDs under the WAF rule set to apply the preconfigured WAF exclusion.
-
#target_rule_set ⇒ String
Target WAF rule set to apply the preconfigured WAF exclusion.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SecurityPolicyRulePreconfiguredWafConfigExclusion
constructor
A new instance of SecurityPolicyRulePreconfiguredWafConfigExclusion.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SecurityPolicyRulePreconfiguredWafConfigExclusion
Returns a new instance of SecurityPolicyRulePreconfiguredWafConfigExclusion.
66750 66751 66752 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 66750 def initialize(**args) update!(**args) end |
Instance Attribute Details
#request_bodies_to_exclude ⇒ Array<Google::Apis::ComputeAlpha::SecurityPolicyRulePreconfiguredWafConfigExclusionFieldParams>
A list of request body fields to be excluded from inspection during
preconfigured WAF evaluation.
Corresponds to the JSON property requestBodiesToExclude
66710 66711 66712 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 66710 def request_bodies_to_exclude @request_bodies_to_exclude end |
#request_cookies_to_exclude ⇒ Array<Google::Apis::ComputeAlpha::SecurityPolicyRulePreconfiguredWafConfigExclusionFieldParams>
A list of request cookie names whose value will be excluded from
inspection during preconfigured WAF evaluation.
Corresponds to the JSON property requestCookiesToExclude
66716 66717 66718 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 66716 def @request_cookies_to_exclude end |
#request_headers_to_exclude ⇒ Array<Google::Apis::ComputeAlpha::SecurityPolicyRulePreconfiguredWafConfigExclusionFieldParams>
A list of request header names whose value will be excluded from
inspection during preconfigured WAF evaluation.
Corresponds to the JSON property requestHeadersToExclude
66722 66723 66724 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 66722 def request_headers_to_exclude @request_headers_to_exclude end |
#request_query_params_to_exclude ⇒ Array<Google::Apis::ComputeAlpha::SecurityPolicyRulePreconfiguredWafConfigExclusionFieldParams>
A list of request query parameter names whose value will be excluded
from inspection during preconfigured WAF evaluation. Note that the
parameter can be in the query string or in the POST body.
Corresponds to the JSON property requestQueryParamsToExclude
66729 66730 66731 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 66729 def request_query_params_to_exclude @request_query_params_to_exclude end |
#request_uris_to_exclude ⇒ Array<Google::Apis::ComputeAlpha::SecurityPolicyRulePreconfiguredWafConfigExclusionFieldParams>
A list of request URIs from the request line to be excluded from
inspection during preconfigured WAF evaluation. When specifying this
field, the query or fragment part should be excluded.
Corresponds to the JSON property requestUrisToExclude
66736 66737 66738 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 66736 def request_uris_to_exclude @request_uris_to_exclude end |
#target_rule_ids ⇒ Array<String>
A list of target rule IDs under the WAF rule set to apply the
preconfigured WAF exclusion. If omitted, it refers to all the rule
IDs under the WAF rule set.
Corresponds to the JSON property targetRuleIds
66743 66744 66745 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 66743 def target_rule_ids @target_rule_ids end |
#target_rule_set ⇒ String
Target WAF rule set to apply the preconfigured WAF exclusion.
Corresponds to the JSON property targetRuleSet
66748 66749 66750 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 66748 def target_rule_set @target_rule_set end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
66755 66756 66757 66758 66759 66760 66761 66762 66763 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 66755 def update!(**args) @request_bodies_to_exclude = args[:request_bodies_to_exclude] if args.key?(:request_bodies_to_exclude) @request_cookies_to_exclude = args[:request_cookies_to_exclude] if args.key?(:request_cookies_to_exclude) @request_headers_to_exclude = args[:request_headers_to_exclude] if args.key?(:request_headers_to_exclude) @request_query_params_to_exclude = args[:request_query_params_to_exclude] if args.key?(:request_query_params_to_exclude) @request_uris_to_exclude = args[:request_uris_to_exclude] if args.key?(:request_uris_to_exclude) @target_rule_ids = args[:target_rule_ids] if args.key?(:target_rule_ids) @target_rule_set = args[:target_rule_set] if args.key?(:target_rule_set) end |