Class: Google::Apis::ComputeAlpha::SecurityPolicyUserDefinedField
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::SecurityPolicyUserDefinedField
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#base ⇒ String
The base relative to which 'offset' is measured.
-
#mask ⇒ String
If specified, apply this mask (bitwise AND) to the field to ignore bits before matching.
-
#name ⇒ String
The name of this field.
-
#offset ⇒ Fixnum
Offset of the first byte of the field (in network byte order) relative to 'base'.
-
#size ⇒ Fixnum
Size of the field in bytes.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SecurityPolicyUserDefinedField
constructor
A new instance of SecurityPolicyUserDefinedField.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SecurityPolicyUserDefinedField
Returns a new instance of SecurityPolicyUserDefinedField.
68825 68826 68827 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 68825 def initialize(**args) update!(**args) end |
Instance Attribute Details
#base ⇒ String
The base relative to which 'offset' is measured. Possible values are:
- IPV4: Points to the beginning of the IPv4 header.
- IPV6: Points to the beginning of the IPv6 header.
- TCP: Points to the beginning of the TCP header, skipping over any IPv4 options or IPv6 extension headers. Not present for non-first fragments.
- UDP: Points to the beginning of the UDP header, skipping
over any IPv4 options or IPv6 extension headers. Not present for
non-first fragments.
required
Corresponds to the JSON property
base
68799 68800 68801 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 68799 def base @base end |
#mask ⇒ String
If specified, apply this mask (bitwise AND) to the field to ignore bits
before matching. Encoded as a hexadecimal number (starting with "0x").
The last byte of the field (in network byte order) corresponds to the
least significant byte of the mask.
Corresponds to the JSON property mask
68807 68808 68809 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 68807 def mask @mask end |
#name ⇒ String
The name of this field. Must be unique within the policy.
Corresponds to the JSON property name
68812 68813 68814 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 68812 def name @name end |
#offset ⇒ Fixnum
Offset of the first byte of the field (in network byte order) relative to
'base'.
Corresponds to the JSON property offset
68818 68819 68820 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 68818 def offset @offset end |
#size ⇒ Fixnum
Size of the field in bytes. Valid values: 1-4.
Corresponds to the JSON property size
68823 68824 68825 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 68823 def size @size end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
68830 68831 68832 68833 68834 68835 68836 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 68830 def update!(**args) @base = args[:base] if args.key?(:base) @mask = args[:mask] if args.key?(:mask) @name = args[:name] if args.key?(:name) @offset = args[:offset] if args.key?(:offset) @size = args[:size] if args.key?(:size) end |