Class: Google::Apis::ComputeAlpha::SecurityPolicyUserDefinedField
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::SecurityPolicyUserDefinedField
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#base ⇒ String
The base relative to which 'offset' is measured.
-
#mask ⇒ String
If specified, apply this mask (bitwise AND) to the field to ignore bits before matching.
-
#name ⇒ String
The name of this field.
-
#offset ⇒ Fixnum
Offset of the first byte of the field (in network byte order) relative to 'base'.
-
#size ⇒ Fixnum
Size of the field in bytes.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SecurityPolicyUserDefinedField
constructor
A new instance of SecurityPolicyUserDefinedField.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SecurityPolicyUserDefinedField
Returns a new instance of SecurityPolicyUserDefinedField.
67121 67122 67123 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 67121 def initialize(**args) update!(**args) end |
Instance Attribute Details
#base ⇒ String
The base relative to which 'offset' is measured. Possible values are:
- IPV4: Points to the beginning of the IPv4 header.
- IPV6: Points to the beginning of the IPv6 header.
- TCP: Points to the beginning of the TCP header, skipping over any IPv4 options or IPv6 extension headers. Not present for non-first fragments.
- UDP: Points to the beginning of the UDP header, skipping
over any IPv4 options or IPv6 extension headers. Not present for
non-first fragments.
required
Corresponds to the JSON property
base
67095 67096 67097 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 67095 def base @base end |
#mask ⇒ String
If specified, apply this mask (bitwise AND) to the field to ignore bits
before matching. Encoded as a hexadecimal number (starting with "0x").
The last byte of the field (in network byte order) corresponds to the
least significant byte of the mask.
Corresponds to the JSON property mask
67103 67104 67105 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 67103 def mask @mask end |
#name ⇒ String
The name of this field. Must be unique within the policy.
Corresponds to the JSON property name
67108 67109 67110 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 67108 def name @name end |
#offset ⇒ Fixnum
Offset of the first byte of the field (in network byte order) relative to
'base'.
Corresponds to the JSON property offset
67114 67115 67116 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 67114 def offset @offset end |
#size ⇒ Fixnum
Size of the field in bytes. Valid values: 1-4.
Corresponds to the JSON property size
67119 67120 67121 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 67119 def size @size end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
67126 67127 67128 67129 67130 67131 67132 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 67126 def update!(**args) @base = args[:base] if args.key?(:base) @mask = args[:mask] if args.key?(:mask) @name = args[:name] if args.key?(:name) @offset = args[:offset] if args.key?(:offset) @size = args[:size] if args.key?(:size) end |