Class: Google::Apis::ComputeAlpha::SecuritySettings

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

The authentication and authorization settings for a BackendService.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SecuritySettings

Returns a new instance of SecuritySettings.



67203
67204
67205
# File 'lib/google/apis/compute_alpha/classes.rb', line 67203

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#authenticationString

[Deprecated] Use clientTlsPolicy instead. Corresponds to the JSON property authentication

Returns:

  • (String)


67142
67143
67144
# File 'lib/google/apis/compute_alpha/classes.rb', line 67142

def authentication
  @authentication
end

#authentication_policyGoogle::Apis::ComputeAlpha::AuthenticationPolicy

[Deprecated] The authentication settings for the backend service. The authentication settings for the backend service. Corresponds to the JSON property authenticationPolicy



67148
67149
67150
# File 'lib/google/apis/compute_alpha/classes.rb', line 67148

def authentication_policy
  @authentication_policy
end

#authorization_configGoogle::Apis::ComputeAlpha::AuthorizationConfig

[Deprecated] Authorization configuration provides service-level and method-level access control for a service. control for a service. Corresponds to the JSON property authorizationConfig



67155
67156
67157
# File 'lib/google/apis/compute_alpha/classes.rb', line 67155

def authorization_config
  @authorization_config
end

#aws_v4_authenticationGoogle::Apis::ComputeAlpha::Awsv4Signature

Contains the configurations necessary to generate a signature for access to private storage buckets that support Signature Version 4 for authentication. The service name for generating the authentication header will always default to 's3'. Corresponds to the JSON property awsV4Authentication



67163
67164
67165
# File 'lib/google/apis/compute_alpha/classes.rb', line 67163

def aws_v4_authentication
  @aws_v4_authentication
end

#client_tls_policyString

Optional. A URL referring to a networksecurity.ClientTlsPolicy resource that describes how clients should authenticate with this service's backends. clientTlsPolicy only applies to a globalBackendService with the loadBalancingScheme set to INTERNAL_SELF_MANAGED. If left blank, communications are not encrypted. Corresponds to the JSON property clientTlsPolicy

Returns:

  • (String)


67174
67175
67176
# File 'lib/google/apis/compute_alpha/classes.rb', line 67174

def client_tls_policy
  @client_tls_policy
end

#client_tls_settingsGoogle::Apis::ComputeAlpha::ClientTlsSettings

[Deprecated] The client side authentication settings for connection originating from the backend service. the backend service. Corresponds to the JSON property clientTlsSettings



67181
67182
67183
# File 'lib/google/apis/compute_alpha/classes.rb', line 67181

def client_tls_settings
  @client_tls_settings
end

#subject_alt_namesArray<String>

Optional. A list of Subject Alternative Names (SANs) that the client verifies during a mutual TLS handshake with an server/endpoint for thisBackendService. When the server presents its X.509 certificate to the client, the client inspects the certificate'ssubjectAltName field. If the field contains one of the specified values, the communication continues. Otherwise, it fails. This additional check enables the client to verify that the server is authorized to run the requested service. Note that the contents of the server certificate's subjectAltName field are configured by the Public Key Infrastructure which provisions server identities. Only applies to a global BackendService withloadBalancingScheme set to INTERNAL_SELF_MANAGED. Only applies when BackendService has an attachedclientTlsPolicy with clientCertificate (mTLS mode). Corresponds to the JSON property subjectAltNames

Returns:

  • (Array<String>)


67201
67202
67203
# File 'lib/google/apis/compute_alpha/classes.rb', line 67201

def subject_alt_names
  @subject_alt_names
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



67208
67209
67210
67211
67212
67213
67214
67215
67216
# File 'lib/google/apis/compute_alpha/classes.rb', line 67208

def update!(**args)
  @authentication = args[:authentication] if args.key?(:authentication)
  @authentication_policy = args[:authentication_policy] if args.key?(:authentication_policy)
  @authorization_config = args[:authorization_config] if args.key?(:authorization_config)
  @aws_v4_authentication = args[:aws_v4_authentication] if args.key?(:aws_v4_authentication)
  @client_tls_policy = args[:client_tls_policy] if args.key?(:client_tls_policy)
  @client_tls_settings = args[:client_tls_settings] if args.key?(:client_tls_settings)
  @subject_alt_names = args[:subject_alt_names] if args.key?(:subject_alt_names)
end