Class: Google::Apis::ComputeAlpha::SerialPortOutput

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

An instance serial console output.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SerialPortOutput

Returns a new instance of SerialPortOutput.



67257
67258
67259
# File 'lib/google/apis/compute_alpha/classes.rb', line 67257

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#contentsString

[Output Only] The contents of the console output. Corresponds to the JSON property contents

Returns:

  • (String)


67226
67227
67228
# File 'lib/google/apis/compute_alpha/classes.rb', line 67226

def contents
  @contents
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# serialPortOutput for serial port output. Corresponds to the JSON property kind

Returns:

  • (String)


67232
67233
67234
# File 'lib/google/apis/compute_alpha/classes.rb', line 67232

def kind
  @kind
end

#nextFixnum

[Output Only] The position of the next byte of content, regardless of whether the content exists, following the output returned in the contents property. Use this value in the next request as the start parameter. Corresponds to the JSON property next

Returns:

  • (Fixnum)


67240
67241
67242
# File 'lib/google/apis/compute_alpha/classes.rb', line 67240

def next
  @next
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


67245
67246
67247
# File 'lib/google/apis/compute_alpha/classes.rb', line 67245

def self_link
  @self_link
end

#startFixnum

The starting byte position of the output that was returned. This should match the start parameter sent with the request. If the serial console output exceeds the size of the buffer (1 MB), older output is overwritten by newer content. The output start value will indicate the byte position of the output that was returned, which might be different than the start value that was specified in the request. Corresponds to the JSON property start

Returns:

  • (Fixnum)


67255
67256
67257
# File 'lib/google/apis/compute_alpha/classes.rb', line 67255

def start
  @start
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



67262
67263
67264
67265
67266
67267
67268
# File 'lib/google/apis/compute_alpha/classes.rb', line 67262

def update!(**args)
  @contents = args[:contents] if args.key?(:contents)
  @kind = args[:kind] if args.key?(:kind)
  @next = args[:next] if args.key?(:next)
  @self_link = args[:self_link] if args.key?(:self_link)
  @start = args[:start] if args.key?(:start)
end