Class: Google::Apis::ComputeAlpha::ServiceAttachment
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::ServiceAttachment
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Represents a ServiceAttachment resource. A service attachment represents a service that a producer has exposed. It encapsulates the load balancer which fronts the service runs and a list of NAT IP ranges that the producers uses to represent the consumers connecting to the service.
Instance Attribute Summary collapse
-
#connected_endpoints ⇒ Array<Google::Apis::ComputeAlpha::ServiceAttachmentConnectedEndpoint>
Output only.
-
#connection_preference ⇒ String
The connection preference of service attachment.
-
#consumer_accept_lists ⇒ Array<Google::Apis::ComputeAlpha::ServiceAttachmentConsumerProjectLimit>
Specifies which consumer projects or networks are allowed to connect to the service attachment.
-
#consumer_reject_lists ⇒ Array<String>
Specifies a list of projects or networks that are not allowed to connect to this service attachment.
-
#creation_timestamp ⇒ String
Output only.
-
#description ⇒ String
An optional description of this resource.
-
#domain_names ⇒ Array<String>
If specified, the domain name will be used during the integration between the PSC connected endpoints and the Cloud DNS.
-
#enable_proxy_protocol ⇒ Boolean
(also: #enable_proxy_protocol?)
If true, enable the proxy protocol which is for supplying client TCP/IP address data in TCP connections that traverse proxies on their way to destination servers.
-
#fingerprint ⇒ String
Fingerprint of this resource.
-
#id ⇒ Fixnum
Output only.
-
#kind ⇒ String
Output only.
-
#metadata ⇒ Hash<String,String>
Metadata of the service attachment.
-
#name ⇒ String
Name of the resource.
-
#nat_subnets ⇒ Array<String>
An array of URLs where each entry is the URL of a subnet provided by the service producer to use for NAT in this service attachment.
-
#producer_forwarding_rule ⇒ String
The URL of a forwarding rule with loadBalancingScheme INTERNAL* that is serving the endpoint identified by this service attachment.
-
#propagated_connection_limit ⇒ Fixnum
The number of consumer spokes that connected Private Service Connect endpoints can be propagated to through Network Connectivity Center.
-
#psc_service_attachment_id ⇒ Google::Apis::ComputeAlpha::Uint128
Output only.
-
#reconcile_connections ⇒ Boolean
(also: #reconcile_connections?)
This flag determines whether a consumer accept/reject list change can reconcile the statuses of existing ACCEPTED or REJECTED PSC endpoints.
-
#region ⇒ String
Output only.
-
#self_link ⇒ String
Output only.
-
#target_service ⇒ String
The URL of a service serving the endpoint identified by this service attachment.
-
#tunneling_config ⇒ Google::Apis::ComputeAlpha::ServiceAttachmentTunnelingConfig
Use to configure this PSC connection in tunneling mode.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ServiceAttachment
constructor
A new instance of ServiceAttachment.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ServiceAttachment
Returns a new instance of ServiceAttachment.
67544 67545 67546 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 67544 def initialize(**args) update!(**args) end |
Instance Attribute Details
#connected_endpoints ⇒ Array<Google::Apis::ComputeAlpha::ServiceAttachmentConnectedEndpoint>
Output only. [Output Only] An array of connections for all the consumers
connected to
this service attachment.
Corresponds to the JSON property connectedEndpoints
67367 67368 67369 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 67367 def connected_endpoints @connected_endpoints end |
#connection_preference ⇒ String
The connection preference of service attachment. The value can be set
to ACCEPT_AUTOMATIC. An ACCEPT_AUTOMATIC
service attachment is one that always accepts the connection from consumer
forwarding rules.
Corresponds to the JSON property connectionPreference
67375 67376 67377 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 67375 def connection_preference @connection_preference end |
#consumer_accept_lists ⇒ Array<Google::Apis::ComputeAlpha::ServiceAttachmentConsumerProjectLimit>
Specifies which consumer projects or networks are allowed to connect to the
service attachment. Each project or network has a connection limit. A given
service attachment can manage connections at either the project or network
level. Therefore, both the accept and reject lists for a given service
attachment must contain either only projects or only networks or only
endpoints.
Corresponds to the JSON property consumerAcceptLists
67385 67386 67387 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 67385 def consumer_accept_lists @consumer_accept_lists end |
#consumer_reject_lists ⇒ Array<String>
Specifies a list of projects or networks that are not allowed to connect to
this service attachment. The project can be specified using its project ID
or project number and the network can be specified using its URL. A given
service attachment can manage connections at either the project or network
level. Therefore, both the reject and accept lists for a given service
attachment must contain either only projects or only networks.
Corresponds to the JSON property consumerRejectLists
67395 67396 67397 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 67395 def consumer_reject_lists @consumer_reject_lists end |
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
67401 67402 67403 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 67401 def @creation_timestamp end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
67407 67408 67409 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 67407 def description @description end |
#domain_names ⇒ Array<String>
If specified, the domain name will be used during the integration between
the PSC connected endpoints and the Cloud DNS. For example, this is a valid
domain name: "p.mycompany.com.". Current max number of domain names
supported is 1.
Corresponds to the JSON property domainNames
67415 67416 67417 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 67415 def domain_names @domain_names end |
#enable_proxy_protocol ⇒ Boolean Also known as: enable_proxy_protocol?
If true, enable the proxy protocol which is for supplying client TCP/IP
address data in TCP connections that traverse proxies on their way to
destination servers.
Corresponds to the JSON property enableProxyProtocol
67422 67423 67424 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 67422 def enable_proxy_protocol @enable_proxy_protocol end |
#fingerprint ⇒ String
Fingerprint of this resource. A hash of the contents stored in this object.
This field is used in optimistic locking. This field will be ignored when
inserting a ServiceAttachment. An up-to-date fingerprint must
be provided in order to patch/update the ServiceAttachment; otherwise, the
request will fail with error 412 conditionNotMet. To see the
latest fingerprint, make a get() request to retrieve the
ServiceAttachment.
Corresponds to the JSON property fingerprint
NOTE: Values are automatically base64 encoded/decoded in the client library.
67435 67436 67437 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 67435 def fingerprint @fingerprint end |
#id ⇒ Fixnum
Output only. [Output Only] The unique identifier for the resource type. The
server
generates this identifier.
Corresponds to the JSON property id
67442 67443 67444 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 67442 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#
serviceAttachment for service attachments.
Corresponds to the JSON property kind
67448 67449 67450 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 67448 def kind @kind end |
#metadata ⇒ Hash<String,String>
Metadata of the service attachment.
Corresponds to the JSON property metadata
67453 67454 67455 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 67453 def @metadata end |
#name ⇒ String
Name of the resource. Provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must
be a dash, lowercase letter, or digit, except the last character, which
cannot be a dash.
Corresponds to the JSON property name
67464 67465 67466 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 67464 def name @name end |
#nat_subnets ⇒ Array<String>
An array of URLs where each entry is the URL of a subnet provided
by the service producer to use for NAT in this service attachment.
Corresponds to the JSON property natSubnets
67470 67471 67472 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 67470 def nat_subnets @nat_subnets end |
#producer_forwarding_rule ⇒ String
The URL of a forwarding rule with loadBalancingScheme INTERNAL* that is
serving the endpoint identified by this service attachment.
Corresponds to the JSON property producerForwardingRule
67476 67477 67478 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 67476 def producer_forwarding_rule @producer_forwarding_rule end |
#propagated_connection_limit ⇒ Fixnum
The number of consumer spokes that connected Private Service Connect
endpoints can be propagated to through Network Connectivity Center. This
limit lets the service producer limit how many propagated Private Service
Connect connections can be established to this service attachment from a
single consumer.
If the connection preference of the service attachment is ACCEPT_MANUAL,
the limit applies to each project or network that is listed in the consumer
accept list. If the connection preference of the service attachment is
ACCEPT_AUTOMATIC, the limit applies to each project that contains a
connected endpoint.
If unspecified, the default propagated connection limit is 250.
Corresponds to the JSON property propagatedConnectionLimit
67491 67492 67493 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 67491 def propagated_connection_limit @propagated_connection_limit end |
#psc_service_attachment_id ⇒ Google::Apis::ComputeAlpha::Uint128
Output only. [Output Only] An 128-bit global unique ID of the PSC service
attachment.
Corresponds to the JSON property pscServiceAttachmentId
67497 67498 67499 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 67497 def @psc_service_attachment_id end |
#reconcile_connections ⇒ Boolean Also known as: reconcile_connections?
This flag determines whether a consumer accept/reject list change can reconcile the statuses of existing ACCEPTED or REJECTED PSC endpoints.
- If false, connection policy update will only affect existing PENDING PSC endpoints. Existing ACCEPTED/REJECTED endpoints will remain untouched regardless how the connection policy is modified .
- If true,
update will affect both PENDING and ACCEPTED/REJECTED PSC endpoints. For
example, an ACCEPTED PSC endpoint will be moved to REJECTED if its project
is added to the reject list.
For newly created service attachment, this boolean defaults to false.
Corresponds to the JSON property
reconcileConnections
67513 67514 67515 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 67513 def reconcile_connections @reconcile_connections end |
#region ⇒ String
Output only. [Output Only] URL of the region where the service attachment
resides.
This field applies only to the region resource. You must specify this
field as part of the HTTP request URL. It is not settable as a field in
the request body.
Corresponds to the JSON property region
67523 67524 67525 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 67523 def region @region end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
67528 67529 67530 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 67528 def self_link @self_link end |
#target_service ⇒ String
The URL of a service serving the endpoint identified by this service
attachment.
Corresponds to the JSON property targetService
67534 67535 67536 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 67534 def target_service @target_service end |
#tunneling_config ⇒ Google::Apis::ComputeAlpha::ServiceAttachmentTunnelingConfig
Use to configure this PSC connection in tunneling mode. In tunneling mode
traffic from consumer to producer will be encapsulated as it crosses the
VPC boundary and traffic from producer to consumer will be decapsulated in
the same manner.
Corresponds to the JSON property tunnelingConfig
67542 67543 67544 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 67542 def tunneling_config @tunneling_config end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
67549 67550 67551 67552 67553 67554 67555 67556 67557 67558 67559 67560 67561 67562 67563 67564 67565 67566 67567 67568 67569 67570 67571 67572 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 67549 def update!(**args) @connected_endpoints = args[:connected_endpoints] if args.key?(:connected_endpoints) @connection_preference = args[:connection_preference] if args.key?(:connection_preference) @consumer_accept_lists = args[:consumer_accept_lists] if args.key?(:consumer_accept_lists) @consumer_reject_lists = args[:consumer_reject_lists] if args.key?(:consumer_reject_lists) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @domain_names = args[:domain_names] if args.key?(:domain_names) @enable_proxy_protocol = args[:enable_proxy_protocol] if args.key?(:enable_proxy_protocol) @fingerprint = args[:fingerprint] if args.key?(:fingerprint) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @metadata = args[:metadata] if args.key?(:metadata) @name = args[:name] if args.key?(:name) @nat_subnets = args[:nat_subnets] if args.key?(:nat_subnets) @producer_forwarding_rule = args[:producer_forwarding_rule] if args.key?(:producer_forwarding_rule) @propagated_connection_limit = args[:propagated_connection_limit] if args.key?(:propagated_connection_limit) @psc_service_attachment_id = args[:psc_service_attachment_id] if args.key?(:psc_service_attachment_id) @reconcile_connections = args[:reconcile_connections] if args.key?(:reconcile_connections) @region = args[:region] if args.key?(:region) @self_link = args[:self_link] if args.key?(:self_link) @target_service = args[:target_service] if args.key?(:target_service) @tunneling_config = args[:tunneling_config] if args.key?(:tunneling_config) end |