Class: Google::Apis::ComputeAlpha::ServiceAttachmentConsumerProjectLimit

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ServiceAttachmentConsumerProjectLimit

Returns a new instance of ServiceAttachmentConsumerProjectLimit.



68900
68901
68902
# File 'lib/google/apis/compute_alpha/classes.rb', line 68900

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#connection_limitFixnum

The value of the limit to set. For endpoint_url, the limit should be no more than 1. Corresponds to the JSON property connectionLimit

Returns:

  • (Fixnum)


68883
68884
68885
# File 'lib/google/apis/compute_alpha/classes.rb', line 68883

def connection_limit
  @connection_limit
end

#endpoint_urlString

The URL for the PSC endpoint to accept Corresponds to the JSON property endpointUrl

Returns:

  • (String)


68888
68889
68890
# File 'lib/google/apis/compute_alpha/classes.rb', line 68888

def endpoint_url
  @endpoint_url
end

#network_urlString

The network URL for the network to set the limit for. Corresponds to the JSON property networkUrl

Returns:

  • (String)


68893
68894
68895
# File 'lib/google/apis/compute_alpha/classes.rb', line 68893

def network_url
  @network_url
end

#project_id_or_numString

The project id or number for the project to set the limit for. Corresponds to the JSON property projectIdOrNum

Returns:

  • (String)


68898
68899
68900
# File 'lib/google/apis/compute_alpha/classes.rb', line 68898

def project_id_or_num
  @project_id_or_num
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



68905
68906
68907
68908
68909
68910
# File 'lib/google/apis/compute_alpha/classes.rb', line 68905

def update!(**args)
  @connection_limit = args[:connection_limit] if args.key?(:connection_limit)
  @endpoint_url = args[:endpoint_url] if args.key?(:endpoint_url)
  @network_url = args[:network_url] if args.key?(:network_url)
  @project_id_or_num = args[:project_id_or_num] if args.key?(:project_id_or_num)
end