Class: Google::Apis::ComputeAlpha::ServiceAttachmentConsumerProjectLimit
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::ServiceAttachmentConsumerProjectLimit
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#connection_limit ⇒ Fixnum
The value of the limit to set.
-
#endpoint_url ⇒ String
The URL for the PSC endpoint to accept Corresponds to the JSON property
endpointUrl. -
#network_url ⇒ String
The network URL for the network to set the limit for.
-
#project_id_or_num ⇒ String
The project id or number for the project to set the limit for.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ServiceAttachmentConsumerProjectLimit
constructor
A new instance of ServiceAttachmentConsumerProjectLimit.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ServiceAttachmentConsumerProjectLimit
Returns a new instance of ServiceAttachmentConsumerProjectLimit.
68677 68678 68679 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 68677 def initialize(**args) update!(**args) end |
Instance Attribute Details
#connection_limit ⇒ Fixnum
The value of the limit to set. For endpoint_url, the limit should be no
more than 1.
Corresponds to the JSON property connectionLimit
68660 68661 68662 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 68660 def connection_limit @connection_limit end |
#endpoint_url ⇒ String
The URL for the PSC endpoint to accept
Corresponds to the JSON property endpointUrl
68665 68666 68667 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 68665 def endpoint_url @endpoint_url end |
#network_url ⇒ String
The network URL for the network to set the limit for.
Corresponds to the JSON property networkUrl
68670 68671 68672 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 68670 def network_url @network_url end |
#project_id_or_num ⇒ String
The project id or number for the project to set the limit for.
Corresponds to the JSON property projectIdOrNum
68675 68676 68677 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 68675 def project_id_or_num @project_id_or_num end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
68682 68683 68684 68685 68686 68687 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 68682 def update!(**args) @connection_limit = args[:connection_limit] if args.key?(:connection_limit) @endpoint_url = args[:endpoint_url] if args.key?(:endpoint_url) @network_url = args[:network_url] if args.key?(:network_url) @project_id_or_num = args[:project_id_or_num] if args.key?(:project_id_or_num) end |