Class: Google::Apis::ComputeAlpha::ServiceAttachmentList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::ServiceAttachmentList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::ServiceAttachment>
A list of ServiceAttachment resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
-
#warning ⇒ Google::Apis::ComputeAlpha::ServiceAttachmentList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ServiceAttachmentList
constructor
A new instance of ServiceAttachmentList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ServiceAttachmentList
Returns a new instance of ServiceAttachmentList.
69551 69552 69553 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 69551 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
69518 69519 69520 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 69518 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::ServiceAttachment>
A list of ServiceAttachment resources.
Corresponds to the JSON property items
69523 69524 69525 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 69523 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#
serviceAttachment for service attachments.
Corresponds to the JSON property kind
69529 69530 69531 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 69529 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
69539 69540 69541 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 69539 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
69544 69545 69546 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 69544 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::ServiceAttachmentList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
69549 69550 69551 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 69549 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
69556 69557 69558 69559 69560 69561 69562 69563 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 69556 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |