Class: Google::Apis::ComputeAlpha::ServiceAttachmentList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ServiceAttachmentList

Returns a new instance of ServiceAttachmentList.



68953
68954
68955
# File 'lib/google/apis/compute_alpha/classes.rb', line 68953

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


68920
68921
68922
# File 'lib/google/apis/compute_alpha/classes.rb', line 68920

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::ServiceAttachment>

A list of ServiceAttachment resources. Corresponds to the JSON property items



68925
68926
68927
# File 'lib/google/apis/compute_alpha/classes.rb', line 68925

def items
  @items
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# serviceAttachment for service attachments. Corresponds to the JSON property kind

Returns:

  • (String)


68931
68932
68933
# File 'lib/google/apis/compute_alpha/classes.rb', line 68931

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


68941
68942
68943
# File 'lib/google/apis/compute_alpha/classes.rb', line 68941

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


68946
68947
68948
# File 'lib/google/apis/compute_alpha/classes.rb', line 68946

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::ServiceAttachmentList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



68951
68952
68953
# File 'lib/google/apis/compute_alpha/classes.rb', line 68951

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



68958
68959
68960
68961
68962
68963
68964
68965
# File 'lib/google/apis/compute_alpha/classes.rb', line 68958

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end