Class: Google::Apis::ComputeAlpha::ServiceAttachmentList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ServiceAttachmentList

Returns a new instance of ServiceAttachmentList.



68730
68731
68732
# File 'lib/google/apis/compute_alpha/classes.rb', line 68730

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


68697
68698
68699
# File 'lib/google/apis/compute_alpha/classes.rb', line 68697

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::ServiceAttachment>

A list of ServiceAttachment resources. Corresponds to the JSON property items



68702
68703
68704
# File 'lib/google/apis/compute_alpha/classes.rb', line 68702

def items
  @items
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# serviceAttachment for service attachments. Corresponds to the JSON property kind

Returns:

  • (String)


68708
68709
68710
# File 'lib/google/apis/compute_alpha/classes.rb', line 68708

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


68718
68719
68720
# File 'lib/google/apis/compute_alpha/classes.rb', line 68718

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


68723
68724
68725
# File 'lib/google/apis/compute_alpha/classes.rb', line 68723

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::ServiceAttachmentList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



68728
68729
68730
# File 'lib/google/apis/compute_alpha/classes.rb', line 68728

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



68735
68736
68737
68738
68739
68740
68741
68742
# File 'lib/google/apis/compute_alpha/classes.rb', line 68735

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end