Class: Google::Apis::ComputeAlpha::ServiceAttachmentList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::ServiceAttachmentList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::ServiceAttachment>
A list of ServiceAttachment resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
-
#warning ⇒ Google::Apis::ComputeAlpha::ServiceAttachmentList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ServiceAttachmentList
constructor
A new instance of ServiceAttachmentList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ServiceAttachmentList
Returns a new instance of ServiceAttachmentList.
67840 67841 67842 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 67840 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
67807 67808 67809 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 67807 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::ServiceAttachment>
A list of ServiceAttachment resources.
Corresponds to the JSON property items
67812 67813 67814 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 67812 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#
serviceAttachment for service attachments.
Corresponds to the JSON property kind
67818 67819 67820 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 67818 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
67828 67829 67830 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 67828 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
67833 67834 67835 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 67833 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::ServiceAttachmentList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
67838 67839 67840 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 67838 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
67845 67846 67847 67848 67849 67850 67851 67852 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 67845 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |