Class: Google::Apis::ComputeAlpha::ServiceAttachmentTunnelingConfig
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::ServiceAttachmentTunnelingConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Use to configure this PSC connection in tunneling mode. In tunneling mode traffic from consumer to producer will be encapsulated as it crosses the VPC boundary and traffic from producer to consumer will be decapsulated in the same manner.
Instance Attribute Summary collapse
-
#encapsulation_profile ⇒ String
Specify the encapsulation protocol and what metadata to include in incoming encapsulated packet headers.
-
#routing_mode ⇒ String
How this Service Attachment will treat traffic sent to the tunnel_ip, destined for the consumer network.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ServiceAttachmentTunnelingConfig
constructor
A new instance of ServiceAttachmentTunnelingConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ServiceAttachmentTunnelingConfig
Returns a new instance of ServiceAttachmentTunnelingConfig.
69057 69058 69059 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 69057 def initialize(**args) update!(**args) end |
Instance Attribute Details
#encapsulation_profile ⇒ String
Specify the encapsulation protocol and what metadata to include in
incoming encapsulated packet headers.
Corresponds to the JSON property encapsulationProfile
69049 69050 69051 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 69049 def encapsulation_profile @encapsulation_profile end |
#routing_mode ⇒ String
How this Service Attachment will treat traffic sent to the tunnel_ip,
destined for the consumer network.
Corresponds to the JSON property routingMode
69055 69056 69057 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 69055 def routing_mode @routing_mode end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
69062 69063 69064 69065 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 69062 def update!(**args) @encapsulation_profile = args[:encapsulation_profile] if args.key?(:encapsulation_profile) @routing_mode = args[:routing_mode] if args.key?(:routing_mode) end |