Class: Google::Apis::ComputeAlpha::SetCommonInstanceMetadataOperationMetadataPerLocationOperationInfo
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::SetCommonInstanceMetadataOperationMetadataPerLocationOperationInfo
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#error ⇒ Google::Apis::ComputeAlpha::Status
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#state ⇒ String
[Output Only] Status of the action, which can be one of the following:
PROPAGATING,PROPAGATED,ABANDONED,FAILED, orDONE.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SetCommonInstanceMetadataOperationMetadataPerLocationOperationInfo
constructor
A new instance of SetCommonInstanceMetadataOperationMetadataPerLocationOperationInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SetCommonInstanceMetadataOperationMetadataPerLocationOperationInfo
Returns a new instance of SetCommonInstanceMetadataOperationMetadataPerLocationOperationInfo.
68140 68141 68142 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 68140 def initialize(**args) update!(**args) end |
Instance Attribute Details
#error ⇒ Google::Apis::ComputeAlpha::Status
The Status type defines a logical error model that is suitable for
different programming environments, including REST APIs and RPC APIs. It is
used by gRPC. Each Status message contains
three pieces of data: error code, error message, and error details.
You can find out more about this error model and how to work with it in the
API Design Guide.
Corresponds to the JSON property error
68132 68133 68134 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 68132 def error @error end |
#state ⇒ String
[Output Only] Status of the action, which can be one of the following:
PROPAGATING, PROPAGATED, ABANDONED, FAILED, or DONE.
Corresponds to the JSON property state
68138 68139 68140 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 68138 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
68145 68146 68147 68148 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 68145 def update!(**args) @error = args[:error] if args.key?(:error) @state = args[:state] if args.key?(:state) end |