Class: Google::Apis::ComputeAlpha::ShareSettings
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::ShareSettings
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
The share setting for reservations and sole tenancy node groups.
Instance Attribute Summary collapse
-
#folder_map ⇒ Hash<String,Google::Apis::ComputeAlpha::ShareSettingsFolderConfig>
A map of folder id and folder config to specify consumer projects for this shared-reservation.
-
#project_map ⇒ Hash<String,Google::Apis::ComputeAlpha::ShareSettingsProjectConfig>
A map of project id and project config.
-
#projects ⇒ Array<String>
A List of Project names to specify consumer projects for this shared-reservation.
-
#share_type ⇒ String
Type of sharing for this shared-reservation Corresponds to the JSON property
shareType.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ShareSettings
constructor
A new instance of ShareSettings.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ShareSettings
Returns a new instance of ShareSettings.
69292 69293 69294 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 69292 def initialize(**args) update!(**args) end |
Instance Attribute Details
#folder_map ⇒ Hash<String,Google::Apis::ComputeAlpha::ShareSettingsFolderConfig>
A map of folder id and folder config to specify consumer projects for this
shared-reservation. This is only valid when share_type's value is
DIRECT_PROJECTS_UNDER_SPECIFIC_FOLDERS.
Folder id should be a string of number, and without "folders/" prefix.
Corresponds to the JSON property folderMap
69272 69273 69274 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 69272 def folder_map @folder_map end |
#project_map ⇒ Hash<String,Google::Apis::ComputeAlpha::ShareSettingsProjectConfig>
A map of project id and project config. This is only valid when
share_type's value is SPECIFIC_PROJECTS.
Corresponds to the JSON property projectMap
69278 69279 69280 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 69278 def project_map @project_map end |
#projects ⇒ Array<String>
A List of Project names to specify consumer projects for this
shared-reservation. This is only valid when share_type's value is
SPECIFIC_PROJECTS.
Corresponds to the JSON property projects
69285 69286 69287 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 69285 def projects @projects end |
#share_type ⇒ String
Type of sharing for this shared-reservation
Corresponds to the JSON property shareType
69290 69291 69292 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 69290 def share_type @share_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
69297 69298 69299 69300 69301 69302 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 69297 def update!(**args) @folder_map = args[:folder_map] if args.key?(:folder_map) @project_map = args[:project_map] if args.key?(:project_map) @projects = args[:projects] if args.key?(:projects) @share_type = args[:share_type] if args.key?(:share_type) end |