Class: Google::Apis::ComputeAlpha::Snapshot

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Represents a Persistent Disk Snapshot resource. You can use snapshots to back up data on a regular interval. For more information, read Creating persistent disk snapshots.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Snapshot

Returns a new instance of Snapshot.



70546
70547
70548
# File 'lib/google/apis/compute_alpha/classes.rb', line 70546

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#architectureString

Output only. [Output Only] The architecture of the snapshot. Valid values are ARM64 or X86_64. Corresponds to the JSON property architecture

Returns:

  • (String)


70230
70231
70232
# File 'lib/google/apis/compute_alpha/classes.rb', line 70230

def architecture
  @architecture
end

#auto_createdBoolean Also known as: auto_created?

Output only. [Output Only] Set to true if snapshots are automatically created by applying resource policy on the target disk. Corresponds to the JSON property autoCreated

Returns:

  • (Boolean)


70237
70238
70239
# File 'lib/google/apis/compute_alpha/classes.rb', line 70237

def auto_created
  @auto_created
end

#chain_nameString

Creates the new snapshot in the snapshot chain labeled with the specified name. The chain name must be 1-63 characters long and comply with RFC1035. This is an uncommon option only for advanced service owners who needs to create separate snapshot chains, for example, for chargeback tracking. When you describe your snapshot resource, this field is visible only if it has a non-empty value. Corresponds to the JSON property chainName

Returns:

  • (String)


70248
70249
70250
# File 'lib/google/apis/compute_alpha/classes.rb', line 70248

def chain_name
  @chain_name
end

#creation_size_bytesFixnum

Output only. [Output Only] Size in bytes of the snapshot at creation time. Corresponds to the JSON property creationSizeBytes

Returns:

  • (Fixnum)


70253
70254
70255
# File 'lib/google/apis/compute_alpha/classes.rb', line 70253

def creation_size_bytes
  @creation_size_bytes
end

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


70259
70260
70261
# File 'lib/google/apis/compute_alpha/classes.rb', line 70259

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


70265
70266
70267
# File 'lib/google/apis/compute_alpha/classes.rb', line 70265

def description
  @description
end

#disk_size_gbFixnum

Output only. [Output Only] Size of the source disk, specified in GB. Corresponds to the JSON property diskSizeGb

Returns:

  • (Fixnum)


70270
70271
70272
# File 'lib/google/apis/compute_alpha/classes.rb', line 70270

def disk_size_gb
  @disk_size_gb
end

#download_bytesFixnum

Output only. [Output Only] Number of bytes downloaded to restore a snapshot to a disk. Corresponds to the JSON property downloadBytes

Returns:

  • (Fixnum)


70276
70277
70278
# File 'lib/google/apis/compute_alpha/classes.rb', line 70276

def download_bytes
  @download_bytes
end

#enable_confidential_computeBoolean Also known as: enable_confidential_compute?

Output only. Whether this snapshot is created from a confidential compute mode disk. [Output Only]: This field is not set by user, but from source disk. Corresponds to the JSON property enableConfidentialCompute

Returns:

  • (Boolean)


70283
70284
70285
# File 'lib/google/apis/compute_alpha/classes.rb', line 70283

def enable_confidential_compute
  @enable_confidential_compute
end

#guest_flushBoolean Also known as: guest_flush?

[Input Only] Whether to attempt an application consistent snapshot by informing the OS to prepare for the snapshot process. Corresponds to the JSON property guestFlush

Returns:

  • (Boolean)


70290
70291
70292
# File 'lib/google/apis/compute_alpha/classes.rb', line 70290

def guest_flush
  @guest_flush
end

#guest_os_featuresArray<Google::Apis::ComputeAlpha::GuestOsFeature>

Output only. [Output Only] A list of features to enable on the guest operating system. Applicable only for bootable images. Read Enabling guest operating system features to see a list of available options. Corresponds to the JSON property guestOsFeatures



70300
70301
70302
# File 'lib/google/apis/compute_alpha/classes.rb', line 70300

def guest_os_features
  @guest_os_features
end

#idFixnum

Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


70307
70308
70309
# File 'lib/google/apis/compute_alpha/classes.rb', line 70307

def id
  @id
end

#kindString

Output only. [Output Only] Type of the resource. Always compute#snapshot for Snapshot resources. Corresponds to the JSON property kind

Returns:

  • (String)


70313
70314
70315
# File 'lib/google/apis/compute_alpha/classes.rb', line 70313

def kind
  @kind
end

#label_fingerprintString

A fingerprint for the labels being applied to this snapshot, which is essentially a hash of the labels set used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update labels. You must always provide an up-to-date fingerprint hash in order to update or change labels, otherwise the request will fail with error412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve a snapshot. Corresponds to the JSON property labelFingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


70326
70327
70328
# File 'lib/google/apis/compute_alpha/classes.rb', line 70326

def label_fingerprint
  @label_fingerprint
end

#labelsHash<String,String>

Labels to apply to this snapshot. These can be later modified by the setLabels method. Label values may be empty. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


70333
70334
70335
# File 'lib/google/apis/compute_alpha/classes.rb', line 70333

def labels
  @labels
end

#license_codesArray<Fixnum>

Output only. [Output Only] Integer license codes indicating which licenses are attached to this snapshot. Corresponds to the JSON property licenseCodes

Returns:

  • (Array<Fixnum>)


70340
70341
70342
# File 'lib/google/apis/compute_alpha/classes.rb', line 70340

def license_codes
  @license_codes
end

#licensesArray<String>

Output only. [Output Only] A list of public visible licenses that apply to this snapshot. This can be because the original image had licenses attached (such as a Windows image). Corresponds to the JSON property licenses

Returns:

  • (Array<String>)


70348
70349
70350
# File 'lib/google/apis/compute_alpha/classes.rb', line 70348

def licenses
  @licenses
end

#location_hintString

An opaque location hint used to place the snapshot close to other resources. This field is for use by internal tools that use the public API. Corresponds to the JSON property locationHint

Returns:

  • (String)


70355
70356
70357
# File 'lib/google/apis/compute_alpha/classes.rb', line 70355

def location_hint
  @location_hint
end

#max_retention_daysFixnum

Number of days the snapshot should be retained before being deleted automatically. Corresponds to the JSON property maxRetentionDays

Returns:

  • (Fixnum)


70361
70362
70363
# File 'lib/google/apis/compute_alpha/classes.rb', line 70361

def max_retention_days
  @max_retention_days
end

#nameString

Name of the resource; provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


70372
70373
70374
# File 'lib/google/apis/compute_alpha/classes.rb', line 70372

def name
  @name
end

#paramsGoogle::Apis::ComputeAlpha::SnapshotParams

Additional snapshot params. Corresponds to the JSON property params



70377
70378
70379
# File 'lib/google/apis/compute_alpha/classes.rb', line 70377

def params
  @params
end

#regionString

Output only. [Output Only] URL of the region where the snapshot resides. Only applicable for regional snapshots. Corresponds to the JSON property region

Returns:

  • (String)


70384
70385
70386
# File 'lib/google/apis/compute_alpha/classes.rb', line 70384

def region
  @region
end

#resource_statusGoogle::Apis::ComputeAlpha::SnapshotResourceStatus

Output only. [Output only] ResourceStatus of the Snapshot resource Corresponds to the JSON property resourceStatus



70389
70390
70391
# File 'lib/google/apis/compute_alpha/classes.rb', line 70389

def resource_status
  @resource_status
end

#satisfies_pziBoolean Also known as: satisfies_pzi?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzi

Returns:

  • (Boolean)


70394
70395
70396
# File 'lib/google/apis/compute_alpha/classes.rb', line 70394

def satisfies_pzi
  @satisfies_pzi
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

Output only. [Output Only] Reserved for future use. Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


70400
70401
70402
# File 'lib/google/apis/compute_alpha/classes.rb', line 70400

def satisfies_pzs
  @satisfies_pzs
end

Output only. [Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


70406
70407
70408
# File 'lib/google/apis/compute_alpha/classes.rb', line 70406

def self_link
  @self_link
end

Output only. [Output Only] Server-defined URL for this resource's resource id. Corresponds to the JSON property selfLinkWithId

Returns:

  • (String)


70411
70412
70413
# File 'lib/google/apis/compute_alpha/classes.rb', line 70411

def self_link_with_id
  @self_link_with_id
end

#snapshot_encryption_keyGoogle::Apis::ComputeAlpha::CustomerEncryptionKey

Encrypts the snapshot using acustomer-supplied encryption key. After you encrypt a snapshot using a customer-supplied key, you must provide the same key if you use the snapshot later. For example, you must provide the encryption key when you create a disk from the encrypted snapshot in a future request. Customer-supplied encryption keys do not protect access to metadata of the snapshot. If you do not provide an encryption key when creating the snapshot, then the snapshot will be encrypted using an automatically generated key and you do not need to provide a key to use the snapshot later. Corresponds to the JSON property snapshotEncryptionKey



70426
70427
70428
# File 'lib/google/apis/compute_alpha/classes.rb', line 70426

def snapshot_encryption_key
  @snapshot_encryption_key
end

#snapshot_group_idString

Output only. [Output Only] The unique ID of the snapshot group that this snapshot belongs to. The usage of snapshot group feature is restricted. Corresponds to the JSON property snapshotGroupId

Returns:

  • (String)


70433
70434
70435
# File 'lib/google/apis/compute_alpha/classes.rb', line 70433

def snapshot_group_id
  @snapshot_group_id
end

#snapshot_group_nameString

Output only. [Output only] The snapshot group that this snapshot belongs to. The usage of snapshot group feature is restricted. Corresponds to the JSON property snapshotGroupName

Returns:

  • (String)


70440
70441
70442
# File 'lib/google/apis/compute_alpha/classes.rb', line 70440

def snapshot_group_name
  @snapshot_group_name
end

#snapshot_typeString

Indicates the type of the snapshot. Corresponds to the JSON property snapshotType

Returns:

  • (String)


70445
70446
70447
# File 'lib/google/apis/compute_alpha/classes.rb', line 70445

def snapshot_type
  @snapshot_type
end

#source_diskString

The source disk used to create this snapshot. Corresponds to the JSON property sourceDisk

Returns:

  • (String)


70450
70451
70452
# File 'lib/google/apis/compute_alpha/classes.rb', line 70450

def source_disk
  @source_disk
end

#source_disk_encryption_keyGoogle::Apis::ComputeAlpha::CustomerEncryptionKey

The customer-supplied encryption key of the source disk. Required if the source disk is protected by a customer-supplied encryption key. Corresponds to the JSON property sourceDiskEncryptionKey



70457
70458
70459
# File 'lib/google/apis/compute_alpha/classes.rb', line 70457

def source_disk_encryption_key
  @source_disk_encryption_key
end

#source_disk_for_recovery_checkpointString

The source disk whose recovery checkpoint will be used to create this snapshot. Corresponds to the JSON property sourceDiskForRecoveryCheckpoint

Returns:

  • (String)


70463
70464
70465
# File 'lib/google/apis/compute_alpha/classes.rb', line 70463

def source_disk_for_recovery_checkpoint
  @source_disk_for_recovery_checkpoint
end

#source_disk_idString

Output only. [Output Only] The ID value of the disk used to create this snapshot. This value may be used to determine whether the snapshot was taken from the current or a previous instance of a given disk name. Corresponds to the JSON property sourceDiskId

Returns:

  • (String)


70471
70472
70473
# File 'lib/google/apis/compute_alpha/classes.rb', line 70471

def source_disk_id
  @source_disk_id
end

#source_instant_snapshotString

The source instant snapshot used to create this snapshot. You can provide this as a partial or full URL to the resource. For example, the following are valid values:

Returns:

  • (String)


70484
70485
70486
# File 'lib/google/apis/compute_alpha/classes.rb', line 70484

def source_instant_snapshot
  @source_instant_snapshot
end

#source_instant_snapshot_encryption_keyGoogle::Apis::ComputeAlpha::CustomerEncryptionKey

Customer provided encryption key when creating Snapshot from Instant Snapshot. Corresponds to the JSON property sourceInstantSnapshotEncryptionKey



70490
70491
70492
# File 'lib/google/apis/compute_alpha/classes.rb', line 70490

def source_instant_snapshot_encryption_key
  @source_instant_snapshot_encryption_key
end

#source_instant_snapshot_idString

Output only. [Output Only] The unique ID of the instant snapshot used to create this snapshot. This value identifies the exact instant snapshot that was used to create this snapshot. For example, if you created the snapshot from an instant snapshot that was later deleted and recreated under the same name, the source instant snapshot ID would identify the exact instant snapshot that was used. Corresponds to the JSON property sourceInstantSnapshotId

Returns:

  • (String)


70501
70502
70503
# File 'lib/google/apis/compute_alpha/classes.rb', line 70501

def source_instant_snapshot_id
  @source_instant_snapshot_id
end

#source_snapshot_schedule_policyString

Output only. [Output Only] URL of the resource policy which created this scheduled snapshot. Corresponds to the JSON property sourceSnapshotSchedulePolicy

Returns:

  • (String)


70507
70508
70509
# File 'lib/google/apis/compute_alpha/classes.rb', line 70507

def source_snapshot_schedule_policy
  @source_snapshot_schedule_policy
end

#source_snapshot_schedule_policy_idString

Output only. [Output Only] ID of the resource policy which created this scheduled snapshot. Corresponds to the JSON property sourceSnapshotSchedulePolicyId

Returns:

  • (String)


70513
70514
70515
# File 'lib/google/apis/compute_alpha/classes.rb', line 70513

def source_snapshot_schedule_policy_id
  @source_snapshot_schedule_policy_id
end

#statusString

Output only. [Output Only] The status of the snapshot. This can beCREATING, DELETING, FAILED,READY, or UPLOADING. Corresponds to the JSON property status

Returns:

  • (String)


70519
70520
70521
# File 'lib/google/apis/compute_alpha/classes.rb', line 70519

def status
  @status
end

#storage_bytesFixnum

Output only. [Output Only] A size of the storage used by the snapshot. As snapshots share storage, this number is expected to change with snapshot creation/deletion. Corresponds to the JSON property storageBytes

Returns:

  • (Fixnum)


70527
70528
70529
# File 'lib/google/apis/compute_alpha/classes.rb', line 70527

def storage_bytes
  @storage_bytes
end

#storage_bytes_statusString

Output only. [Deprecated] Instead, check the storageBytes field. After snapshot creation, the storageBytesStatus field is alwaysUP_TO_DATE. [Output Only] An indicator whether storageBytes is in a stable state or it is being adjusted as a result of shared storage reallocation. This status can either be unset, meaning the snapshot is being created, or UP_TO_DATE, meaning the size of the snapshot is up-to-date. Corresponds to the JSON property storageBytesStatus

Returns:

  • (String)


70538
70539
70540
# File 'lib/google/apis/compute_alpha/classes.rb', line 70538

def storage_bytes_status
  @storage_bytes_status
end

#storage_locationsArray<String>

Cloud Storage bucket storage location of the snapshot (regional or multi-regional). Corresponds to the JSON property storageLocations

Returns:

  • (Array<String>)


70544
70545
70546
# File 'lib/google/apis/compute_alpha/classes.rb', line 70544

def storage_locations
  @storage_locations
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



70551
70552
70553
70554
70555
70556
70557
70558
70559
70560
70561
70562
70563
70564
70565
70566
70567
70568
70569
70570
70571
70572
70573
70574
70575
70576
70577
70578
70579
70580
70581
70582
70583
70584
70585
70586
70587
70588
70589
70590
70591
70592
70593
70594
70595
70596
# File 'lib/google/apis/compute_alpha/classes.rb', line 70551

def update!(**args)
  @architecture = args[:architecture] if args.key?(:architecture)
  @auto_created = args[:auto_created] if args.key?(:auto_created)
  @chain_name = args[:chain_name] if args.key?(:chain_name)
  @creation_size_bytes = args[:creation_size_bytes] if args.key?(:creation_size_bytes)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @disk_size_gb = args[:disk_size_gb] if args.key?(:disk_size_gb)
  @download_bytes = args[:download_bytes] if args.key?(:download_bytes)
  @enable_confidential_compute = args[:enable_confidential_compute] if args.key?(:enable_confidential_compute)
  @guest_flush = args[:guest_flush] if args.key?(:guest_flush)
  @guest_os_features = args[:guest_os_features] if args.key?(:guest_os_features)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @label_fingerprint = args[:label_fingerprint] if args.key?(:label_fingerprint)
  @labels = args[:labels] if args.key?(:labels)
  @license_codes = args[:license_codes] if args.key?(:license_codes)
  @licenses = args[:licenses] if args.key?(:licenses)
  @location_hint = args[:location_hint] if args.key?(:location_hint)
  @max_retention_days = args[:max_retention_days] if args.key?(:max_retention_days)
  @name = args[:name] if args.key?(:name)
  @params = args[:params] if args.key?(:params)
  @region = args[:region] if args.key?(:region)
  @resource_status = args[:resource_status] if args.key?(:resource_status)
  @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @self_link = args[:self_link] if args.key?(:self_link)
  @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id)
  @snapshot_encryption_key = args[:snapshot_encryption_key] if args.key?(:snapshot_encryption_key)
  @snapshot_group_id = args[:snapshot_group_id] if args.key?(:snapshot_group_id)
  @snapshot_group_name = args[:snapshot_group_name] if args.key?(:snapshot_group_name)
  @snapshot_type = args[:snapshot_type] if args.key?(:snapshot_type)
  @source_disk = args[:source_disk] if args.key?(:source_disk)
  @source_disk_encryption_key = args[:source_disk_encryption_key] if args.key?(:source_disk_encryption_key)
  @source_disk_for_recovery_checkpoint = args[:source_disk_for_recovery_checkpoint] if args.key?(:source_disk_for_recovery_checkpoint)
  @source_disk_id = args[:source_disk_id] if args.key?(:source_disk_id)
  @source_instant_snapshot = args[:source_instant_snapshot] if args.key?(:source_instant_snapshot)
  @source_instant_snapshot_encryption_key = args[:source_instant_snapshot_encryption_key] if args.key?(:source_instant_snapshot_encryption_key)
  @source_instant_snapshot_id = args[:source_instant_snapshot_id] if args.key?(:source_instant_snapshot_id)
  @source_snapshot_schedule_policy = args[:source_snapshot_schedule_policy] if args.key?(:source_snapshot_schedule_policy)
  @source_snapshot_schedule_policy_id = args[:source_snapshot_schedule_policy_id] if args.key?(:source_snapshot_schedule_policy_id)
  @status = args[:status] if args.key?(:status)
  @storage_bytes = args[:storage_bytes] if args.key?(:storage_bytes)
  @storage_bytes_status = args[:storage_bytes_status] if args.key?(:storage_bytes_status)
  @storage_locations = args[:storage_locations] if args.key?(:storage_locations)
end