Class: Google::Apis::ComputeAlpha::SnapshotGroup

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Represents a SnapshotGroup resource. A snapshot group is a set of snapshots that represents a point in time state of a consistency group.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SnapshotGroup

Returns a new instance of SnapshotGroup.



70212
70213
70214
# File 'lib/google/apis/compute_alpha/classes.rb', line 70212

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


70147
70148
70149
# File 'lib/google/apis/compute_alpha/classes.rb', line 70147

def creation_timestamp
  @creation_timestamp
end

#descriptionString

Optional. An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


70154
70155
70156
# File 'lib/google/apis/compute_alpha/classes.rb', line 70154

def description
  @description
end

#idFixnum

Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


70161
70162
70163
# File 'lib/google/apis/compute_alpha/classes.rb', line 70161

def id
  @id
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute#snapshotGroup for SnapshotGroup resources. Corresponds to the JSON property kind

Returns:

  • (String)


70168
70169
70170
# File 'lib/google/apis/compute_alpha/classes.rb', line 70168

def kind
  @kind
end

#nameString

Identifier. Name of the resource; provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


70180
70181
70182
# File 'lib/google/apis/compute_alpha/classes.rb', line 70180

def name
  @name
end

Output only. [Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


70185
70186
70187
# File 'lib/google/apis/compute_alpha/classes.rb', line 70185

def self_link
  @self_link
end

Output only. [Output Only] Server-defined URL for this resource's resource id. Corresponds to the JSON property selfLinkWithId

Returns:

  • (String)


70190
70191
70192
# File 'lib/google/apis/compute_alpha/classes.rb', line 70190

def self_link_with_id
  @self_link_with_id
end

#source_infoGoogle::Apis::ComputeAlpha::SnapshotGroupSourceInfo

Output only. [Output Only] Corresponds to the JSON property sourceInfo



70195
70196
70197
# File 'lib/google/apis/compute_alpha/classes.rb', line 70195

def source_info
  @source_info
end

#source_instant_snapshot_groupString

Input field for the source instant snapshot group. Corresponds to the JSON property sourceInstantSnapshotGroup

Returns:

  • (String)


70200
70201
70202
# File 'lib/google/apis/compute_alpha/classes.rb', line 70200

def source_instant_snapshot_group
  @source_instant_snapshot_group
end

#source_instant_snapshot_group_infoGoogle::Apis::ComputeAlpha::SnapshotGroupSourceInstantSnapshotGroupInfo

Output only. [Output Only] Corresponds to the JSON property sourceInstantSnapshotGroupInfo



70205
70206
70207
# File 'lib/google/apis/compute_alpha/classes.rb', line 70205

def source_instant_snapshot_group_info
  @source_instant_snapshot_group_info
end

#statusString

Output only. [Output Only] Corresponds to the JSON property status

Returns:

  • (String)


70210
70211
70212
# File 'lib/google/apis/compute_alpha/classes.rb', line 70210

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



70217
70218
70219
70220
70221
70222
70223
70224
70225
70226
70227
70228
70229
# File 'lib/google/apis/compute_alpha/classes.rb', line 70217

def update!(**args)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @self_link = args[:self_link] if args.key?(:self_link)
  @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id)
  @source_info = args[:source_info] if args.key?(:source_info)
  @source_instant_snapshot_group = args[:source_instant_snapshot_group] if args.key?(:source_instant_snapshot_group)
  @source_instant_snapshot_group_info = args[:source_instant_snapshot_group_info] if args.key?(:source_instant_snapshot_group_info)
  @status = args[:status] if args.key?(:status)
end