Class: Google::Apis::ComputeAlpha::SnapshotGroup
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::SnapshotGroup
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Represents a SnapshotGroup resource. A snapshot group is a set of snapshots that represents a point in time state of a consistency group.
Instance Attribute Summary collapse
-
#creation_timestamp ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#id ⇒ Fixnum
Output only.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
Identifier.
-
#self_link ⇒ String
Output only.
-
#self_link_with_id ⇒ String
Output only.
-
#source_info ⇒ Google::Apis::ComputeAlpha::SnapshotGroupSourceInfo
Output only.
-
#source_instant_snapshot_group ⇒ String
Input field for the source instant snapshot group.
-
#source_instant_snapshot_group_info ⇒ Google::Apis::ComputeAlpha::SnapshotGroupSourceInstantSnapshotGroupInfo
Output only.
-
#status ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SnapshotGroup
constructor
A new instance of SnapshotGroup.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SnapshotGroup
Returns a new instance of SnapshotGroup.
69989 69990 69991 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 69989 def initialize(**args) update!(**args) end |
Instance Attribute Details
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
69924 69925 69926 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 69924 def @creation_timestamp end |
#description ⇒ String
Optional. An optional description of this resource. Provide this property when
you
create the resource.
Corresponds to the JSON property description
69931 69932 69933 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 69931 def description @description end |
#id ⇒ Fixnum
Output only. [Output Only] The unique identifier for the resource. This
identifier is
defined by the server.
Corresponds to the JSON property id
69938 69939 69940 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 69938 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#snapshotGroup
for SnapshotGroup
resources.
Corresponds to the JSON property kind
69945 69946 69947 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 69945 def kind @kind end |
#name ⇒ String
Identifier. Name of the resource; provided by the client when the resource is
created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must be
a dash, lowercase letter, or digit, except the last character, which cannot
be a dash.
Corresponds to the JSON property name
69957 69958 69959 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 69957 def name @name end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
69962 69963 69964 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 69962 def self_link @self_link end |
#self_link_with_id ⇒ String
Output only. [Output Only] Server-defined URL for this resource's resource id.
Corresponds to the JSON property selfLinkWithId
69967 69968 69969 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 69967 def self_link_with_id @self_link_with_id end |
#source_info ⇒ Google::Apis::ComputeAlpha::SnapshotGroupSourceInfo
Output only. [Output Only]
Corresponds to the JSON property sourceInfo
69972 69973 69974 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 69972 def source_info @source_info end |
#source_instant_snapshot_group ⇒ String
Input field for the source instant snapshot group.
Corresponds to the JSON property sourceInstantSnapshotGroup
69977 69978 69979 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 69977 def source_instant_snapshot_group @source_instant_snapshot_group end |
#source_instant_snapshot_group_info ⇒ Google::Apis::ComputeAlpha::SnapshotGroupSourceInstantSnapshotGroupInfo
Output only. [Output Only]
Corresponds to the JSON property sourceInstantSnapshotGroupInfo
69982 69983 69984 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 69982 def source_instant_snapshot_group_info @source_instant_snapshot_group_info end |
#status ⇒ String
Output only. [Output Only]
Corresponds to the JSON property status
69987 69988 69989 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 69987 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
69994 69995 69996 69997 69998 69999 70000 70001 70002 70003 70004 70005 70006 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 69994 def update!(**args) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @self_link = args[:self_link] if args.key?(:self_link) @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id) @source_info = args[:source_info] if args.key?(:source_info) @source_instant_snapshot_group = args[:source_instant_snapshot_group] if args.key?(:source_instant_snapshot_group) @source_instant_snapshot_group_info = args[:source_instant_snapshot_group_info] if args.key?(:source_instant_snapshot_group_info) @status = args[:status] if args.key?(:status) end |