Class: Google::Apis::ComputeAlpha::SnapshotGroupParameters
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::SnapshotGroupParameters
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#replica_zones ⇒ Array<String>
URLs of the zones where disks should be replicated to.
-
#source_snapshot_group ⇒ String
The source snapshot group used to create disks.
-
#type ⇒ String
URL of the disk type resource describing which disk type to use to create disks.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SnapshotGroupParameters
constructor
A new instance of SnapshotGroupParameters.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SnapshotGroupParameters
Returns a new instance of SnapshotGroupParameters.
69148 69149 69150 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 69148 def initialize(**args) update!(**args) end |
Instance Attribute Details
#replica_zones ⇒ Array<String>
URLs of the zones where disks should be replicated to. Only applicable
for regional resources.
Corresponds to the JSON property replicaZones
69125 69126 69127 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 69125 def replica_zones @replica_zones end |
#source_snapshot_group ⇒ String
The source snapshot group used to create disks. You can provide this as a partial or full URL to the resource. For example, the following are valid values:
- https://www.googleapis.com/compute/v1/projects/project/global/ snapshotGroups/snapshotGroup
- projects/project/global/snapshotGroups/snapshotGroup
- global/snapshotGroups/snapshotGroup
Corresponds to the JSON property
sourceSnapshotGroup
69138 69139 69140 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 69138 def source_snapshot_group @source_snapshot_group end |
#type ⇒ String
URL of the disk type resource describing which disk type to use to create
disks. Provide this when creating the disk. For example:projects/project/zones/
zone/diskTypes/pd-ssd. See Persistent disk
types.
Corresponds to the JSON property type
69146 69147 69148 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 69146 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
69153 69154 69155 69156 69157 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 69153 def update!(**args) @replica_zones = args[:replica_zones] if args.key?(:replica_zones) @source_snapshot_group = args[:source_snapshot_group] if args.key?(:source_snapshot_group) @type = args[:type] if args.key?(:type) end |