Class: Google::Apis::ComputeAlpha::SnapshotList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of Snapshot resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SnapshotList

Returns a new instance of SnapshotList.



72390
72391
72392
# File 'lib/google/apis/compute_alpha/classes.rb', line 72390

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


72358
72359
72360
# File 'lib/google/apis/compute_alpha/classes.rb', line 72358

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::Snapshot>

A list of Snapshot resources. Corresponds to the JSON property items



72363
72364
72365
# File 'lib/google/apis/compute_alpha/classes.rb', line 72363

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


72368
72369
72370
# File 'lib/google/apis/compute_alpha/classes.rb', line 72368

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


72378
72379
72380
# File 'lib/google/apis/compute_alpha/classes.rb', line 72378

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


72383
72384
72385
# File 'lib/google/apis/compute_alpha/classes.rb', line 72383

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::SnapshotList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



72388
72389
72390
# File 'lib/google/apis/compute_alpha/classes.rb', line 72388

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



72395
72396
72397
72398
72399
72400
72401
72402
# File 'lib/google/apis/compute_alpha/classes.rb', line 72395

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end