Class: Google::Apis::ComputeAlpha::SnapshotList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::SnapshotList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Contains a list of Snapshot resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::Snapshot>
A list of Snapshot resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::SnapshotList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SnapshotList
constructor
A new instance of SnapshotList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SnapshotList
Returns a new instance of SnapshotList.
71021 71022 71023 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 71021 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
70989 70990 70991 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 70989 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::Snapshot>
A list of Snapshot resources.
Corresponds to the JSON property items
70994 70995 70996 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 70994 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
70999 71000 71001 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 70999 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
71009 71010 71011 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 71009 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
71014 71015 71016 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 71014 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::SnapshotList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
71019 71020 71021 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 71019 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
71026 71027 71028 71029 71030 71031 71032 71033 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 71026 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |