Class: Google::Apis::ComputeAlpha::SnapshotList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of Snapshot resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SnapshotList

Returns a new instance of SnapshotList.



70964
70965
70966
# File 'lib/google/apis/compute_alpha/classes.rb', line 70964

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


70932
70933
70934
# File 'lib/google/apis/compute_alpha/classes.rb', line 70932

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::Snapshot>

A list of Snapshot resources. Corresponds to the JSON property items



70937
70938
70939
# File 'lib/google/apis/compute_alpha/classes.rb', line 70937

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


70942
70943
70944
# File 'lib/google/apis/compute_alpha/classes.rb', line 70942

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


70952
70953
70954
# File 'lib/google/apis/compute_alpha/classes.rb', line 70952

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


70957
70958
70959
# File 'lib/google/apis/compute_alpha/classes.rb', line 70957

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::SnapshotList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



70962
70963
70964
# File 'lib/google/apis/compute_alpha/classes.rb', line 70962

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



70969
70970
70971
70972
70973
70974
70975
70976
# File 'lib/google/apis/compute_alpha/classes.rb', line 70969

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end