Class: Google::Apis::ComputeAlpha::SnapshotList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::SnapshotList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Contains a list of Snapshot resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::Snapshot>
A list of Snapshot resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::SnapshotList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SnapshotList
constructor
A new instance of SnapshotList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SnapshotList
Returns a new instance of SnapshotList.
70141 70142 70143 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 70141 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
70109 70110 70111 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 70109 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::Snapshot>
A list of Snapshot resources.
Corresponds to the JSON property items
70114 70115 70116 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 70114 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
70119 70120 70121 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 70119 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
70129 70130 70131 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 70129 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
70134 70135 70136 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 70134 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::SnapshotList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
70139 70140 70141 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 70139 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
70146 70147 70148 70149 70150 70151 70152 70153 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 70146 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |