Class: Google::Apis::ComputeAlpha::SnapshotRecycleBinPolicy
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::SnapshotRecycleBinPolicy
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Represents the singleton resource Snapshot Recycle Bin Policy that configures the retention duration for snapshots in the recycle bin. You can configure the retention duration for snapshots in the recycle bin at the project or organization level. If you configure the policy at the organization level, all projects in that organization will share the same policy. If you configure the policy at the project level it will be merged with org level policy (if any) and the snapshots in that project will use that policy.
Instance Attribute Summary collapse
-
#rules ⇒ Hash<String,Google::Apis::ComputeAlpha::SnapshotRecycleBinPolicyRule>
The rules for the snapshot recycle bin policy.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SnapshotRecycleBinPolicy
constructor
A new instance of SnapshotRecycleBinPolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SnapshotRecycleBinPolicy
Returns a new instance of SnapshotRecycleBinPolicy.
70497 70498 70499 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 70497 def initialize(**args) update!(**args) end |
Instance Attribute Details
#rules ⇒ Hash<String,Google::Apis::ComputeAlpha::SnapshotRecycleBinPolicyRule>
The rules for the snapshot recycle bin policy. The key is either 'default'
or namespacedName of the TagValue which can be in the format:
organization_id`/`tag_key_short_name`/`tag_value_short_name or
project_id`/`tag_key_short_name`/`tag_value_short_name or
project_number`/`tag_key_short_name`/`tag_value_short_name. The default
rule is applied if snapshots do not have any of these tags.
The value is the rule for the key.
Corresponds to the JSON property rules
70495 70496 70497 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 70495 def rules @rules end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
70502 70503 70504 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 70502 def update!(**args) @rules = args[:rules] if args.key?(:rules) end |