Class: Google::Apis::ComputeAlpha::SnapshotRecycleBinPolicyRule
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::SnapshotRecycleBinPolicyRule
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
A rule that defines the retention policy for snapshots in the recycle bin.
Instance Attribute Summary collapse
-
#standard_snapshots ⇒ Google::Apis::ComputeAlpha::SnapshotRecycleBinPolicyRuleRuleConfig
The rule config for snapshots in the recycle bin.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SnapshotRecycleBinPolicyRule
constructor
A new instance of SnapshotRecycleBinPolicyRule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SnapshotRecycleBinPolicyRule
Returns a new instance of SnapshotRecycleBinPolicyRule.
70293 70294 70295 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 70293 def initialize(**args) update!(**args) end |
Instance Attribute Details
#standard_snapshots ⇒ Google::Apis::ComputeAlpha::SnapshotRecycleBinPolicyRuleRuleConfig
The rule config for snapshots in the recycle bin.
Corresponds to the JSON property standardSnapshots
70291 70292 70293 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 70291 def standard_snapshots @standard_snapshots end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
70298 70299 70300 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 70298 def update!(**args) @standard_snapshots = args[:standard_snapshots] if args.key?(:standard_snapshots) end |