Class: Google::Apis::ComputeAlpha::SnapshotRecycleBinPolicyRule
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::SnapshotRecycleBinPolicyRule
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
A rule that defines the retention policy for snapshots in the recycle bin.
Instance Attribute Summary collapse
-
#standard_snapshots ⇒ Google::Apis::ComputeAlpha::SnapshotRecycleBinPolicyRuleRuleConfig
The rule config for snapshots in the recycle bin.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SnapshotRecycleBinPolicyRule
constructor
A new instance of SnapshotRecycleBinPolicyRule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SnapshotRecycleBinPolicyRule
Returns a new instance of SnapshotRecycleBinPolicyRule.
69401 69402 69403 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 69401 def initialize(**args) update!(**args) end |
Instance Attribute Details
#standard_snapshots ⇒ Google::Apis::ComputeAlpha::SnapshotRecycleBinPolicyRuleRuleConfig
The rule config for snapshots in the recycle bin.
Corresponds to the JSON property standardSnapshots
69399 69400 69401 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 69399 def standard_snapshots @standard_snapshots end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
69406 69407 69408 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 69406 def update!(**args) @standard_snapshots = args[:standard_snapshots] if args.key?(:standard_snapshots) end |