Class: Google::Apis::ComputeAlpha::SnapshotRecycleBinPolicyRuleRuleConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

The rule config for snapshots in the recycle bin.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SnapshotRecycleBinPolicyRuleRuleConfig

Returns a new instance of SnapshotRecycleBinPolicyRuleRuleConfig.



70534
70535
70536
# File 'lib/google/apis/compute_alpha/classes.rb', line 70534

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#retention_duration_daysFixnum

The retention duration for snapshots in the recycle bin after which the snapshots are automatically deleted from recycle bin. Corresponds to the JSON property retentionDurationDays

Returns:

  • (Fixnum)


70532
70533
70534
# File 'lib/google/apis/compute_alpha/classes.rb', line 70532

def retention_duration_days
  @retention_duration_days
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



70539
70540
70541
# File 'lib/google/apis/compute_alpha/classes.rb', line 70539

def update!(**args)
  @retention_duration_days = args[:retention_duration_days] if args.key?(:retention_duration_days)
end