Class: Google::Apis::ComputeAlpha::SnapshotRecycleBinPolicyRuleRuleConfig
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::SnapshotRecycleBinPolicyRuleRuleConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
The rule config for snapshots in the recycle bin.
Instance Attribute Summary collapse
-
#retention_duration_days ⇒ Fixnum
The retention duration for snapshots in the recycle bin after which the snapshots are automatically deleted from recycle bin.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SnapshotRecycleBinPolicyRuleRuleConfig
constructor
A new instance of SnapshotRecycleBinPolicyRuleRuleConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SnapshotRecycleBinPolicyRuleRuleConfig
Returns a new instance of SnapshotRecycleBinPolicyRuleRuleConfig.
69421 69422 69423 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 69421 def initialize(**args) update!(**args) end |
Instance Attribute Details
#retention_duration_days ⇒ Fixnum
The retention duration for snapshots in the recycle bin after which the
snapshots are automatically deleted from recycle bin.
Corresponds to the JSON property retentionDurationDays
69419 69420 69421 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 69419 def retention_duration_days @retention_duration_days end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
69426 69427 69428 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 69426 def update!(**args) @retention_duration_days = args[:retention_duration_days] if args.key?(:retention_duration_days) end |