Class: Google::Apis::ComputeAlpha::SnapshotSettings
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::SnapshotSettings
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#access_location ⇒ Google::Apis::ComputeAlpha::SnapshotSettingsAccessLocation
(Regional snapshots use only)Policy of which location is allowed to access snapshot.
-
#storage_location ⇒ Google::Apis::ComputeAlpha::SnapshotSettingsStorageLocationSettings
Policy of which storage location is going to be resolved, and additional data that particularizes how the policy is going to be carried out.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SnapshotSettings
constructor
A new instance of SnapshotSettings.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SnapshotSettings
Returns a new instance of SnapshotSettings.
69468 69469 69470 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 69468 def initialize(**args) update!(**args) end |
Instance Attribute Details
#access_location ⇒ Google::Apis::ComputeAlpha::SnapshotSettingsAccessLocation
(Regional snapshots use only)Policy of which location is allowed to access
snapshot.
Corresponds to the JSON property accessLocation
69460 69461 69462 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 69460 def access_location @access_location end |
#storage_location ⇒ Google::Apis::ComputeAlpha::SnapshotSettingsStorageLocationSettings
Policy of which storage location is going to be resolved, and additional
data that particularizes how the policy is going to be carried out.
Corresponds to the JSON property storageLocation
69466 69467 69468 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 69466 def storage_location @storage_location end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
69473 69474 69475 69476 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 69473 def update!(**args) @access_location = args[:access_location] if args.key?(:access_location) @storage_location = args[:storage_location] if args.key?(:storage_location) end |