Class: Google::Apis::ComputeAlpha::SnapshotSettingsAccessLocation
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::SnapshotSettingsAccessLocation
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#locations ⇒ Hash<String,Google::Apis::ComputeAlpha::SnapshotSettingsAccessLocationAccessLocationPreference>
List of regions that can restore a regional snapshot from the current region Corresponds to the JSON property
locations. -
#policy ⇒ String
Policy of which location is allowed to access snapshot.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SnapshotSettingsAccessLocation
constructor
A new instance of SnapshotSettingsAccessLocation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SnapshotSettingsAccessLocation
Returns a new instance of SnapshotSettingsAccessLocation.
69494 69495 69496 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 69494 def initialize(**args) update!(**args) end |
Instance Attribute Details
#locations ⇒ Hash<String,Google::Apis::ComputeAlpha::SnapshotSettingsAccessLocationAccessLocationPreference>
List of regions that can restore a regional
snapshot from the current region
Corresponds to the JSON property locations
69487 69488 69489 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 69487 def locations @locations end |
#policy ⇒ String
Policy of which location is allowed to access snapshot.
Corresponds to the JSON property policy
69492 69493 69494 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 69492 def policy @policy end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
69499 69500 69501 69502 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 69499 def update!(**args) @locations = args[:locations] if args.key?(:locations) @policy = args[:policy] if args.key?(:policy) end |