Class: Google::Apis::ComputeAlpha::SnapshotsGetEffectiveRecycleBinRuleResponse
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::SnapshotsGetEffectiveRecycleBinRuleResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#retention_duration_days ⇒ Fixnum
The retention duration of the snapshot in recycle bin.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SnapshotsGetEffectiveRecycleBinRuleResponse
constructor
A new instance of SnapshotsGetEffectiveRecycleBinRuleResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SnapshotsGetEffectiveRecycleBinRuleResponse
Returns a new instance of SnapshotsGetEffectiveRecycleBinRuleResponse.
69580 69581 69582 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 69580 def initialize(**args) update!(**args) end |
Instance Attribute Details
#retention_duration_days ⇒ Fixnum
The retention duration of the snapshot in recycle bin.
Corresponds to the JSON property retentionDurationDays
69578 69579 69580 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 69578 def retention_duration_days @retention_duration_days end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
69585 69586 69587 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 69585 def update!(**args) @retention_duration_days = args[:retention_duration_days] if args.key?(:retention_duration_days) end |