Class: Google::Apis::ComputeAlpha::SourceDiskEncryptionKey
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::SourceDiskEncryptionKey
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#disk_encryption_key ⇒ Google::Apis::ComputeAlpha::CustomerEncryptionKey
Thecustomer-supplied encryption key of the source disk.
-
#source_disk ⇒ String
URL of the disk attached to the source instance.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SourceDiskEncryptionKey
constructor
A new instance of SourceDiskEncryptionKey.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SourceDiskEncryptionKey
Returns a new instance of SourceDiskEncryptionKey.
69710 69711 69712 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 69710 def initialize(**args) update!(**args) end |
Instance Attribute Details
#disk_encryption_key ⇒ Google::Apis::ComputeAlpha::CustomerEncryptionKey
Thecustomer-supplied
encryption key of the source disk. Required if the source disk is
protected by a customer-supplied encryption key.
Corresponds to the JSON property diskEncryptionKey
69696 69697 69698 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 69696 def disk_encryption_key @disk_encryption_key end |
#source_disk ⇒ String
URL of the disk attached to the source instance. This can be a full or valid partial URL. For example, the following are valid values:
- https://www.googleapis.com/compute/v1/projects/project/zones/zone/disks/ disk
- projects/project/zones/zone/disks/disk
- zones/zone/disks/disk
Corresponds to the JSON property
sourceDisk
69708 69709 69710 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 69708 def source_disk @source_disk end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
69715 69716 69717 69718 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 69715 def update!(**args) @disk_encryption_key = args[:disk_encryption_key] if args.key?(:disk_encryption_key) @source_disk = args[:source_disk] if args.key?(:source_disk) end |