Class: Google::Apis::ComputeAlpha::SourceInstanceProperties
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::SourceInstanceProperties
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
DEPRECATED: Please use compute#instanceProperties instead. New properties will not be added to this field.
Instance Attribute Summary collapse
-
#can_ip_forward ⇒ Boolean
(also: #can_ip_forward?)
Enables instances created based on this machine image to send packets with source IP addresses other than their own and receive packets with destination IP addresses other than their own.
-
#deletion_protection ⇒ Boolean
(also: #deletion_protection?)
Whether the instance created from this machine image should be protected against deletion.
-
#description ⇒ String
An optional text description for the instances that are created from this machine image.
-
#disks ⇒ Array<Google::Apis::ComputeAlpha::SavedAttachedDisk>
An array of disks that are associated with the instances that are created from this machine image.
-
#guest_accelerators ⇒ Array<Google::Apis::ComputeAlpha::AcceleratorConfig>
A list of guest accelerator cards' type and count to use for instances created from this machine image.
-
#key_revocation_action_type ⇒ String
KeyRevocationActionType of the instance.
-
#labels ⇒ Hash<String,String>
Labels to apply to instances that are created from this machine image.
-
#machine_type ⇒ String
The machine type to use for instances that are created from this machine image.
-
#metadata ⇒ Google::Apis::ComputeAlpha::Metadata
A metadata key/value entry.
-
#min_cpu_platform ⇒ String
Minimum cpu/platform to be used by instances created from this machine image.
-
#network_interfaces ⇒ Array<Google::Apis::ComputeAlpha::NetworkInterface>
An array of network access configurations for this interface.
-
#post_key_revocation_action_type ⇒ String
PostKeyRevocationActionType of the instance.
-
#scheduling ⇒ Google::Apis::ComputeAlpha::Scheduling
Sets the scheduling options for an Instance.
-
#service_accounts ⇒ Array<Google::Apis::ComputeAlpha::ServiceAccount>
A list of service accounts with specified scopes.
-
#tags ⇒ Google::Apis::ComputeAlpha::Tags
A set of instance tags.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SourceInstanceProperties
constructor
A new instance of SourceInstanceProperties.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SourceInstanceProperties
Returns a new instance of SourceInstanceProperties.
69847 69848 69849 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 69847 def initialize(**args) update!(**args) end |
Instance Attribute Details
#can_ip_forward ⇒ Boolean Also known as: can_ip_forward?
Enables instances created based on this machine image to send packets with
source IP addresses other than their own and receive packets with
destination IP addresses other than their own. If these instances will be
used as an IP gateway or it will be set as the next-hop in a Route
resource, specify true. If unsure, leave this set tofalse. See theEnable IP
forwarding
documentation for more information.
Corresponds to the JSON property canIpForward
69758 69759 69760 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 69758 def can_ip_forward @can_ip_forward end |
#deletion_protection ⇒ Boolean Also known as: deletion_protection?
Whether the instance created from this machine image should be protected
against deletion.
Corresponds to the JSON property deletionProtection
69765 69766 69767 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 69765 def deletion_protection @deletion_protection end |
#description ⇒ String
An optional text description for the instances that are created from this
machine image.
Corresponds to the JSON property description
69772 69773 69774 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 69772 def description @description end |
#disks ⇒ Array<Google::Apis::ComputeAlpha::SavedAttachedDisk>
An array of disks that are associated with the instances that are created
from this machine image.
Corresponds to the JSON property disks
69778 69779 69780 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 69778 def disks @disks end |
#guest_accelerators ⇒ Array<Google::Apis::ComputeAlpha::AcceleratorConfig>
A list of guest accelerator cards' type and count to use for instances
created from this machine image.
Corresponds to the JSON property guestAccelerators
69784 69785 69786 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 69784 def guest_accelerators @guest_accelerators end |
#key_revocation_action_type ⇒ String
KeyRevocationActionType of the instance. Supported options are "STOP" and
"NONE". The default value is "NONE" if it is not specified.
Corresponds to the JSON property keyRevocationActionType
69790 69791 69792 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 69790 def key_revocation_action_type @key_revocation_action_type end |
#labels ⇒ Hash<String,String>
Labels to apply to instances that are created from this machine image.
Corresponds to the JSON property labels
69795 69796 69797 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 69795 def labels @labels end |
#machine_type ⇒ String
The machine type to use for instances that are created from this machine
image.
Corresponds to the JSON property machineType
69801 69802 69803 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 69801 def machine_type @machine_type end |
#metadata ⇒ Google::Apis::ComputeAlpha::Metadata
A metadata key/value entry.
Corresponds to the JSON property metadata
69806 69807 69808 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 69806 def @metadata end |
#min_cpu_platform ⇒ String
Minimum cpu/platform to be used by instances created from this machine
image. The instance may be scheduled on the specified or newer
cpu/platform. Applicable values are the friendly names of CPU platforms,
such as minCpuPlatform: "Intel Haswell" orminCpuPlatform: "Intel Sandy Bridge".
For more
information, read Specifying a
Minimum CPU Platform.
Corresponds to the JSON property minCpuPlatform
69817 69818 69819 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 69817 def min_cpu_platform @min_cpu_platform end |
#network_interfaces ⇒ Array<Google::Apis::ComputeAlpha::NetworkInterface>
An array of network access configurations for this interface.
Corresponds to the JSON property networkInterfaces
69822 69823 69824 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 69822 def network_interfaces @network_interfaces end |
#post_key_revocation_action_type ⇒ String
PostKeyRevocationActionType of the instance.
Corresponds to the JSON property postKeyRevocationActionType
69827 69828 69829 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 69827 def post_key_revocation_action_type @post_key_revocation_action_type end |
#scheduling ⇒ Google::Apis::ComputeAlpha::Scheduling
Sets the scheduling options for an Instance.
Corresponds to the JSON property scheduling
69832 69833 69834 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 69832 def scheduling @scheduling end |
#service_accounts ⇒ Array<Google::Apis::ComputeAlpha::ServiceAccount>
A list of service accounts with specified scopes. Access tokens for these
service accounts are available to the instances that are created from this
machine image. Use metadata queries to obtain the access tokens for these
instances.
Corresponds to the JSON property serviceAccounts
69840 69841 69842 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 69840 def service_accounts @service_accounts end |
#tags ⇒ Google::Apis::ComputeAlpha::Tags
A set of instance tags.
Corresponds to the JSON property tags
69845 69846 69847 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 69845 def @tags end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
69852 69853 69854 69855 69856 69857 69858 69859 69860 69861 69862 69863 69864 69865 69866 69867 69868 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 69852 def update!(**args) @can_ip_forward = args[:can_ip_forward] if args.key?(:can_ip_forward) @deletion_protection = args[:deletion_protection] if args.key?(:deletion_protection) @description = args[:description] if args.key?(:description) @disks = args[:disks] if args.key?(:disks) @guest_accelerators = args[:guest_accelerators] if args.key?(:guest_accelerators) @key_revocation_action_type = args[:key_revocation_action_type] if args.key?(:key_revocation_action_type) @labels = args[:labels] if args.key?(:labels) @machine_type = args[:machine_type] if args.key?(:machine_type) @metadata = args[:metadata] if args.key?(:metadata) @min_cpu_platform = args[:min_cpu_platform] if args.key?(:min_cpu_platform) @network_interfaces = args[:network_interfaces] if args.key?(:network_interfaces) @post_key_revocation_action_type = args[:post_key_revocation_action_type] if args.key?(:post_key_revocation_action_type) @scheduling = args[:scheduling] if args.key?(:scheduling) @service_accounts = args[:service_accounts] if args.key?(:service_accounts) @tags = args[:tags] if args.key?(:tags) end |