Class: Google::Apis::ComputeAlpha::SslCertificateAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::SslCertificateAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::SslCertificatesScopedList>
A list of SslCertificatesScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::SslCertificateAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SslCertificateAggregatedList
constructor
A new instance of SslCertificateAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SslCertificateAggregatedList
Returns a new instance of SslCertificateAggregatedList.
73542 73543 73544 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 73542 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
73503 73504 73505 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 73503 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::SslCertificatesScopedList>
A list of SslCertificatesScopedList resources.
Corresponds to the JSON property items
73508 73509 73510 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 73508 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
sslCertificateAggregatedList for lists of SSL
Certificates.
Corresponds to the JSON property kind
73515 73516 73517 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 73515 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
73525 73526 73527 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 73525 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
73530 73531 73532 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 73530 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
73535 73536 73537 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 73535 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::SslCertificateAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
73540 73541 73542 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 73540 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
73547 73548 73549 73550 73551 73552 73553 73554 73555 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 73547 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |