Class: Google::Apis::ComputeAlpha::SslCertificateAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SslCertificateAggregatedList

Returns a new instance of SslCertificateAggregatedList.



73236
73237
73238
# File 'lib/google/apis/compute_alpha/classes.rb', line 73236

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


73197
73198
73199
# File 'lib/google/apis/compute_alpha/classes.rb', line 73197

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::SslCertificatesScopedList>

A list of SslCertificatesScopedList resources. Corresponds to the JSON property items



73202
73203
73204
# File 'lib/google/apis/compute_alpha/classes.rb', line 73202

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# sslCertificateAggregatedList for lists of SSL Certificates. Corresponds to the JSON property kind

Returns:

  • (String)


73209
73210
73211
# File 'lib/google/apis/compute_alpha/classes.rb', line 73209

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


73219
73220
73221
# File 'lib/google/apis/compute_alpha/classes.rb', line 73219

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


73224
73225
73226
# File 'lib/google/apis/compute_alpha/classes.rb', line 73224

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


73229
73230
73231
# File 'lib/google/apis/compute_alpha/classes.rb', line 73229

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::SslCertificateAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



73234
73235
73236
# File 'lib/google/apis/compute_alpha/classes.rb', line 73234

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



73241
73242
73243
73244
73245
73246
73247
73248
73249
# File 'lib/google/apis/compute_alpha/classes.rb', line 73241

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end