Class: Google::Apis::ComputeAlpha::SslCertificateAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SslCertificateAggregatedList

Returns a new instance of SslCertificateAggregatedList.



71867
71868
71869
# File 'lib/google/apis/compute_alpha/classes.rb', line 71867

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


71828
71829
71830
# File 'lib/google/apis/compute_alpha/classes.rb', line 71828

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::SslCertificatesScopedList>

A list of SslCertificatesScopedList resources. Corresponds to the JSON property items



71833
71834
71835
# File 'lib/google/apis/compute_alpha/classes.rb', line 71833

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# sslCertificateAggregatedList for lists of SSL Certificates. Corresponds to the JSON property kind

Returns:

  • (String)


71840
71841
71842
# File 'lib/google/apis/compute_alpha/classes.rb', line 71840

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


71850
71851
71852
# File 'lib/google/apis/compute_alpha/classes.rb', line 71850

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


71855
71856
71857
# File 'lib/google/apis/compute_alpha/classes.rb', line 71855

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


71860
71861
71862
# File 'lib/google/apis/compute_alpha/classes.rb', line 71860

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::SslCertificateAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



71865
71866
71867
# File 'lib/google/apis/compute_alpha/classes.rb', line 71865

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



71872
71873
71874
71875
71876
71877
71878
71879
71880
# File 'lib/google/apis/compute_alpha/classes.rb', line 71872

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end