Class: Google::Apis::ComputeAlpha::SslCertificateAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SslCertificateAggregatedList

Returns a new instance of SslCertificateAggregatedList.



70980
70981
70982
# File 'lib/google/apis/compute_alpha/classes.rb', line 70980

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


70941
70942
70943
# File 'lib/google/apis/compute_alpha/classes.rb', line 70941

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::SslCertificatesScopedList>

A list of SslCertificatesScopedList resources. Corresponds to the JSON property items



70946
70947
70948
# File 'lib/google/apis/compute_alpha/classes.rb', line 70946

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# sslCertificateAggregatedList for lists of SSL Certificates. Corresponds to the JSON property kind

Returns:

  • (String)


70953
70954
70955
# File 'lib/google/apis/compute_alpha/classes.rb', line 70953

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


70963
70964
70965
# File 'lib/google/apis/compute_alpha/classes.rb', line 70963

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


70968
70969
70970
# File 'lib/google/apis/compute_alpha/classes.rb', line 70968

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


70973
70974
70975
# File 'lib/google/apis/compute_alpha/classes.rb', line 70973

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::SslCertificateAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



70978
70979
70980
# File 'lib/google/apis/compute_alpha/classes.rb', line 70978

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



70985
70986
70987
70988
70989
70990
70991
70992
70993
# File 'lib/google/apis/compute_alpha/classes.rb', line 70985

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end