Class: Google::Apis::ComputeAlpha::SslCertificateAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SslCertificateAggregatedList

Returns a new instance of SslCertificateAggregatedList.



70062
70063
70064
# File 'lib/google/apis/compute_alpha/classes.rb', line 70062

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


70023
70024
70025
# File 'lib/google/apis/compute_alpha/classes.rb', line 70023

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::SslCertificatesScopedList>

A list of SslCertificatesScopedList resources. Corresponds to the JSON property items



70028
70029
70030
# File 'lib/google/apis/compute_alpha/classes.rb', line 70028

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# sslCertificateAggregatedList for lists of SSL Certificates. Corresponds to the JSON property kind

Returns:

  • (String)


70035
70036
70037
# File 'lib/google/apis/compute_alpha/classes.rb', line 70035

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


70045
70046
70047
# File 'lib/google/apis/compute_alpha/classes.rb', line 70045

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


70050
70051
70052
# File 'lib/google/apis/compute_alpha/classes.rb', line 70050

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


70055
70056
70057
# File 'lib/google/apis/compute_alpha/classes.rb', line 70055

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::SslCertificateAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



70060
70061
70062
# File 'lib/google/apis/compute_alpha/classes.rb', line 70060

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



70067
70068
70069
70070
70071
70072
70073
70074
70075
# File 'lib/google/apis/compute_alpha/classes.rb', line 70067

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end