Class: Google::Apis::ComputeAlpha::SslCertificateList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::SslCertificateList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Contains a list of SslCertificate resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::SslCertificate>
A list of SslCertificate resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::SslCertificateList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SslCertificateList
constructor
A new instance of SslCertificateList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SslCertificateList
Returns a new instance of SslCertificateList.
73667 73668 73669 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 73667 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
73635 73636 73637 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 73635 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::SslCertificate>
A list of SslCertificate resources.
Corresponds to the JSON property items
73640 73641 73642 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 73640 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
73645 73646 73647 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 73645 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
73655 73656 73657 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 73655 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
73660 73661 73662 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 73660 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::SslCertificateList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
73665 73666 73667 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 73665 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
73672 73673 73674 73675 73676 73677 73678 73679 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 73672 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |