Class: Google::Apis::ComputeAlpha::SslCertificateList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of SslCertificate resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SslCertificateList

Returns a new instance of SslCertificateList.



71992
71993
71994
# File 'lib/google/apis/compute_alpha/classes.rb', line 71992

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


71960
71961
71962
# File 'lib/google/apis/compute_alpha/classes.rb', line 71960

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::SslCertificate>

A list of SslCertificate resources. Corresponds to the JSON property items



71965
71966
71967
# File 'lib/google/apis/compute_alpha/classes.rb', line 71965

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


71970
71971
71972
# File 'lib/google/apis/compute_alpha/classes.rb', line 71970

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


71980
71981
71982
# File 'lib/google/apis/compute_alpha/classes.rb', line 71980

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


71985
71986
71987
# File 'lib/google/apis/compute_alpha/classes.rb', line 71985

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::SslCertificateList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



71990
71991
71992
# File 'lib/google/apis/compute_alpha/classes.rb', line 71990

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



71997
71998
71999
72000
72001
72002
72003
72004
# File 'lib/google/apis/compute_alpha/classes.rb', line 71997

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end