Class: Google::Apis::ComputeAlpha::SslCertificateList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::SslCertificateList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Contains a list of SslCertificate resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::SslCertificate>
A list of SslCertificate resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::SslCertificateList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SslCertificateList
constructor
A new instance of SslCertificateList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SslCertificateList
Returns a new instance of SslCertificateList.
71328 71329 71330 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 71328 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
71296 71297 71298 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 71296 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::SslCertificate>
A list of SslCertificate resources.
Corresponds to the JSON property items
71301 71302 71303 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 71301 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
71306 71307 71308 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 71306 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
71316 71317 71318 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 71316 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
71321 71322 71323 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 71321 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::SslCertificateList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
71326 71327 71328 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 71326 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
71333 71334 71335 71336 71337 71338 71339 71340 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 71333 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |