Class: Google::Apis::ComputeAlpha::SslCertificateList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::SslCertificateList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Contains a list of SslCertificate resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::SslCertificate>
A list of SslCertificate resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::SslCertificateList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SslCertificateList
constructor
A new instance of SslCertificateList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SslCertificateList
Returns a new instance of SslCertificateList.
71105 71106 71107 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 71105 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
71073 71074 71075 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 71073 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::SslCertificate>
A list of SslCertificate resources.
Corresponds to the JSON property items
71078 71079 71080 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 71078 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
71083 71084 71085 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 71083 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
71093 71094 71095 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 71093 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
71098 71099 71100 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 71098 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::SslCertificateList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
71103 71104 71105 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 71103 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
71110 71111 71112 71113 71114 71115 71116 71117 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 71110 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |