Class: Google::Apis::ComputeAlpha::SslCertificateList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of SslCertificate resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SslCertificateList

Returns a new instance of SslCertificateList.



70187
70188
70189
# File 'lib/google/apis/compute_alpha/classes.rb', line 70187

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


70155
70156
70157
# File 'lib/google/apis/compute_alpha/classes.rb', line 70155

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::SslCertificate>

A list of SslCertificate resources. Corresponds to the JSON property items



70160
70161
70162
# File 'lib/google/apis/compute_alpha/classes.rb', line 70160

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


70165
70166
70167
# File 'lib/google/apis/compute_alpha/classes.rb', line 70165

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


70175
70176
70177
# File 'lib/google/apis/compute_alpha/classes.rb', line 70175

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


70180
70181
70182
# File 'lib/google/apis/compute_alpha/classes.rb', line 70180

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::SslCertificateList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



70185
70186
70187
# File 'lib/google/apis/compute_alpha/classes.rb', line 70185

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



70192
70193
70194
70195
70196
70197
70198
70199
# File 'lib/google/apis/compute_alpha/classes.rb', line 70192

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end