Class: Google::Apis::ComputeAlpha::SslHealthCheck
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::SslHealthCheck
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#port ⇒ Fixnum
The TCP port number to which the health check prober sends packets.
-
#port_name ⇒ String
Not supported.
-
#port_specification ⇒ String
Specifies how a port is selected for health checking.
-
#proxy_header ⇒ String
Specifies the type of proxy header to append before sending data to the backend, either NONE or PROXY_V1.
-
#request ⇒ String
Instructs the health check prober to send this exact ASCII string, up to 1024 bytes in length, after establishing the TCP connection and SSL handshake.
-
#response ⇒ String
Creates a content-based SSL health check.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SslHealthCheck
constructor
A new instance of SslHealthCheck.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SslHealthCheck
Returns a new instance of SslHealthCheck.
64458 64459 64460 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64458 def initialize(**args) update!(**args) end |
Instance Attribute Details
#port ⇒ Fixnum
The TCP port number to which the health check prober sends packets. The
default value is 443. Valid values are 1 through65535.
Corresponds to the JSON property port
64400 64401 64402 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64400 def port @port end |
#port_name ⇒ String
Not supported.
Corresponds to the JSON property portName
64405 64406 64407 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64405 def port_name @port_name end |
#port_specification ⇒ String
Specifies how a port is selected for health checking. Can be one of the
following values:
USE_FIXED_PORT: Specifies a port number explicitly using theport field in the
health check. Supported by backend services
for passthrough load balancers and backend services for proxy load
balancers. Not supported by target pools. The health check supports all
backends supported by the backend service provided the backend can be
health checked. For example, GCE_VM_IP network endpoint
groups, GCE_VM_IP_PORT network endpoint groups, and instance
group backends.
USE_NAMED_PORT: Not supported.
USE_SERVING_PORT: Provides an indirect method of specifying
the health check port by referring to the backend service. Only supported
by backend services for proxy load balancers. Not supported by target
pools. Not supported by backend services for passthrough load balancers.
Supports all backends that can be health checked; for example,GCE_VM_IP_PORT
network endpoint groups and instance group
backends.
For GCE_VM_IP_PORT network endpoint group backends, the health
check uses the port number specified for each endpoint in the network
endpoint group. For instance group backends, the health check uses the
port number determined by looking up the backend service's named port in
the instance group's list of named ports.
Corresponds to the JSON property portSpecification
64432 64433 64434 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64432 def port_specification @port_specification end |
#proxy_header ⇒ String
Specifies the type of proxy header to append before sending data to the
backend, either NONE or PROXY_V1. The default
is NONE.
Corresponds to the JSON property proxyHeader
64439 64440 64441 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64439 def proxy_header @proxy_header end |
#request ⇒ String
Instructs the health check prober to send this exact ASCII string, up to
1024 bytes in length, after establishing the TCP connection and SSL
handshake.
Corresponds to the JSON property request
64446 64447 64448 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64446 def request @request end |
#response ⇒ String
Creates a content-based SSL health check. In addition to establishing a
TCP connection and the TLS handshake, you can configure the health check to
pass only when the backend sends this exact response ASCII string, up to
1024 bytes in length. For details, see:
https://cloud.google.com/load-balancing/docs/health-check-concepts#criteria-
protocol-ssl-tcp
Corresponds to the JSON property response
64456 64457 64458 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64456 def response @response end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
64463 64464 64465 64466 64467 64468 64469 64470 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 64463 def update!(**args) @port = args[:port] if args.key?(:port) @port_name = args[:port_name] if args.key?(:port_name) @port_specification = args[:port_specification] if args.key?(:port_specification) @proxy_header = args[:proxy_header] if args.key?(:proxy_header) @request = args[:request] if args.key?(:request) @response = args[:response] if args.key?(:response) end |