Class: Google::Apis::ComputeAlpha::SslPoliciesAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SslPoliciesAggregatedList

Returns a new instance of SslPoliciesAggregatedList.



73657
73658
73659
# File 'lib/google/apis/compute_alpha/classes.rb', line 73657

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


73614
73615
73616
# File 'lib/google/apis/compute_alpha/classes.rb', line 73614

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


73619
73620
73621
# File 'lib/google/apis/compute_alpha/classes.rb', line 73619

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::SslPoliciesScopedList>

A list of SslPoliciesScopedList resources. Corresponds to the JSON property items



73624
73625
73626
# File 'lib/google/apis/compute_alpha/classes.rb', line 73624

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# sslPolicyAggregatedList for lists of SSL Policies. Corresponds to the JSON property kind

Returns:

  • (String)


73630
73631
73632
# File 'lib/google/apis/compute_alpha/classes.rb', line 73630

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


73640
73641
73642
# File 'lib/google/apis/compute_alpha/classes.rb', line 73640

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


73645
73646
73647
# File 'lib/google/apis/compute_alpha/classes.rb', line 73645

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


73650
73651
73652
# File 'lib/google/apis/compute_alpha/classes.rb', line 73650

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::SslPoliciesAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



73655
73656
73657
# File 'lib/google/apis/compute_alpha/classes.rb', line 73655

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



73662
73663
73664
73665
73666
73667
73668
73669
73670
73671
# File 'lib/google/apis/compute_alpha/classes.rb', line 73662

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end