Class: Google::Apis::ComputeAlpha::SslPoliciesAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SslPoliciesAggregatedList

Returns a new instance of SslPoliciesAggregatedList.



72288
72289
72290
# File 'lib/google/apis/compute_alpha/classes.rb', line 72288

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


72245
72246
72247
# File 'lib/google/apis/compute_alpha/classes.rb', line 72245

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


72250
72251
72252
# File 'lib/google/apis/compute_alpha/classes.rb', line 72250

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::SslPoliciesScopedList>

A list of SslPoliciesScopedList resources. Corresponds to the JSON property items



72255
72256
72257
# File 'lib/google/apis/compute_alpha/classes.rb', line 72255

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# sslPolicyAggregatedList for lists of SSL Policies. Corresponds to the JSON property kind

Returns:

  • (String)


72261
72262
72263
# File 'lib/google/apis/compute_alpha/classes.rb', line 72261

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


72271
72272
72273
# File 'lib/google/apis/compute_alpha/classes.rb', line 72271

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


72276
72277
72278
# File 'lib/google/apis/compute_alpha/classes.rb', line 72276

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


72281
72282
72283
# File 'lib/google/apis/compute_alpha/classes.rb', line 72281

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::SslPoliciesAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



72286
72287
72288
# File 'lib/google/apis/compute_alpha/classes.rb', line 72286

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



72293
72294
72295
72296
72297
72298
72299
72300
72301
72302
# File 'lib/google/apis/compute_alpha/classes.rb', line 72293

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end