Class: Google::Apis::ComputeAlpha::SslPoliciesAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SslPoliciesAggregatedList

Returns a new instance of SslPoliciesAggregatedList.



72231
72232
72233
# File 'lib/google/apis/compute_alpha/classes.rb', line 72231

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


72188
72189
72190
# File 'lib/google/apis/compute_alpha/classes.rb', line 72188

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


72193
72194
72195
# File 'lib/google/apis/compute_alpha/classes.rb', line 72193

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::SslPoliciesScopedList>

A list of SslPoliciesScopedList resources. Corresponds to the JSON property items



72198
72199
72200
# File 'lib/google/apis/compute_alpha/classes.rb', line 72198

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# sslPolicyAggregatedList for lists of SSL Policies. Corresponds to the JSON property kind

Returns:

  • (String)


72204
72205
72206
# File 'lib/google/apis/compute_alpha/classes.rb', line 72204

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


72214
72215
72216
# File 'lib/google/apis/compute_alpha/classes.rb', line 72214

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


72219
72220
72221
# File 'lib/google/apis/compute_alpha/classes.rb', line 72219

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


72224
72225
72226
# File 'lib/google/apis/compute_alpha/classes.rb', line 72224

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::SslPoliciesAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



72229
72230
72231
# File 'lib/google/apis/compute_alpha/classes.rb', line 72229

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



72236
72237
72238
72239
72240
72241
72242
72243
72244
72245
# File 'lib/google/apis/compute_alpha/classes.rb', line 72236

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end