Class: Google::Apis::ComputeAlpha::SslPoliciesAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::SslPoliciesAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::SslPoliciesScopedList>
A list of SslPoliciesScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::SslPoliciesAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SslPoliciesAggregatedList
constructor
A new instance of SslPoliciesAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SslPoliciesAggregatedList
Returns a new instance of SslPoliciesAggregatedList.
71624 71625 71626 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 71624 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
71581 71582 71583 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 71581 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
71586 71587 71588 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 71586 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::SslPoliciesScopedList>
A list of SslPoliciesScopedList resources.
Corresponds to the JSON property items
71591 71592 71593 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 71591 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
sslPolicyAggregatedList for lists of SSL Policies.
Corresponds to the JSON property kind
71597 71598 71599 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 71597 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
71607 71608 71609 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 71607 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
71612 71613 71614 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 71612 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
71617 71618 71619 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 71617 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::SslPoliciesAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
71622 71623 71624 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 71622 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
71629 71630 71631 71632 71633 71634 71635 71636 71637 71638 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 71629 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |