Class: Google::Apis::ComputeAlpha::SslPoliciesAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SslPoliciesAggregatedList

Returns a new instance of SslPoliciesAggregatedList.



71622
71623
71624
# File 'lib/google/apis/compute_alpha/classes.rb', line 71622

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


71579
71580
71581
# File 'lib/google/apis/compute_alpha/classes.rb', line 71579

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


71584
71585
71586
# File 'lib/google/apis/compute_alpha/classes.rb', line 71584

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::SslPoliciesScopedList>

A list of SslPoliciesScopedList resources. Corresponds to the JSON property items



71589
71590
71591
# File 'lib/google/apis/compute_alpha/classes.rb', line 71589

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# sslPolicyAggregatedList for lists of SSL Policies. Corresponds to the JSON property kind

Returns:

  • (String)


71595
71596
71597
# File 'lib/google/apis/compute_alpha/classes.rb', line 71595

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


71605
71606
71607
# File 'lib/google/apis/compute_alpha/classes.rb', line 71605

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


71610
71611
71612
# File 'lib/google/apis/compute_alpha/classes.rb', line 71610

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


71615
71616
71617
# File 'lib/google/apis/compute_alpha/classes.rb', line 71615

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::SslPoliciesAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



71620
71621
71622
# File 'lib/google/apis/compute_alpha/classes.rb', line 71620

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



71627
71628
71629
71630
71631
71632
71633
71634
71635
71636
# File 'lib/google/apis/compute_alpha/classes.rb', line 71627

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end