Class: Google::Apis::ComputeAlpha::SslPoliciesAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::SslPoliciesAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::SslPoliciesScopedList>
A list of SslPoliciesScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::SslPoliciesAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SslPoliciesAggregatedList
constructor
A new instance of SslPoliciesAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SslPoliciesAggregatedList
Returns a new instance of SslPoliciesAggregatedList.
70483 70484 70485 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 70483 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
70440 70441 70442 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 70440 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
70445 70446 70447 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 70445 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::SslPoliciesScopedList>
A list of SslPoliciesScopedList resources.
Corresponds to the JSON property items
70450 70451 70452 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 70450 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
sslPolicyAggregatedList for lists of SSL Policies.
Corresponds to the JSON property kind
70456 70457 70458 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 70456 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
70466 70467 70468 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 70466 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
70471 70472 70473 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 70471 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
70476 70477 70478 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 70476 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::SslPoliciesAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
70481 70482 70483 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 70481 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
70488 70489 70490 70491 70492 70493 70494 70495 70496 70497 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 70488 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |