Class: Google::Apis::ComputeAlpha::SslPoliciesList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SslPoliciesList

Returns a new instance of SslPoliciesList.



74092
74093
74094
# File 'lib/google/apis/compute_alpha/classes.rb', line 74092

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Output only. [Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


74058
74059
74060
# File 'lib/google/apis/compute_alpha/classes.rb', line 74058

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::SslPolicy>

Output only. A list of SslPolicy resources. Corresponds to the JSON property items



74063
74064
74065
# File 'lib/google/apis/compute_alpha/classes.rb', line 74063

def items
  @items
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute#sslPoliciesList for lists of sslPolicies. Corresponds to the JSON property kind

Returns:

  • (String)


74069
74070
74071
# File 'lib/google/apis/compute_alpha/classes.rb', line 74069

def kind
  @kind
end

#next_page_tokenString

Output only. [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


74080
74081
74082
# File 'lib/google/apis/compute_alpha/classes.rb', line 74080

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


74085
74086
74087
# File 'lib/google/apis/compute_alpha/classes.rb', line 74085

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::SslPoliciesList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



74090
74091
74092
# File 'lib/google/apis/compute_alpha/classes.rb', line 74090

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



74097
74098
74099
74100
74101
74102
74103
74104
# File 'lib/google/apis/compute_alpha/classes.rb', line 74097

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end