Class: Google::Apis::ComputeAlpha::SslPoliciesList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SslPoliciesList

Returns a new instance of SslPoliciesList.



72417
72418
72419
# File 'lib/google/apis/compute_alpha/classes.rb', line 72417

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Output only. [Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


72383
72384
72385
# File 'lib/google/apis/compute_alpha/classes.rb', line 72383

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::SslPolicy>

Output only. A list of SslPolicy resources. Corresponds to the JSON property items



72388
72389
72390
# File 'lib/google/apis/compute_alpha/classes.rb', line 72388

def items
  @items
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute#sslPoliciesList for lists of sslPolicies. Corresponds to the JSON property kind

Returns:

  • (String)


72394
72395
72396
# File 'lib/google/apis/compute_alpha/classes.rb', line 72394

def kind
  @kind
end

#next_page_tokenString

Output only. [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


72405
72406
72407
# File 'lib/google/apis/compute_alpha/classes.rb', line 72405

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


72410
72411
72412
# File 'lib/google/apis/compute_alpha/classes.rb', line 72410

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::SslPoliciesList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



72415
72416
72417
# File 'lib/google/apis/compute_alpha/classes.rb', line 72415

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



72422
72423
72424
72425
72426
72427
72428
72429
# File 'lib/google/apis/compute_alpha/classes.rb', line 72422

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end