Class: Google::Apis::ComputeAlpha::SslPoliciesList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SslPoliciesList

Returns a new instance of SslPoliciesList.



72360
72361
72362
# File 'lib/google/apis/compute_alpha/classes.rb', line 72360

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Output only. [Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


72326
72327
72328
# File 'lib/google/apis/compute_alpha/classes.rb', line 72326

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::SslPolicy>

Output only. A list of SslPolicy resources. Corresponds to the JSON property items



72331
72332
72333
# File 'lib/google/apis/compute_alpha/classes.rb', line 72331

def items
  @items
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute#sslPoliciesList for lists of sslPolicies. Corresponds to the JSON property kind

Returns:

  • (String)


72337
72338
72339
# File 'lib/google/apis/compute_alpha/classes.rb', line 72337

def kind
  @kind
end

#next_page_tokenString

Output only. [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


72348
72349
72350
# File 'lib/google/apis/compute_alpha/classes.rb', line 72348

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


72353
72354
72355
# File 'lib/google/apis/compute_alpha/classes.rb', line 72353

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::SslPoliciesList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



72358
72359
72360
# File 'lib/google/apis/compute_alpha/classes.rb', line 72358

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



72365
72366
72367
72368
72369
72370
72371
72372
# File 'lib/google/apis/compute_alpha/classes.rb', line 72365

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end