Class: Google::Apis::ComputeAlpha::SslPoliciesList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SslPoliciesList

Returns a new instance of SslPoliciesList.



71753
71754
71755
# File 'lib/google/apis/compute_alpha/classes.rb', line 71753

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Output only. [Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


71719
71720
71721
# File 'lib/google/apis/compute_alpha/classes.rb', line 71719

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::SslPolicy>

Output only. A list of SslPolicy resources. Corresponds to the JSON property items



71724
71725
71726
# File 'lib/google/apis/compute_alpha/classes.rb', line 71724

def items
  @items
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute#sslPoliciesList for lists of sslPolicies. Corresponds to the JSON property kind

Returns:

  • (String)


71730
71731
71732
# File 'lib/google/apis/compute_alpha/classes.rb', line 71730

def kind
  @kind
end

#next_page_tokenString

Output only. [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


71741
71742
71743
# File 'lib/google/apis/compute_alpha/classes.rb', line 71741

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


71746
71747
71748
# File 'lib/google/apis/compute_alpha/classes.rb', line 71746

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::SslPoliciesList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



71751
71752
71753
# File 'lib/google/apis/compute_alpha/classes.rb', line 71751

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



71758
71759
71760
71761
71762
71763
71764
71765
# File 'lib/google/apis/compute_alpha/classes.rb', line 71758

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end