Class: Google::Apis::ComputeAlpha::SslPoliciesList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SslPoliciesList

Returns a new instance of SslPoliciesList.



70612
70613
70614
# File 'lib/google/apis/compute_alpha/classes.rb', line 70612

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Output only. [Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


70578
70579
70580
# File 'lib/google/apis/compute_alpha/classes.rb', line 70578

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::SslPolicy>

Output only. A list of SslPolicy resources. Corresponds to the JSON property items



70583
70584
70585
# File 'lib/google/apis/compute_alpha/classes.rb', line 70583

def items
  @items
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute#sslPoliciesList for lists of sslPolicies. Corresponds to the JSON property kind

Returns:

  • (String)


70589
70590
70591
# File 'lib/google/apis/compute_alpha/classes.rb', line 70589

def kind
  @kind
end

#next_page_tokenString

Output only. [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


70600
70601
70602
# File 'lib/google/apis/compute_alpha/classes.rb', line 70600

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


70605
70606
70607
# File 'lib/google/apis/compute_alpha/classes.rb', line 70605

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::SslPoliciesList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



70610
70611
70612
# File 'lib/google/apis/compute_alpha/classes.rb', line 70610

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



70617
70618
70619
70620
70621
70622
70623
70624
# File 'lib/google/apis/compute_alpha/classes.rb', line 70617

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end