Class: Google::Apis::ComputeAlpha::SslPolicy

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Represents an SSL Policy resource. Use SSL policies to control SSL features, such as versions and cipher suites, that are offered by Application Load Balancers and proxy Network Load Balancers. For more information, read SSL policies overview.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SslPolicy

Returns a new instance of SslPolicy.



72080
72081
72082
# File 'lib/google/apis/compute_alpha/classes.rb', line 72080

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


71964
71965
71966
# File 'lib/google/apis/compute_alpha/classes.rb', line 71964

def creation_timestamp
  @creation_timestamp
end

#custom_featuresArray<String>

A list of features enabled when the selected profile is CUSTOM. The method returns the set of features that can be specified in this list. This field must be empty if the profile is notCUSTOM. Corresponds to the JSON property customFeatures

Returns:

  • (Array<String>)


71971
71972
71973
# File 'lib/google/apis/compute_alpha/classes.rb', line 71971

def custom_features
  @custom_features
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


71977
71978
71979
# File 'lib/google/apis/compute_alpha/classes.rb', line 71977

def description
  @description
end

#enabled_featuresArray<String>

Output only. [Output Only] The list of features enabled in the SSL policy. Corresponds to the JSON property enabledFeatures

Returns:

  • (Array<String>)


71982
71983
71984
# File 'lib/google/apis/compute_alpha/classes.rb', line 71982

def enabled_features
  @enabled_features
end

#fingerprintString

Fingerprint of this resource. A hash of the contents stored in this object. This field is used in optimistic locking. This field will be ignored when inserting a SslPolicy. An up-to-date fingerprint must be provided in order to update the SslPolicy, otherwise the request will fail with error 412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve an SslPolicy. Corresponds to the JSON property fingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


71994
71995
71996
# File 'lib/google/apis/compute_alpha/classes.rb', line 71994

def fingerprint
  @fingerprint
end

#idFixnum

Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


72001
72002
72003
# File 'lib/google/apis/compute_alpha/classes.rb', line 72001

def id
  @id
end

#kindString

Output only. [Output only] Type of the resource. Alwayscompute#sslPolicyfor SSL policies. Corresponds to the JSON property kind

Returns:

  • (String)


72007
72008
72009
# File 'lib/google/apis/compute_alpha/classes.rb', line 72007

def kind
  @kind
end

#min_tls_versionString

The minimum version of SSL protocol that can be used by the clients to establish a connection with the load balancer. This can be one ofTLS_1_0, TLS_1_1, TLS_1_2,TLS_1_3. When set to TLS_1_3, the profile field must be set to RESTRICTED. Corresponds to the JSON property minTlsVersion

Returns:

  • (String)


72015
72016
72017
# File 'lib/google/apis/compute_alpha/classes.rb', line 72015

def min_tls_version
  @min_tls_version
end

#nameString

Name of the resource. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


72026
72027
72028
# File 'lib/google/apis/compute_alpha/classes.rb', line 72026

def name
  @name
end

#post_quantum_key_exchangeString

One of DEFAULT, ENABLED, orDEFERRED. Controls whether the load balancer negotiates X25519MLKEM768 key exchange when clients advertise support for it. When set to DEFAULT, or if no SSL Policy is attached to the target proxy, the load balancer disallows X25519MLKEM768 key exchange before October 2026, and allows it afterward. When set to ENABLED, the load balancer allows X25519MLKEM768 key exchange. When set toDEFERRED, the load balancer disallows X25519MLKEM768 key exchange until October 2027, and allows it afterward. Corresponds to the JSON property postQuantumKeyExchange

Returns:

  • (String)


72039
72040
72041
# File 'lib/google/apis/compute_alpha/classes.rb', line 72039

def post_quantum_key_exchange
  @post_quantum_key_exchange
end

#profileString

Profile specifies the set of SSL features that can be used by the load balancer when negotiating SSL with clients. This can be one ofCOMPATIBLE, MODERN, RESTRICTED,FIPS_202205, or CUSTOM. If usingCUSTOM, the set of SSL features to enable must be specified in the customFeatures field. If using FIPS_202205, the min_tls_version field must be set to TLS_1_2. Corresponds to the JSON property profile

Returns:

  • (String)


72049
72050
72051
# File 'lib/google/apis/compute_alpha/classes.rb', line 72049

def profile
  @profile
end

#regionString

Output only. [Output Only] URL of the region where the regional SSL policy resides. This field is not applicable to global SSL policies. Corresponds to the JSON property region

Returns:

  • (String)


72055
72056
72057
# File 'lib/google/apis/compute_alpha/classes.rb', line 72055

def region
  @region
end

Output only. [Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


72060
72061
72062
# File 'lib/google/apis/compute_alpha/classes.rb', line 72060

def self_link
  @self_link
end

Output only. [Output Only] Server-defined URL for this resource with the resource id. Corresponds to the JSON property selfLinkWithId

Returns:

  • (String)


72066
72067
72068
# File 'lib/google/apis/compute_alpha/classes.rb', line 72066

def self_link_with_id
  @self_link_with_id
end

#tls_settingsGoogle::Apis::ComputeAlpha::ServerTlsSettings

The TLS settings for the server. Corresponds to the JSON property tlsSettings



72071
72072
72073
# File 'lib/google/apis/compute_alpha/classes.rb', line 72071

def tls_settings
  @tls_settings
end

#warningsArray<Google::Apis::ComputeAlpha::SslPolicy::Warning>

Output only. [Output Only] If potential misconfigurations are detected for this SSL policy, this field will be populated with warning messages. Corresponds to the JSON property warnings



72078
72079
72080
# File 'lib/google/apis/compute_alpha/classes.rb', line 72078

def warnings
  @warnings
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



72085
72086
72087
72088
72089
72090
72091
72092
72093
72094
72095
72096
72097
72098
72099
72100
72101
72102
# File 'lib/google/apis/compute_alpha/classes.rb', line 72085

def update!(**args)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @custom_features = args[:custom_features] if args.key?(:custom_features)
  @description = args[:description] if args.key?(:description)
  @enabled_features = args[:enabled_features] if args.key?(:enabled_features)
  @fingerprint = args[:fingerprint] if args.key?(:fingerprint)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @min_tls_version = args[:min_tls_version] if args.key?(:min_tls_version)
  @name = args[:name] if args.key?(:name)
  @post_quantum_key_exchange = args[:post_quantum_key_exchange] if args.key?(:post_quantum_key_exchange)
  @profile = args[:profile] if args.key?(:profile)
  @region = args[:region] if args.key?(:region)
  @self_link = args[:self_link] if args.key?(:self_link)
  @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id)
  @tls_settings = args[:tls_settings] if args.key?(:tls_settings)
  @warnings = args[:warnings] if args.key?(:warnings)
end