Class: Google::Apis::ComputeAlpha::StatefulPolicyPreservedState

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Configuration of preserved resources.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StatefulPolicyPreservedState

Returns a new instance of StatefulPolicyPreservedState.



74579
74580
74581
# File 'lib/google/apis/compute_alpha/classes.rb', line 74579

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#disksHash<String,Google::Apis::ComputeAlpha::StatefulPolicyPreservedStateDiskDevice>

Disks created on the instances that will be preserved on instance delete, update, etc. This map is keyed with the device names of the disks. Corresponds to the JSON property disks



74563
74564
74565
# File 'lib/google/apis/compute_alpha/classes.rb', line 74563

def disks
  @disks
end

#external_i_psHash<String,Google::Apis::ComputeAlpha::StatefulPolicyPreservedStateNetworkIp>

External network IPs assigned to the instances that will be preserved on instance delete, update, etc. This map is keyed with the network interface name. Corresponds to the JSON property externalIPs



74570
74571
74572
# File 'lib/google/apis/compute_alpha/classes.rb', line 74570

def external_i_ps
  @external_i_ps
end

#internal_i_psHash<String,Google::Apis::ComputeAlpha::StatefulPolicyPreservedStateNetworkIp>

Internal network IPs assigned to the instances that will be preserved on instance delete, update, etc. This map is keyed with the network interface name. Corresponds to the JSON property internalIPs



74577
74578
74579
# File 'lib/google/apis/compute_alpha/classes.rb', line 74577

def internal_i_ps
  @internal_i_ps
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



74584
74585
74586
74587
74588
# File 'lib/google/apis/compute_alpha/classes.rb', line 74584

def update!(**args)
  @disks = args[:disks] if args.key?(:disks)
  @external_i_ps = args[:external_i_ps] if args.key?(:external_i_ps)
  @internal_i_ps = args[:internal_i_ps] if args.key?(:internal_i_ps)
end