Class: Google::Apis::ComputeAlpha::StatefulPolicyPreservedStateDiskDevice

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StatefulPolicyPreservedStateDiskDevice

Returns a new instance of StatefulPolicyPreservedStateDiskDevice.



72044
72045
72046
# File 'lib/google/apis/compute_alpha/classes.rb', line 72044

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#auto_deleteString

These stateful disks will never be deleted during autohealing, update or VM instance recreate operations. This flag is used to configure if the disk should be deleted after it is no longer used by the group, e.g. when the given instance or the whole group is deleted. Note: disks attached inREAD_ONLY mode cannot be auto-deleted. Corresponds to the JSON property autoDelete

Returns:

  • (String)


72042
72043
72044
# File 'lib/google/apis/compute_alpha/classes.rb', line 72042

def auto_delete
  @auto_delete
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



72049
72050
72051
# File 'lib/google/apis/compute_alpha/classes.rb', line 72049

def update!(**args)
  @auto_delete = args[:auto_delete] if args.key?(:auto_delete)
end