Class: Google::Apis::ComputeAlpha::StatefulPolicyPreservedStateDiskDevice

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StatefulPolicyPreservedStateDiskDevice

Returns a new instance of StatefulPolicyPreservedStateDiskDevice.



71123
71124
71125
# File 'lib/google/apis/compute_alpha/classes.rb', line 71123

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#auto_deleteString

These stateful disks will never be deleted during autohealing, update or VM instance recreate operations. This flag is used to configure if the disk should be deleted after it is no longer used by the group, e.g. when the given instance or the whole group is deleted. Note: disks attached inREAD_ONLY mode cannot be auto-deleted. Corresponds to the JSON property autoDelete

Returns:

  • (String)


71121
71122
71123
# File 'lib/google/apis/compute_alpha/classes.rb', line 71121

def auto_delete
  @auto_delete
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



71128
71129
71130
# File 'lib/google/apis/compute_alpha/classes.rb', line 71128

def update!(**args)
  @auto_delete = args[:auto_delete] if args.key?(:auto_delete)
end