Class: Google::Apis::ComputeAlpha::StatefulPolicyPreservedStateNetworkIp

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StatefulPolicyPreservedStateNetworkIp

Returns a new instance of StatefulPolicyPreservedStateNetworkIp.



74628
74629
74630
# File 'lib/google/apis/compute_alpha/classes.rb', line 74628

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#auto_deleteString

These stateful IPs will never be released during autohealing, update or VM instance recreate operations. This flag is used to configure if the IP reservation should be deleted after it is no longer used by the group, e.g. when the given instance or the whole group is deleted. Corresponds to the JSON property autoDelete

Returns:

  • (String)


74626
74627
74628
# File 'lib/google/apis/compute_alpha/classes.rb', line 74626

def auto_delete
  @auto_delete
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



74633
74634
74635
# File 'lib/google/apis/compute_alpha/classes.rb', line 74633

def update!(**args)
  @auto_delete = args[:auto_delete] if args.key?(:auto_delete)
end