Class: Google::Apis::ComputeAlpha::StatefulPolicyPreservedStateNetworkIp
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::StatefulPolicyPreservedStateNetworkIp
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#auto_delete ⇒ String
These stateful IPs will never be released during autohealing, update or VM instance recreate operations.
Instance Method Summary collapse
-
#initialize(**args) ⇒ StatefulPolicyPreservedStateNetworkIp
constructor
A new instance of StatefulPolicyPreservedStateNetworkIp.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ StatefulPolicyPreservedStateNetworkIp
Returns a new instance of StatefulPolicyPreservedStateNetworkIp.
72288 72289 72290 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 72288 def initialize(**args) update!(**args) end |
Instance Attribute Details
#auto_delete ⇒ String
These stateful IPs will never be released during autohealing,
update or VM instance recreate operations.
This flag is used to configure if the IP reservation should be deleted
after it is no longer used by the group, e.g. when the given instance
or the whole group is deleted.
Corresponds to the JSON property autoDelete
72286 72287 72288 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 72286 def auto_delete @auto_delete end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
72293 72294 72295 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 72293 def update!(**args) @auto_delete = args[:auto_delete] if args.key?(:auto_delete) end |