Class: Google::Apis::ComputeAlpha::StatefulPolicyPreservedStateNetworkIp
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::StatefulPolicyPreservedStateNetworkIp
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#auto_delete ⇒ String
These stateful IPs will never be released during autohealing, update or VM instance recreate operations.
Instance Method Summary collapse
-
#initialize(**args) ⇒ StatefulPolicyPreservedStateNetworkIp
constructor
A new instance of StatefulPolicyPreservedStateNetworkIp.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ StatefulPolicyPreservedStateNetworkIp
Returns a new instance of StatefulPolicyPreservedStateNetworkIp.
71146 71147 71148 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 71146 def initialize(**args) update!(**args) end |
Instance Attribute Details
#auto_delete ⇒ String
These stateful IPs will never be released during autohealing,
update or VM instance recreate operations.
This flag is used to configure if the IP reservation should be deleted
after it is no longer used by the group, e.g. when the given instance
or the whole group is deleted.
Corresponds to the JSON property autoDelete
71144 71145 71146 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 71144 def auto_delete @auto_delete end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
71151 71152 71153 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 71151 def update!(**args) @auto_delete = args[:auto_delete] if args.key?(:auto_delete) end |