Class: Google::Apis::ComputeAlpha::StoragePool

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Represents a zonal storage pool resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StoragePool

Returns a new instance of StoragePool.



74840
74841
74842
# File 'lib/google/apis/compute_alpha/classes.rb', line 74840

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#capacity_provisioning_typeString

Provisioning type of the byte capacity of the pool. Corresponds to the JSON property capacityProvisioningType

Returns:

  • (String)


74684
74685
74686
# File 'lib/google/apis/compute_alpha/classes.rb', line 74684

def capacity_provisioning_type
  @capacity_provisioning_type
end

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


74690
74691
74692
# File 'lib/google/apis/compute_alpha/classes.rb', line 74690

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


74696
74697
74698
# File 'lib/google/apis/compute_alpha/classes.rb', line 74696

def description
  @description
end

#exapool_provisioned_capacity_gbGoogle::Apis::ComputeAlpha::StoragePoolExapoolProvisionedCapacityGb

Exapool provisioned capacities for each SKU type Corresponds to the JSON property exapoolProvisionedCapacityGb



74701
74702
74703
# File 'lib/google/apis/compute_alpha/classes.rb', line 74701

def exapool_provisioned_capacity_gb
  @exapool_provisioned_capacity_gb
end

#idFixnum

Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


74708
74709
74710
# File 'lib/google/apis/compute_alpha/classes.rb', line 74708

def id
  @id
end

#kindString

Output only. [Output Only] Type of the resource. Always compute#storagePool for storage pools. Corresponds to the JSON property kind

Returns:

  • (String)


74714
74715
74716
# File 'lib/google/apis/compute_alpha/classes.rb', line 74714

def kind
  @kind
end

#label_fingerprintString

A fingerprint for the labels being applied to this storage pool, which is essentially a hash of the labels set used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update labels. You must always provide an up-to-date fingerprint hash in order to update or change labels, otherwise the request will fail with error412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve a storage pool. Corresponds to the JSON property labelFingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


74727
74728
74729
# File 'lib/google/apis/compute_alpha/classes.rb', line 74727

def label_fingerprint
  @label_fingerprint
end

#labelsHash<String,String>

Labels to apply to this storage pool. These can be later modified by the setLabels method. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


74733
74734
74735
# File 'lib/google/apis/compute_alpha/classes.rb', line 74733

def labels
  @labels
end

#nameString

Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


74744
74745
74746
# File 'lib/google/apis/compute_alpha/classes.rb', line 74744

def name
  @name
end

#paramsGoogle::Apis::ComputeAlpha::StoragePoolParams

Additional storage pool params. Corresponds to the JSON property params



74749
74750
74751
# File 'lib/google/apis/compute_alpha/classes.rb', line 74749

def params
  @params
end

#performance_provisioning_typeString

Provisioning type of the performance-related parameters of the pool, such as throughput and IOPS. Corresponds to the JSON property performanceProvisioningType

Returns:

  • (String)


74755
74756
74757
# File 'lib/google/apis/compute_alpha/classes.rb', line 74755

def performance_provisioning_type
  @performance_provisioning_type
end

#pool_provisioned_capacity_gbFixnum

Size of the storage pool in GiB. For more information about the size limits, see https://cloud.google.com/compute/docs/disks/storage-pools. Corresponds to the JSON property poolProvisionedCapacityGb

Returns:

  • (Fixnum)


74761
74762
74763
# File 'lib/google/apis/compute_alpha/classes.rb', line 74761

def pool_provisioned_capacity_gb
  @pool_provisioned_capacity_gb
end

#pool_provisioned_iopsFixnum

Provisioned IOPS of the storage pool. Only relevant if the storage pool type is hyperdisk-balanced. Corresponds to the JSON property poolProvisionedIops

Returns:

  • (Fixnum)


74767
74768
74769
# File 'lib/google/apis/compute_alpha/classes.rb', line 74767

def pool_provisioned_iops
  @pool_provisioned_iops
end

#pool_provisioned_throughputFixnum

Provisioned throughput of the storage pool in MiB/s. Only relevant if the storage pool type is hyperdisk-balanced or hyperdisk-throughput. Corresponds to the JSON property poolProvisionedThroughput

Returns:

  • (Fixnum)


74773
74774
74775
# File 'lib/google/apis/compute_alpha/classes.rb', line 74773

def pool_provisioned_throughput
  @pool_provisioned_throughput
end

#provisioned_iopsFixnum

DEPRECATED -- use "pool provisioned IOPS". Corresponds to the JSON property provisionedIops

Returns:

  • (Fixnum)


74778
74779
74780
# File 'lib/google/apis/compute_alpha/classes.rb', line 74778

def provisioned_iops
  @provisioned_iops
end

#provisioned_throughputFixnum

DEPRECATED -- use "pool provisioned throughput". Corresponds to the JSON property provisionedThroughput

Returns:

  • (Fixnum)


74783
74784
74785
# File 'lib/google/apis/compute_alpha/classes.rb', line 74783

def provisioned_throughput
  @provisioned_throughput
end

#resource_statusGoogle::Apis::ComputeAlpha::StoragePoolResourceStatus

[Output Only] Contains output only fields. Corresponds to the JSON property resourceStatus



74788
74789
74790
# File 'lib/google/apis/compute_alpha/classes.rb', line 74788

def resource_status
  @resource_status
end

Output only. [Output Only] Server-defined fully-qualified URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


74794
74795
74796
# File 'lib/google/apis/compute_alpha/classes.rb', line 74794

def self_link
  @self_link
end

Output only. [Output Only] Server-defined URL for this resource's resource id. Corresponds to the JSON property selfLinkWithId

Returns:

  • (String)


74799
74800
74801
# File 'lib/google/apis/compute_alpha/classes.rb', line 74799

def self_link_with_id
  @self_link_with_id
end

#share_settingsGoogle::Apis::ComputeAlpha::StoragePoolShareSettings

Share settings for the storage pool. Corresponds to the JSON property shareSettings



74804
74805
74806
# File 'lib/google/apis/compute_alpha/classes.rb', line 74804

def share_settings
  @share_settings
end

#size_gbFixnum

DEPRECATED -- use "pool provisioned capacity gb". Corresponds to the JSON property sizeGb

Returns:

  • (Fixnum)


74809
74810
74811
# File 'lib/google/apis/compute_alpha/classes.rb', line 74809

def size_gb
  @size_gb
end

#stateString

Output only. [Output Only] The status of storage pool creation.

  • CREATING: Storage pool is provisioning. storagePool.
  • FAILED: Storage pool creation failed.
  • READY: Storage pool is ready for use.
  • DELETING: Storage pool is deleting. Corresponds to the JSON property state

Returns:

  • (String)


74821
74822
74823
# File 'lib/google/apis/compute_alpha/classes.rb', line 74821

def state
  @state
end

#statusGoogle::Apis::ComputeAlpha::StoragePoolResourceStatus

[Output Only] Contains output only fields. Corresponds to the JSON property status



74826
74827
74828
# File 'lib/google/apis/compute_alpha/classes.rb', line 74826

def status
  @status
end

#storage_pool_typeString

Type of the storage pool. Corresponds to the JSON property storagePoolType

Returns:

  • (String)


74831
74832
74833
# File 'lib/google/apis/compute_alpha/classes.rb', line 74831

def storage_pool_type
  @storage_pool_type
end

#zoneString

Output only. [Output Only] URL of the zone where the storage pool resides. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body. Corresponds to the JSON property zone

Returns:

  • (String)


74838
74839
74840
# File 'lib/google/apis/compute_alpha/classes.rb', line 74838

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



74845
74846
74847
74848
74849
74850
74851
74852
74853
74854
74855
74856
74857
74858
74859
74860
74861
74862
74863
74864
74865
74866
74867
74868
74869
74870
74871
# File 'lib/google/apis/compute_alpha/classes.rb', line 74845

def update!(**args)
  @capacity_provisioning_type = args[:capacity_provisioning_type] if args.key?(:capacity_provisioning_type)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @exapool_provisioned_capacity_gb = args[:exapool_provisioned_capacity_gb] if args.key?(:exapool_provisioned_capacity_gb)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @label_fingerprint = args[:label_fingerprint] if args.key?(:label_fingerprint)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @params = args[:params] if args.key?(:params)
  @performance_provisioning_type = args[:performance_provisioning_type] if args.key?(:performance_provisioning_type)
  @pool_provisioned_capacity_gb = args[:pool_provisioned_capacity_gb] if args.key?(:pool_provisioned_capacity_gb)
  @pool_provisioned_iops = args[:pool_provisioned_iops] if args.key?(:pool_provisioned_iops)
  @pool_provisioned_throughput = args[:pool_provisioned_throughput] if args.key?(:pool_provisioned_throughput)
  @provisioned_iops = args[:provisioned_iops] if args.key?(:provisioned_iops)
  @provisioned_throughput = args[:provisioned_throughput] if args.key?(:provisioned_throughput)
  @resource_status = args[:resource_status] if args.key?(:resource_status)
  @self_link = args[:self_link] if args.key?(:self_link)
  @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id)
  @share_settings = args[:share_settings] if args.key?(:share_settings)
  @size_gb = args[:size_gb] if args.key?(:size_gb)
  @state = args[:state] if args.key?(:state)
  @status = args[:status] if args.key?(:status)
  @storage_pool_type = args[:storage_pool_type] if args.key?(:storage_pool_type)
  @zone = args[:zone] if args.key?(:zone)
end