Class: Google::Apis::ComputeAlpha::StoragePool

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Represents a zonal storage pool resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StoragePool

Returns a new instance of StoragePool.



74534
74535
74536
# File 'lib/google/apis/compute_alpha/classes.rb', line 74534

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#capacity_provisioning_typeString

Provisioning type of the byte capacity of the pool. Corresponds to the JSON property capacityProvisioningType

Returns:

  • (String)


74378
74379
74380
# File 'lib/google/apis/compute_alpha/classes.rb', line 74378

def capacity_provisioning_type
  @capacity_provisioning_type
end

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


74384
74385
74386
# File 'lib/google/apis/compute_alpha/classes.rb', line 74384

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


74390
74391
74392
# File 'lib/google/apis/compute_alpha/classes.rb', line 74390

def description
  @description
end

#exapool_provisioned_capacity_gbGoogle::Apis::ComputeAlpha::StoragePoolExapoolProvisionedCapacityGb

Exapool provisioned capacities for each SKU type Corresponds to the JSON property exapoolProvisionedCapacityGb



74395
74396
74397
# File 'lib/google/apis/compute_alpha/classes.rb', line 74395

def exapool_provisioned_capacity_gb
  @exapool_provisioned_capacity_gb
end

#idFixnum

Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


74402
74403
74404
# File 'lib/google/apis/compute_alpha/classes.rb', line 74402

def id
  @id
end

#kindString

Output only. [Output Only] Type of the resource. Always compute#storagePool for storage pools. Corresponds to the JSON property kind

Returns:

  • (String)


74408
74409
74410
# File 'lib/google/apis/compute_alpha/classes.rb', line 74408

def kind
  @kind
end

#label_fingerprintString

A fingerprint for the labels being applied to this storage pool, which is essentially a hash of the labels set used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update labels. You must always provide an up-to-date fingerprint hash in order to update or change labels, otherwise the request will fail with error412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve a storage pool. Corresponds to the JSON property labelFingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


74421
74422
74423
# File 'lib/google/apis/compute_alpha/classes.rb', line 74421

def label_fingerprint
  @label_fingerprint
end

#labelsHash<String,String>

Labels to apply to this storage pool. These can be later modified by the setLabels method. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


74427
74428
74429
# File 'lib/google/apis/compute_alpha/classes.rb', line 74427

def labels
  @labels
end

#nameString

Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


74438
74439
74440
# File 'lib/google/apis/compute_alpha/classes.rb', line 74438

def name
  @name
end

#paramsGoogle::Apis::ComputeAlpha::StoragePoolParams

Additional storage pool params. Corresponds to the JSON property params



74443
74444
74445
# File 'lib/google/apis/compute_alpha/classes.rb', line 74443

def params
  @params
end

#performance_provisioning_typeString

Provisioning type of the performance-related parameters of the pool, such as throughput and IOPS. Corresponds to the JSON property performanceProvisioningType

Returns:

  • (String)


74449
74450
74451
# File 'lib/google/apis/compute_alpha/classes.rb', line 74449

def performance_provisioning_type
  @performance_provisioning_type
end

#pool_provisioned_capacity_gbFixnum

Size of the storage pool in GiB. For more information about the size limits, see https://cloud.google.com/compute/docs/disks/storage-pools. Corresponds to the JSON property poolProvisionedCapacityGb

Returns:

  • (Fixnum)


74455
74456
74457
# File 'lib/google/apis/compute_alpha/classes.rb', line 74455

def pool_provisioned_capacity_gb
  @pool_provisioned_capacity_gb
end

#pool_provisioned_iopsFixnum

Provisioned IOPS of the storage pool. Only relevant if the storage pool type is hyperdisk-balanced. Corresponds to the JSON property poolProvisionedIops

Returns:

  • (Fixnum)


74461
74462
74463
# File 'lib/google/apis/compute_alpha/classes.rb', line 74461

def pool_provisioned_iops
  @pool_provisioned_iops
end

#pool_provisioned_throughputFixnum

Provisioned throughput of the storage pool in MiB/s. Only relevant if the storage pool type is hyperdisk-balanced or hyperdisk-throughput. Corresponds to the JSON property poolProvisionedThroughput

Returns:

  • (Fixnum)


74467
74468
74469
# File 'lib/google/apis/compute_alpha/classes.rb', line 74467

def pool_provisioned_throughput
  @pool_provisioned_throughput
end

#provisioned_iopsFixnum

DEPRECATED -- use "pool provisioned IOPS". Corresponds to the JSON property provisionedIops

Returns:

  • (Fixnum)


74472
74473
74474
# File 'lib/google/apis/compute_alpha/classes.rb', line 74472

def provisioned_iops
  @provisioned_iops
end

#provisioned_throughputFixnum

DEPRECATED -- use "pool provisioned throughput". Corresponds to the JSON property provisionedThroughput

Returns:

  • (Fixnum)


74477
74478
74479
# File 'lib/google/apis/compute_alpha/classes.rb', line 74477

def provisioned_throughput
  @provisioned_throughput
end

#resource_statusGoogle::Apis::ComputeAlpha::StoragePoolResourceStatus

[Output Only] Contains output only fields. Corresponds to the JSON property resourceStatus



74482
74483
74484
# File 'lib/google/apis/compute_alpha/classes.rb', line 74482

def resource_status
  @resource_status
end

Output only. [Output Only] Server-defined fully-qualified URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


74488
74489
74490
# File 'lib/google/apis/compute_alpha/classes.rb', line 74488

def self_link
  @self_link
end

Output only. [Output Only] Server-defined URL for this resource's resource id. Corresponds to the JSON property selfLinkWithId

Returns:

  • (String)


74493
74494
74495
# File 'lib/google/apis/compute_alpha/classes.rb', line 74493

def self_link_with_id
  @self_link_with_id
end

#share_settingsGoogle::Apis::ComputeAlpha::StoragePoolShareSettings

Share settings for the storage pool. Corresponds to the JSON property shareSettings



74498
74499
74500
# File 'lib/google/apis/compute_alpha/classes.rb', line 74498

def share_settings
  @share_settings
end

#size_gbFixnum

DEPRECATED -- use "pool provisioned capacity gb". Corresponds to the JSON property sizeGb

Returns:

  • (Fixnum)


74503
74504
74505
# File 'lib/google/apis/compute_alpha/classes.rb', line 74503

def size_gb
  @size_gb
end

#stateString

Output only. [Output Only] The status of storage pool creation.

  • CREATING: Storage pool is provisioning. storagePool.
  • FAILED: Storage pool creation failed.
  • READY: Storage pool is ready for use.
  • DELETING: Storage pool is deleting. Corresponds to the JSON property state

Returns:

  • (String)


74515
74516
74517
# File 'lib/google/apis/compute_alpha/classes.rb', line 74515

def state
  @state
end

#statusGoogle::Apis::ComputeAlpha::StoragePoolResourceStatus

[Output Only] Contains output only fields. Corresponds to the JSON property status



74520
74521
74522
# File 'lib/google/apis/compute_alpha/classes.rb', line 74520

def status
  @status
end

#storage_pool_typeString

Type of the storage pool. Corresponds to the JSON property storagePoolType

Returns:

  • (String)


74525
74526
74527
# File 'lib/google/apis/compute_alpha/classes.rb', line 74525

def storage_pool_type
  @storage_pool_type
end

#zoneString

Output only. [Output Only] URL of the zone where the storage pool resides. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body. Corresponds to the JSON property zone

Returns:

  • (String)


74532
74533
74534
# File 'lib/google/apis/compute_alpha/classes.rb', line 74532

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



74539
74540
74541
74542
74543
74544
74545
74546
74547
74548
74549
74550
74551
74552
74553
74554
74555
74556
74557
74558
74559
74560
74561
74562
74563
74564
74565
# File 'lib/google/apis/compute_alpha/classes.rb', line 74539

def update!(**args)
  @capacity_provisioning_type = args[:capacity_provisioning_type] if args.key?(:capacity_provisioning_type)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @exapool_provisioned_capacity_gb = args[:exapool_provisioned_capacity_gb] if args.key?(:exapool_provisioned_capacity_gb)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @label_fingerprint = args[:label_fingerprint] if args.key?(:label_fingerprint)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @params = args[:params] if args.key?(:params)
  @performance_provisioning_type = args[:performance_provisioning_type] if args.key?(:performance_provisioning_type)
  @pool_provisioned_capacity_gb = args[:pool_provisioned_capacity_gb] if args.key?(:pool_provisioned_capacity_gb)
  @pool_provisioned_iops = args[:pool_provisioned_iops] if args.key?(:pool_provisioned_iops)
  @pool_provisioned_throughput = args[:pool_provisioned_throughput] if args.key?(:pool_provisioned_throughput)
  @provisioned_iops = args[:provisioned_iops] if args.key?(:provisioned_iops)
  @provisioned_throughput = args[:provisioned_throughput] if args.key?(:provisioned_throughput)
  @resource_status = args[:resource_status] if args.key?(:resource_status)
  @self_link = args[:self_link] if args.key?(:self_link)
  @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id)
  @share_settings = args[:share_settings] if args.key?(:share_settings)
  @size_gb = args[:size_gb] if args.key?(:size_gb)
  @state = args[:state] if args.key?(:state)
  @status = args[:status] if args.key?(:status)
  @storage_pool_type = args[:storage_pool_type] if args.key?(:storage_pool_type)
  @zone = args[:zone] if args.key?(:zone)
end