Class: Google::Apis::ComputeAlpha::StoragePool
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::StoragePool
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Represents a zonal storage pool resource.
Instance Attribute Summary collapse
-
#capacity_provisioning_type ⇒ String
Provisioning type of the byte capacity of the pool.
-
#creation_timestamp ⇒ String
Output only.
-
#description ⇒ String
An optional description of this resource.
-
#exapool_provisioned_capacity_gb ⇒ Google::Apis::ComputeAlpha::StoragePoolExapoolProvisionedCapacityGb
Exapool provisioned capacities for each SKU type Corresponds to the JSON property
exapoolProvisionedCapacityGb. -
#id ⇒ Fixnum
Output only.
-
#kind ⇒ String
Output only.
-
#label_fingerprint ⇒ String
A fingerprint for the labels being applied to this storage pool, which is essentially a hash of the labels set used for optimistic locking.
-
#labels ⇒ Hash<String,String>
Labels to apply to this storage pool.
-
#name ⇒ String
Name of the resource.
-
#params ⇒ Google::Apis::ComputeAlpha::StoragePoolParams
Additional storage pool params.
-
#performance_provisioning_type ⇒ String
Provisioning type of the performance-related parameters of the pool, such as throughput and IOPS.
-
#pool_provisioned_capacity_gb ⇒ Fixnum
Size of the storage pool in GiB.
-
#pool_provisioned_iops ⇒ Fixnum
Provisioned IOPS of the storage pool.
-
#pool_provisioned_throughput ⇒ Fixnum
Provisioned throughput of the storage pool in MiB/s.
-
#provisioned_iops ⇒ Fixnum
DEPRECATED -- use "pool provisioned IOPS".
-
#provisioned_throughput ⇒ Fixnum
DEPRECATED -- use "pool provisioned throughput".
-
#resource_status ⇒ Google::Apis::ComputeAlpha::StoragePoolResourceStatus
[Output Only] Contains output only fields.
-
#self_link ⇒ String
Output only.
-
#self_link_with_id ⇒ String
Output only.
-
#share_settings ⇒ Google::Apis::ComputeAlpha::StoragePoolShareSettings
Share settings for the storage pool.
-
#size_gb ⇒ Fixnum
DEPRECATED -- use "pool provisioned capacity gb".
-
#state ⇒ String
Output only.
-
#status ⇒ Google::Apis::ComputeAlpha::StoragePoolResourceStatus
[Output Only] Contains output only fields.
-
#storage_pool_type ⇒ String
Type of the storage pool.
-
#zone ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ StoragePool
constructor
A new instance of StoragePool.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ StoragePool
Returns a new instance of StoragePool.
73166 73167 73168 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 73166 def initialize(**args) update!(**args) end |
Instance Attribute Details
#capacity_provisioning_type ⇒ String
Provisioning type of the byte capacity of the pool.
Corresponds to the JSON property capacityProvisioningType
73010 73011 73012 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 73010 def capacity_provisioning_type @capacity_provisioning_type end |
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
73016 73017 73018 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 73016 def @creation_timestamp end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
73022 73023 73024 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 73022 def description @description end |
#exapool_provisioned_capacity_gb ⇒ Google::Apis::ComputeAlpha::StoragePoolExapoolProvisionedCapacityGb
Exapool provisioned capacities for each SKU type
Corresponds to the JSON property exapoolProvisionedCapacityGb
73027 73028 73029 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 73027 def exapool_provisioned_capacity_gb @exapool_provisioned_capacity_gb end |
#id ⇒ Fixnum
Output only. [Output Only] The unique identifier for the resource. This
identifier is
defined by the server.
Corresponds to the JSON property id
73034 73035 73036 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 73034 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Always compute#storagePool
for storage pools.
Corresponds to the JSON property kind
73040 73041 73042 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 73040 def kind @kind end |
#label_fingerprint ⇒ String
A fingerprint for the labels being applied to this storage pool, which is
essentially a hash of the labels set used for optimistic locking. The
fingerprint is initially generated by Compute Engine and changes after
every request to modify or update labels. You must always provide an
up-to-date fingerprint hash in order to update or change labels,
otherwise the request will fail with error412 conditionNotMet.
To see the latest fingerprint, make a get() request to
retrieve a storage pool.
Corresponds to the JSON property labelFingerprint
NOTE: Values are automatically base64 encoded/decoded in the client library.
73053 73054 73055 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 73053 def label_fingerprint @label_fingerprint end |
#labels ⇒ Hash<String,String>
Labels to apply to this storage pool. These can be later modified by
the setLabels method.
Corresponds to the JSON property labels
73059 73060 73061 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 73059 def labels @labels end |
#name ⇒ String
Name of the resource. Provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])?
which means the first character must be a lowercase letter, and all
following characters must be a dash, lowercase letter, or digit, except
the last character, which cannot be a dash.
Corresponds to the JSON property name
73070 73071 73072 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 73070 def name @name end |
#params ⇒ Google::Apis::ComputeAlpha::StoragePoolParams
Additional storage pool params.
Corresponds to the JSON property params
73075 73076 73077 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 73075 def params @params end |
#performance_provisioning_type ⇒ String
Provisioning type of the performance-related parameters of the pool,
such as throughput and IOPS.
Corresponds to the JSON property performanceProvisioningType
73081 73082 73083 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 73081 def performance_provisioning_type @performance_provisioning_type end |
#pool_provisioned_capacity_gb ⇒ Fixnum
Size of the storage pool in GiB. For more information about the size
limits, see https://cloud.google.com/compute/docs/disks/storage-pools.
Corresponds to the JSON property poolProvisionedCapacityGb
73087 73088 73089 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 73087 def pool_provisioned_capacity_gb @pool_provisioned_capacity_gb end |
#pool_provisioned_iops ⇒ Fixnum
Provisioned IOPS of the storage pool. Only relevant if the storage pool
type is hyperdisk-balanced.
Corresponds to the JSON property poolProvisionedIops
73093 73094 73095 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 73093 def pool_provisioned_iops @pool_provisioned_iops end |
#pool_provisioned_throughput ⇒ Fixnum
Provisioned throughput of the storage pool in MiB/s. Only relevant if the
storage pool type is hyperdisk-balanced or hyperdisk-throughput.
Corresponds to the JSON property poolProvisionedThroughput
73099 73100 73101 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 73099 def pool_provisioned_throughput @pool_provisioned_throughput end |
#provisioned_iops ⇒ Fixnum
DEPRECATED -- use "pool provisioned IOPS".
Corresponds to the JSON property provisionedIops
73104 73105 73106 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 73104 def provisioned_iops @provisioned_iops end |
#provisioned_throughput ⇒ Fixnum
DEPRECATED -- use "pool provisioned throughput".
Corresponds to the JSON property provisionedThroughput
73109 73110 73111 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 73109 def provisioned_throughput @provisioned_throughput end |
#resource_status ⇒ Google::Apis::ComputeAlpha::StoragePoolResourceStatus
[Output Only] Contains output only fields.
Corresponds to the JSON property resourceStatus
73114 73115 73116 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 73114 def resource_status @resource_status end |
#self_link ⇒ String
Output only. [Output Only] Server-defined fully-qualified URL for this
resource.
Corresponds to the JSON property selfLink
73120 73121 73122 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 73120 def self_link @self_link end |
#self_link_with_id ⇒ String
Output only. [Output Only] Server-defined URL for this resource's resource id.
Corresponds to the JSON property selfLinkWithId
73125 73126 73127 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 73125 def self_link_with_id @self_link_with_id end |
#share_settings ⇒ Google::Apis::ComputeAlpha::StoragePoolShareSettings
Share settings for the storage pool.
Corresponds to the JSON property shareSettings
73130 73131 73132 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 73130 def share_settings @share_settings end |
#size_gb ⇒ Fixnum
DEPRECATED -- use "pool provisioned capacity gb".
Corresponds to the JSON property sizeGb
73135 73136 73137 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 73135 def size_gb @size_gb end |
#state ⇒ String
Output only. [Output Only] The status of storage pool creation.
- CREATING: Storage pool is provisioning. storagePool.
- FAILED: Storage pool creation failed.
- READY: Storage pool is ready for use.
- DELETING: Storage pool is deleting.
Corresponds to the JSON property
state
73147 73148 73149 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 73147 def state @state end |
#status ⇒ Google::Apis::ComputeAlpha::StoragePoolResourceStatus
[Output Only] Contains output only fields.
Corresponds to the JSON property status
73152 73153 73154 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 73152 def status @status end |
#storage_pool_type ⇒ String
Type of the storage pool.
Corresponds to the JSON property storagePoolType
73157 73158 73159 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 73157 def storage_pool_type @storage_pool_type end |
#zone ⇒ String
Output only. [Output Only] URL of the zone where the storage pool resides.
You must specify this field as part of the HTTP request URL. It is
not settable as a field in the request body.
Corresponds to the JSON property zone
73164 73165 73166 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 73164 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
73171 73172 73173 73174 73175 73176 73177 73178 73179 73180 73181 73182 73183 73184 73185 73186 73187 73188 73189 73190 73191 73192 73193 73194 73195 73196 73197 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 73171 def update!(**args) @capacity_provisioning_type = args[:capacity_provisioning_type] if args.key?(:capacity_provisioning_type) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @exapool_provisioned_capacity_gb = args[:exapool_provisioned_capacity_gb] if args.key?(:exapool_provisioned_capacity_gb) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @label_fingerprint = args[:label_fingerprint] if args.key?(:label_fingerprint) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @params = args[:params] if args.key?(:params) @performance_provisioning_type = args[:performance_provisioning_type] if args.key?(:performance_provisioning_type) @pool_provisioned_capacity_gb = args[:pool_provisioned_capacity_gb] if args.key?(:pool_provisioned_capacity_gb) @pool_provisioned_iops = args[:pool_provisioned_iops] if args.key?(:pool_provisioned_iops) @pool_provisioned_throughput = args[:pool_provisioned_throughput] if args.key?(:pool_provisioned_throughput) @provisioned_iops = args[:provisioned_iops] if args.key?(:provisioned_iops) @provisioned_throughput = args[:provisioned_throughput] if args.key?(:provisioned_throughput) @resource_status = args[:resource_status] if args.key?(:resource_status) @self_link = args[:self_link] if args.key?(:self_link) @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id) @share_settings = args[:share_settings] if args.key?(:share_settings) @size_gb = args[:size_gb] if args.key?(:size_gb) @state = args[:state] if args.key?(:state) @status = args[:status] if args.key?(:status) @storage_pool_type = args[:storage_pool_type] if args.key?(:storage_pool_type) @zone = args[:zone] if args.key?(:zone) end |