Class: Google::Apis::ComputeAlpha::StoragePool

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Represents a zonal storage pool resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StoragePool

Returns a new instance of StoragePool.



72502
72503
72504
# File 'lib/google/apis/compute_alpha/classes.rb', line 72502

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#capacity_provisioning_typeString

Provisioning type of the byte capacity of the pool. Corresponds to the JSON property capacityProvisioningType

Returns:

  • (String)


72346
72347
72348
# File 'lib/google/apis/compute_alpha/classes.rb', line 72346

def capacity_provisioning_type
  @capacity_provisioning_type
end

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


72352
72353
72354
# File 'lib/google/apis/compute_alpha/classes.rb', line 72352

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


72358
72359
72360
# File 'lib/google/apis/compute_alpha/classes.rb', line 72358

def description
  @description
end

#exapool_provisioned_capacity_gbGoogle::Apis::ComputeAlpha::StoragePoolExapoolProvisionedCapacityGb

Exapool provisioned capacities for each SKU type Corresponds to the JSON property exapoolProvisionedCapacityGb



72363
72364
72365
# File 'lib/google/apis/compute_alpha/classes.rb', line 72363

def exapool_provisioned_capacity_gb
  @exapool_provisioned_capacity_gb
end

#idFixnum

Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


72370
72371
72372
# File 'lib/google/apis/compute_alpha/classes.rb', line 72370

def id
  @id
end

#kindString

Output only. [Output Only] Type of the resource. Always compute#storagePool for storage pools. Corresponds to the JSON property kind

Returns:

  • (String)


72376
72377
72378
# File 'lib/google/apis/compute_alpha/classes.rb', line 72376

def kind
  @kind
end

#label_fingerprintString

A fingerprint for the labels being applied to this storage pool, which is essentially a hash of the labels set used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update labels. You must always provide an up-to-date fingerprint hash in order to update or change labels, otherwise the request will fail with error412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve a storage pool. Corresponds to the JSON property labelFingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


72389
72390
72391
# File 'lib/google/apis/compute_alpha/classes.rb', line 72389

def label_fingerprint
  @label_fingerprint
end

#labelsHash<String,String>

Labels to apply to this storage pool. These can be later modified by the setLabels method. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


72395
72396
72397
# File 'lib/google/apis/compute_alpha/classes.rb', line 72395

def labels
  @labels
end

#nameString

Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


72406
72407
72408
# File 'lib/google/apis/compute_alpha/classes.rb', line 72406

def name
  @name
end

#paramsGoogle::Apis::ComputeAlpha::StoragePoolParams

Additional storage pool params. Corresponds to the JSON property params



72411
72412
72413
# File 'lib/google/apis/compute_alpha/classes.rb', line 72411

def params
  @params
end

#performance_provisioning_typeString

Provisioning type of the performance-related parameters of the pool, such as throughput and IOPS. Corresponds to the JSON property performanceProvisioningType

Returns:

  • (String)


72417
72418
72419
# File 'lib/google/apis/compute_alpha/classes.rb', line 72417

def performance_provisioning_type
  @performance_provisioning_type
end

#pool_provisioned_capacity_gbFixnum

Size of the storage pool in GiB. For more information about the size limits, see https://cloud.google.com/compute/docs/disks/storage-pools. Corresponds to the JSON property poolProvisionedCapacityGb

Returns:

  • (Fixnum)


72423
72424
72425
# File 'lib/google/apis/compute_alpha/classes.rb', line 72423

def pool_provisioned_capacity_gb
  @pool_provisioned_capacity_gb
end

#pool_provisioned_iopsFixnum

Provisioned IOPS of the storage pool. Only relevant if the storage pool type is hyperdisk-balanced. Corresponds to the JSON property poolProvisionedIops

Returns:

  • (Fixnum)


72429
72430
72431
# File 'lib/google/apis/compute_alpha/classes.rb', line 72429

def pool_provisioned_iops
  @pool_provisioned_iops
end

#pool_provisioned_throughputFixnum

Provisioned throughput of the storage pool in MiB/s. Only relevant if the storage pool type is hyperdisk-balanced or hyperdisk-throughput. Corresponds to the JSON property poolProvisionedThroughput

Returns:

  • (Fixnum)


72435
72436
72437
# File 'lib/google/apis/compute_alpha/classes.rb', line 72435

def pool_provisioned_throughput
  @pool_provisioned_throughput
end

#provisioned_iopsFixnum

DEPRECATED -- use "pool provisioned IOPS". Corresponds to the JSON property provisionedIops

Returns:

  • (Fixnum)


72440
72441
72442
# File 'lib/google/apis/compute_alpha/classes.rb', line 72440

def provisioned_iops
  @provisioned_iops
end

#provisioned_throughputFixnum

DEPRECATED -- use "pool provisioned throughput". Corresponds to the JSON property provisionedThroughput

Returns:

  • (Fixnum)


72445
72446
72447
# File 'lib/google/apis/compute_alpha/classes.rb', line 72445

def provisioned_throughput
  @provisioned_throughput
end

#resource_statusGoogle::Apis::ComputeAlpha::StoragePoolResourceStatus

[Output Only] Contains output only fields. Corresponds to the JSON property resourceStatus



72450
72451
72452
# File 'lib/google/apis/compute_alpha/classes.rb', line 72450

def resource_status
  @resource_status
end

Output only. [Output Only] Server-defined fully-qualified URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


72456
72457
72458
# File 'lib/google/apis/compute_alpha/classes.rb', line 72456

def self_link
  @self_link
end

Output only. [Output Only] Server-defined URL for this resource's resource id. Corresponds to the JSON property selfLinkWithId

Returns:

  • (String)


72461
72462
72463
# File 'lib/google/apis/compute_alpha/classes.rb', line 72461

def self_link_with_id
  @self_link_with_id
end

#share_settingsGoogle::Apis::ComputeAlpha::StoragePoolShareSettings

Share settings for the storage pool. Corresponds to the JSON property shareSettings



72466
72467
72468
# File 'lib/google/apis/compute_alpha/classes.rb', line 72466

def share_settings
  @share_settings
end

#size_gbFixnum

DEPRECATED -- use "pool provisioned capacity gb". Corresponds to the JSON property sizeGb

Returns:

  • (Fixnum)


72471
72472
72473
# File 'lib/google/apis/compute_alpha/classes.rb', line 72471

def size_gb
  @size_gb
end

#stateString

Output only. [Output Only] The status of storage pool creation.

  • CREATING: Storage pool is provisioning. storagePool.
  • FAILED: Storage pool creation failed.
  • READY: Storage pool is ready for use.
  • DELETING: Storage pool is deleting. Corresponds to the JSON property state

Returns:

  • (String)


72483
72484
72485
# File 'lib/google/apis/compute_alpha/classes.rb', line 72483

def state
  @state
end

#statusGoogle::Apis::ComputeAlpha::StoragePoolResourceStatus

[Output Only] Contains output only fields. Corresponds to the JSON property status



72488
72489
72490
# File 'lib/google/apis/compute_alpha/classes.rb', line 72488

def status
  @status
end

#storage_pool_typeString

Type of the storage pool. Corresponds to the JSON property storagePoolType

Returns:

  • (String)


72493
72494
72495
# File 'lib/google/apis/compute_alpha/classes.rb', line 72493

def storage_pool_type
  @storage_pool_type
end

#zoneString

Output only. [Output Only] URL of the zone where the storage pool resides. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body. Corresponds to the JSON property zone

Returns:

  • (String)


72500
72501
72502
# File 'lib/google/apis/compute_alpha/classes.rb', line 72500

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



72507
72508
72509
72510
72511
72512
72513
72514
72515
72516
72517
72518
72519
72520
72521
72522
72523
72524
72525
72526
72527
72528
72529
72530
72531
72532
72533
# File 'lib/google/apis/compute_alpha/classes.rb', line 72507

def update!(**args)
  @capacity_provisioning_type = args[:capacity_provisioning_type] if args.key?(:capacity_provisioning_type)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @exapool_provisioned_capacity_gb = args[:exapool_provisioned_capacity_gb] if args.key?(:exapool_provisioned_capacity_gb)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @label_fingerprint = args[:label_fingerprint] if args.key?(:label_fingerprint)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @params = args[:params] if args.key?(:params)
  @performance_provisioning_type = args[:performance_provisioning_type] if args.key?(:performance_provisioning_type)
  @pool_provisioned_capacity_gb = args[:pool_provisioned_capacity_gb] if args.key?(:pool_provisioned_capacity_gb)
  @pool_provisioned_iops = args[:pool_provisioned_iops] if args.key?(:pool_provisioned_iops)
  @pool_provisioned_throughput = args[:pool_provisioned_throughput] if args.key?(:pool_provisioned_throughput)
  @provisioned_iops = args[:provisioned_iops] if args.key?(:provisioned_iops)
  @provisioned_throughput = args[:provisioned_throughput] if args.key?(:provisioned_throughput)
  @resource_status = args[:resource_status] if args.key?(:resource_status)
  @self_link = args[:self_link] if args.key?(:self_link)
  @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id)
  @share_settings = args[:share_settings] if args.key?(:share_settings)
  @size_gb = args[:size_gb] if args.key?(:size_gb)
  @state = args[:state] if args.key?(:state)
  @status = args[:status] if args.key?(:status)
  @storage_pool_type = args[:storage_pool_type] if args.key?(:storage_pool_type)
  @zone = args[:zone] if args.key?(:zone)
end