Class: Google::Apis::ComputeAlpha::StoragePool
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::StoragePool
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Represents a zonal storage pool resource.
Instance Attribute Summary collapse
-
#capacity_provisioning_type ⇒ String
Provisioning type of the byte capacity of the pool.
-
#creation_timestamp ⇒ String
Output only.
-
#description ⇒ String
An optional description of this resource.
-
#exapool_provisioned_capacity_gb ⇒ Google::Apis::ComputeAlpha::StoragePoolExapoolProvisionedCapacityGb
Exapool provisioned capacities for each SKU type Corresponds to the JSON property
exapoolProvisionedCapacityGb. -
#id ⇒ Fixnum
Output only.
-
#kind ⇒ String
Output only.
-
#label_fingerprint ⇒ String
A fingerprint for the labels being applied to this storage pool, which is essentially a hash of the labels set used for optimistic locking.
-
#labels ⇒ Hash<String,String>
Labels to apply to this storage pool.
-
#name ⇒ String
Name of the resource.
-
#params ⇒ Google::Apis::ComputeAlpha::StoragePoolParams
Additional storage pool params.
-
#performance_provisioning_type ⇒ String
Provisioning type of the performance-related parameters of the pool, such as throughput and IOPS.
-
#pool_provisioned_capacity_gb ⇒ Fixnum
Size of the storage pool in GiB.
-
#pool_provisioned_iops ⇒ Fixnum
Provisioned IOPS of the storage pool.
-
#pool_provisioned_throughput ⇒ Fixnum
Provisioned throughput of the storage pool in MiB/s.
-
#provisioned_iops ⇒ Fixnum
DEPRECATED -- use "pool provisioned IOPS".
-
#provisioned_throughput ⇒ Fixnum
DEPRECATED -- use "pool provisioned throughput".
-
#resource_status ⇒ Google::Apis::ComputeAlpha::StoragePoolResourceStatus
[Output Only] Contains output only fields.
-
#self_link ⇒ String
Output only.
-
#self_link_with_id ⇒ String
Output only.
-
#size_gb ⇒ Fixnum
DEPRECATED -- use "pool provisioned capacity gb".
-
#state ⇒ String
Output only.
-
#status ⇒ Google::Apis::ComputeAlpha::StoragePoolResourceStatus
[Output Only] Contains output only fields.
-
#storage_pool_type ⇒ String
Type of the storage pool.
-
#zone ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ StoragePool
constructor
A new instance of StoragePool.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ StoragePool
Returns a new instance of StoragePool.
72274 72275 72276 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 72274 def initialize(**args) update!(**args) end |
Instance Attribute Details
#capacity_provisioning_type ⇒ String
Provisioning type of the byte capacity of the pool.
Corresponds to the JSON property capacityProvisioningType
72123 72124 72125 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 72123 def capacity_provisioning_type @capacity_provisioning_type end |
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
72129 72130 72131 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 72129 def @creation_timestamp end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
72135 72136 72137 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 72135 def description @description end |
#exapool_provisioned_capacity_gb ⇒ Google::Apis::ComputeAlpha::StoragePoolExapoolProvisionedCapacityGb
Exapool provisioned capacities for each SKU type
Corresponds to the JSON property exapoolProvisionedCapacityGb
72140 72141 72142 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 72140 def exapool_provisioned_capacity_gb @exapool_provisioned_capacity_gb end |
#id ⇒ Fixnum
Output only. [Output Only] The unique identifier for the resource. This
identifier is
defined by the server.
Corresponds to the JSON property id
72147 72148 72149 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 72147 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Always compute#storagePool
for storage pools.
Corresponds to the JSON property kind
72153 72154 72155 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 72153 def kind @kind end |
#label_fingerprint ⇒ String
A fingerprint for the labels being applied to this storage pool, which is
essentially a hash of the labels set used for optimistic locking. The
fingerprint is initially generated by Compute Engine and changes after
every request to modify or update labels. You must always provide an
up-to-date fingerprint hash in order to update or change labels,
otherwise the request will fail with error412 conditionNotMet.
To see the latest fingerprint, make a get() request to
retrieve a storage pool.
Corresponds to the JSON property labelFingerprint
NOTE: Values are automatically base64 encoded/decoded in the client library.
72166 72167 72168 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 72166 def label_fingerprint @label_fingerprint end |
#labels ⇒ Hash<String,String>
Labels to apply to this storage pool. These can be later modified by
the setLabels method.
Corresponds to the JSON property labels
72172 72173 72174 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 72172 def labels @labels end |
#name ⇒ String
Name of the resource. Provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])?
which means the first character must be a lowercase letter, and all
following characters must be a dash, lowercase letter, or digit, except
the last character, which cannot be a dash.
Corresponds to the JSON property name
72183 72184 72185 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 72183 def name @name end |
#params ⇒ Google::Apis::ComputeAlpha::StoragePoolParams
Additional storage pool params.
Corresponds to the JSON property params
72188 72189 72190 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 72188 def params @params end |
#performance_provisioning_type ⇒ String
Provisioning type of the performance-related parameters of the pool,
such as throughput and IOPS.
Corresponds to the JSON property performanceProvisioningType
72194 72195 72196 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 72194 def performance_provisioning_type @performance_provisioning_type end |
#pool_provisioned_capacity_gb ⇒ Fixnum
Size of the storage pool in GiB. For more information about the size
limits, see https://cloud.google.com/compute/docs/disks/storage-pools.
Corresponds to the JSON property poolProvisionedCapacityGb
72200 72201 72202 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 72200 def pool_provisioned_capacity_gb @pool_provisioned_capacity_gb end |
#pool_provisioned_iops ⇒ Fixnum
Provisioned IOPS of the storage pool. Only relevant if the storage pool
type is hyperdisk-balanced.
Corresponds to the JSON property poolProvisionedIops
72206 72207 72208 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 72206 def pool_provisioned_iops @pool_provisioned_iops end |
#pool_provisioned_throughput ⇒ Fixnum
Provisioned throughput of the storage pool in MiB/s. Only relevant if the
storage pool type is hyperdisk-balanced or hyperdisk-throughput.
Corresponds to the JSON property poolProvisionedThroughput
72212 72213 72214 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 72212 def pool_provisioned_throughput @pool_provisioned_throughput end |
#provisioned_iops ⇒ Fixnum
DEPRECATED -- use "pool provisioned IOPS".
Corresponds to the JSON property provisionedIops
72217 72218 72219 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 72217 def provisioned_iops @provisioned_iops end |
#provisioned_throughput ⇒ Fixnum
DEPRECATED -- use "pool provisioned throughput".
Corresponds to the JSON property provisionedThroughput
72222 72223 72224 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 72222 def provisioned_throughput @provisioned_throughput end |
#resource_status ⇒ Google::Apis::ComputeAlpha::StoragePoolResourceStatus
[Output Only] Contains output only fields.
Corresponds to the JSON property resourceStatus
72227 72228 72229 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 72227 def resource_status @resource_status end |
#self_link ⇒ String
Output only. [Output Only] Server-defined fully-qualified URL for this
resource.
Corresponds to the JSON property selfLink
72233 72234 72235 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 72233 def self_link @self_link end |
#self_link_with_id ⇒ String
Output only. [Output Only] Server-defined URL for this resource's resource id.
Corresponds to the JSON property selfLinkWithId
72238 72239 72240 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 72238 def self_link_with_id @self_link_with_id end |
#size_gb ⇒ Fixnum
DEPRECATED -- use "pool provisioned capacity gb".
Corresponds to the JSON property sizeGb
72243 72244 72245 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 72243 def size_gb @size_gb end |
#state ⇒ String
Output only. [Output Only] The status of storage pool creation.
- CREATING: Storage pool is provisioning. storagePool.
- FAILED: Storage pool creation failed.
- READY: Storage pool is ready for use.
- DELETING: Storage pool is deleting.
Corresponds to the JSON property
state
72255 72256 72257 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 72255 def state @state end |
#status ⇒ Google::Apis::ComputeAlpha::StoragePoolResourceStatus
[Output Only] Contains output only fields.
Corresponds to the JSON property status
72260 72261 72262 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 72260 def status @status end |
#storage_pool_type ⇒ String
Type of the storage pool.
Corresponds to the JSON property storagePoolType
72265 72266 72267 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 72265 def storage_pool_type @storage_pool_type end |
#zone ⇒ String
Output only. [Output Only] URL of the zone where the storage pool resides.
You must specify this field as part of the HTTP request URL. It is
not settable as a field in the request body.
Corresponds to the JSON property zone
72272 72273 72274 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 72272 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
72279 72280 72281 72282 72283 72284 72285 72286 72287 72288 72289 72290 72291 72292 72293 72294 72295 72296 72297 72298 72299 72300 72301 72302 72303 72304 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 72279 def update!(**args) @capacity_provisioning_type = args[:capacity_provisioning_type] if args.key?(:capacity_provisioning_type) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @exapool_provisioned_capacity_gb = args[:exapool_provisioned_capacity_gb] if args.key?(:exapool_provisioned_capacity_gb) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @label_fingerprint = args[:label_fingerprint] if args.key?(:label_fingerprint) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @params = args[:params] if args.key?(:params) @performance_provisioning_type = args[:performance_provisioning_type] if args.key?(:performance_provisioning_type) @pool_provisioned_capacity_gb = args[:pool_provisioned_capacity_gb] if args.key?(:pool_provisioned_capacity_gb) @pool_provisioned_iops = args[:pool_provisioned_iops] if args.key?(:pool_provisioned_iops) @pool_provisioned_throughput = args[:pool_provisioned_throughput] if args.key?(:pool_provisioned_throughput) @provisioned_iops = args[:provisioned_iops] if args.key?(:provisioned_iops) @provisioned_throughput = args[:provisioned_throughput] if args.key?(:provisioned_throughput) @resource_status = args[:resource_status] if args.key?(:resource_status) @self_link = args[:self_link] if args.key?(:self_link) @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id) @size_gb = args[:size_gb] if args.key?(:size_gb) @state = args[:state] if args.key?(:state) @status = args[:status] if args.key?(:status) @storage_pool_type = args[:storage_pool_type] if args.key?(:storage_pool_type) @zone = args[:zone] if args.key?(:zone) end |