Class: Google::Apis::ComputeAlpha::StoragePoolAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::StoragePoolAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::StoragePoolsScopedList>
A list of StoragePoolsScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::StoragePoolAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ StoragePoolAggregatedList
constructor
A new instance of StoragePoolAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ StoragePoolAggregatedList
Returns a new instance of StoragePoolAggregatedList.
75201 75202 75203 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 75201 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
75157 75158 75159 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 75157 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
75162 75163 75164 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 75162 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::StoragePoolsScopedList>
A list of StoragePoolsScopedList resources.
Corresponds to the JSON property items
75167 75168 75169 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 75167 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
storagePoolAggregatedList for aggregated lists of
storage pools.
Corresponds to the JSON property kind
75174 75175 75176 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 75174 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
75184 75185 75186 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 75184 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
75189 75190 75191 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 75189 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
75194 75195 75196 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 75194 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::StoragePoolAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
75199 75200 75201 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 75199 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
75206 75207 75208 75209 75210 75211 75212 75213 75214 75215 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 75206 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |