Class: Google::Apis::ComputeAlpha::StoragePoolAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::StoragePoolAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::StoragePoolsScopedList>
A list of StoragePoolsScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::StoragePoolAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ StoragePoolAggregatedList
constructor
A new instance of StoragePoolAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ StoragePoolAggregatedList
Returns a new instance of StoragePoolAggregatedList.
74619 74620 74621 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 74619 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
74575 74576 74577 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 74575 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
74580 74581 74582 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 74580 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::StoragePoolsScopedList>
A list of StoragePoolsScopedList resources.
Corresponds to the JSON property items
74585 74586 74587 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 74585 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
storagePoolAggregatedList for aggregated lists of
storage pools.
Corresponds to the JSON property kind
74592 74593 74594 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 74592 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
74602 74603 74604 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 74602 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
74607 74608 74609 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 74607 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
74612 74613 74614 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 74612 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::StoragePoolAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
74617 74618 74619 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 74617 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
74624 74625 74626 74627 74628 74629 74630 74631 74632 74633 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 74624 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |