Class: Google::Apis::ComputeAlpha::StoragePoolAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StoragePoolAggregatedList

Returns a new instance of StoragePoolAggregatedList.



72585
72586
72587
# File 'lib/google/apis/compute_alpha/classes.rb', line 72585

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


72541
72542
72543
# File 'lib/google/apis/compute_alpha/classes.rb', line 72541

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


72546
72547
72548
# File 'lib/google/apis/compute_alpha/classes.rb', line 72546

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::StoragePoolsScopedList>

A list of StoragePoolsScopedList resources. Corresponds to the JSON property items



72551
72552
72553
# File 'lib/google/apis/compute_alpha/classes.rb', line 72551

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# storagePoolAggregatedList for aggregated lists of storage pools. Corresponds to the JSON property kind

Returns:

  • (String)


72558
72559
72560
# File 'lib/google/apis/compute_alpha/classes.rb', line 72558

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


72568
72569
72570
# File 'lib/google/apis/compute_alpha/classes.rb', line 72568

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


72573
72574
72575
# File 'lib/google/apis/compute_alpha/classes.rb', line 72573

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


72578
72579
72580
# File 'lib/google/apis/compute_alpha/classes.rb', line 72578

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::StoragePoolAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



72583
72584
72585
# File 'lib/google/apis/compute_alpha/classes.rb', line 72583

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



72590
72591
72592
72593
72594
72595
72596
72597
72598
72599
# File 'lib/google/apis/compute_alpha/classes.rb', line 72590

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end