Class: Google::Apis::ComputeAlpha::StoragePoolAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StoragePoolAggregatedList

Returns a new instance of StoragePoolAggregatedList.



72358
72359
72360
# File 'lib/google/apis/compute_alpha/classes.rb', line 72358

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


72314
72315
72316
# File 'lib/google/apis/compute_alpha/classes.rb', line 72314

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


72319
72320
72321
# File 'lib/google/apis/compute_alpha/classes.rb', line 72319

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::StoragePoolsScopedList>

A list of StoragePoolsScopedList resources. Corresponds to the JSON property items



72324
72325
72326
# File 'lib/google/apis/compute_alpha/classes.rb', line 72324

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# storagePoolAggregatedList for aggregated lists of storage pools. Corresponds to the JSON property kind

Returns:

  • (String)


72331
72332
72333
# File 'lib/google/apis/compute_alpha/classes.rb', line 72331

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


72341
72342
72343
# File 'lib/google/apis/compute_alpha/classes.rb', line 72341

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


72346
72347
72348
# File 'lib/google/apis/compute_alpha/classes.rb', line 72346

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


72351
72352
72353
# File 'lib/google/apis/compute_alpha/classes.rb', line 72351

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::StoragePoolAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



72356
72357
72358
# File 'lib/google/apis/compute_alpha/classes.rb', line 72356

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



72363
72364
72365
72366
72367
72368
72369
72370
72371
72372
# File 'lib/google/apis/compute_alpha/classes.rb', line 72363

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end