Class: Google::Apis::ComputeAlpha::StoragePoolList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::StoragePoolList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
A list of StoragePool resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::StoragePool>
A list of StoragePool resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::StoragePoolList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ StoragePoolList
constructor
A new instance of StoragePoolList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ StoragePoolList
Returns a new instance of StoragePoolList.
74870 74871 74872 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 74870 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
74826 74827 74828 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 74826 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
74831 74832 74833 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 74831 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::StoragePool>
A list of StoragePool resources.
Corresponds to the JSON property items
74836 74837 74838 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 74836 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#storagePoolList
for lists of storagePools.
Corresponds to the JSON property kind
74842 74843 74844 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 74842 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
74852 74853 74854 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 74852 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
74857 74858 74859 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 74857 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
end_interface: MixerListResponseWithEtagBuilder
Corresponds to the JSON property unreachables
74863 74864 74865 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 74863 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::StoragePoolList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
74868 74869 74870 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 74868 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
74875 74876 74877 74878 74879 74880 74881 74882 74883 74884 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 74875 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |