Class: Google::Apis::ComputeAlpha::StoragePoolList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

A list of StoragePool resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StoragePoolList

Returns a new instance of StoragePoolList.



73502
73503
73504
# File 'lib/google/apis/compute_alpha/classes.rb', line 73502

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


73458
73459
73460
# File 'lib/google/apis/compute_alpha/classes.rb', line 73458

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


73463
73464
73465
# File 'lib/google/apis/compute_alpha/classes.rb', line 73463

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::StoragePool>

A list of StoragePool resources. Corresponds to the JSON property items



73468
73469
73470
# File 'lib/google/apis/compute_alpha/classes.rb', line 73468

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#storagePoolList for lists of storagePools. Corresponds to the JSON property kind

Returns:

  • (String)


73474
73475
73476
# File 'lib/google/apis/compute_alpha/classes.rb', line 73474

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


73484
73485
73486
# File 'lib/google/apis/compute_alpha/classes.rb', line 73484

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


73489
73490
73491
# File 'lib/google/apis/compute_alpha/classes.rb', line 73489

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


73495
73496
73497
# File 'lib/google/apis/compute_alpha/classes.rb', line 73495

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::StoragePoolList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



73500
73501
73502
# File 'lib/google/apis/compute_alpha/classes.rb', line 73500

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



73507
73508
73509
73510
73511
73512
73513
73514
73515
73516
# File 'lib/google/apis/compute_alpha/classes.rb', line 73507

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end