Class: Google::Apis::ComputeAlpha::StoragePoolList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::StoragePoolList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
A list of StoragePool resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::StoragePool>
A list of StoragePool resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::StoragePoolList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ StoragePoolList
constructor
A new instance of StoragePoolList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ StoragePoolList
Returns a new instance of StoragePoolList.
73445 73446 73447 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 73445 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
73401 73402 73403 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 73401 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
73406 73407 73408 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 73406 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::StoragePool>
A list of StoragePool resources.
Corresponds to the JSON property items
73411 73412 73413 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 73411 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#storagePoolList
for lists of storagePools.
Corresponds to the JSON property kind
73417 73418 73419 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 73417 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
73427 73428 73429 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 73427 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
73432 73433 73434 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 73432 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
end_interface: MixerListResponseWithEtagBuilder
Corresponds to the JSON property unreachables
73438 73439 73440 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 73438 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::StoragePoolList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
73443 73444 73445 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 73443 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
73450 73451 73452 73453 73454 73455 73456 73457 73458 73459 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 73450 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |