Class: Google::Apis::ComputeAlpha::StoragePoolList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

A list of StoragePool resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StoragePoolList

Returns a new instance of StoragePoolList.



72838
72839
72840
# File 'lib/google/apis/compute_alpha/classes.rb', line 72838

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


72794
72795
72796
# File 'lib/google/apis/compute_alpha/classes.rb', line 72794

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


72799
72800
72801
# File 'lib/google/apis/compute_alpha/classes.rb', line 72799

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::StoragePool>

A list of StoragePool resources. Corresponds to the JSON property items



72804
72805
72806
# File 'lib/google/apis/compute_alpha/classes.rb', line 72804

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#storagePoolList for lists of storagePools. Corresponds to the JSON property kind

Returns:

  • (String)


72810
72811
72812
# File 'lib/google/apis/compute_alpha/classes.rb', line 72810

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


72820
72821
72822
# File 'lib/google/apis/compute_alpha/classes.rb', line 72820

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


72825
72826
72827
# File 'lib/google/apis/compute_alpha/classes.rb', line 72825

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


72831
72832
72833
# File 'lib/google/apis/compute_alpha/classes.rb', line 72831

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::StoragePoolList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



72836
72837
72838
# File 'lib/google/apis/compute_alpha/classes.rb', line 72836

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



72843
72844
72845
72846
72847
72848
72849
72850
72851
72852
# File 'lib/google/apis/compute_alpha/classes.rb', line 72843

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end