Class: Google::Apis::ComputeAlpha::StoragePoolList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::StoragePoolList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
A list of StoragePool resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::StoragePool>
A list of StoragePool resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::StoragePoolList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ StoragePoolList
constructor
A new instance of StoragePoolList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ StoragePoolList
Returns a new instance of StoragePoolList.
72836 72837 72838 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 72836 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
72792 72793 72794 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 72792 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
72797 72798 72799 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 72797 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::StoragePool>
A list of StoragePool resources.
Corresponds to the JSON property items
72802 72803 72804 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 72802 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#storagePoolList
for lists of storagePools.
Corresponds to the JSON property kind
72808 72809 72810 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 72808 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
72818 72819 72820 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 72818 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
72823 72824 72825 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 72823 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
end_interface: MixerListResponseWithEtagBuilder
Corresponds to the JSON property unreachables
72829 72830 72831 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 72829 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::StoragePoolList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
72834 72835 72836 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 72834 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
72841 72842 72843 72844 72845 72846 72847 72848 72849 72850 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 72841 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |