Class: Google::Apis::ComputeAlpha::StoragePoolListDisks

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StoragePoolListDisks

Returns a new instance of StoragePoolListDisks.



73586
73587
73588
# File 'lib/google/apis/compute_alpha/classes.rb', line 73586

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


73539
73540
73541
# File 'lib/google/apis/compute_alpha/classes.rb', line 73539

def etag
  @etag
end

#idString

Output only. [Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


73545
73546
73547
# File 'lib/google/apis/compute_alpha/classes.rb', line 73545

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::StoragePoolDisk>

A list of StoragePoolDisk resources. Corresponds to the JSON property items



73550
73551
73552
# File 'lib/google/apis/compute_alpha/classes.rb', line 73550

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# storagePoolListDisks for lists of disks in a storagePool. Corresponds to the JSON property kind

Returns:

  • (String)


73557
73558
73559
# File 'lib/google/apis/compute_alpha/classes.rb', line 73557

def kind
  @kind
end

#next_page_tokenString

Output only. [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


73568
73569
73570
# File 'lib/google/apis/compute_alpha/classes.rb', line 73568

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


73573
73574
73575
# File 'lib/google/apis/compute_alpha/classes.rb', line 73573

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


73579
73580
73581
# File 'lib/google/apis/compute_alpha/classes.rb', line 73579

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::StoragePoolListDisks::Warning

Output only. [Output Only] Informational warning message. Corresponds to the JSON property warning



73584
73585
73586
# File 'lib/google/apis/compute_alpha/classes.rb', line 73584

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



73591
73592
73593
73594
73595
73596
73597
73598
73599
73600
# File 'lib/google/apis/compute_alpha/classes.rb', line 73591

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end