Class: Google::Apis::ComputeAlpha::StoragePoolListDisks

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StoragePoolListDisks

Returns a new instance of StoragePoolListDisks.



72750
72751
72752
# File 'lib/google/apis/compute_alpha/classes.rb', line 72750

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


72703
72704
72705
# File 'lib/google/apis/compute_alpha/classes.rb', line 72703

def etag
  @etag
end

#idString

Output only. [Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


72709
72710
72711
# File 'lib/google/apis/compute_alpha/classes.rb', line 72709

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::StoragePoolDisk>

A list of StoragePoolDisk resources. Corresponds to the JSON property items



72714
72715
72716
# File 'lib/google/apis/compute_alpha/classes.rb', line 72714

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# storagePoolListDisks for lists of disks in a storagePool. Corresponds to the JSON property kind

Returns:

  • (String)


72721
72722
72723
# File 'lib/google/apis/compute_alpha/classes.rb', line 72721

def kind
  @kind
end

#next_page_tokenString

Output only. [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


72732
72733
72734
# File 'lib/google/apis/compute_alpha/classes.rb', line 72732

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


72737
72738
72739
# File 'lib/google/apis/compute_alpha/classes.rb', line 72737

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


72743
72744
72745
# File 'lib/google/apis/compute_alpha/classes.rb', line 72743

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::StoragePoolListDisks::Warning

Output only. [Output Only] Informational warning message. Corresponds to the JSON property warning



72748
72749
72750
# File 'lib/google/apis/compute_alpha/classes.rb', line 72748

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



72755
72756
72757
72758
72759
72760
72761
72762
72763
72764
# File 'lib/google/apis/compute_alpha/classes.rb', line 72755

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end