Class: Google::Apis::ComputeAlpha::StoragePoolListDisks

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StoragePoolListDisks

Returns a new instance of StoragePoolListDisks.



71829
71830
71831
# File 'lib/google/apis/compute_alpha/classes.rb', line 71829

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


71782
71783
71784
# File 'lib/google/apis/compute_alpha/classes.rb', line 71782

def etag
  @etag
end

#idString

Output only. [Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


71788
71789
71790
# File 'lib/google/apis/compute_alpha/classes.rb', line 71788

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::StoragePoolDisk>

A list of StoragePoolDisk resources. Corresponds to the JSON property items



71793
71794
71795
# File 'lib/google/apis/compute_alpha/classes.rb', line 71793

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# storagePoolListDisks for lists of disks in a storagePool. Corresponds to the JSON property kind

Returns:

  • (String)


71800
71801
71802
# File 'lib/google/apis/compute_alpha/classes.rb', line 71800

def kind
  @kind
end

#next_page_tokenString

Output only. [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


71811
71812
71813
# File 'lib/google/apis/compute_alpha/classes.rb', line 71811

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


71816
71817
71818
# File 'lib/google/apis/compute_alpha/classes.rb', line 71816

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


71822
71823
71824
# File 'lib/google/apis/compute_alpha/classes.rb', line 71822

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::StoragePoolListDisks::Warning

Output only. [Output Only] Informational warning message. Corresponds to the JSON property warning



71827
71828
71829
# File 'lib/google/apis/compute_alpha/classes.rb', line 71827

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



71834
71835
71836
71837
71838
71839
71840
71841
71842
71843
# File 'lib/google/apis/compute_alpha/classes.rb', line 71834

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end