Class: Google::Apis::ComputeAlpha::StoragePoolParams
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::StoragePoolParams
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Additional storage pool params.
Instance Attribute Summary collapse
-
#resource_manager_tags ⇒ Hash<String,String>
Input only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ StoragePoolParams
constructor
A new instance of StoragePoolParams.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ StoragePoolParams
Returns a new instance of StoragePoolParams.
71932 71933 71934 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 71932 def initialize(**args) update!(**args) end |
Instance Attribute Details
#resource_manager_tags ⇒ Hash<String,String>
Input only. Resource manager tags to be bound to the storage pool. Tag keys
and values
have the same definition as resource
manager tags. Keys and values can be either in numeric format,
such as tagKeys/tag_key_idand `tagValues/456` or in namespaced
format such asorg_id|project_id/tag_key_short_nameand
tag_value_short_name`. The field is ignored (both PUT &
PATCH) when empty.
Corresponds to the JSON propertyresourceManagerTags`
71930 71931 71932 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 71930 def @resource_manager_tags end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
71937 71938 71939 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 71937 def update!(**args) @resource_manager_tags = args[:resource_manager_tags] if args.key?(:resource_manager_tags) end |