Class: Google::Apis::ComputeAlpha::StoragePoolResourceStatus
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::StoragePoolResourceStatus
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
[Output Only] Contains output only fields.
Instance Attribute Summary collapse
-
#aggregate_disk_provisioned_iops ⇒ Fixnum
DEPRECATED -- use "total_provisioned_disk_iops".
-
#aggregate_disk_size_gb ⇒ Fixnum
DEPRECATED -- use "total provisioned disk size gb".
-
#disk_count ⇒ Fixnum
[Output Only] Number of disks used.
-
#exapool_max_read_iops ⇒ Fixnum
Output only.
-
#exapool_max_read_throughput ⇒ Fixnum
Output only.
-
#exapool_max_write_iops ⇒ Fixnum
Output only.
-
#exapool_max_write_throughput ⇒ Fixnum
Output only.
-
#last_resize_timestamp ⇒ String
Output only.
-
#max_aggregate_disk_size_gb ⇒ Fixnum
DEPRECATED -- use "max provisioned disk size gb" Corresponds to the JSON property
maxAggregateDiskSizeGb. -
#max_total_provisioned_disk_capacity_gb ⇒ Fixnum
[Output Only] Maximum allowed aggregate disk size in GiB.
-
#number_of_disks ⇒ Fixnum
DEPRECATED -- use "disk count".
-
#pool_used_capacity_bytes ⇒ Fixnum
[Output Only] Space used by data stored in disks within the storage pool (in bytes).
-
#pool_used_iops ⇒ Fixnum
[Output Only] Sum of all the disks' provisioned IOPS, minus some amount that is allowed per disk that is not counted towards pool's IOPS capacity.
-
#pool_used_throughput ⇒ Fixnum
[Output Only] Sum of all the disks' provisioned throughput in MiB/s.
-
#pool_user_written_bytes ⇒ Fixnum
[Output Only] Amount of data written into the pool, before it is compacted.
-
#total_provisioned_disk_capacity_gb ⇒ Fixnum
[Output Only] Sum of all the disks' provisioned capacity (in GiB) in this storage pool.
-
#total_provisioned_disk_iops ⇒ Fixnum
[Output Only] Sum of all the disks' provisioned IOPS.
-
#total_provisioned_disk_throughput ⇒ Fixnum
[Output Only] Sum of all the disks' provisioned throughput in MiB/s, minus some amount that is allowed per disk that is not counted towards pool's throughput capacity.
-
#used_bytes ⇒ Fixnum
DEPRECATED -- use "pool used capacity".
-
#used_reduced_bytes ⇒ Fixnum
DEPRECATED -- do not use, will be removed.
-
#used_throughput ⇒ Fixnum
DEPRECATED -- use "pool used throughput".
Instance Method Summary collapse
-
#initialize(**args) ⇒ StoragePoolResourceStatus
constructor
A new instance of StoragePoolResourceStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ StoragePoolResourceStatus
Returns a new instance of StoragePoolResourceStatus.
75828 75829 75830 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 75828 def initialize(**args) update!(**args) end |
Instance Attribute Details
#aggregate_disk_provisioned_iops ⇒ Fixnum
DEPRECATED -- use "total_provisioned_disk_iops".
Corresponds to the JSON property aggregateDiskProvisionedIops
75713 75714 75715 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 75713 def aggregate_disk_provisioned_iops @aggregate_disk_provisioned_iops end |
#aggregate_disk_size_gb ⇒ Fixnum
DEPRECATED -- use "total provisioned disk size gb".
Corresponds to the JSON property aggregateDiskSizeGb
75718 75719 75720 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 75718 def aggregate_disk_size_gb @aggregate_disk_size_gb end |
#disk_count ⇒ Fixnum
[Output Only] Number of disks used.
Corresponds to the JSON property diskCount
75723 75724 75725 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 75723 def disk_count @disk_count end |
#exapool_max_read_iops ⇒ Fixnum
Output only. [Output Only] Maximum allowed read IOPS for this Exapool.
Corresponds to the JSON property exapoolMaxReadIops
75728 75729 75730 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 75728 def exapool_max_read_iops @exapool_max_read_iops end |
#exapool_max_read_throughput ⇒ Fixnum
Output only. [Output Only] Maximum allowed read throughput in MiB/s for
this Exapool.
Corresponds to the JSON property exapoolMaxReadThroughput
75734 75735 75736 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 75734 def exapool_max_read_throughput @exapool_max_read_throughput end |
#exapool_max_write_iops ⇒ Fixnum
Output only. [Output Only] Maximum allowed write IOPS for this Exapool.
Corresponds to the JSON property exapoolMaxWriteIops
75739 75740 75741 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 75739 def exapool_max_write_iops @exapool_max_write_iops end |
#exapool_max_write_throughput ⇒ Fixnum
Output only. [Output Only] Maximum allowed write throughput in MiB/s
for this Exapool.
Corresponds to the JSON property exapoolMaxWriteThroughput
75745 75746 75747 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 75745 def exapool_max_write_throughput @exapool_max_write_throughput end |
#last_resize_timestamp ⇒ String
Output only. [Output Only] Timestamp of the last successful resize inRFC3339
text format.
Corresponds to the JSON property lastResizeTimestamp
75751 75752 75753 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 75751 def @last_resize_timestamp end |
#max_aggregate_disk_size_gb ⇒ Fixnum
DEPRECATED -- use "max provisioned disk size gb"
Corresponds to the JSON property maxAggregateDiskSizeGb
75756 75757 75758 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 75756 def max_aggregate_disk_size_gb @max_aggregate_disk_size_gb end |
#max_total_provisioned_disk_capacity_gb ⇒ Fixnum
[Output Only] Maximum allowed aggregate disk size in GiB.
Corresponds to the JSON property maxTotalProvisionedDiskCapacityGb
75761 75762 75763 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 75761 def max_total_provisioned_disk_capacity_gb @max_total_provisioned_disk_capacity_gb end |
#number_of_disks ⇒ Fixnum
DEPRECATED -- use "disk count".
Corresponds to the JSON property numberOfDisks
75766 75767 75768 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 75766 def number_of_disks @number_of_disks end |
#pool_used_capacity_bytes ⇒ Fixnum
[Output Only] Space used by data stored in disks within the storage pool
(in bytes). This will reflect the total number of bytes written to the
disks in the pool, in contrast to the capacity of those disks.
Corresponds to the JSON property poolUsedCapacityBytes
75773 75774 75775 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 75773 def pool_used_capacity_bytes @pool_used_capacity_bytes end |
#pool_used_iops ⇒ Fixnum
[Output Only] Sum of all the disks' provisioned IOPS, minus some amount
that is allowed per disk that is not counted towards pool's IOPS
capacity. For more information, see
https://cloud.google.com/compute/docs/disks/storage-pools.
Corresponds to the JSON property poolUsedIops
75781 75782 75783 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 75781 def pool_used_iops @pool_used_iops end |
#pool_used_throughput ⇒ Fixnum
[Output Only] Sum of all the disks' provisioned throughput in MiB/s.
Corresponds to the JSON property poolUsedThroughput
75786 75787 75788 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 75786 def pool_used_throughput @pool_used_throughput end |
#pool_user_written_bytes ⇒ Fixnum
[Output Only] Amount of data written into the pool, before it is
compacted.
Corresponds to the JSON property poolUserWrittenBytes
75792 75793 75794 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 75792 def pool_user_written_bytes @pool_user_written_bytes end |
#total_provisioned_disk_capacity_gb ⇒ Fixnum
[Output Only] Sum of all the disks' provisioned capacity (in GiB) in
this storage pool. A disk's provisioned capacity is the same as its total
capacity.
Corresponds to the JSON property totalProvisionedDiskCapacityGb
75799 75800 75801 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 75799 def total_provisioned_disk_capacity_gb @total_provisioned_disk_capacity_gb end |
#total_provisioned_disk_iops ⇒ Fixnum
[Output Only] Sum of all the disks' provisioned IOPS.
Corresponds to the JSON property totalProvisionedDiskIops
75804 75805 75806 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 75804 def total_provisioned_disk_iops @total_provisioned_disk_iops end |
#total_provisioned_disk_throughput ⇒ Fixnum
[Output Only] Sum of all the disks' provisioned throughput in MiB/s,
minus some amount that is allowed per disk that is not counted towards
pool's throughput capacity.
Corresponds to the JSON property totalProvisionedDiskThroughput
75811 75812 75813 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 75811 def total_provisioned_disk_throughput @total_provisioned_disk_throughput end |
#used_bytes ⇒ Fixnum
DEPRECATED -- use "pool used capacity".
Corresponds to the JSON property usedBytes
75816 75817 75818 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 75816 def used_bytes @used_bytes end |
#used_reduced_bytes ⇒ Fixnum
DEPRECATED -- do not use, will be removed.
Corresponds to the JSON property usedReducedBytes
75821 75822 75823 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 75821 def used_reduced_bytes @used_reduced_bytes end |
#used_throughput ⇒ Fixnum
DEPRECATED -- use "pool used throughput".
Corresponds to the JSON property usedThroughput
75826 75827 75828 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 75826 def used_throughput @used_throughput end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
75833 75834 75835 75836 75837 75838 75839 75840 75841 75842 75843 75844 75845 75846 75847 75848 75849 75850 75851 75852 75853 75854 75855 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 75833 def update!(**args) @aggregate_disk_provisioned_iops = args[:aggregate_disk_provisioned_iops] if args.key?(:aggregate_disk_provisioned_iops) @aggregate_disk_size_gb = args[:aggregate_disk_size_gb] if args.key?(:aggregate_disk_size_gb) @disk_count = args[:disk_count] if args.key?(:disk_count) @exapool_max_read_iops = args[:exapool_max_read_iops] if args.key?(:exapool_max_read_iops) @exapool_max_read_throughput = args[:exapool_max_read_throughput] if args.key?(:exapool_max_read_throughput) @exapool_max_write_iops = args[:exapool_max_write_iops] if args.key?(:exapool_max_write_iops) @exapool_max_write_throughput = args[:exapool_max_write_throughput] if args.key?(:exapool_max_write_throughput) @last_resize_timestamp = args[:last_resize_timestamp] if args.key?(:last_resize_timestamp) @max_aggregate_disk_size_gb = args[:max_aggregate_disk_size_gb] if args.key?(:max_aggregate_disk_size_gb) @max_total_provisioned_disk_capacity_gb = args[:max_total_provisioned_disk_capacity_gb] if args.key?(:max_total_provisioned_disk_capacity_gb) @number_of_disks = args[:number_of_disks] if args.key?(:number_of_disks) @pool_used_capacity_bytes = args[:pool_used_capacity_bytes] if args.key?(:pool_used_capacity_bytes) @pool_used_iops = args[:pool_used_iops] if args.key?(:pool_used_iops) @pool_used_throughput = args[:pool_used_throughput] if args.key?(:pool_used_throughput) @pool_user_written_bytes = args[:pool_user_written_bytes] if args.key?(:pool_user_written_bytes) @total_provisioned_disk_capacity_gb = args[:total_provisioned_disk_capacity_gb] if args.key?(:total_provisioned_disk_capacity_gb) @total_provisioned_disk_iops = args[:total_provisioned_disk_iops] if args.key?(:total_provisioned_disk_iops) @total_provisioned_disk_throughput = args[:total_provisioned_disk_throughput] if args.key?(:total_provisioned_disk_throughput) @used_bytes = args[:used_bytes] if args.key?(:used_bytes) @used_reduced_bytes = args[:used_reduced_bytes] if args.key?(:used_reduced_bytes) @used_throughput = args[:used_throughput] if args.key?(:used_throughput) end |