Class: Google::Apis::ComputeAlpha::StoragePoolResourceStatus

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

[Output Only] Contains output only fields.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StoragePoolResourceStatus

Returns a new instance of StoragePoolResourceStatus.



75552
75553
75554
# File 'lib/google/apis/compute_alpha/classes.rb', line 75552

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#aggregate_disk_provisioned_iopsFixnum

DEPRECATED -- use "total_provisioned_disk_iops". Corresponds to the JSON property aggregateDiskProvisionedIops

Returns:

  • (Fixnum)


75437
75438
75439
# File 'lib/google/apis/compute_alpha/classes.rb', line 75437

def aggregate_disk_provisioned_iops
  @aggregate_disk_provisioned_iops
end

#aggregate_disk_size_gbFixnum

DEPRECATED -- use "total provisioned disk size gb". Corresponds to the JSON property aggregateDiskSizeGb

Returns:

  • (Fixnum)


75442
75443
75444
# File 'lib/google/apis/compute_alpha/classes.rb', line 75442

def aggregate_disk_size_gb
  @aggregate_disk_size_gb
end

#disk_countFixnum

[Output Only] Number of disks used. Corresponds to the JSON property diskCount

Returns:

  • (Fixnum)


75447
75448
75449
# File 'lib/google/apis/compute_alpha/classes.rb', line 75447

def disk_count
  @disk_count
end

#exapool_max_read_iopsFixnum

Output only. [Output Only] Maximum allowed read IOPS for this Exapool. Corresponds to the JSON property exapoolMaxReadIops

Returns:

  • (Fixnum)


75452
75453
75454
# File 'lib/google/apis/compute_alpha/classes.rb', line 75452

def exapool_max_read_iops
  @exapool_max_read_iops
end

#exapool_max_read_throughputFixnum

Output only. [Output Only] Maximum allowed read throughput in MiB/s for this Exapool. Corresponds to the JSON property exapoolMaxReadThroughput

Returns:

  • (Fixnum)


75458
75459
75460
# File 'lib/google/apis/compute_alpha/classes.rb', line 75458

def exapool_max_read_throughput
  @exapool_max_read_throughput
end

#exapool_max_write_iopsFixnum

Output only. [Output Only] Maximum allowed write IOPS for this Exapool. Corresponds to the JSON property exapoolMaxWriteIops

Returns:

  • (Fixnum)


75463
75464
75465
# File 'lib/google/apis/compute_alpha/classes.rb', line 75463

def exapool_max_write_iops
  @exapool_max_write_iops
end

#exapool_max_write_throughputFixnum

Output only. [Output Only] Maximum allowed write throughput in MiB/s for this Exapool. Corresponds to the JSON property exapoolMaxWriteThroughput

Returns:

  • (Fixnum)


75469
75470
75471
# File 'lib/google/apis/compute_alpha/classes.rb', line 75469

def exapool_max_write_throughput
  @exapool_max_write_throughput
end

#last_resize_timestampString

Output only. [Output Only] Timestamp of the last successful resize inRFC3339 text format. Corresponds to the JSON property lastResizeTimestamp

Returns:

  • (String)


75475
75476
75477
# File 'lib/google/apis/compute_alpha/classes.rb', line 75475

def last_resize_timestamp
  @last_resize_timestamp
end

#max_aggregate_disk_size_gbFixnum

DEPRECATED -- use "max provisioned disk size gb" Corresponds to the JSON property maxAggregateDiskSizeGb

Returns:

  • (Fixnum)


75480
75481
75482
# File 'lib/google/apis/compute_alpha/classes.rb', line 75480

def max_aggregate_disk_size_gb
  @max_aggregate_disk_size_gb
end

#max_total_provisioned_disk_capacity_gbFixnum

[Output Only] Maximum allowed aggregate disk size in GiB. Corresponds to the JSON property maxTotalProvisionedDiskCapacityGb

Returns:

  • (Fixnum)


75485
75486
75487
# File 'lib/google/apis/compute_alpha/classes.rb', line 75485

def max_total_provisioned_disk_capacity_gb
  @max_total_provisioned_disk_capacity_gb
end

#number_of_disksFixnum

DEPRECATED -- use "disk count". Corresponds to the JSON property numberOfDisks

Returns:

  • (Fixnum)


75490
75491
75492
# File 'lib/google/apis/compute_alpha/classes.rb', line 75490

def number_of_disks
  @number_of_disks
end

#pool_used_capacity_bytesFixnum

[Output Only] Space used by data stored in disks within the storage pool (in bytes). This will reflect the total number of bytes written to the disks in the pool, in contrast to the capacity of those disks. Corresponds to the JSON property poolUsedCapacityBytes

Returns:

  • (Fixnum)


75497
75498
75499
# File 'lib/google/apis/compute_alpha/classes.rb', line 75497

def pool_used_capacity_bytes
  @pool_used_capacity_bytes
end

#pool_used_iopsFixnum

[Output Only] Sum of all the disks' provisioned IOPS, minus some amount that is allowed per disk that is not counted towards pool's IOPS capacity. For more information, see https://cloud.google.com/compute/docs/disks/storage-pools. Corresponds to the JSON property poolUsedIops

Returns:

  • (Fixnum)


75505
75506
75507
# File 'lib/google/apis/compute_alpha/classes.rb', line 75505

def pool_used_iops
  @pool_used_iops
end

#pool_used_throughputFixnum

[Output Only] Sum of all the disks' provisioned throughput in MiB/s. Corresponds to the JSON property poolUsedThroughput

Returns:

  • (Fixnum)


75510
75511
75512
# File 'lib/google/apis/compute_alpha/classes.rb', line 75510

def pool_used_throughput
  @pool_used_throughput
end

#pool_user_written_bytesFixnum

[Output Only] Amount of data written into the pool, before it is compacted. Corresponds to the JSON property poolUserWrittenBytes

Returns:

  • (Fixnum)


75516
75517
75518
# File 'lib/google/apis/compute_alpha/classes.rb', line 75516

def pool_user_written_bytes
  @pool_user_written_bytes
end

#total_provisioned_disk_capacity_gbFixnum

[Output Only] Sum of all the disks' provisioned capacity (in GiB) in this storage pool. A disk's provisioned capacity is the same as its total capacity. Corresponds to the JSON property totalProvisionedDiskCapacityGb

Returns:

  • (Fixnum)


75523
75524
75525
# File 'lib/google/apis/compute_alpha/classes.rb', line 75523

def total_provisioned_disk_capacity_gb
  @total_provisioned_disk_capacity_gb
end

#total_provisioned_disk_iopsFixnum

[Output Only] Sum of all the disks' provisioned IOPS. Corresponds to the JSON property totalProvisionedDiskIops

Returns:

  • (Fixnum)


75528
75529
75530
# File 'lib/google/apis/compute_alpha/classes.rb', line 75528

def total_provisioned_disk_iops
  @total_provisioned_disk_iops
end

#total_provisioned_disk_throughputFixnum

[Output Only] Sum of all the disks' provisioned throughput in MiB/s, minus some amount that is allowed per disk that is not counted towards pool's throughput capacity. Corresponds to the JSON property totalProvisionedDiskThroughput

Returns:

  • (Fixnum)


75535
75536
75537
# File 'lib/google/apis/compute_alpha/classes.rb', line 75535

def total_provisioned_disk_throughput
  @total_provisioned_disk_throughput
end

#used_bytesFixnum

DEPRECATED -- use "pool used capacity". Corresponds to the JSON property usedBytes

Returns:

  • (Fixnum)


75540
75541
75542
# File 'lib/google/apis/compute_alpha/classes.rb', line 75540

def used_bytes
  @used_bytes
end

#used_reduced_bytesFixnum

DEPRECATED -- do not use, will be removed. Corresponds to the JSON property usedReducedBytes

Returns:

  • (Fixnum)


75545
75546
75547
# File 'lib/google/apis/compute_alpha/classes.rb', line 75545

def used_reduced_bytes
  @used_reduced_bytes
end

#used_throughputFixnum

DEPRECATED -- use "pool used throughput". Corresponds to the JSON property usedThroughput

Returns:

  • (Fixnum)


75550
75551
75552
# File 'lib/google/apis/compute_alpha/classes.rb', line 75550

def used_throughput
  @used_throughput
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



75557
75558
75559
75560
75561
75562
75563
75564
75565
75566
75567
75568
75569
75570
75571
75572
75573
75574
75575
75576
75577
75578
75579
# File 'lib/google/apis/compute_alpha/classes.rb', line 75557

def update!(**args)
  @aggregate_disk_provisioned_iops = args[:aggregate_disk_provisioned_iops] if args.key?(:aggregate_disk_provisioned_iops)
  @aggregate_disk_size_gb = args[:aggregate_disk_size_gb] if args.key?(:aggregate_disk_size_gb)
  @disk_count = args[:disk_count] if args.key?(:disk_count)
  @exapool_max_read_iops = args[:exapool_max_read_iops] if args.key?(:exapool_max_read_iops)
  @exapool_max_read_throughput = args[:exapool_max_read_throughput] if args.key?(:exapool_max_read_throughput)
  @exapool_max_write_iops = args[:exapool_max_write_iops] if args.key?(:exapool_max_write_iops)
  @exapool_max_write_throughput = args[:exapool_max_write_throughput] if args.key?(:exapool_max_write_throughput)
  @last_resize_timestamp = args[:last_resize_timestamp] if args.key?(:last_resize_timestamp)
  @max_aggregate_disk_size_gb = args[:max_aggregate_disk_size_gb] if args.key?(:max_aggregate_disk_size_gb)
  @max_total_provisioned_disk_capacity_gb = args[:max_total_provisioned_disk_capacity_gb] if args.key?(:max_total_provisioned_disk_capacity_gb)
  @number_of_disks = args[:number_of_disks] if args.key?(:number_of_disks)
  @pool_used_capacity_bytes = args[:pool_used_capacity_bytes] if args.key?(:pool_used_capacity_bytes)
  @pool_used_iops = args[:pool_used_iops] if args.key?(:pool_used_iops)
  @pool_used_throughput = args[:pool_used_throughput] if args.key?(:pool_used_throughput)
  @pool_user_written_bytes = args[:pool_user_written_bytes] if args.key?(:pool_user_written_bytes)
  @total_provisioned_disk_capacity_gb = args[:total_provisioned_disk_capacity_gb] if args.key?(:total_provisioned_disk_capacity_gb)
  @total_provisioned_disk_iops = args[:total_provisioned_disk_iops] if args.key?(:total_provisioned_disk_iops)
  @total_provisioned_disk_throughput = args[:total_provisioned_disk_throughput] if args.key?(:total_provisioned_disk_throughput)
  @used_bytes = args[:used_bytes] if args.key?(:used_bytes)
  @used_reduced_bytes = args[:used_reduced_bytes] if args.key?(:used_reduced_bytes)
  @used_throughput = args[:used_throughput] if args.key?(:used_throughput)
end