Class: Google::Apis::ComputeAlpha::StoragePoolResourceStatus
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::StoragePoolResourceStatus
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
[Output Only] Contains output only fields.
Instance Attribute Summary collapse
-
#aggregate_disk_provisioned_iops ⇒ Fixnum
DEPRECATED -- use "total_provisioned_disk_iops".
-
#aggregate_disk_size_gb ⇒ Fixnum
DEPRECATED -- use "total provisioned disk size gb".
-
#disk_count ⇒ Fixnum
[Output Only] Number of disks used.
-
#exapool_max_read_iops ⇒ Fixnum
Output only.
-
#exapool_max_read_throughput ⇒ Fixnum
Output only.
-
#exapool_max_write_iops ⇒ Fixnum
Output only.
-
#exapool_max_write_throughput ⇒ Fixnum
Output only.
-
#last_resize_timestamp ⇒ String
Output only.
-
#max_aggregate_disk_size_gb ⇒ Fixnum
DEPRECATED -- use "max provisioned disk size gb" Corresponds to the JSON property
maxAggregateDiskSizeGb. -
#max_total_provisioned_disk_capacity_gb ⇒ Fixnum
[Output Only] Maximum allowed aggregate disk size in GiB.
-
#number_of_disks ⇒ Fixnum
DEPRECATED -- use "disk count".
-
#pool_used_capacity_bytes ⇒ Fixnum
[Output Only] Space used by data stored in disks within the storage pool (in bytes).
-
#pool_used_iops ⇒ Fixnum
[Output Only] Sum of all the disks' provisioned IOPS, minus some amount that is allowed per disk that is not counted towards pool's IOPS capacity.
-
#pool_used_throughput ⇒ Fixnum
[Output Only] Sum of all the disks' provisioned throughput in MiB/s.
-
#pool_user_written_bytes ⇒ Fixnum
[Output Only] Amount of data written into the pool, before it is compacted.
-
#total_provisioned_disk_capacity_gb ⇒ Fixnum
[Output Only] Sum of all the disks' provisioned capacity (in GiB) in this storage pool.
-
#total_provisioned_disk_iops ⇒ Fixnum
[Output Only] Sum of all the disks' provisioned IOPS.
-
#total_provisioned_disk_throughput ⇒ Fixnum
[Output Only] Sum of all the disks' provisioned throughput in MiB/s, minus some amount that is allowed per disk that is not counted towards pool's throughput capacity.
-
#used_bytes ⇒ Fixnum
DEPRECATED -- use "pool used capacity".
-
#used_reduced_bytes ⇒ Fixnum
DEPRECATED -- do not use, will be removed.
-
#used_throughput ⇒ Fixnum
DEPRECATED -- use "pool used throughput".
Instance Method Summary collapse
-
#initialize(**args) ⇒ StoragePoolResourceStatus
constructor
A new instance of StoragePoolResourceStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ StoragePoolResourceStatus
Returns a new instance of StoragePoolResourceStatus.
75246 75247 75248 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 75246 def initialize(**args) update!(**args) end |
Instance Attribute Details
#aggregate_disk_provisioned_iops ⇒ Fixnum
DEPRECATED -- use "total_provisioned_disk_iops".
Corresponds to the JSON property aggregateDiskProvisionedIops
75131 75132 75133 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 75131 def aggregate_disk_provisioned_iops @aggregate_disk_provisioned_iops end |
#aggregate_disk_size_gb ⇒ Fixnum
DEPRECATED -- use "total provisioned disk size gb".
Corresponds to the JSON property aggregateDiskSizeGb
75136 75137 75138 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 75136 def aggregate_disk_size_gb @aggregate_disk_size_gb end |
#disk_count ⇒ Fixnum
[Output Only] Number of disks used.
Corresponds to the JSON property diskCount
75141 75142 75143 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 75141 def disk_count @disk_count end |
#exapool_max_read_iops ⇒ Fixnum
Output only. [Output Only] Maximum allowed read IOPS for this Exapool.
Corresponds to the JSON property exapoolMaxReadIops
75146 75147 75148 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 75146 def exapool_max_read_iops @exapool_max_read_iops end |
#exapool_max_read_throughput ⇒ Fixnum
Output only. [Output Only] Maximum allowed read throughput in MiB/s for
this Exapool.
Corresponds to the JSON property exapoolMaxReadThroughput
75152 75153 75154 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 75152 def exapool_max_read_throughput @exapool_max_read_throughput end |
#exapool_max_write_iops ⇒ Fixnum
Output only. [Output Only] Maximum allowed write IOPS for this Exapool.
Corresponds to the JSON property exapoolMaxWriteIops
75157 75158 75159 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 75157 def exapool_max_write_iops @exapool_max_write_iops end |
#exapool_max_write_throughput ⇒ Fixnum
Output only. [Output Only] Maximum allowed write throughput in MiB/s
for this Exapool.
Corresponds to the JSON property exapoolMaxWriteThroughput
75163 75164 75165 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 75163 def exapool_max_write_throughput @exapool_max_write_throughput end |
#last_resize_timestamp ⇒ String
Output only. [Output Only] Timestamp of the last successful resize inRFC3339
text format.
Corresponds to the JSON property lastResizeTimestamp
75169 75170 75171 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 75169 def @last_resize_timestamp end |
#max_aggregate_disk_size_gb ⇒ Fixnum
DEPRECATED -- use "max provisioned disk size gb"
Corresponds to the JSON property maxAggregateDiskSizeGb
75174 75175 75176 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 75174 def max_aggregate_disk_size_gb @max_aggregate_disk_size_gb end |
#max_total_provisioned_disk_capacity_gb ⇒ Fixnum
[Output Only] Maximum allowed aggregate disk size in GiB.
Corresponds to the JSON property maxTotalProvisionedDiskCapacityGb
75179 75180 75181 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 75179 def max_total_provisioned_disk_capacity_gb @max_total_provisioned_disk_capacity_gb end |
#number_of_disks ⇒ Fixnum
DEPRECATED -- use "disk count".
Corresponds to the JSON property numberOfDisks
75184 75185 75186 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 75184 def number_of_disks @number_of_disks end |
#pool_used_capacity_bytes ⇒ Fixnum
[Output Only] Space used by data stored in disks within the storage pool
(in bytes). This will reflect the total number of bytes written to the
disks in the pool, in contrast to the capacity of those disks.
Corresponds to the JSON property poolUsedCapacityBytes
75191 75192 75193 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 75191 def pool_used_capacity_bytes @pool_used_capacity_bytes end |
#pool_used_iops ⇒ Fixnum
[Output Only] Sum of all the disks' provisioned IOPS, minus some amount
that is allowed per disk that is not counted towards pool's IOPS
capacity. For more information, see
https://cloud.google.com/compute/docs/disks/storage-pools.
Corresponds to the JSON property poolUsedIops
75199 75200 75201 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 75199 def pool_used_iops @pool_used_iops end |
#pool_used_throughput ⇒ Fixnum
[Output Only] Sum of all the disks' provisioned throughput in MiB/s.
Corresponds to the JSON property poolUsedThroughput
75204 75205 75206 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 75204 def pool_used_throughput @pool_used_throughput end |
#pool_user_written_bytes ⇒ Fixnum
[Output Only] Amount of data written into the pool, before it is
compacted.
Corresponds to the JSON property poolUserWrittenBytes
75210 75211 75212 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 75210 def pool_user_written_bytes @pool_user_written_bytes end |
#total_provisioned_disk_capacity_gb ⇒ Fixnum
[Output Only] Sum of all the disks' provisioned capacity (in GiB) in
this storage pool. A disk's provisioned capacity is the same as its total
capacity.
Corresponds to the JSON property totalProvisionedDiskCapacityGb
75217 75218 75219 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 75217 def total_provisioned_disk_capacity_gb @total_provisioned_disk_capacity_gb end |
#total_provisioned_disk_iops ⇒ Fixnum
[Output Only] Sum of all the disks' provisioned IOPS.
Corresponds to the JSON property totalProvisionedDiskIops
75222 75223 75224 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 75222 def total_provisioned_disk_iops @total_provisioned_disk_iops end |
#total_provisioned_disk_throughput ⇒ Fixnum
[Output Only] Sum of all the disks' provisioned throughput in MiB/s,
minus some amount that is allowed per disk that is not counted towards
pool's throughput capacity.
Corresponds to the JSON property totalProvisionedDiskThroughput
75229 75230 75231 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 75229 def total_provisioned_disk_throughput @total_provisioned_disk_throughput end |
#used_bytes ⇒ Fixnum
DEPRECATED -- use "pool used capacity".
Corresponds to the JSON property usedBytes
75234 75235 75236 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 75234 def used_bytes @used_bytes end |
#used_reduced_bytes ⇒ Fixnum
DEPRECATED -- do not use, will be removed.
Corresponds to the JSON property usedReducedBytes
75239 75240 75241 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 75239 def used_reduced_bytes @used_reduced_bytes end |
#used_throughput ⇒ Fixnum
DEPRECATED -- use "pool used throughput".
Corresponds to the JSON property usedThroughput
75244 75245 75246 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 75244 def used_throughput @used_throughput end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
75251 75252 75253 75254 75255 75256 75257 75258 75259 75260 75261 75262 75263 75264 75265 75266 75267 75268 75269 75270 75271 75272 75273 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 75251 def update!(**args) @aggregate_disk_provisioned_iops = args[:aggregate_disk_provisioned_iops] if args.key?(:aggregate_disk_provisioned_iops) @aggregate_disk_size_gb = args[:aggregate_disk_size_gb] if args.key?(:aggregate_disk_size_gb) @disk_count = args[:disk_count] if args.key?(:disk_count) @exapool_max_read_iops = args[:exapool_max_read_iops] if args.key?(:exapool_max_read_iops) @exapool_max_read_throughput = args[:exapool_max_read_throughput] if args.key?(:exapool_max_read_throughput) @exapool_max_write_iops = args[:exapool_max_write_iops] if args.key?(:exapool_max_write_iops) @exapool_max_write_throughput = args[:exapool_max_write_throughput] if args.key?(:exapool_max_write_throughput) @last_resize_timestamp = args[:last_resize_timestamp] if args.key?(:last_resize_timestamp) @max_aggregate_disk_size_gb = args[:max_aggregate_disk_size_gb] if args.key?(:max_aggregate_disk_size_gb) @max_total_provisioned_disk_capacity_gb = args[:max_total_provisioned_disk_capacity_gb] if args.key?(:max_total_provisioned_disk_capacity_gb) @number_of_disks = args[:number_of_disks] if args.key?(:number_of_disks) @pool_used_capacity_bytes = args[:pool_used_capacity_bytes] if args.key?(:pool_used_capacity_bytes) @pool_used_iops = args[:pool_used_iops] if args.key?(:pool_used_iops) @pool_used_throughput = args[:pool_used_throughput] if args.key?(:pool_used_throughput) @pool_user_written_bytes = args[:pool_user_written_bytes] if args.key?(:pool_user_written_bytes) @total_provisioned_disk_capacity_gb = args[:total_provisioned_disk_capacity_gb] if args.key?(:total_provisioned_disk_capacity_gb) @total_provisioned_disk_iops = args[:total_provisioned_disk_iops] if args.key?(:total_provisioned_disk_iops) @total_provisioned_disk_throughput = args[:total_provisioned_disk_throughput] if args.key?(:total_provisioned_disk_throughput) @used_bytes = args[:used_bytes] if args.key?(:used_bytes) @used_reduced_bytes = args[:used_reduced_bytes] if args.key?(:used_reduced_bytes) @used_throughput = args[:used_throughput] if args.key?(:used_throughput) end |