Class: Google::Apis::ComputeAlpha::StoragePoolResourceStatus

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

[Output Only] Contains output only fields.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StoragePoolResourceStatus

Returns a new instance of StoragePoolResourceStatus.



73821
73822
73823
# File 'lib/google/apis/compute_alpha/classes.rb', line 73821

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#aggregate_disk_provisioned_iopsFixnum

DEPRECATED -- use "total_provisioned_disk_iops". Corresponds to the JSON property aggregateDiskProvisionedIops

Returns:

  • (Fixnum)


73706
73707
73708
# File 'lib/google/apis/compute_alpha/classes.rb', line 73706

def aggregate_disk_provisioned_iops
  @aggregate_disk_provisioned_iops
end

#aggregate_disk_size_gbFixnum

DEPRECATED -- use "total provisioned disk size gb". Corresponds to the JSON property aggregateDiskSizeGb

Returns:

  • (Fixnum)


73711
73712
73713
# File 'lib/google/apis/compute_alpha/classes.rb', line 73711

def aggregate_disk_size_gb
  @aggregate_disk_size_gb
end

#disk_countFixnum

[Output Only] Number of disks used. Corresponds to the JSON property diskCount

Returns:

  • (Fixnum)


73716
73717
73718
# File 'lib/google/apis/compute_alpha/classes.rb', line 73716

def disk_count
  @disk_count
end

#exapool_max_read_iopsFixnum

Output only. [Output Only] Maximum allowed read IOPS for this Exapool. Corresponds to the JSON property exapoolMaxReadIops

Returns:

  • (Fixnum)


73721
73722
73723
# File 'lib/google/apis/compute_alpha/classes.rb', line 73721

def exapool_max_read_iops
  @exapool_max_read_iops
end

#exapool_max_read_throughputFixnum

Output only. [Output Only] Maximum allowed read throughput in MiB/s for this Exapool. Corresponds to the JSON property exapoolMaxReadThroughput

Returns:

  • (Fixnum)


73727
73728
73729
# File 'lib/google/apis/compute_alpha/classes.rb', line 73727

def exapool_max_read_throughput
  @exapool_max_read_throughput
end

#exapool_max_write_iopsFixnum

Output only. [Output Only] Maximum allowed write IOPS for this Exapool. Corresponds to the JSON property exapoolMaxWriteIops

Returns:

  • (Fixnum)


73732
73733
73734
# File 'lib/google/apis/compute_alpha/classes.rb', line 73732

def exapool_max_write_iops
  @exapool_max_write_iops
end

#exapool_max_write_throughputFixnum

Output only. [Output Only] Maximum allowed write throughput in MiB/s for this Exapool. Corresponds to the JSON property exapoolMaxWriteThroughput

Returns:

  • (Fixnum)


73738
73739
73740
# File 'lib/google/apis/compute_alpha/classes.rb', line 73738

def exapool_max_write_throughput
  @exapool_max_write_throughput
end

#last_resize_timestampString

Output only. [Output Only] Timestamp of the last successful resize inRFC3339 text format. Corresponds to the JSON property lastResizeTimestamp

Returns:

  • (String)


73744
73745
73746
# File 'lib/google/apis/compute_alpha/classes.rb', line 73744

def last_resize_timestamp
  @last_resize_timestamp
end

#max_aggregate_disk_size_gbFixnum

DEPRECATED -- use "max provisioned disk size gb" Corresponds to the JSON property maxAggregateDiskSizeGb

Returns:

  • (Fixnum)


73749
73750
73751
# File 'lib/google/apis/compute_alpha/classes.rb', line 73749

def max_aggregate_disk_size_gb
  @max_aggregate_disk_size_gb
end

#max_total_provisioned_disk_capacity_gbFixnum

[Output Only] Maximum allowed aggregate disk size in GiB. Corresponds to the JSON property maxTotalProvisionedDiskCapacityGb

Returns:

  • (Fixnum)


73754
73755
73756
# File 'lib/google/apis/compute_alpha/classes.rb', line 73754

def max_total_provisioned_disk_capacity_gb
  @max_total_provisioned_disk_capacity_gb
end

#number_of_disksFixnum

DEPRECATED -- use "disk count". Corresponds to the JSON property numberOfDisks

Returns:

  • (Fixnum)


73759
73760
73761
# File 'lib/google/apis/compute_alpha/classes.rb', line 73759

def number_of_disks
  @number_of_disks
end

#pool_used_capacity_bytesFixnum

[Output Only] Space used by data stored in disks within the storage pool (in bytes). This will reflect the total number of bytes written to the disks in the pool, in contrast to the capacity of those disks. Corresponds to the JSON property poolUsedCapacityBytes

Returns:

  • (Fixnum)


73766
73767
73768
# File 'lib/google/apis/compute_alpha/classes.rb', line 73766

def pool_used_capacity_bytes
  @pool_used_capacity_bytes
end

#pool_used_iopsFixnum

[Output Only] Sum of all the disks' provisioned IOPS, minus some amount that is allowed per disk that is not counted towards pool's IOPS capacity. For more information, see https://cloud.google.com/compute/docs/disks/storage-pools. Corresponds to the JSON property poolUsedIops

Returns:

  • (Fixnum)


73774
73775
73776
# File 'lib/google/apis/compute_alpha/classes.rb', line 73774

def pool_used_iops
  @pool_used_iops
end

#pool_used_throughputFixnum

[Output Only] Sum of all the disks' provisioned throughput in MiB/s. Corresponds to the JSON property poolUsedThroughput

Returns:

  • (Fixnum)


73779
73780
73781
# File 'lib/google/apis/compute_alpha/classes.rb', line 73779

def pool_used_throughput
  @pool_used_throughput
end

#pool_user_written_bytesFixnum

[Output Only] Amount of data written into the pool, before it is compacted. Corresponds to the JSON property poolUserWrittenBytes

Returns:

  • (Fixnum)


73785
73786
73787
# File 'lib/google/apis/compute_alpha/classes.rb', line 73785

def pool_user_written_bytes
  @pool_user_written_bytes
end

#total_provisioned_disk_capacity_gbFixnum

[Output Only] Sum of all the disks' provisioned capacity (in GiB) in this storage pool. A disk's provisioned capacity is the same as its total capacity. Corresponds to the JSON property totalProvisionedDiskCapacityGb

Returns:

  • (Fixnum)


73792
73793
73794
# File 'lib/google/apis/compute_alpha/classes.rb', line 73792

def total_provisioned_disk_capacity_gb
  @total_provisioned_disk_capacity_gb
end

#total_provisioned_disk_iopsFixnum

[Output Only] Sum of all the disks' provisioned IOPS. Corresponds to the JSON property totalProvisionedDiskIops

Returns:

  • (Fixnum)


73797
73798
73799
# File 'lib/google/apis/compute_alpha/classes.rb', line 73797

def total_provisioned_disk_iops
  @total_provisioned_disk_iops
end

#total_provisioned_disk_throughputFixnum

[Output Only] Sum of all the disks' provisioned throughput in MiB/s, minus some amount that is allowed per disk that is not counted towards pool's throughput capacity. Corresponds to the JSON property totalProvisionedDiskThroughput

Returns:

  • (Fixnum)


73804
73805
73806
# File 'lib/google/apis/compute_alpha/classes.rb', line 73804

def total_provisioned_disk_throughput
  @total_provisioned_disk_throughput
end

#used_bytesFixnum

DEPRECATED -- use "pool used capacity". Corresponds to the JSON property usedBytes

Returns:

  • (Fixnum)


73809
73810
73811
# File 'lib/google/apis/compute_alpha/classes.rb', line 73809

def used_bytes
  @used_bytes
end

#used_reduced_bytesFixnum

DEPRECATED -- do not use, will be removed. Corresponds to the JSON property usedReducedBytes

Returns:

  • (Fixnum)


73814
73815
73816
# File 'lib/google/apis/compute_alpha/classes.rb', line 73814

def used_reduced_bytes
  @used_reduced_bytes
end

#used_throughputFixnum

DEPRECATED -- use "pool used throughput". Corresponds to the JSON property usedThroughput

Returns:

  • (Fixnum)


73819
73820
73821
# File 'lib/google/apis/compute_alpha/classes.rb', line 73819

def used_throughput
  @used_throughput
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



73826
73827
73828
73829
73830
73831
73832
73833
73834
73835
73836
73837
73838
73839
73840
73841
73842
73843
73844
73845
73846
73847
73848
# File 'lib/google/apis/compute_alpha/classes.rb', line 73826

def update!(**args)
  @aggregate_disk_provisioned_iops = args[:aggregate_disk_provisioned_iops] if args.key?(:aggregate_disk_provisioned_iops)
  @aggregate_disk_size_gb = args[:aggregate_disk_size_gb] if args.key?(:aggregate_disk_size_gb)
  @disk_count = args[:disk_count] if args.key?(:disk_count)
  @exapool_max_read_iops = args[:exapool_max_read_iops] if args.key?(:exapool_max_read_iops)
  @exapool_max_read_throughput = args[:exapool_max_read_throughput] if args.key?(:exapool_max_read_throughput)
  @exapool_max_write_iops = args[:exapool_max_write_iops] if args.key?(:exapool_max_write_iops)
  @exapool_max_write_throughput = args[:exapool_max_write_throughput] if args.key?(:exapool_max_write_throughput)
  @last_resize_timestamp = args[:last_resize_timestamp] if args.key?(:last_resize_timestamp)
  @max_aggregate_disk_size_gb = args[:max_aggregate_disk_size_gb] if args.key?(:max_aggregate_disk_size_gb)
  @max_total_provisioned_disk_capacity_gb = args[:max_total_provisioned_disk_capacity_gb] if args.key?(:max_total_provisioned_disk_capacity_gb)
  @number_of_disks = args[:number_of_disks] if args.key?(:number_of_disks)
  @pool_used_capacity_bytes = args[:pool_used_capacity_bytes] if args.key?(:pool_used_capacity_bytes)
  @pool_used_iops = args[:pool_used_iops] if args.key?(:pool_used_iops)
  @pool_used_throughput = args[:pool_used_throughput] if args.key?(:pool_used_throughput)
  @pool_user_written_bytes = args[:pool_user_written_bytes] if args.key?(:pool_user_written_bytes)
  @total_provisioned_disk_capacity_gb = args[:total_provisioned_disk_capacity_gb] if args.key?(:total_provisioned_disk_capacity_gb)
  @total_provisioned_disk_iops = args[:total_provisioned_disk_iops] if args.key?(:total_provisioned_disk_iops)
  @total_provisioned_disk_throughput = args[:total_provisioned_disk_throughput] if args.key?(:total_provisioned_disk_throughput)
  @used_bytes = args[:used_bytes] if args.key?(:used_bytes)
  @used_reduced_bytes = args[:used_reduced_bytes] if args.key?(:used_reduced_bytes)
  @used_throughput = args[:used_throughput] if args.key?(:used_throughput)
end