Class: Google::Apis::ComputeAlpha::StoragePoolResourceStatus

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

[Output Only] Contains output only fields.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StoragePoolResourceStatus

Returns a new instance of StoragePoolResourceStatus.



73212
73213
73214
# File 'lib/google/apis/compute_alpha/classes.rb', line 73212

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#aggregate_disk_provisioned_iopsFixnum

DEPRECATED -- use "total_provisioned_disk_iops". Corresponds to the JSON property aggregateDiskProvisionedIops

Returns:

  • (Fixnum)


73097
73098
73099
# File 'lib/google/apis/compute_alpha/classes.rb', line 73097

def aggregate_disk_provisioned_iops
  @aggregate_disk_provisioned_iops
end

#aggregate_disk_size_gbFixnum

DEPRECATED -- use "total provisioned disk size gb". Corresponds to the JSON property aggregateDiskSizeGb

Returns:

  • (Fixnum)


73102
73103
73104
# File 'lib/google/apis/compute_alpha/classes.rb', line 73102

def aggregate_disk_size_gb
  @aggregate_disk_size_gb
end

#disk_countFixnum

[Output Only] Number of disks used. Corresponds to the JSON property diskCount

Returns:

  • (Fixnum)


73107
73108
73109
# File 'lib/google/apis/compute_alpha/classes.rb', line 73107

def disk_count
  @disk_count
end

#exapool_max_read_iopsFixnum

Output only. [Output Only] Maximum allowed read IOPS for this Exapool. Corresponds to the JSON property exapoolMaxReadIops

Returns:

  • (Fixnum)


73112
73113
73114
# File 'lib/google/apis/compute_alpha/classes.rb', line 73112

def exapool_max_read_iops
  @exapool_max_read_iops
end

#exapool_max_read_throughputFixnum

Output only. [Output Only] Maximum allowed read throughput in MiB/s for this Exapool. Corresponds to the JSON property exapoolMaxReadThroughput

Returns:

  • (Fixnum)


73118
73119
73120
# File 'lib/google/apis/compute_alpha/classes.rb', line 73118

def exapool_max_read_throughput
  @exapool_max_read_throughput
end

#exapool_max_write_iopsFixnum

Output only. [Output Only] Maximum allowed write IOPS for this Exapool. Corresponds to the JSON property exapoolMaxWriteIops

Returns:

  • (Fixnum)


73123
73124
73125
# File 'lib/google/apis/compute_alpha/classes.rb', line 73123

def exapool_max_write_iops
  @exapool_max_write_iops
end

#exapool_max_write_throughputFixnum

Output only. [Output Only] Maximum allowed write throughput in MiB/s for this Exapool. Corresponds to the JSON property exapoolMaxWriteThroughput

Returns:

  • (Fixnum)


73129
73130
73131
# File 'lib/google/apis/compute_alpha/classes.rb', line 73129

def exapool_max_write_throughput
  @exapool_max_write_throughput
end

#last_resize_timestampString

Output only. [Output Only] Timestamp of the last successful resize inRFC3339 text format. Corresponds to the JSON property lastResizeTimestamp

Returns:

  • (String)


73135
73136
73137
# File 'lib/google/apis/compute_alpha/classes.rb', line 73135

def last_resize_timestamp
  @last_resize_timestamp
end

#max_aggregate_disk_size_gbFixnum

DEPRECATED -- use "max provisioned disk size gb" Corresponds to the JSON property maxAggregateDiskSizeGb

Returns:

  • (Fixnum)


73140
73141
73142
# File 'lib/google/apis/compute_alpha/classes.rb', line 73140

def max_aggregate_disk_size_gb
  @max_aggregate_disk_size_gb
end

#max_total_provisioned_disk_capacity_gbFixnum

[Output Only] Maximum allowed aggregate disk size in GiB. Corresponds to the JSON property maxTotalProvisionedDiskCapacityGb

Returns:

  • (Fixnum)


73145
73146
73147
# File 'lib/google/apis/compute_alpha/classes.rb', line 73145

def max_total_provisioned_disk_capacity_gb
  @max_total_provisioned_disk_capacity_gb
end

#number_of_disksFixnum

DEPRECATED -- use "disk count". Corresponds to the JSON property numberOfDisks

Returns:

  • (Fixnum)


73150
73151
73152
# File 'lib/google/apis/compute_alpha/classes.rb', line 73150

def number_of_disks
  @number_of_disks
end

#pool_used_capacity_bytesFixnum

[Output Only] Space used by data stored in disks within the storage pool (in bytes). This will reflect the total number of bytes written to the disks in the pool, in contrast to the capacity of those disks. Corresponds to the JSON property poolUsedCapacityBytes

Returns:

  • (Fixnum)


73157
73158
73159
# File 'lib/google/apis/compute_alpha/classes.rb', line 73157

def pool_used_capacity_bytes
  @pool_used_capacity_bytes
end

#pool_used_iopsFixnum

[Output Only] Sum of all the disks' provisioned IOPS, minus some amount that is allowed per disk that is not counted towards pool's IOPS capacity. For more information, see https://cloud.google.com/compute/docs/disks/storage-pools. Corresponds to the JSON property poolUsedIops

Returns:

  • (Fixnum)


73165
73166
73167
# File 'lib/google/apis/compute_alpha/classes.rb', line 73165

def pool_used_iops
  @pool_used_iops
end

#pool_used_throughputFixnum

[Output Only] Sum of all the disks' provisioned throughput in MiB/s. Corresponds to the JSON property poolUsedThroughput

Returns:

  • (Fixnum)


73170
73171
73172
# File 'lib/google/apis/compute_alpha/classes.rb', line 73170

def pool_used_throughput
  @pool_used_throughput
end

#pool_user_written_bytesFixnum

[Output Only] Amount of data written into the pool, before it is compacted. Corresponds to the JSON property poolUserWrittenBytes

Returns:

  • (Fixnum)


73176
73177
73178
# File 'lib/google/apis/compute_alpha/classes.rb', line 73176

def pool_user_written_bytes
  @pool_user_written_bytes
end

#total_provisioned_disk_capacity_gbFixnum

[Output Only] Sum of all the disks' provisioned capacity (in GiB) in this storage pool. A disk's provisioned capacity is the same as its total capacity. Corresponds to the JSON property totalProvisionedDiskCapacityGb

Returns:

  • (Fixnum)


73183
73184
73185
# File 'lib/google/apis/compute_alpha/classes.rb', line 73183

def total_provisioned_disk_capacity_gb
  @total_provisioned_disk_capacity_gb
end

#total_provisioned_disk_iopsFixnum

[Output Only] Sum of all the disks' provisioned IOPS. Corresponds to the JSON property totalProvisionedDiskIops

Returns:

  • (Fixnum)


73188
73189
73190
# File 'lib/google/apis/compute_alpha/classes.rb', line 73188

def total_provisioned_disk_iops
  @total_provisioned_disk_iops
end

#total_provisioned_disk_throughputFixnum

[Output Only] Sum of all the disks' provisioned throughput in MiB/s, minus some amount that is allowed per disk that is not counted towards pool's throughput capacity. Corresponds to the JSON property totalProvisionedDiskThroughput

Returns:

  • (Fixnum)


73195
73196
73197
# File 'lib/google/apis/compute_alpha/classes.rb', line 73195

def total_provisioned_disk_throughput
  @total_provisioned_disk_throughput
end

#used_bytesFixnum

DEPRECATED -- use "pool used capacity". Corresponds to the JSON property usedBytes

Returns:

  • (Fixnum)


73200
73201
73202
# File 'lib/google/apis/compute_alpha/classes.rb', line 73200

def used_bytes
  @used_bytes
end

#used_reduced_bytesFixnum

DEPRECATED -- do not use, will be removed. Corresponds to the JSON property usedReducedBytes

Returns:

  • (Fixnum)


73205
73206
73207
# File 'lib/google/apis/compute_alpha/classes.rb', line 73205

def used_reduced_bytes
  @used_reduced_bytes
end

#used_throughputFixnum

DEPRECATED -- use "pool used throughput". Corresponds to the JSON property usedThroughput

Returns:

  • (Fixnum)


73210
73211
73212
# File 'lib/google/apis/compute_alpha/classes.rb', line 73210

def used_throughput
  @used_throughput
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



73217
73218
73219
73220
73221
73222
73223
73224
73225
73226
73227
73228
73229
73230
73231
73232
73233
73234
73235
73236
73237
73238
73239
# File 'lib/google/apis/compute_alpha/classes.rb', line 73217

def update!(**args)
  @aggregate_disk_provisioned_iops = args[:aggregate_disk_provisioned_iops] if args.key?(:aggregate_disk_provisioned_iops)
  @aggregate_disk_size_gb = args[:aggregate_disk_size_gb] if args.key?(:aggregate_disk_size_gb)
  @disk_count = args[:disk_count] if args.key?(:disk_count)
  @exapool_max_read_iops = args[:exapool_max_read_iops] if args.key?(:exapool_max_read_iops)
  @exapool_max_read_throughput = args[:exapool_max_read_throughput] if args.key?(:exapool_max_read_throughput)
  @exapool_max_write_iops = args[:exapool_max_write_iops] if args.key?(:exapool_max_write_iops)
  @exapool_max_write_throughput = args[:exapool_max_write_throughput] if args.key?(:exapool_max_write_throughput)
  @last_resize_timestamp = args[:last_resize_timestamp] if args.key?(:last_resize_timestamp)
  @max_aggregate_disk_size_gb = args[:max_aggregate_disk_size_gb] if args.key?(:max_aggregate_disk_size_gb)
  @max_total_provisioned_disk_capacity_gb = args[:max_total_provisioned_disk_capacity_gb] if args.key?(:max_total_provisioned_disk_capacity_gb)
  @number_of_disks = args[:number_of_disks] if args.key?(:number_of_disks)
  @pool_used_capacity_bytes = args[:pool_used_capacity_bytes] if args.key?(:pool_used_capacity_bytes)
  @pool_used_iops = args[:pool_used_iops] if args.key?(:pool_used_iops)
  @pool_used_throughput = args[:pool_used_throughput] if args.key?(:pool_used_throughput)
  @pool_user_written_bytes = args[:pool_user_written_bytes] if args.key?(:pool_user_written_bytes)
  @total_provisioned_disk_capacity_gb = args[:total_provisioned_disk_capacity_gb] if args.key?(:total_provisioned_disk_capacity_gb)
  @total_provisioned_disk_iops = args[:total_provisioned_disk_iops] if args.key?(:total_provisioned_disk_iops)
  @total_provisioned_disk_throughput = args[:total_provisioned_disk_throughput] if args.key?(:total_provisioned_disk_throughput)
  @used_bytes = args[:used_bytes] if args.key?(:used_bytes)
  @used_reduced_bytes = args[:used_reduced_bytes] if args.key?(:used_reduced_bytes)
  @used_throughput = args[:used_throughput] if args.key?(:used_throughput)
end