Class: Google::Apis::ComputeAlpha::SubnetworkAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::SubnetworkAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::SubnetworksScopedList>
A list of SubnetworksScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::SubnetworkAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SubnetworkAggregatedList
constructor
A new instance of SubnetworkAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SubnetworkAggregatedList
Returns a new instance of SubnetworkAggregatedList.
76926 76927 76928 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 76926 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
76887 76888 76889 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 76887 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::SubnetworksScopedList>
A list of SubnetworksScopedList resources.
Corresponds to the JSON property items
76892 76893 76894 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 76892 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
subnetworkAggregatedList for aggregated lists of
subnetworks.
Corresponds to the JSON property kind
76899 76900 76901 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 76899 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
76909 76910 76911 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 76909 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
76914 76915 76916 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 76914 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
76919 76920 76921 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 76919 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::SubnetworkAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
76924 76925 76926 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 76924 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
76931 76932 76933 76934 76935 76936 76937 76938 76939 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 76931 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |