Class: Google::Apis::ComputeAlpha::SubnetworkAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::SubnetworkAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::SubnetworksScopedList>
A list of SubnetworksScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::SubnetworkAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SubnetworkAggregatedList
constructor
A new instance of SubnetworkAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SubnetworkAggregatedList
Returns a new instance of SubnetworkAggregatedList.
76650 76651 76652 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 76650 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
76611 76612 76613 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 76611 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::SubnetworksScopedList>
A list of SubnetworksScopedList resources.
Corresponds to the JSON property items
76616 76617 76618 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 76616 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
subnetworkAggregatedList for aggregated lists of
subnetworks.
Corresponds to the JSON property kind
76623 76624 76625 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 76623 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
76633 76634 76635 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 76633 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
76638 76639 76640 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 76638 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
76643 76644 76645 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 76643 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::SubnetworkAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
76648 76649 76650 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 76648 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
76655 76656 76657 76658 76659 76660 76661 76662 76663 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 76655 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |