Class: Google::Apis::ComputeAlpha::SubnetworkAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SubnetworkAggregatedList

Returns a new instance of SubnetworkAggregatedList.



76344
76345
76346
# File 'lib/google/apis/compute_alpha/classes.rb', line 76344

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


76305
76306
76307
# File 'lib/google/apis/compute_alpha/classes.rb', line 76305

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::SubnetworksScopedList>

A list of SubnetworksScopedList resources. Corresponds to the JSON property items



76310
76311
76312
# File 'lib/google/apis/compute_alpha/classes.rb', line 76310

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# subnetworkAggregatedList for aggregated lists of subnetworks. Corresponds to the JSON property kind

Returns:

  • (String)


76317
76318
76319
# File 'lib/google/apis/compute_alpha/classes.rb', line 76317

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


76327
76328
76329
# File 'lib/google/apis/compute_alpha/classes.rb', line 76327

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


76332
76333
76334
# File 'lib/google/apis/compute_alpha/classes.rb', line 76332

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


76337
76338
76339
# File 'lib/google/apis/compute_alpha/classes.rb', line 76337

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::SubnetworkAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



76342
76343
76344
# File 'lib/google/apis/compute_alpha/classes.rb', line 76342

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



76349
76350
76351
76352
76353
76354
76355
76356
76357
# File 'lib/google/apis/compute_alpha/classes.rb', line 76349

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end