Class: Google::Apis::ComputeAlpha::SubnetworkAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::SubnetworkAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::SubnetworksScopedList>
A list of SubnetworksScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::SubnetworkAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SubnetworkAggregatedList
constructor
A new instance of SubnetworkAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SubnetworkAggregatedList
Returns a new instance of SubnetworkAggregatedList.
74976 74977 74978 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 74976 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
74937 74938 74939 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 74937 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::SubnetworksScopedList>
A list of SubnetworksScopedList resources.
Corresponds to the JSON property items
74942 74943 74944 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 74942 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
subnetworkAggregatedList for aggregated lists of
subnetworks.
Corresponds to the JSON property kind
74949 74950 74951 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 74949 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
74959 74960 74961 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 74959 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
74964 74965 74966 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 74964 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
74969 74970 74971 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 74969 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::SubnetworkAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
74974 74975 74976 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 74974 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
74981 74982 74983 74984 74985 74986 74987 74988 74989 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 74981 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |