Class: Google::Apis::ComputeAlpha::SubnetworkAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SubnetworkAggregatedList

Returns a new instance of SubnetworkAggregatedList.



74310
74311
74312
# File 'lib/google/apis/compute_alpha/classes.rb', line 74310

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


74271
74272
74273
# File 'lib/google/apis/compute_alpha/classes.rb', line 74271

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::SubnetworksScopedList>

A list of SubnetworksScopedList resources. Corresponds to the JSON property items



74276
74277
74278
# File 'lib/google/apis/compute_alpha/classes.rb', line 74276

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# subnetworkAggregatedList for aggregated lists of subnetworks. Corresponds to the JSON property kind

Returns:

  • (String)


74283
74284
74285
# File 'lib/google/apis/compute_alpha/classes.rb', line 74283

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


74293
74294
74295
# File 'lib/google/apis/compute_alpha/classes.rb', line 74293

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


74298
74299
74300
# File 'lib/google/apis/compute_alpha/classes.rb', line 74298

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


74303
74304
74305
# File 'lib/google/apis/compute_alpha/classes.rb', line 74303

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::SubnetworkAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



74308
74309
74310
# File 'lib/google/apis/compute_alpha/classes.rb', line 74308

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



74315
74316
74317
74318
74319
74320
74321
74322
74323
# File 'lib/google/apis/compute_alpha/classes.rb', line 74315

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end