Class: Google::Apis::ComputeAlpha::SubnetworkAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SubnetworkAggregatedList

Returns a new instance of SubnetworkAggregatedList.



74044
74045
74046
# File 'lib/google/apis/compute_alpha/classes.rb', line 74044

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


74005
74006
74007
# File 'lib/google/apis/compute_alpha/classes.rb', line 74005

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::SubnetworksScopedList>

A list of SubnetworksScopedList resources. Corresponds to the JSON property items



74010
74011
74012
# File 'lib/google/apis/compute_alpha/classes.rb', line 74010

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# subnetworkAggregatedList for aggregated lists of subnetworks. Corresponds to the JSON property kind

Returns:

  • (String)


74017
74018
74019
# File 'lib/google/apis/compute_alpha/classes.rb', line 74017

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


74027
74028
74029
# File 'lib/google/apis/compute_alpha/classes.rb', line 74027

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


74032
74033
74034
# File 'lib/google/apis/compute_alpha/classes.rb', line 74032

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


74037
74038
74039
# File 'lib/google/apis/compute_alpha/classes.rb', line 74037

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::SubnetworkAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



74042
74043
74044
# File 'lib/google/apis/compute_alpha/classes.rb', line 74042

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



74049
74050
74051
74052
74053
74054
74055
74056
74057
# File 'lib/google/apis/compute_alpha/classes.rb', line 74049

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end