Class: Google::Apis::ComputeAlpha::SubnetworkAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::SubnetworkAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::SubnetworksScopedList>
A list of SubnetworksScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::SubnetworkAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SubnetworkAggregatedList
constructor
A new instance of SubnetworkAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SubnetworkAggregatedList
Returns a new instance of SubnetworkAggregatedList.
73114 73115 73116 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 73114 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
73075 73076 73077 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 73075 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::SubnetworksScopedList>
A list of SubnetworksScopedList resources.
Corresponds to the JSON property items
73080 73081 73082 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 73080 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
subnetworkAggregatedList for aggregated lists of
subnetworks.
Corresponds to the JSON property kind
73087 73088 73089 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 73087 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
73097 73098 73099 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 73097 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
73102 73103 73104 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 73102 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
73107 73108 73109 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 73107 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::SubnetworkAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
73112 73113 73114 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 73112 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
73119 73120 73121 73122 73123 73124 73125 73126 73127 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 73119 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |