Class: Google::Apis::ComputeAlpha::SubnetworkList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of Subnetwork resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SubnetworkList

Returns a new instance of SubnetworkList.



75045
75046
75047
# File 'lib/google/apis/compute_alpha/classes.rb', line 75045

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


75012
75013
75014
# File 'lib/google/apis/compute_alpha/classes.rb', line 75012

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::Subnetwork>

A list of Subnetwork resources. Corresponds to the JSON property items



75017
75018
75019
# File 'lib/google/apis/compute_alpha/classes.rb', line 75017

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#subnetworkList for lists of subnetworks. Corresponds to the JSON property kind

Returns:

  • (String)


75023
75024
75025
# File 'lib/google/apis/compute_alpha/classes.rb', line 75023

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


75033
75034
75035
# File 'lib/google/apis/compute_alpha/classes.rb', line 75033

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


75038
75039
75040
# File 'lib/google/apis/compute_alpha/classes.rb', line 75038

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::SubnetworkList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



75043
75044
75045
# File 'lib/google/apis/compute_alpha/classes.rb', line 75043

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



75050
75051
75052
75053
75054
75055
75056
75057
# File 'lib/google/apis/compute_alpha/classes.rb', line 75050

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end