Class: Google::Apis::ComputeAlpha::SubnetworkList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of Subnetwork resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SubnetworkList

Returns a new instance of SubnetworkList.



74436
74437
74438
# File 'lib/google/apis/compute_alpha/classes.rb', line 74436

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


74403
74404
74405
# File 'lib/google/apis/compute_alpha/classes.rb', line 74403

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::Subnetwork>

A list of Subnetwork resources. Corresponds to the JSON property items



74408
74409
74410
# File 'lib/google/apis/compute_alpha/classes.rb', line 74408

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#subnetworkList for lists of subnetworks. Corresponds to the JSON property kind

Returns:

  • (String)


74414
74415
74416
# File 'lib/google/apis/compute_alpha/classes.rb', line 74414

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


74424
74425
74426
# File 'lib/google/apis/compute_alpha/classes.rb', line 74424

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


74429
74430
74431
# File 'lib/google/apis/compute_alpha/classes.rb', line 74429

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::SubnetworkList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



74434
74435
74436
# File 'lib/google/apis/compute_alpha/classes.rb', line 74434

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



74441
74442
74443
74444
74445
74446
74447
74448
# File 'lib/google/apis/compute_alpha/classes.rb', line 74441

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end