Class: Google::Apis::ComputeAlpha::SubnetworkList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of Subnetwork resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SubnetworkList

Returns a new instance of SubnetworkList.



74170
74171
74172
# File 'lib/google/apis/compute_alpha/classes.rb', line 74170

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


74137
74138
74139
# File 'lib/google/apis/compute_alpha/classes.rb', line 74137

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::Subnetwork>

A list of Subnetwork resources. Corresponds to the JSON property items



74142
74143
74144
# File 'lib/google/apis/compute_alpha/classes.rb', line 74142

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#subnetworkList for lists of subnetworks. Corresponds to the JSON property kind

Returns:

  • (String)


74148
74149
74150
# File 'lib/google/apis/compute_alpha/classes.rb', line 74148

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


74158
74159
74160
# File 'lib/google/apis/compute_alpha/classes.rb', line 74158

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


74163
74164
74165
# File 'lib/google/apis/compute_alpha/classes.rb', line 74163

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::SubnetworkList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



74168
74169
74170
# File 'lib/google/apis/compute_alpha/classes.rb', line 74168

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



74175
74176
74177
74178
74179
74180
74181
74182
# File 'lib/google/apis/compute_alpha/classes.rb', line 74175

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end