Class: Google::Apis::ComputeAlpha::SubnetworkSecondaryRange
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::SubnetworkSecondaryRange
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Represents a secondary IP range of a subnetwork.
Instance Attribute Summary collapse
-
#ip_cidr_range ⇒ String
The range of IP addresses belonging to this subnetwork secondary range.
-
#ip_collection ⇒ String
Reference to a Public Delegated Prefix (PDP) for BYOIP.
-
#ip_version ⇒ String
Corresponds to the JSON property
ipVersion. -
#range_name ⇒ String
The name associated with this subnetwork secondary range, used when adding an alias IP/IPv6 range to a VM instance.
-
#reserved_internal_range ⇒ String
The URL of the reserved internal range.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SubnetworkSecondaryRange
constructor
A new instance of SubnetworkSecondaryRange.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SubnetworkSecondaryRange
Returns a new instance of SubnetworkSecondaryRange.
74408 74409 74410 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 74408 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ip_cidr_range ⇒ String
The range of IP addresses belonging to this subnetwork secondary range.
Provide this property when you create the subnetwork. Ranges must be
unique and non-overlapping with all primary and secondary IP ranges
within a network. Both IPv4 and IPv6 ranges are supported. For IPv4,
the range can be any range listed in theValid
ranges list.
For IPv6:
The range must have a /64 prefix length.
The range must be omitted, for auto-allocation from Google-defined ULA
IPv6 range.
For BYOGUA internal IPv6 secondary range, the range may be specified
along with the ipCollection field.
If an ipCollection is specified, the requested ip_cidr_range must lie
within the range of the PDP referenced by the ipCollection field for
allocation.
If ipCollection field is specified, but ip_cidr_range is not,
the range is auto-allocated from the PDP referenced by the ipCollection
field.
Corresponds to the JSON property ipCidrRange
74377 74378 74379 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 74377 def ip_cidr_range @ip_cidr_range end |
#ip_collection ⇒ String
Reference to a Public Delegated Prefix (PDP) for BYOIP.
This field should be specified for configuring BYOGUA internal IPv6
secondary range.
When specified along with the ip_cidr_range, the ip_cidr_range must lie
within the PDP referenced by the ipCollection field.
When specified without the ip_cidr_range, the range is auto-allocated
from the PDP referenced by the ipCollection field.
Corresponds to the JSON property ipCollection
74388 74389 74390 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 74388 def ip_collection @ip_collection end |
#ip_version ⇒ String
Corresponds to the JSON property ipVersion
74393 74394 74395 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 74393 def ip_version @ip_version end |
#range_name ⇒ String
The name associated with this subnetwork secondary range, used when adding
an alias IP/IPv6 range to a VM instance.
The name must be 1-63 characters long, and comply withRFC1035.
The name must be unique within the subnetwork.
Corresponds to the JSON property rangeName
74401 74402 74403 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 74401 def range_name @range_name end |
#reserved_internal_range ⇒ String
The URL of the reserved internal range. Only IPv4 is supported.
Corresponds to the JSON property reservedInternalRange
74406 74407 74408 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 74406 def reserved_internal_range @reserved_internal_range end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
74413 74414 74415 74416 74417 74418 74419 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 74413 def update!(**args) @ip_cidr_range = args[:ip_cidr_range] if args.key?(:ip_cidr_range) @ip_collection = args[:ip_collection] if args.key?(:ip_collection) @ip_version = args[:ip_version] if args.key?(:ip_version) @range_name = args[:range_name] if args.key?(:range_name) @reserved_internal_range = args[:reserved_internal_range] if args.key?(:reserved_internal_range) end |