Class: Google::Apis::ComputeAlpha::SubnetworksExpandIpCidrRangeRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SubnetworksExpandIpCidrRangeRequest

Returns a new instance of SubnetworksExpandIpCidrRangeRequest.



73581
73582
73583
# File 'lib/google/apis/compute_alpha/classes.rb', line 73581

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ip_cidr_rangeString

The IP (in CIDR format or netmask) of internal addresses that are legal on this Subnetwork. This range should be disjoint from other subnetworks within this network. This range can only be larger than (i.e. a superset of) the range previously defined before the update. Corresponds to the JSON property ipCidrRange

Returns:

  • (String)


73579
73580
73581
# File 'lib/google/apis/compute_alpha/classes.rb', line 73579

def ip_cidr_range
  @ip_cidr_range
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



73586
73587
73588
# File 'lib/google/apis/compute_alpha/classes.rb', line 73586

def update!(**args)
  @ip_cidr_range = args[:ip_cidr_range] if args.key?(:ip_cidr_range)
end