Class: Google::Apis::ComputeAlpha::SubnetworksScopedWarning
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::SubnetworksScopedWarning
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#scope_name ⇒ String
Name of the scope containing this set of Subnetworks.
-
#warning ⇒ Google::Apis::ComputeAlpha::SubnetworksScopedWarning::Warning
An informational warning about unreachable scope Corresponds to the JSON property
warning.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SubnetworksScopedWarning
constructor
A new instance of SubnetworksScopedWarning.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SubnetworksScopedWarning
Returns a new instance of SubnetworksScopedWarning.
75582 75583 75584 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 75582 def initialize(**args) update!(**args) end |
Instance Attribute Details
#scope_name ⇒ String
Name of the scope containing this set of Subnetworks.
Corresponds to the JSON property scopeName
75575 75576 75577 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 75575 def scope_name @scope_name end |
#warning ⇒ Google::Apis::ComputeAlpha::SubnetworksScopedWarning::Warning
An informational warning about unreachable scope
Corresponds to the JSON property warning
75580 75581 75582 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 75580 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
75587 75588 75589 75590 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 75587 def update!(**args) @scope_name = args[:scope_name] if args.key?(:scope_name) @warning = args[:warning] if args.key?(:warning) end |