Class: Google::Apis::ComputeAlpha::SubnetworksScopedWarning

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SubnetworksScopedWarning

Returns a new instance of SubnetworksScopedWarning.



74918
74919
74920
# File 'lib/google/apis/compute_alpha/classes.rb', line 74918

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#scope_nameString

Name of the scope containing this set of Subnetworks. Corresponds to the JSON property scopeName

Returns:

  • (String)


74911
74912
74913
# File 'lib/google/apis/compute_alpha/classes.rb', line 74911

def scope_name
  @scope_name
end

#warningGoogle::Apis::ComputeAlpha::SubnetworksScopedWarning::Warning

An informational warning about unreachable scope Corresponds to the JSON property warning



74916
74917
74918
# File 'lib/google/apis/compute_alpha/classes.rb', line 74916

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



74923
74924
74925
74926
# File 'lib/google/apis/compute_alpha/classes.rb', line 74923

def update!(**args)
  @scope_name = args[:scope_name] if args.key?(:scope_name)
  @warning = args[:warning] if args.key?(:warning)
end