Class: Google::Apis::ComputeAlpha::SubnetworksScopedWarning

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SubnetworksScopedWarning

Returns a new instance of SubnetworksScopedWarning.



74916
74917
74918
# File 'lib/google/apis/compute_alpha/classes.rb', line 74916

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#scope_nameString

Name of the scope containing this set of Subnetworks. Corresponds to the JSON property scopeName

Returns:

  • (String)


74909
74910
74911
# File 'lib/google/apis/compute_alpha/classes.rb', line 74909

def scope_name
  @scope_name
end

#warningGoogle::Apis::ComputeAlpha::SubnetworksScopedWarning::Warning

An informational warning about unreachable scope Corresponds to the JSON property warning



74914
74915
74916
# File 'lib/google/apis/compute_alpha/classes.rb', line 74914

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



74921
74922
74923
74924
# File 'lib/google/apis/compute_alpha/classes.rb', line 74921

def update!(**args)
  @scope_name = args[:scope_name] if args.key?(:scope_name)
  @warning = args[:warning] if args.key?(:warning)
end