Class: Google::Apis::ComputeAlpha::SubnetworksScopedWarning

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SubnetworksScopedWarning

Returns a new instance of SubnetworksScopedWarning.



74650
74651
74652
# File 'lib/google/apis/compute_alpha/classes.rb', line 74650

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#scope_nameString

Name of the scope containing this set of Subnetworks. Corresponds to the JSON property scopeName

Returns:

  • (String)


74643
74644
74645
# File 'lib/google/apis/compute_alpha/classes.rb', line 74643

def scope_name
  @scope_name
end

#warningGoogle::Apis::ComputeAlpha::SubnetworksScopedWarning::Warning

An informational warning about unreachable scope Corresponds to the JSON property warning



74648
74649
74650
# File 'lib/google/apis/compute_alpha/classes.rb', line 74648

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



74655
74656
74657
74658
# File 'lib/google/apis/compute_alpha/classes.rb', line 74655

def update!(**args)
  @scope_name = args[:scope_name] if args.key?(:scope_name)
  @warning = args[:warning] if args.key?(:warning)
end