Class: Google::Apis::ComputeAlpha::Subsetting
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::Subsetting
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Subsetting configuration for this BackendService. Currently this is applicable only for Internal TCP/UDP load balancing, Internal HTTP(S) load balancing and Traffic Director.
Instance Attribute Summary collapse
-
#policy ⇒ String
Corresponds to the JSON property
policy. -
#subset_size ⇒ Fixnum
The number of backends per backend group assigned to each proxy instance or each service mesh client.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Subsetting
constructor
A new instance of Subsetting.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Subsetting
Returns a new instance of Subsetting.
73831 73832 73833 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 73831 def initialize(**args) update!(**args) end |
Instance Attribute Details
#policy ⇒ String
Corresponds to the JSON property policy
73812 73813 73814 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 73812 def policy @policy end |
#subset_size ⇒ Fixnum
The number of backends per backend group assigned to each proxy instance or
each service mesh client.
An input parameter to the CONSISTENT_HASH_SUBSETTING algorithm.
Can only be set if policy is set to CONSISTENT_HASH_SUBSETTING.
Can only be set if load balancing scheme is INTERNAL_MANAGED or
INTERNAL_SELF_MANAGED.
subset_size is optional for Internal HTTP(S) load balancing
and required for Traffic Director.
If you do not provide this value, Cloud Load Balancing will calculate it
dynamically to optimize the number of proxies/clients visible to each
backend and vice versa.
Must be greater than 0. If subset_size is larger than the number of
backends/endpoints, then subsetting is disabled.
Corresponds to the JSON property subsetSize
73829 73830 73831 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 73829 def subset_size @subset_size end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
73836 73837 73838 73839 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 73836 def update!(**args) @policy = args[:policy] if args.key?(:policy) @subset_size = args[:subset_size] if args.key?(:subset_size) end |