Class: Google::Apis::ComputeAlpha::TargetGrpcProxy

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Represents a Target gRPC Proxy resource. A target gRPC proxy is a component of load balancers intended for load balancing gRPC traffic. Only global forwarding rules with load balancing scheme INTERNAL_SELF_MANAGED can reference a target gRPC proxy. The target gRPC Proxy references a URL map that specifies how traffic is routed to gRPC backend services.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetGrpcProxy

Returns a new instance of TargetGrpcProxy.



74992
74993
74994
# File 'lib/google/apis/compute_alpha/classes.rb', line 74992

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


74916
74917
74918
# File 'lib/google/apis/compute_alpha/classes.rb', line 74916

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


74922
74923
74924
# File 'lib/google/apis/compute_alpha/classes.rb', line 74922

def description
  @description
end

#fingerprintString

Fingerprint of this resource. A hash of the contents stored in this object. This field is used in optimistic locking. This field will be ignored when inserting a TargetGrpcProxy. An up-to-date fingerprint must be provided in order to patch/update the TargetGrpcProxy; otherwise, the request will fail with error 412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve the TargetGrpcProxy. Corresponds to the JSON property fingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


74934
74935
74936
# File 'lib/google/apis/compute_alpha/classes.rb', line 74934

def fingerprint
  @fingerprint
end

#idFixnum

Output only. [Output Only] The unique identifier for the resource type. The server generates this identifier. Corresponds to the JSON property id

Returns:

  • (Fixnum)


74941
74942
74943
# File 'lib/google/apis/compute_alpha/classes.rb', line 74941

def id
  @id
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute#targetGrpcProxy for target grpc proxies. Corresponds to the JSON property kind

Returns:

  • (String)


74947
74948
74949
# File 'lib/google/apis/compute_alpha/classes.rb', line 74947

def kind
  @kind
end

#nameString

Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


74958
74959
74960
# File 'lib/google/apis/compute_alpha/classes.rb', line 74958

def name
  @name
end

Output only. [Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


74963
74964
74965
# File 'lib/google/apis/compute_alpha/classes.rb', line 74963

def self_link
  @self_link
end

Output only. [Output Only] Server-defined URL with id for the resource. Corresponds to the JSON property selfLinkWithId

Returns:

  • (String)


74968
74969
74970
# File 'lib/google/apis/compute_alpha/classes.rb', line 74968

def self_link_with_id
  @self_link_with_id
end

#url_mapString

URL to the UrlMap resource that defines the mapping from URL to the BackendService. The protocol field in the BackendService must be set to GRPC. Corresponds to the JSON property urlMap

Returns:

  • (String)


74975
74976
74977
# File 'lib/google/apis/compute_alpha/classes.rb', line 74975

def url_map
  @url_map
end

#validate_for_proxylessBoolean Also known as: validate_for_proxyless?

If true, indicates that the BackendServices referenced by the urlMap may be accessed by gRPC applications without using a sidecar proxy. This will enable configuration checks on urlMap and its referenced BackendServices to not allow unsupported features. A gRPC application must use "xds:///" scheme in the target URI of the service it is connecting to. If false, indicates that the BackendServices referenced by the urlMap will be accessed by gRPC applications via a sidecar proxy. In this case, a gRPC application must not use "xds:///" scheme in the target URI of the service it is connecting to Corresponds to the JSON property validateForProxyless

Returns:

  • (Boolean)


74989
74990
74991
# File 'lib/google/apis/compute_alpha/classes.rb', line 74989

def validate_for_proxyless
  @validate_for_proxyless
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



74997
74998
74999
75000
75001
75002
75003
75004
75005
75006
75007
75008
# File 'lib/google/apis/compute_alpha/classes.rb', line 74997

def update!(**args)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @fingerprint = args[:fingerprint] if args.key?(:fingerprint)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @self_link = args[:self_link] if args.key?(:self_link)
  @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id)
  @url_map = args[:url_map] if args.key?(:url_map)
  @validate_for_proxyless = args[:validate_for_proxyless] if args.key?(:validate_for_proxyless)
end