Class: Google::Apis::ComputeAlpha::TargetGrpcProxyList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::TargetGrpcProxyList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::TargetGrpcProxy>
A list of TargetGrpcProxy resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
-
#warning ⇒ Google::Apis::ComputeAlpha::TargetGrpcProxyList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TargetGrpcProxyList
constructor
A new instance of TargetGrpcProxyList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TargetGrpcProxyList
Returns a new instance of TargetGrpcProxyList.
77657 77658 77659 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 77657 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
77624 77625 77626 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 77624 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::TargetGrpcProxy>
A list of TargetGrpcProxy resources.
Corresponds to the JSON property items
77629 77630 77631 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 77629 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#targetGrpcProxy
for target grpc proxies.
Corresponds to the JSON property kind
77635 77636 77637 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 77635 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
77645 77646 77647 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 77645 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
77650 77651 77652 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 77650 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::TargetGrpcProxyList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
77655 77656 77657 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 77655 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
77662 77663 77664 77665 77666 77667 77668 77669 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 77662 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |