Class: Google::Apis::ComputeAlpha::TargetGrpcProxyList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetGrpcProxyList

Returns a new instance of TargetGrpcProxyList.



77351
77352
77353
# File 'lib/google/apis/compute_alpha/classes.rb', line 77351

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


77318
77319
77320
# File 'lib/google/apis/compute_alpha/classes.rb', line 77318

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::TargetGrpcProxy>

A list of TargetGrpcProxy resources. Corresponds to the JSON property items



77323
77324
77325
# File 'lib/google/apis/compute_alpha/classes.rb', line 77323

def items
  @items
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute#targetGrpcProxy for target grpc proxies. Corresponds to the JSON property kind

Returns:

  • (String)


77329
77330
77331
# File 'lib/google/apis/compute_alpha/classes.rb', line 77329

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


77339
77340
77341
# File 'lib/google/apis/compute_alpha/classes.rb', line 77339

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


77344
77345
77346
# File 'lib/google/apis/compute_alpha/classes.rb', line 77344

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::TargetGrpcProxyList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



77349
77350
77351
# File 'lib/google/apis/compute_alpha/classes.rb', line 77349

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



77356
77357
77358
77359
77360
77361
77362
77363
# File 'lib/google/apis/compute_alpha/classes.rb', line 77356

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end