Class: Google::Apis::ComputeAlpha::TargetGrpcProxyList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetGrpcProxyList

Returns a new instance of TargetGrpcProxyList.



75983
75984
75985
# File 'lib/google/apis/compute_alpha/classes.rb', line 75983

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


75950
75951
75952
# File 'lib/google/apis/compute_alpha/classes.rb', line 75950

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::TargetGrpcProxy>

A list of TargetGrpcProxy resources. Corresponds to the JSON property items



75955
75956
75957
# File 'lib/google/apis/compute_alpha/classes.rb', line 75955

def items
  @items
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute#targetGrpcProxy for target grpc proxies. Corresponds to the JSON property kind

Returns:

  • (String)


75961
75962
75963
# File 'lib/google/apis/compute_alpha/classes.rb', line 75961

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


75971
75972
75973
# File 'lib/google/apis/compute_alpha/classes.rb', line 75971

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


75976
75977
75978
# File 'lib/google/apis/compute_alpha/classes.rb', line 75976

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::TargetGrpcProxyList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



75981
75982
75983
# File 'lib/google/apis/compute_alpha/classes.rb', line 75981

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



75988
75989
75990
75991
75992
75993
75994
75995
# File 'lib/google/apis/compute_alpha/classes.rb', line 75988

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end