Class: Google::Apis::ComputeAlpha::TargetGrpcProxyList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetGrpcProxyList

Returns a new instance of TargetGrpcProxyList.



75319
75320
75321
# File 'lib/google/apis/compute_alpha/classes.rb', line 75319

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


75286
75287
75288
# File 'lib/google/apis/compute_alpha/classes.rb', line 75286

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::TargetGrpcProxy>

A list of TargetGrpcProxy resources. Corresponds to the JSON property items



75291
75292
75293
# File 'lib/google/apis/compute_alpha/classes.rb', line 75291

def items
  @items
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute#targetGrpcProxy for target grpc proxies. Corresponds to the JSON property kind

Returns:

  • (String)


75297
75298
75299
# File 'lib/google/apis/compute_alpha/classes.rb', line 75297

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


75307
75308
75309
# File 'lib/google/apis/compute_alpha/classes.rb', line 75307

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


75312
75313
75314
# File 'lib/google/apis/compute_alpha/classes.rb', line 75312

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::TargetGrpcProxyList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



75317
75318
75319
# File 'lib/google/apis/compute_alpha/classes.rb', line 75317

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



75324
75325
75326
75327
75328
75329
75330
75331
# File 'lib/google/apis/compute_alpha/classes.rb', line 75324

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end