Class: Google::Apis::ComputeAlpha::TargetGrpcProxyList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::TargetGrpcProxyList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::TargetGrpcProxy>
A list of TargetGrpcProxy resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
-
#warning ⇒ Google::Apis::ComputeAlpha::TargetGrpcProxyList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TargetGrpcProxyList
constructor
A new instance of TargetGrpcProxyList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TargetGrpcProxyList
Returns a new instance of TargetGrpcProxyList.
75051 75052 75053 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 75051 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
75018 75019 75020 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 75018 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::TargetGrpcProxy>
A list of TargetGrpcProxy resources.
Corresponds to the JSON property items
75023 75024 75025 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 75023 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#targetGrpcProxy
for target grpc proxies.
Corresponds to the JSON property kind
75029 75030 75031 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 75029 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
75039 75040 75041 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 75039 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
75044 75045 75046 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 75044 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::TargetGrpcProxyList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
75049 75050 75051 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 75049 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
75056 75057 75058 75059 75060 75061 75062 75063 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 75056 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |