Class: Google::Apis::ComputeAlpha::TargetHttpProxy
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::TargetHttpProxy
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Represents a Target HTTP Proxy resource. Google Compute Engine has two Target HTTP Proxy resources:
- Global
- Regional A target HTTP proxy is a component of Google Cloud HTTP load balancers.
- targetHttpProxies are used by global external Application Load Balancers, classic Application Load Balancers, cross-region internal Application Load Balancers, and Traffic Director.
- regionTargetHttpProxies are used by regional internal Application Load Balancers and regional external Application Load Balancers. Forwarding rules reference a target HTTP proxy, and the target proxy then references a URL map. For more information, readUsing Target Proxies and Forwarding rule concepts.
Instance Attribute Summary collapse
-
#creation_timestamp ⇒ String
Output only.
-
#description ⇒ String
An optional description of this resource.
-
#fingerprint ⇒ String
Fingerprint of this resource.
-
#http_filters ⇒ Array<String>
URLs to networkservices.HttpFilter resources enabled for xDS clients using this configuration.
-
#http_keep_alive_timeout_sec ⇒ Fixnum
Specifies how long to keep a connection open, after completing a response, while there is no matching traffic (in seconds).
-
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
Name of the resource.
-
#proxy_bind ⇒ Boolean
(also: #proxy_bind?)
This field only applies when the forwarding rule that references this target proxy has a loadBalancingScheme set toINTERNAL_SELF_MANAGED.
-
#region ⇒ String
Output only.
-
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
-
#self_link_with_id ⇒ String
Output only.
-
#url_map ⇒ String
URL to the UrlMap resource that defines the mapping from URL to the BackendService.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TargetHttpProxy
constructor
A new instance of TargetHttpProxy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TargetHttpProxy
Returns a new instance of TargetHttpProxy.
74415 74416 74417 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 74415 def initialize(**args) update!(**args) end |
Instance Attribute Details
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
74306 74307 74308 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 74306 def @creation_timestamp end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
74312 74313 74314 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 74312 def description @description end |
#fingerprint ⇒ String
Fingerprint of this resource. A hash of the contents stored in this object.
This field is used in optimistic locking. This field will be ignored when
inserting a TargetHttpProxy. An up-to-date fingerprint must
be provided in order to patch/update the TargetHttpProxy; otherwise, the
request will fail with error 412 conditionNotMet. To see the
latest fingerprint, make a get() request to retrieve the
TargetHttpProxy.
Corresponds to the JSON property fingerprint
NOTE: Values are automatically base64 encoded/decoded in the client library.
74324 74325 74326 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 74324 def fingerprint @fingerprint end |
#http_filters ⇒ Array<String>
URLs to networkservices.HttpFilter resources
enabled for xDS clients using this configuration. For example,https://
networkservices.googleapis.com/v1alpha1/projects/project/locations/
locationhttpFilters/httpFilter
Only filters that handle outbound connection and
stream events may be specified. These filters work in conjunction with
a default set of HTTP filters that may already be configured by Traffic
Director. Traffic Director will determine the final location of these
filters within xDS configuration based on the name of the HTTP filter. If
Traffic Director positions multiple filters at the same location, those
filters will be in the same order as specified in this list.
httpFilters only applies for loadbalancers withloadBalancingScheme set to
INTERNAL_SELF_MANAGED.
See ForwardingRule for more details.
Corresponds to the JSON property httpFilters
74342 74343 74344 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 74342 def http_filters @http_filters end |
#http_keep_alive_timeout_sec ⇒ Fixnum
Specifies how long to keep a connection open, after completing a response,
while there is no matching traffic (in seconds). If an HTTP keep-alive is
not specified, a default value (610 seconds) will be used.
For global external Application Load Balancers, the minimum allowed value
is 5 seconds and the maximum allowed value is 1200 seconds.
For classic Application Load Balancers, this option is not supported.
Corresponds to the JSON property httpKeepAliveTimeoutSec
74352 74353 74354 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 74352 def http_keep_alive_timeout_sec @http_keep_alive_timeout_sec end |
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
74358 74359 74360 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 74358 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#targetHttpProxy
for target HTTP proxies.
Corresponds to the JSON property kind
74364 74365 74366 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 74364 def kind @kind end |
#name ⇒ String
Name of the resource. Provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must
be a dash, lowercase letter, or digit, except the last character, which
cannot be a dash.
Corresponds to the JSON property name
74375 74376 74377 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 74375 def name @name end |
#proxy_bind ⇒ Boolean Also known as: proxy_bind?
This field only applies when the forwarding rule that references this
target proxy has a loadBalancingScheme set toINTERNAL_SELF_MANAGED.
When this field is set to true, Envoy proxies set up inbound
traffic interception and bind to the IP address and port specified in the
forwarding rule. This is generally useful when using Traffic Director to
configure Envoy as a gateway or middle proxy (in other words, not a
sidecar proxy). The Envoy proxy listens for inbound requests and handles
requests when it receives them.
The default is false.
Corresponds to the JSON property proxyBind
74388 74389 74390 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 74388 def proxy_bind @proxy_bind end |
#region ⇒ String
Output only. [Output Only] URL of the region where the regional Target HTTP
Proxy
resides. This field is not applicable to global Target HTTP Proxies.
Corresponds to the JSON property region
74396 74397 74398 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 74396 def region @region end |
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
74401 74402 74403 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 74401 def self_link @self_link end |
#self_link_with_id ⇒ String
Output only. [Output Only] Server-defined URL for this resource with the
resource id.
Corresponds to the JSON property selfLinkWithId
74407 74408 74409 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 74407 def self_link_with_id @self_link_with_id end |
#url_map ⇒ String
URL to the UrlMap resource that defines the mapping from URL to
the BackendService.
Corresponds to the JSON property urlMap
74413 74414 74415 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 74413 def url_map @url_map end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
74420 74421 74422 74423 74424 74425 74426 74427 74428 74429 74430 74431 74432 74433 74434 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 74420 def update!(**args) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @fingerprint = args[:fingerprint] if args.key?(:fingerprint) @http_filters = args[:http_filters] if args.key?(:http_filters) @http_keep_alive_timeout_sec = args[:http_keep_alive_timeout_sec] if args.key?(:http_keep_alive_timeout_sec) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @proxy_bind = args[:proxy_bind] if args.key?(:proxy_bind) @region = args[:region] if args.key?(:region) @self_link = args[:self_link] if args.key?(:self_link) @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id) @url_map = args[:url_map] if args.key?(:url_map) end |