Class: Google::Apis::ComputeAlpha::TargetHttpProxyAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetHttpProxyAggregatedList

Returns a new instance of TargetHttpProxyAggregatedList.



77731
77732
77733
# File 'lib/google/apis/compute_alpha/classes.rb', line 77731

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


77692
77693
77694
# File 'lib/google/apis/compute_alpha/classes.rb', line 77692

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::TargetHttpProxiesScopedList>

A list of TargetHttpProxiesScopedList resources. Corresponds to the JSON property items



77697
77698
77699
# File 'lib/google/apis/compute_alpha/classes.rb', line 77697

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# targetHttpProxyAggregatedList for lists of Target HTTP Proxies. Corresponds to the JSON property kind

Returns:

  • (String)


77704
77705
77706
# File 'lib/google/apis/compute_alpha/classes.rb', line 77704

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


77714
77715
77716
# File 'lib/google/apis/compute_alpha/classes.rb', line 77714

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


77719
77720
77721
# File 'lib/google/apis/compute_alpha/classes.rb', line 77719

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


77724
77725
77726
# File 'lib/google/apis/compute_alpha/classes.rb', line 77724

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::TargetHttpProxyAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



77729
77730
77731
# File 'lib/google/apis/compute_alpha/classes.rb', line 77729

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



77736
77737
77738
77739
77740
77741
77742
77743
77744
# File 'lib/google/apis/compute_alpha/classes.rb', line 77736

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end