Class: Google::Apis::ComputeAlpha::TargetHttpProxyAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::TargetHttpProxyAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::TargetHttpProxiesScopedList>
A list of TargetHttpProxiesScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::TargetHttpProxyAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TargetHttpProxyAggregatedList
constructor
A new instance of TargetHttpProxyAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TargetHttpProxyAggregatedList
Returns a new instance of TargetHttpProxyAggregatedList.
76363 76364 76365 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 76363 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
76324 76325 76326 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 76324 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::TargetHttpProxiesScopedList>
A list of TargetHttpProxiesScopedList resources.
Corresponds to the JSON property items
76329 76330 76331 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 76329 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
targetHttpProxyAggregatedList for lists of Target HTTP
Proxies.
Corresponds to the JSON property kind
76336 76337 76338 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 76336 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
76346 76347 76348 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 76346 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
76351 76352 76353 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 76351 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
76356 76357 76358 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 76356 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::TargetHttpProxyAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
76361 76362 76363 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 76361 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
76368 76369 76370 76371 76372 76373 76374 76375 76376 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 76368 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |