Class: Google::Apis::ComputeAlpha::TargetHttpProxyAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetHttpProxyAggregatedList

Returns a new instance of TargetHttpProxyAggregatedList.



76306
76307
76308
# File 'lib/google/apis/compute_alpha/classes.rb', line 76306

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


76267
76268
76269
# File 'lib/google/apis/compute_alpha/classes.rb', line 76267

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::TargetHttpProxiesScopedList>

A list of TargetHttpProxiesScopedList resources. Corresponds to the JSON property items



76272
76273
76274
# File 'lib/google/apis/compute_alpha/classes.rb', line 76272

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# targetHttpProxyAggregatedList for lists of Target HTTP Proxies. Corresponds to the JSON property kind

Returns:

  • (String)


76279
76280
76281
# File 'lib/google/apis/compute_alpha/classes.rb', line 76279

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


76289
76290
76291
# File 'lib/google/apis/compute_alpha/classes.rb', line 76289

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


76294
76295
76296
# File 'lib/google/apis/compute_alpha/classes.rb', line 76294

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


76299
76300
76301
# File 'lib/google/apis/compute_alpha/classes.rb', line 76299

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::TargetHttpProxyAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



76304
76305
76306
# File 'lib/google/apis/compute_alpha/classes.rb', line 76304

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



76311
76312
76313
76314
76315
76316
76317
76318
76319
# File 'lib/google/apis/compute_alpha/classes.rb', line 76311

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end