Class: Google::Apis::ComputeAlpha::TargetHttpProxyAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetHttpProxyAggregatedList

Returns a new instance of TargetHttpProxyAggregatedList.



75697
75698
75699
# File 'lib/google/apis/compute_alpha/classes.rb', line 75697

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


75658
75659
75660
# File 'lib/google/apis/compute_alpha/classes.rb', line 75658

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::TargetHttpProxiesScopedList>

A list of TargetHttpProxiesScopedList resources. Corresponds to the JSON property items



75663
75664
75665
# File 'lib/google/apis/compute_alpha/classes.rb', line 75663

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# targetHttpProxyAggregatedList for lists of Target HTTP Proxies. Corresponds to the JSON property kind

Returns:

  • (String)


75670
75671
75672
# File 'lib/google/apis/compute_alpha/classes.rb', line 75670

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


75680
75681
75682
# File 'lib/google/apis/compute_alpha/classes.rb', line 75680

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


75685
75686
75687
# File 'lib/google/apis/compute_alpha/classes.rb', line 75685

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


75690
75691
75692
# File 'lib/google/apis/compute_alpha/classes.rb', line 75690

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::TargetHttpProxyAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



75695
75696
75697
# File 'lib/google/apis/compute_alpha/classes.rb', line 75695

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



75702
75703
75704
75705
75706
75707
75708
75709
75710
# File 'lib/google/apis/compute_alpha/classes.rb', line 75702

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end