Class: Google::Apis::ComputeAlpha::TargetHttpProxyAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetHttpProxyAggregatedList

Returns a new instance of TargetHttpProxyAggregatedList.



75431
75432
75433
# File 'lib/google/apis/compute_alpha/classes.rb', line 75431

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


75392
75393
75394
# File 'lib/google/apis/compute_alpha/classes.rb', line 75392

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::TargetHttpProxiesScopedList>

A list of TargetHttpProxiesScopedList resources. Corresponds to the JSON property items



75397
75398
75399
# File 'lib/google/apis/compute_alpha/classes.rb', line 75397

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# targetHttpProxyAggregatedList for lists of Target HTTP Proxies. Corresponds to the JSON property kind

Returns:

  • (String)


75404
75405
75406
# File 'lib/google/apis/compute_alpha/classes.rb', line 75404

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


75414
75415
75416
# File 'lib/google/apis/compute_alpha/classes.rb', line 75414

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


75419
75420
75421
# File 'lib/google/apis/compute_alpha/classes.rb', line 75419

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


75424
75425
75426
# File 'lib/google/apis/compute_alpha/classes.rb', line 75424

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::TargetHttpProxyAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



75429
75430
75431
# File 'lib/google/apis/compute_alpha/classes.rb', line 75429

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



75436
75437
75438
75439
75440
75441
75442
75443
75444
# File 'lib/google/apis/compute_alpha/classes.rb', line 75436

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end