Class: Google::Apis::ComputeAlpha::TargetHttpProxyAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetHttpProxyAggregatedList

Returns a new instance of TargetHttpProxyAggregatedList.



74483
74484
74485
# File 'lib/google/apis/compute_alpha/classes.rb', line 74483

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


74444
74445
74446
# File 'lib/google/apis/compute_alpha/classes.rb', line 74444

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::TargetHttpProxiesScopedList>

A list of TargetHttpProxiesScopedList resources. Corresponds to the JSON property items



74449
74450
74451
# File 'lib/google/apis/compute_alpha/classes.rb', line 74449

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# targetHttpProxyAggregatedList for lists of Target HTTP Proxies. Corresponds to the JSON property kind

Returns:

  • (String)


74456
74457
74458
# File 'lib/google/apis/compute_alpha/classes.rb', line 74456

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


74466
74467
74468
# File 'lib/google/apis/compute_alpha/classes.rb', line 74466

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


74471
74472
74473
# File 'lib/google/apis/compute_alpha/classes.rb', line 74471

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


74476
74477
74478
# File 'lib/google/apis/compute_alpha/classes.rb', line 74476

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::TargetHttpProxyAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



74481
74482
74483
# File 'lib/google/apis/compute_alpha/classes.rb', line 74481

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



74488
74489
74490
74491
74492
74493
74494
74495
74496
# File 'lib/google/apis/compute_alpha/classes.rb', line 74488

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end