Class: Google::Apis::ComputeAlpha::TargetHttpProxyList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

A list of TargetHttpProxy resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetHttpProxyList

Returns a new instance of TargetHttpProxyList.



78163
78164
78165
# File 'lib/google/apis/compute_alpha/classes.rb', line 78163

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


78130
78131
78132
# File 'lib/google/apis/compute_alpha/classes.rb', line 78130

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::TargetHttpProxy>

A list of TargetHttpProxy resources. Corresponds to the JSON property items



78135
78136
78137
# File 'lib/google/apis/compute_alpha/classes.rb', line 78135

def items
  @items
end

#kindString

Output only. Type of resource. Always compute#targetHttpProxyList for lists of target HTTP proxies. Corresponds to the JSON property kind

Returns:

  • (String)


78141
78142
78143
# File 'lib/google/apis/compute_alpha/classes.rb', line 78141

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


78151
78152
78153
# File 'lib/google/apis/compute_alpha/classes.rb', line 78151

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


78156
78157
78158
# File 'lib/google/apis/compute_alpha/classes.rb', line 78156

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::TargetHttpProxyList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



78161
78162
78163
# File 'lib/google/apis/compute_alpha/classes.rb', line 78161

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



78168
78169
78170
78171
78172
78173
78174
78175
# File 'lib/google/apis/compute_alpha/classes.rb', line 78168

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end