Class: Google::Apis::ComputeAlpha::TargetHttpProxyList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::TargetHttpProxyList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
A list of TargetHttpProxy resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::TargetHttpProxy>
A list of TargetHttpProxy resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::TargetHttpProxyList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TargetHttpProxyList
constructor
A new instance of TargetHttpProxyList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TargetHttpProxyList
Returns a new instance of TargetHttpProxyList.
76489 76490 76491 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 76489 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
76456 76457 76458 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 76456 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::TargetHttpProxy>
A list of TargetHttpProxy resources.
Corresponds to the JSON property items
76461 76462 76463 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 76461 def items @items end |
#kind ⇒ String
Output only. Type of resource. Always compute#targetHttpProxyList for lists
of target HTTP proxies.
Corresponds to the JSON property kind
76467 76468 76469 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 76467 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
76477 76478 76479 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 76477 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
76482 76483 76484 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 76482 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::TargetHttpProxyList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
76487 76488 76489 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 76487 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
76494 76495 76496 76497 76498 76499 76500 76501 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 76494 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |