Class: Google::Apis::ComputeAlpha::TargetHttpProxyList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::TargetHttpProxyList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
A list of TargetHttpProxy resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::TargetHttpProxy>
A list of TargetHttpProxy resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::TargetHttpProxyList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TargetHttpProxyList
constructor
A new instance of TargetHttpProxyList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TargetHttpProxyList
Returns a new instance of TargetHttpProxyList.
75825 75826 75827 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 75825 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
75792 75793 75794 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 75792 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::TargetHttpProxy>
A list of TargetHttpProxy resources.
Corresponds to the JSON property items
75797 75798 75799 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 75797 def items @items end |
#kind ⇒ String
Output only. Type of resource. Always compute#targetHttpProxyList for lists
of target HTTP proxies.
Corresponds to the JSON property kind
75803 75804 75805 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 75803 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
75813 75814 75815 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 75813 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
75818 75819 75820 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 75818 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::TargetHttpProxyList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
75823 75824 75825 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 75823 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
75830 75831 75832 75833 75834 75835 75836 75837 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 75830 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |