Class: Google::Apis::ComputeAlpha::TargetHttpsProxyAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetHttpsProxyAggregatedList

Returns a new instance of TargetHttpsProxyAggregatedList.



77008
77009
77010
# File 'lib/google/apis/compute_alpha/classes.rb', line 77008

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


76969
76970
76971
# File 'lib/google/apis/compute_alpha/classes.rb', line 76969

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::TargetHttpsProxiesScopedList>

A list of TargetHttpsProxiesScopedList resources. Corresponds to the JSON property items



76974
76975
76976
# File 'lib/google/apis/compute_alpha/classes.rb', line 76974

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# targetHttpsProxyAggregatedList for lists of Target HTTP Proxies. Corresponds to the JSON property kind

Returns:

  • (String)


76981
76982
76983
# File 'lib/google/apis/compute_alpha/classes.rb', line 76981

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


76991
76992
76993
# File 'lib/google/apis/compute_alpha/classes.rb', line 76991

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


76996
76997
76998
# File 'lib/google/apis/compute_alpha/classes.rb', line 76996

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


77001
77002
77003
# File 'lib/google/apis/compute_alpha/classes.rb', line 77001

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::TargetHttpsProxyAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



77006
77007
77008
# File 'lib/google/apis/compute_alpha/classes.rb', line 77006

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



77013
77014
77015
77016
77017
77018
77019
77020
77021
# File 'lib/google/apis/compute_alpha/classes.rb', line 77013

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end