Class: Google::Apis::ComputeAlpha::TargetHttpsProxyAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetHttpsProxyAggregatedList

Returns a new instance of TargetHttpsProxyAggregatedList.



76399
76400
76401
# File 'lib/google/apis/compute_alpha/classes.rb', line 76399

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


76360
76361
76362
# File 'lib/google/apis/compute_alpha/classes.rb', line 76360

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::TargetHttpsProxiesScopedList>

A list of TargetHttpsProxiesScopedList resources. Corresponds to the JSON property items



76365
76366
76367
# File 'lib/google/apis/compute_alpha/classes.rb', line 76365

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# targetHttpsProxyAggregatedList for lists of Target HTTP Proxies. Corresponds to the JSON property kind

Returns:

  • (String)


76372
76373
76374
# File 'lib/google/apis/compute_alpha/classes.rb', line 76372

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


76382
76383
76384
# File 'lib/google/apis/compute_alpha/classes.rb', line 76382

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


76387
76388
76389
# File 'lib/google/apis/compute_alpha/classes.rb', line 76387

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


76392
76393
76394
# File 'lib/google/apis/compute_alpha/classes.rb', line 76392

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::TargetHttpsProxyAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



76397
76398
76399
# File 'lib/google/apis/compute_alpha/classes.rb', line 76397

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



76404
76405
76406
76407
76408
76409
76410
76411
76412
# File 'lib/google/apis/compute_alpha/classes.rb', line 76404

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end