Class: Google::Apis::ComputeAlpha::TargetHttpsProxyAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetHttpsProxyAggregatedList

Returns a new instance of TargetHttpsProxyAggregatedList.



75185
75186
75187
# File 'lib/google/apis/compute_alpha/classes.rb', line 75185

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


75146
75147
75148
# File 'lib/google/apis/compute_alpha/classes.rb', line 75146

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::TargetHttpsProxiesScopedList>

A list of TargetHttpsProxiesScopedList resources. Corresponds to the JSON property items



75151
75152
75153
# File 'lib/google/apis/compute_alpha/classes.rb', line 75151

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# targetHttpsProxyAggregatedList for lists of Target HTTP Proxies. Corresponds to the JSON property kind

Returns:

  • (String)


75158
75159
75160
# File 'lib/google/apis/compute_alpha/classes.rb', line 75158

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


75168
75169
75170
# File 'lib/google/apis/compute_alpha/classes.rb', line 75168

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


75173
75174
75175
# File 'lib/google/apis/compute_alpha/classes.rb', line 75173

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


75178
75179
75180
# File 'lib/google/apis/compute_alpha/classes.rb', line 75178

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::TargetHttpsProxyAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



75183
75184
75185
# File 'lib/google/apis/compute_alpha/classes.rb', line 75183

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



75190
75191
75192
75193
75194
75195
75196
75197
75198
# File 'lib/google/apis/compute_alpha/classes.rb', line 75190

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end