Class: Google::Apis::ComputeAlpha::TargetHttpsProxyList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of TargetHttpsProxy resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetHttpsProxyList

Returns a new instance of TargetHttpsProxyList.



78865
78866
78867
# File 'lib/google/apis/compute_alpha/classes.rb', line 78865

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


78832
78833
78834
# File 'lib/google/apis/compute_alpha/classes.rb', line 78832

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::TargetHttpsProxy>

A list of TargetHttpsProxy resources. Corresponds to the JSON property items



78837
78838
78839
# File 'lib/google/apis/compute_alpha/classes.rb', line 78837

def items
  @items
end

#kindString

Output only. Type of resource. Always compute#targetHttpsProxyList for lists of target HTTPS proxies. Corresponds to the JSON property kind

Returns:

  • (String)


78843
78844
78845
# File 'lib/google/apis/compute_alpha/classes.rb', line 78843

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


78853
78854
78855
# File 'lib/google/apis/compute_alpha/classes.rb', line 78853

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


78858
78859
78860
# File 'lib/google/apis/compute_alpha/classes.rb', line 78858

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::TargetHttpsProxyList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



78863
78864
78865
# File 'lib/google/apis/compute_alpha/classes.rb', line 78863

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



78870
78871
78872
78873
78874
78875
78876
78877
# File 'lib/google/apis/compute_alpha/classes.rb', line 78870

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end