Class: Google::Apis::ComputeAlpha::TargetHttpsProxyList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::TargetHttpsProxyList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Contains a list of TargetHttpsProxy resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::TargetHttpsProxy>
A list of TargetHttpsProxy resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::TargetHttpsProxyList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TargetHttpsProxyList
constructor
A new instance of TargetHttpsProxyList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TargetHttpsProxyList
Returns a new instance of TargetHttpsProxyList.
76259 76260 76261 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 76259 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
76226 76227 76228 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 76226 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::TargetHttpsProxy>
A list of TargetHttpsProxy resources.
Corresponds to the JSON property items
76231 76232 76233 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 76231 def items @items end |
#kind ⇒ String
Output only. Type of resource. Always compute#targetHttpsProxyList for
lists of target HTTPS proxies.
Corresponds to the JSON property kind
76237 76238 76239 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 76237 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
76247 76248 76249 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 76247 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
76252 76253 76254 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 76252 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::TargetHttpsProxyList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
76257 76258 76259 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 76257 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
76264 76265 76266 76267 76268 76269 76270 76271 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 76264 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |