Class: Google::Apis::ComputeAlpha::TargetHttpsProxyList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::TargetHttpsProxyList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Contains a list of TargetHttpsProxy resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::TargetHttpsProxy>
A list of TargetHttpsProxy resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::TargetHttpsProxyList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TargetHttpsProxyList
constructor
A new instance of TargetHttpsProxyList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TargetHttpsProxyList
Returns a new instance of TargetHttpsProxyList.
75311 75312 75313 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 75311 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
75278 75279 75280 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 75278 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::TargetHttpsProxy>
A list of TargetHttpsProxy resources.
Corresponds to the JSON property items
75283 75284 75285 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 75283 def items @items end |
#kind ⇒ String
Output only. Type of resource. Always compute#targetHttpsProxyList for
lists of target HTTPS proxies.
Corresponds to the JSON property kind
75289 75290 75291 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 75289 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
75299 75300 75301 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 75299 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
75304 75305 75306 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 75304 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::TargetHttpsProxyList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
75309 75310 75311 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 75309 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
75316 75317 75318 75319 75320 75321 75322 75323 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 75316 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |