Class: Google::Apis::ComputeAlpha::TargetInstanceAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetInstanceAggregatedList

Returns a new instance of TargetInstanceAggregatedList.



79110
79111
79112
# File 'lib/google/apis/compute_alpha/classes.rb', line 79110

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


79073
79074
79075
# File 'lib/google/apis/compute_alpha/classes.rb', line 79073

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::TargetInstancesScopedList>

A list of TargetInstance resources. Corresponds to the JSON property items



79078
79079
79080
# File 'lib/google/apis/compute_alpha/classes.rb', line 79078

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


79083
79084
79085
# File 'lib/google/apis/compute_alpha/classes.rb', line 79083

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


79093
79094
79095
# File 'lib/google/apis/compute_alpha/classes.rb', line 79093

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


79098
79099
79100
# File 'lib/google/apis/compute_alpha/classes.rb', line 79098

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


79103
79104
79105
# File 'lib/google/apis/compute_alpha/classes.rb', line 79103

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::TargetInstanceAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



79108
79109
79110
# File 'lib/google/apis/compute_alpha/classes.rb', line 79108

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



79115
79116
79117
79118
79119
79120
79121
79122
79123
# File 'lib/google/apis/compute_alpha/classes.rb', line 79115

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end