Class: Google::Apis::ComputeAlpha::TargetInstanceAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetInstanceAggregatedList

Returns a new instance of TargetInstanceAggregatedList.



78804
78805
78806
# File 'lib/google/apis/compute_alpha/classes.rb', line 78804

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


78767
78768
78769
# File 'lib/google/apis/compute_alpha/classes.rb', line 78767

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::TargetInstancesScopedList>

A list of TargetInstance resources. Corresponds to the JSON property items



78772
78773
78774
# File 'lib/google/apis/compute_alpha/classes.rb', line 78772

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


78777
78778
78779
# File 'lib/google/apis/compute_alpha/classes.rb', line 78777

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


78787
78788
78789
# File 'lib/google/apis/compute_alpha/classes.rb', line 78787

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


78792
78793
78794
# File 'lib/google/apis/compute_alpha/classes.rb', line 78792

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


78797
78798
78799
# File 'lib/google/apis/compute_alpha/classes.rb', line 78797

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::TargetInstanceAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



78802
78803
78804
# File 'lib/google/apis/compute_alpha/classes.rb', line 78802

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



78809
78810
78811
78812
78813
78814
78815
78816
78817
# File 'lib/google/apis/compute_alpha/classes.rb', line 78809

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end