Class: Google::Apis::ComputeAlpha::TargetInstanceAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetInstanceAggregatedList

Returns a new instance of TargetInstanceAggregatedList.



77436
77437
77438
# File 'lib/google/apis/compute_alpha/classes.rb', line 77436

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


77399
77400
77401
# File 'lib/google/apis/compute_alpha/classes.rb', line 77399

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::TargetInstancesScopedList>

A list of TargetInstance resources. Corresponds to the JSON property items



77404
77405
77406
# File 'lib/google/apis/compute_alpha/classes.rb', line 77404

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


77409
77410
77411
# File 'lib/google/apis/compute_alpha/classes.rb', line 77409

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


77419
77420
77421
# File 'lib/google/apis/compute_alpha/classes.rb', line 77419

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


77424
77425
77426
# File 'lib/google/apis/compute_alpha/classes.rb', line 77424

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


77429
77430
77431
# File 'lib/google/apis/compute_alpha/classes.rb', line 77429

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::TargetInstanceAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



77434
77435
77436
# File 'lib/google/apis/compute_alpha/classes.rb', line 77434

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



77441
77442
77443
77444
77445
77446
77447
77448
77449
# File 'lib/google/apis/compute_alpha/classes.rb', line 77441

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end