Class: Google::Apis::ComputeAlpha::TargetInstanceAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::TargetInstanceAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::TargetInstancesScopedList>
A list of TargetInstance resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::TargetInstanceAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TargetInstanceAggregatedList
constructor
A new instance of TargetInstanceAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TargetInstanceAggregatedList
Returns a new instance of TargetInstanceAggregatedList.
77379 77380 77381 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 77379 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
77342 77343 77344 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 77342 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::TargetInstancesScopedList>
A list of TargetInstance resources.
Corresponds to the JSON property items
77347 77348 77349 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 77347 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
77352 77353 77354 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 77352 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
77362 77363 77364 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 77362 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
77367 77368 77369 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 77367 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
77372 77373 77374 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 77372 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::TargetInstanceAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
77377 77378 77379 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 77377 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
77384 77385 77386 77387 77388 77389 77390 77391 77392 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 77384 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |