Class: Google::Apis::ComputeAlpha::TargetInstanceAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::TargetInstanceAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::TargetInstancesScopedList>
A list of TargetInstance resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::TargetInstanceAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TargetInstanceAggregatedList
constructor
A new instance of TargetInstanceAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TargetInstanceAggregatedList
Returns a new instance of TargetInstanceAggregatedList.
76772 76773 76774 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 76772 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
76735 76736 76737 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 76735 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::TargetInstancesScopedList>
A list of TargetInstance resources.
Corresponds to the JSON property items
76740 76741 76742 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 76740 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
76745 76746 76747 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 76745 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
76755 76756 76757 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 76755 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
76760 76761 76762 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 76760 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
76765 76766 76767 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 76765 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::TargetInstanceAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
76770 76771 76772 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 76770 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
76777 76778 76779 76780 76781 76782 76783 76784 76785 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 76777 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |