Class: Google::Apis::ComputeAlpha::TargetInstanceAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetInstanceAggregatedList

Returns a new instance of TargetInstanceAggregatedList.



75556
75557
75558
# File 'lib/google/apis/compute_alpha/classes.rb', line 75556

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


75519
75520
75521
# File 'lib/google/apis/compute_alpha/classes.rb', line 75519

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::TargetInstancesScopedList>

A list of TargetInstance resources. Corresponds to the JSON property items



75524
75525
75526
# File 'lib/google/apis/compute_alpha/classes.rb', line 75524

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


75529
75530
75531
# File 'lib/google/apis/compute_alpha/classes.rb', line 75529

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


75539
75540
75541
# File 'lib/google/apis/compute_alpha/classes.rb', line 75539

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


75544
75545
75546
# File 'lib/google/apis/compute_alpha/classes.rb', line 75544

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


75549
75550
75551
# File 'lib/google/apis/compute_alpha/classes.rb', line 75549

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::TargetInstanceAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



75554
75555
75556
# File 'lib/google/apis/compute_alpha/classes.rb', line 75554

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



75561
75562
75563
75564
75565
75566
75567
75568
75569
# File 'lib/google/apis/compute_alpha/classes.rb', line 75561

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end