Class: Google::Apis::ComputeAlpha::TargetInstanceList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::TargetInstanceList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Contains a list of TargetInstance resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::TargetInstance>
A list of TargetInstance resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::TargetInstanceList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TargetInstanceList
constructor
A new instance of TargetInstanceList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TargetInstanceList
Returns a new instance of TargetInstanceList.
79511 79512 79513 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 79511 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
79479 79480 79481 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 79479 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::TargetInstance>
A list of TargetInstance resources.
Corresponds to the JSON property items
79484 79485 79486 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 79484 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
79489 79490 79491 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 79489 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
79499 79500 79501 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 79499 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
79504 79505 79506 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 79504 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::TargetInstanceList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
79509 79510 79511 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 79509 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
79516 79517 79518 79519 79520 79521 79522 79523 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 79516 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |