Class: Google::Apis::ComputeAlpha::TargetInstanceList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of TargetInstance resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetInstanceList

Returns a new instance of TargetInstanceList.



78929
78930
78931
# File 'lib/google/apis/compute_alpha/classes.rb', line 78929

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


78897
78898
78899
# File 'lib/google/apis/compute_alpha/classes.rb', line 78897

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::TargetInstance>

A list of TargetInstance resources. Corresponds to the JSON property items



78902
78903
78904
# File 'lib/google/apis/compute_alpha/classes.rb', line 78902

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


78907
78908
78909
# File 'lib/google/apis/compute_alpha/classes.rb', line 78907

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


78917
78918
78919
# File 'lib/google/apis/compute_alpha/classes.rb', line 78917

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


78922
78923
78924
# File 'lib/google/apis/compute_alpha/classes.rb', line 78922

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::TargetInstanceList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



78927
78928
78929
# File 'lib/google/apis/compute_alpha/classes.rb', line 78927

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



78934
78935
78936
78937
78938
78939
78940
78941
# File 'lib/google/apis/compute_alpha/classes.rb', line 78934

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end