Class: Google::Apis::ComputeAlpha::TargetInstanceList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of TargetInstance resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetInstanceList

Returns a new instance of TargetInstanceList.



77561
77562
77563
# File 'lib/google/apis/compute_alpha/classes.rb', line 77561

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


77529
77530
77531
# File 'lib/google/apis/compute_alpha/classes.rb', line 77529

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::TargetInstance>

A list of TargetInstance resources. Corresponds to the JSON property items



77534
77535
77536
# File 'lib/google/apis/compute_alpha/classes.rb', line 77534

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


77539
77540
77541
# File 'lib/google/apis/compute_alpha/classes.rb', line 77539

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


77549
77550
77551
# File 'lib/google/apis/compute_alpha/classes.rb', line 77549

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


77554
77555
77556
# File 'lib/google/apis/compute_alpha/classes.rb', line 77554

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::TargetInstanceList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



77559
77560
77561
# File 'lib/google/apis/compute_alpha/classes.rb', line 77559

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



77566
77567
77568
77569
77570
77571
77572
77573
# File 'lib/google/apis/compute_alpha/classes.rb', line 77566

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end