Class: Google::Apis::ComputeAlpha::TargetInstanceList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::TargetInstanceList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Contains a list of TargetInstance resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::TargetInstance>
A list of TargetInstance resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::TargetInstanceList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TargetInstanceList
constructor
A new instance of TargetInstanceList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TargetInstanceList
Returns a new instance of TargetInstanceList.
77504 77505 77506 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 77504 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
77472 77473 77474 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 77472 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::TargetInstance>
A list of TargetInstance resources.
Corresponds to the JSON property items
77477 77478 77479 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 77477 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
77482 77483 77484 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 77482 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
77492 77493 77494 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 77492 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
77497 77498 77499 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 77497 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::TargetInstanceList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
77502 77503 77504 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 77502 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
77509 77510 77511 77512 77513 77514 77515 77516 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 77509 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |