Class: Google::Apis::ComputeAlpha::TargetInstanceList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::TargetInstanceList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Contains a list of TargetInstance resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::TargetInstance>
A list of TargetInstance resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::TargetInstanceList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TargetInstanceList
constructor
A new instance of TargetInstanceList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TargetInstanceList
Returns a new instance of TargetInstanceList.
76897 76898 76899 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 76897 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
76865 76866 76867 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 76865 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::TargetInstance>
A list of TargetInstance resources.
Corresponds to the JSON property items
76870 76871 76872 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 76870 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
76875 76876 76877 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 76875 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
76885 76886 76887 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 76885 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
76890 76891 76892 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 76890 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::TargetInstanceList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
76895 76896 76897 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 76895 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
76902 76903 76904 76905 76906 76907 76908 76909 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 76902 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |