Class: Google::Apis::ComputeAlpha::TargetInstancesScopedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetInstancesScopedList

Returns a new instance of TargetInstancesScopedList.



77661
77662
77663
# File 'lib/google/apis/compute_alpha/classes.rb', line 77661

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#target_instancesArray<Google::Apis::ComputeAlpha::TargetInstance>

A list of target instances contained in this scope. Corresponds to the JSON property targetInstances



77653
77654
77655
# File 'lib/google/apis/compute_alpha/classes.rb', line 77653

def target_instances
  @target_instances
end

#warningGoogle::Apis::ComputeAlpha::TargetInstancesScopedList::Warning

Informational warning which replaces the list of addresses when the list is empty. Corresponds to the JSON property warning



77659
77660
77661
# File 'lib/google/apis/compute_alpha/classes.rb', line 77659

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



77666
77667
77668
77669
# File 'lib/google/apis/compute_alpha/classes.rb', line 77666

def update!(**args)
  @target_instances = args[:target_instances] if args.key?(:target_instances)
  @warning = args[:warning] if args.key?(:warning)
end