Class: Google::Apis::ComputeAlpha::TargetInstancesScopedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetInstancesScopedList

Returns a new instance of TargetInstancesScopedList.



76995
76996
76997
# File 'lib/google/apis/compute_alpha/classes.rb', line 76995

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#target_instancesArray<Google::Apis::ComputeAlpha::TargetInstance>

A list of target instances contained in this scope. Corresponds to the JSON property targetInstances



76987
76988
76989
# File 'lib/google/apis/compute_alpha/classes.rb', line 76987

def target_instances
  @target_instances
end

#warningGoogle::Apis::ComputeAlpha::TargetInstancesScopedList::Warning

Informational warning which replaces the list of addresses when the list is empty. Corresponds to the JSON property warning



76993
76994
76995
# File 'lib/google/apis/compute_alpha/classes.rb', line 76993

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



77000
77001
77002
77003
# File 'lib/google/apis/compute_alpha/classes.rb', line 77000

def update!(**args)
  @target_instances = args[:target_instances] if args.key?(:target_instances)
  @warning = args[:warning] if args.key?(:warning)
end