Class: Google::Apis::ComputeAlpha::TargetPool

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Represents a Target Pool resource. Target pools are used with external passthrough Network Load Balancers. A target pool references member instances, an associated legacy HttpHealthCheck resource, and, optionally, a backup target pool. For more information, readUsing target pools.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetPool

Returns a new instance of TargetPool.



79237
79238
79239
# File 'lib/google/apis/compute_alpha/classes.rb', line 79237

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backup_poolString

The server-defined URL for the resource. This field is applicable only when the containing target pool is serving a forwarding rule as the primary pool, and its failoverRatio field is properly set to a value between [0, 1].backupPool and failoverRatio together define the fallback behavior of the primary target pool: if the ratio of the healthy instances in the primary pool is at or belowfailoverRatio, traffic arriving at the load-balanced IP will be directed to the backup pool. In case where failoverRatio and backupPool are not set, or all the instances in the backup pool are unhealthy, the traffic will be directed back to the primary pool in the "force" mode, where traffic will be spread to the healthy instances with the best effort, or to all instances when no instance is healthy. Corresponds to the JSON property backupPool

Returns:

  • (String)


79134
79135
79136
# File 'lib/google/apis/compute_alpha/classes.rb', line 79134

def backup_pool
  @backup_pool
end

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


79140
79141
79142
# File 'lib/google/apis/compute_alpha/classes.rb', line 79140

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


79146
79147
79148
# File 'lib/google/apis/compute_alpha/classes.rb', line 79146

def description
  @description
end

#failover_ratioFloat

This field is applicable only when the containing target pool is serving a forwarding rule as the primary pool (i.e., not as a backup pool to some other target pool). The value of the field must be in [0, 1]. If set, backupPool must also be set. They together define the fallback behavior of the primary target pool: if the ratio of the healthy instances in the primary pool is at or below this number, traffic arriving at the load-balanced IP will be directed to the backup pool. In case where failoverRatio is not set or all the instances in the backup pool are unhealthy, the traffic will be directed back to the primary pool in the "force" mode, where traffic will be spread to the healthy instances with the best effort, or to all instances when no instance is healthy. Corresponds to the JSON property failoverRatio

Returns:

  • (Float)


79163
79164
79165
# File 'lib/google/apis/compute_alpha/classes.rb', line 79163

def failover_ratio
  @failover_ratio
end

#health_checksArray<String>

The URL of the HttpHealthCheck resource. A member instance in this pool is considered healthy if and only if the health checks pass. Only legacy HttpHealthChecks are supported. Only one health check may be specified. Corresponds to the JSON property healthChecks

Returns:

  • (Array<String>)


79171
79172
79173
# File 'lib/google/apis/compute_alpha/classes.rb', line 79171

def health_checks
  @health_checks
end

#idFixnum

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


79177
79178
79179
# File 'lib/google/apis/compute_alpha/classes.rb', line 79177

def id
  @id
end

#instancesArray<String>

A list of resource URLs to the virtual machine instances serving this pool. They must live in zones contained in the same region as this pool. Corresponds to the JSON property instances

Returns:

  • (Array<String>)


79183
79184
79185
# File 'lib/google/apis/compute_alpha/classes.rb', line 79183

def instances
  @instances
end

#kindString

Output only. [Output Only] Type of the resource. Always compute#targetPool for target pools. Corresponds to the JSON property kind

Returns:

  • (String)


79189
79190
79191
# File 'lib/google/apis/compute_alpha/classes.rb', line 79189

def kind
  @kind
end

#nameString

Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


79200
79201
79202
# File 'lib/google/apis/compute_alpha/classes.rb', line 79200

def name
  @name
end

#regionString

Output only. [Output Only] URL of the region where the target pool resides. Corresponds to the JSON property region

Returns:

  • (String)


79205
79206
79207
# File 'lib/google/apis/compute_alpha/classes.rb', line 79205

def region
  @region
end

#security_policyString

[Output Only] The resource URL for the security policy associated with this target pool. Corresponds to the JSON property securityPolicy

Returns:

  • (String)


79211
79212
79213
# File 'lib/google/apis/compute_alpha/classes.rb', line 79211

def security_policy
  @security_policy
end

[Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


79216
79217
79218
# File 'lib/google/apis/compute_alpha/classes.rb', line 79216

def self_link
  @self_link
end

Output only. [Output Only] Server-defined URL for this resource with the resource id. Corresponds to the JSON property selfLinkWithId

Returns:

  • (String)


79222
79223
79224
# File 'lib/google/apis/compute_alpha/classes.rb', line 79222

def self_link_with_id
  @self_link_with_id
end

#session_affinityString

Session affinity option, must be one of the following values: NONE: Connections from the same client IP may go to any instance in the pool. CLIENT_IP: Connections from the same client IP will go to the same instance in the pool while that instance remains healthy. CLIENT_IP_PROTO: Connections from the same client IP with the same IP protocol will go to the same instance in the pool while that instance remains healthy. Corresponds to the JSON property sessionAffinity

Returns:

  • (String)


79235
79236
79237
# File 'lib/google/apis/compute_alpha/classes.rb', line 79235

def session_affinity
  @session_affinity
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



79242
79243
79244
79245
79246
79247
79248
79249
79250
79251
79252
79253
79254
79255
79256
79257
# File 'lib/google/apis/compute_alpha/classes.rb', line 79242

def update!(**args)
  @backup_pool = args[:backup_pool] if args.key?(:backup_pool)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @failover_ratio = args[:failover_ratio] if args.key?(:failover_ratio)
  @health_checks = args[:health_checks] if args.key?(:health_checks)
  @id = args[:id] if args.key?(:id)
  @instances = args[:instances] if args.key?(:instances)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @region = args[:region] if args.key?(:region)
  @security_policy = args[:security_policy] if args.key?(:security_policy)
  @self_link = args[:self_link] if args.key?(:self_link)
  @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id)
  @session_affinity = args[:session_affinity] if args.key?(:session_affinity)
end