Class: Google::Apis::ComputeAlpha::TargetPoolAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetPoolAggregatedList

Returns a new instance of TargetPoolAggregatedList.



77274
77275
77276
# File 'lib/google/apis/compute_alpha/classes.rb', line 77274

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


77235
77236
77237
# File 'lib/google/apis/compute_alpha/classes.rb', line 77235

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::TargetPoolsScopedList>

A list of TargetPool resources. Corresponds to the JSON property items



77240
77241
77242
# File 'lib/google/apis/compute_alpha/classes.rb', line 77240

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# targetPoolAggregatedList for aggregated lists of target pools. Corresponds to the JSON property kind

Returns:

  • (String)


77247
77248
77249
# File 'lib/google/apis/compute_alpha/classes.rb', line 77247

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


77257
77258
77259
# File 'lib/google/apis/compute_alpha/classes.rb', line 77257

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


77262
77263
77264
# File 'lib/google/apis/compute_alpha/classes.rb', line 77262

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


77267
77268
77269
# File 'lib/google/apis/compute_alpha/classes.rb', line 77267

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::TargetPoolAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



77272
77273
77274
# File 'lib/google/apis/compute_alpha/classes.rb', line 77272

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



77279
77280
77281
77282
77283
77284
77285
77286
77287
# File 'lib/google/apis/compute_alpha/classes.rb', line 77279

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end