Class: Google::Apis::ComputeAlpha::TargetPoolAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::TargetPoolAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::TargetPoolsScopedList>
A list of TargetPool resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::TargetPoolAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TargetPoolAggregatedList
constructor
A new instance of TargetPoolAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TargetPoolAggregatedList
Returns a new instance of TargetPoolAggregatedList.
77006 77007 77008 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 77006 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
76967 76968 76969 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 76967 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::TargetPoolsScopedList>
A list of TargetPool resources.
Corresponds to the JSON property items
76972 76973 76974 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 76972 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
targetPoolAggregatedList for aggregated lists of
target pools.
Corresponds to the JSON property kind
76979 76980 76981 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 76979 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
76989 76990 76991 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 76989 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
76994 76995 76996 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 76994 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
76999 77000 77001 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 76999 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::TargetPoolAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
77004 77005 77006 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 77004 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
77011 77012 77013 77014 77015 77016 77017 77018 77019 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 77011 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |