Class: Google::Apis::ComputeAlpha::TargetPoolList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::TargetPoolList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Contains a list of TargetPool resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::TargetPool>
A list of TargetPool resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::TargetPoolList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TargetPoolList
constructor
A new instance of TargetPoolList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TargetPoolList
Returns a new instance of TargetPoolList.
80042 80043 80044 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 80042 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
80009 80010 80011 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 80009 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::TargetPool>
A list of TargetPool resources.
Corresponds to the JSON property items
80014 80015 80016 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 80014 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#targetPoolList
for lists of target pools.
Corresponds to the JSON property kind
80020 80021 80022 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 80020 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
80030 80031 80032 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 80030 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
80035 80036 80037 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 80035 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::TargetPoolList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
80040 80041 80042 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 80040 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
80047 80048 80049 80050 80051 80052 80053 80054 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 80047 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |