Class: Google::Apis::ComputeAlpha::TargetPoolList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::TargetPoolList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Contains a list of TargetPool resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::TargetPool>
A list of TargetPool resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::TargetPoolList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TargetPoolList
constructor
A new instance of TargetPoolList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TargetPoolList
Returns a new instance of TargetPoolList.
79459 79460 79461 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 79459 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
79426 79427 79428 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 79426 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::TargetPool>
A list of TargetPool resources.
Corresponds to the JSON property items
79431 79432 79433 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 79431 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#targetPoolList
for lists of target pools.
Corresponds to the JSON property kind
79437 79438 79439 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 79437 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
79447 79448 79449 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 79447 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
79452 79453 79454 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 79452 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::TargetPoolList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
79457 79458 79459 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 79457 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
79464 79465 79466 79467 79468 79469 79470 79471 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 79464 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |