Class: Google::Apis::ComputeAlpha::TargetPoolList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::TargetPoolList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Contains a list of TargetPool resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::TargetPool>
A list of TargetPool resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::TargetPoolList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TargetPoolList
constructor
A new instance of TargetPoolList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TargetPoolList
Returns a new instance of TargetPoolList.
78091 78092 78093 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 78091 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
78058 78059 78060 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 78058 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::TargetPool>
A list of TargetPool resources.
Corresponds to the JSON property items
78063 78064 78065 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 78063 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#targetPoolList
for lists of target pools.
Corresponds to the JSON property kind
78069 78070 78071 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 78069 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
78079 78080 78081 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 78079 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
78084 78085 78086 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 78084 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::TargetPoolList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
78089 78090 78091 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 78089 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
78096 78097 78098 78099 78100 78101 78102 78103 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 78096 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |