Class: Google::Apis::ComputeAlpha::TargetPoolList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of TargetPool resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetPoolList

Returns a new instance of TargetPoolList.



78034
78035
78036
# File 'lib/google/apis/compute_alpha/classes.rb', line 78034

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


78001
78002
78003
# File 'lib/google/apis/compute_alpha/classes.rb', line 78001

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::TargetPool>

A list of TargetPool resources. Corresponds to the JSON property items



78006
78007
78008
# File 'lib/google/apis/compute_alpha/classes.rb', line 78006

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#targetPoolList for lists of target pools. Corresponds to the JSON property kind

Returns:

  • (String)


78012
78013
78014
# File 'lib/google/apis/compute_alpha/classes.rb', line 78012

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


78022
78023
78024
# File 'lib/google/apis/compute_alpha/classes.rb', line 78022

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


78027
78028
78029
# File 'lib/google/apis/compute_alpha/classes.rb', line 78027

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::TargetPoolList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



78032
78033
78034
# File 'lib/google/apis/compute_alpha/classes.rb', line 78032

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



78039
78040
78041
78042
78043
78044
78045
78046
# File 'lib/google/apis/compute_alpha/classes.rb', line 78039

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end