Class: Google::Apis::ComputeAlpha::TargetPoolList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of TargetPool resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetPoolList

Returns a new instance of TargetPoolList.



77427
77428
77429
# File 'lib/google/apis/compute_alpha/classes.rb', line 77427

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


77394
77395
77396
# File 'lib/google/apis/compute_alpha/classes.rb', line 77394

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::TargetPool>

A list of TargetPool resources. Corresponds to the JSON property items



77399
77400
77401
# File 'lib/google/apis/compute_alpha/classes.rb', line 77399

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#targetPoolList for lists of target pools. Corresponds to the JSON property kind

Returns:

  • (String)


77405
77406
77407
# File 'lib/google/apis/compute_alpha/classes.rb', line 77405

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


77415
77416
77417
# File 'lib/google/apis/compute_alpha/classes.rb', line 77415

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


77420
77421
77422
# File 'lib/google/apis/compute_alpha/classes.rb', line 77420

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::TargetPoolList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



77425
77426
77427
# File 'lib/google/apis/compute_alpha/classes.rb', line 77425

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



77432
77433
77434
77435
77436
77437
77438
77439
# File 'lib/google/apis/compute_alpha/classes.rb', line 77432

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end