Class: Google::Apis::ComputeAlpha::TargetSslProxyList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of TargetSslProxy resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetSslProxyList

Returns a new instance of TargetSslProxyList.



79974
79975
79976
# File 'lib/google/apis/compute_alpha/classes.rb', line 79974

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


79942
79943
79944
# File 'lib/google/apis/compute_alpha/classes.rb', line 79942

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::TargetSslProxy>

A list of TargetSslProxy resources. Corresponds to the JSON property items



79947
79948
79949
# File 'lib/google/apis/compute_alpha/classes.rb', line 79947

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


79952
79953
79954
# File 'lib/google/apis/compute_alpha/classes.rb', line 79952

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


79962
79963
79964
# File 'lib/google/apis/compute_alpha/classes.rb', line 79962

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


79967
79968
79969
# File 'lib/google/apis/compute_alpha/classes.rb', line 79967

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::TargetSslProxyList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



79972
79973
79974
# File 'lib/google/apis/compute_alpha/classes.rb', line 79972

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



79979
79980
79981
79982
79983
79984
79985
79986
# File 'lib/google/apis/compute_alpha/classes.rb', line 79979

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end