Class: Google::Apis::ComputeAlpha::TargetSslProxyList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of TargetSslProxy resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetSslProxyList

Returns a new instance of TargetSslProxyList.



77942
77943
77944
# File 'lib/google/apis/compute_alpha/classes.rb', line 77942

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


77910
77911
77912
# File 'lib/google/apis/compute_alpha/classes.rb', line 77910

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::TargetSslProxy>

A list of TargetSslProxy resources. Corresponds to the JSON property items



77915
77916
77917
# File 'lib/google/apis/compute_alpha/classes.rb', line 77915

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


77920
77921
77922
# File 'lib/google/apis/compute_alpha/classes.rb', line 77920

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


77930
77931
77932
# File 'lib/google/apis/compute_alpha/classes.rb', line 77930

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


77935
77936
77937
# File 'lib/google/apis/compute_alpha/classes.rb', line 77935

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::TargetSslProxyList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



77940
77941
77942
# File 'lib/google/apis/compute_alpha/classes.rb', line 77940

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



77947
77948
77949
77950
77951
77952
77953
77954
# File 'lib/google/apis/compute_alpha/classes.rb', line 77947

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end