Class: Google::Apis::ComputeAlpha::TargetSslProxyList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::TargetSslProxyList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Contains a list of TargetSslProxy resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::TargetSslProxy>
A list of TargetSslProxy resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::TargetSslProxyList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TargetSslProxyList
constructor
A new instance of TargetSslProxyList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TargetSslProxyList
Returns a new instance of TargetSslProxyList.
77674 77675 77676 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 77674 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
77642 77643 77644 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 77642 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::TargetSslProxy>
A list of TargetSslProxy resources.
Corresponds to the JSON property items
77647 77648 77649 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 77647 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
77652 77653 77654 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 77652 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
77662 77663 77664 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 77662 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
77667 77668 77669 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 77667 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::TargetSslProxyList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
77672 77673 77674 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 77672 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
77679 77680 77681 77682 77683 77684 77685 77686 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 77679 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |