Class: Google::Apis::ComputeAlpha::TargetSslProxyList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of TargetSslProxy resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetSslProxyList

Returns a new instance of TargetSslProxyList.



76726
76727
76728
# File 'lib/google/apis/compute_alpha/classes.rb', line 76726

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


76694
76695
76696
# File 'lib/google/apis/compute_alpha/classes.rb', line 76694

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::TargetSslProxy>

A list of TargetSslProxy resources. Corresponds to the JSON property items



76699
76700
76701
# File 'lib/google/apis/compute_alpha/classes.rb', line 76699

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


76704
76705
76706
# File 'lib/google/apis/compute_alpha/classes.rb', line 76704

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


76714
76715
76716
# File 'lib/google/apis/compute_alpha/classes.rb', line 76714

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


76719
76720
76721
# File 'lib/google/apis/compute_alpha/classes.rb', line 76719

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::TargetSslProxyList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



76724
76725
76726
# File 'lib/google/apis/compute_alpha/classes.rb', line 76724

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



76731
76732
76733
76734
76735
76736
76737
76738
# File 'lib/google/apis/compute_alpha/classes.rb', line 76731

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end