Class: Google::Apis::ComputeAlpha::TargetTcpProxy

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Represents a Target TCP Proxy resource. A target TCP proxy is a component of a Proxy Network Load Balancer. The forwarding rule references the target TCP proxy, and the target proxy then references a backend service. For more information, readProxy Network Load Balancer overview.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetTcpProxy

Returns a new instance of TargetTcpProxy.



78249
78250
78251
# File 'lib/google/apis/compute_alpha/classes.rb', line 78249

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


78175
78176
78177
# File 'lib/google/apis/compute_alpha/classes.rb', line 78175

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


78181
78182
78183
# File 'lib/google/apis/compute_alpha/classes.rb', line 78181

def description
  @description
end

#idFixnum

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


78187
78188
78189
# File 'lib/google/apis/compute_alpha/classes.rb', line 78187

def id
  @id
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute#targetTcpProxy for target TCP proxies. Corresponds to the JSON property kind

Returns:

  • (String)


78193
78194
78195
# File 'lib/google/apis/compute_alpha/classes.rb', line 78193

def kind
  @kind
end

#load_balancing_schemeString

Specifies the type of load balancing scheme used by this target proxy. Corresponds to the JSON property loadBalancingScheme

Returns:

  • (String)


78198
78199
78200
# File 'lib/google/apis/compute_alpha/classes.rb', line 78198

def load_balancing_scheme
  @load_balancing_scheme
end

#nameString

Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


78209
78210
78211
# File 'lib/google/apis/compute_alpha/classes.rb', line 78209

def name
  @name
end

#proxy_bindBoolean Also known as: proxy_bind?

This field only applies when the forwarding rule that references this target proxy has a loadBalancingScheme set toINTERNAL_SELF_MANAGED. When this field is set to true, Envoy proxies set up inbound traffic interception and bind to the IP address and port specified in the forwarding rule. This is generally useful when using Traffic Director to configure Envoy as a gateway or middle proxy (in other words, not a sidecar proxy). The Envoy proxy listens for inbound requests and handles requests when it receives them. The default is false. Corresponds to the JSON property proxyBind

Returns:

  • (Boolean)


78222
78223
78224
# File 'lib/google/apis/compute_alpha/classes.rb', line 78222

def proxy_bind
  @proxy_bind
end

#proxy_headerString

Specifies the type of proxy header to append before sending data to the backend, either NONE or PROXY_V1. The default is NONE. Corresponds to the JSON property proxyHeader

Returns:

  • (String)


78230
78231
78232
# File 'lib/google/apis/compute_alpha/classes.rb', line 78230

def proxy_header
  @proxy_header
end

#regionString

Output only. [Output Only] URL of the region where the regional TCP proxy resides. This field is not applicable to global TCP proxy. Corresponds to the JSON property region

Returns:

  • (String)


78237
78238
78239
# File 'lib/google/apis/compute_alpha/classes.rb', line 78237

def region
  @region
end

[Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


78242
78243
78244
# File 'lib/google/apis/compute_alpha/classes.rb', line 78242

def self_link
  @self_link
end

#serviceString

URL to the BackendService resource. Corresponds to the JSON property service

Returns:

  • (String)


78247
78248
78249
# File 'lib/google/apis/compute_alpha/classes.rb', line 78247

def service
  @service
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



78254
78255
78256
78257
78258
78259
78260
78261
78262
78263
78264
78265
78266
# File 'lib/google/apis/compute_alpha/classes.rb', line 78254

def update!(**args)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @load_balancing_scheme = args[:load_balancing_scheme] if args.key?(:load_balancing_scheme)
  @name = args[:name] if args.key?(:name)
  @proxy_bind = args[:proxy_bind] if args.key?(:proxy_bind)
  @proxy_header = args[:proxy_header] if args.key?(:proxy_header)
  @region = args[:region] if args.key?(:region)
  @self_link = args[:self_link] if args.key?(:self_link)
  @service = args[:service] if args.key?(:service)
end