Class: Google::Apis::ComputeAlpha::TargetTcpProxy

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Represents a Target TCP Proxy resource. A target TCP proxy is a component of a Proxy Network Load Balancer. The forwarding rule references the target TCP proxy, and the target proxy then references a backend service. For more information, readProxy Network Load Balancer overview.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetTcpProxy

Returns a new instance of TargetTcpProxy.



77033
77034
77035
# File 'lib/google/apis/compute_alpha/classes.rb', line 77033

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


76959
76960
76961
# File 'lib/google/apis/compute_alpha/classes.rb', line 76959

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


76965
76966
76967
# File 'lib/google/apis/compute_alpha/classes.rb', line 76965

def description
  @description
end

#idFixnum

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


76971
76972
76973
# File 'lib/google/apis/compute_alpha/classes.rb', line 76971

def id
  @id
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute#targetTcpProxy for target TCP proxies. Corresponds to the JSON property kind

Returns:

  • (String)


76977
76978
76979
# File 'lib/google/apis/compute_alpha/classes.rb', line 76977

def kind
  @kind
end

#load_balancing_schemeString

Specifies the type of load balancing scheme used by this target proxy. Corresponds to the JSON property loadBalancingScheme

Returns:

  • (String)


76982
76983
76984
# File 'lib/google/apis/compute_alpha/classes.rb', line 76982

def load_balancing_scheme
  @load_balancing_scheme
end

#nameString

Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


76993
76994
76995
# File 'lib/google/apis/compute_alpha/classes.rb', line 76993

def name
  @name
end

#proxy_bindBoolean Also known as: proxy_bind?

This field only applies when the forwarding rule that references this target proxy has a loadBalancingScheme set toINTERNAL_SELF_MANAGED. When this field is set to true, Envoy proxies set up inbound traffic interception and bind to the IP address and port specified in the forwarding rule. This is generally useful when using Traffic Director to configure Envoy as a gateway or middle proxy (in other words, not a sidecar proxy). The Envoy proxy listens for inbound requests and handles requests when it receives them. The default is false. Corresponds to the JSON property proxyBind

Returns:

  • (Boolean)


77006
77007
77008
# File 'lib/google/apis/compute_alpha/classes.rb', line 77006

def proxy_bind
  @proxy_bind
end

#proxy_headerString

Specifies the type of proxy header to append before sending data to the backend, either NONE or PROXY_V1. The default is NONE. Corresponds to the JSON property proxyHeader

Returns:

  • (String)


77014
77015
77016
# File 'lib/google/apis/compute_alpha/classes.rb', line 77014

def proxy_header
  @proxy_header
end

#regionString

Output only. [Output Only] URL of the region where the regional TCP proxy resides. This field is not applicable to global TCP proxy. Corresponds to the JSON property region

Returns:

  • (String)


77021
77022
77023
# File 'lib/google/apis/compute_alpha/classes.rb', line 77021

def region
  @region
end

[Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


77026
77027
77028
# File 'lib/google/apis/compute_alpha/classes.rb', line 77026

def self_link
  @self_link
end

#serviceString

URL to the BackendService resource. Corresponds to the JSON property service

Returns:

  • (String)


77031
77032
77033
# File 'lib/google/apis/compute_alpha/classes.rb', line 77031

def service
  @service
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



77038
77039
77040
77041
77042
77043
77044
77045
77046
77047
77048
77049
77050
# File 'lib/google/apis/compute_alpha/classes.rb', line 77038

def update!(**args)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @load_balancing_scheme = args[:load_balancing_scheme] if args.key?(:load_balancing_scheme)
  @name = args[:name] if args.key?(:name)
  @proxy_bind = args[:proxy_bind] if args.key?(:proxy_bind)
  @proxy_header = args[:proxy_header] if args.key?(:proxy_header)
  @region = args[:region] if args.key?(:region)
  @self_link = args[:self_link] if args.key?(:self_link)
  @service = args[:service] if args.key?(:service)
end