Class: Google::Apis::ComputeAlpha::TargetTcpProxyAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::TargetTcpProxyAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::TargetTcpProxiesScopedList>
A list of TargetTcpProxiesScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::TargetTcpProxyAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TargetTcpProxyAggregatedList
constructor
A new instance of TargetTcpProxyAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TargetTcpProxyAggregatedList
Returns a new instance of TargetTcpProxyAggregatedList.
80653 80654 80655 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 80653 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
80614 80615 80616 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 80614 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::TargetTcpProxiesScopedList>
A list of TargetTcpProxiesScopedList resources.
Corresponds to the JSON property items
80619 80620 80621 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 80619 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
targetTcpProxyAggregatedList for lists of Target
TCP Proxies.
Corresponds to the JSON property kind
80626 80627 80628 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 80626 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
80636 80637 80638 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 80636 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
80641 80642 80643 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 80641 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
80646 80647 80648 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 80646 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::TargetTcpProxyAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
80651 80652 80653 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 80651 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
80658 80659 80660 80661 80662 80663 80664 80665 80666 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 80658 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |