Class: Google::Apis::ComputeAlpha::TargetTcpProxyAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetTcpProxyAggregatedList

Returns a new instance of TargetTcpProxyAggregatedList.



78979
78980
78981
# File 'lib/google/apis/compute_alpha/classes.rb', line 78979

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


78940
78941
78942
# File 'lib/google/apis/compute_alpha/classes.rb', line 78940

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::TargetTcpProxiesScopedList>

A list of TargetTcpProxiesScopedList resources. Corresponds to the JSON property items



78945
78946
78947
# File 'lib/google/apis/compute_alpha/classes.rb', line 78945

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# targetTcpProxyAggregatedList for lists of Target TCP Proxies. Corresponds to the JSON property kind

Returns:

  • (String)


78952
78953
78954
# File 'lib/google/apis/compute_alpha/classes.rb', line 78952

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


78962
78963
78964
# File 'lib/google/apis/compute_alpha/classes.rb', line 78962

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


78967
78968
78969
# File 'lib/google/apis/compute_alpha/classes.rb', line 78967

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


78972
78973
78974
# File 'lib/google/apis/compute_alpha/classes.rb', line 78972

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::TargetTcpProxyAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



78977
78978
78979
# File 'lib/google/apis/compute_alpha/classes.rb', line 78977

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



78984
78985
78986
78987
78988
78989
78990
78991
78992
# File 'lib/google/apis/compute_alpha/classes.rb', line 78984

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end