Class: Google::Apis::ComputeAlpha::TargetTcpProxyAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetTcpProxyAggregatedList

Returns a new instance of TargetTcpProxyAggregatedList.



77099
77100
77101
# File 'lib/google/apis/compute_alpha/classes.rb', line 77099

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


77060
77061
77062
# File 'lib/google/apis/compute_alpha/classes.rb', line 77060

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::TargetTcpProxiesScopedList>

A list of TargetTcpProxiesScopedList resources. Corresponds to the JSON property items



77065
77066
77067
# File 'lib/google/apis/compute_alpha/classes.rb', line 77065

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# targetTcpProxyAggregatedList for lists of Target TCP Proxies. Corresponds to the JSON property kind

Returns:

  • (String)


77072
77073
77074
# File 'lib/google/apis/compute_alpha/classes.rb', line 77072

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


77082
77083
77084
# File 'lib/google/apis/compute_alpha/classes.rb', line 77082

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


77087
77088
77089
# File 'lib/google/apis/compute_alpha/classes.rb', line 77087

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


77092
77093
77094
# File 'lib/google/apis/compute_alpha/classes.rb', line 77092

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::TargetTcpProxyAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



77097
77098
77099
# File 'lib/google/apis/compute_alpha/classes.rb', line 77097

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



77104
77105
77106
77107
77108
77109
77110
77111
77112
# File 'lib/google/apis/compute_alpha/classes.rb', line 77104

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end