Class: Google::Apis::ComputeAlpha::TargetTcpProxyList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of TargetTcpProxy resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetTcpProxyList

Returns a new instance of TargetTcpProxyList.



79104
79105
79106
# File 'lib/google/apis/compute_alpha/classes.rb', line 79104

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


79072
79073
79074
# File 'lib/google/apis/compute_alpha/classes.rb', line 79072

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::TargetTcpProxy>

A list of TargetTcpProxy resources. Corresponds to the JSON property items



79077
79078
79079
# File 'lib/google/apis/compute_alpha/classes.rb', line 79077

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


79082
79083
79084
# File 'lib/google/apis/compute_alpha/classes.rb', line 79082

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


79092
79093
79094
# File 'lib/google/apis/compute_alpha/classes.rb', line 79092

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


79097
79098
79099
# File 'lib/google/apis/compute_alpha/classes.rb', line 79097

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::TargetTcpProxyList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



79102
79103
79104
# File 'lib/google/apis/compute_alpha/classes.rb', line 79102

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



79109
79110
79111
79112
79113
79114
79115
79116
# File 'lib/google/apis/compute_alpha/classes.rb', line 79109

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end