Class: Google::Apis::ComputeAlpha::TargetTcpProxyList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::TargetTcpProxyList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Contains a list of TargetTcpProxy resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::TargetTcpProxy>
A list of TargetTcpProxy resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::TargetTcpProxyList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TargetTcpProxyList
constructor
A new instance of TargetTcpProxyList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TargetTcpProxyList
Returns a new instance of TargetTcpProxyList.
78440 78441 78442 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 78440 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
78408 78409 78410 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 78408 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::TargetTcpProxy>
A list of TargetTcpProxy resources.
Corresponds to the JSON property items
78413 78414 78415 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 78413 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
78418 78419 78420 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 78418 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
78428 78429 78430 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 78428 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
78433 78434 78435 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 78433 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::TargetTcpProxyList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
78438 78439 78440 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 78438 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
78445 78446 78447 78448 78449 78450 78451 78452 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 78445 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |