Class: Google::Apis::ComputeAlpha::TargetTcpProxyList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of TargetTcpProxy resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetTcpProxyList

Returns a new instance of TargetTcpProxyList.



78438
78439
78440
# File 'lib/google/apis/compute_alpha/classes.rb', line 78438

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


78406
78407
78408
# File 'lib/google/apis/compute_alpha/classes.rb', line 78406

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::TargetTcpProxy>

A list of TargetTcpProxy resources. Corresponds to the JSON property items



78411
78412
78413
# File 'lib/google/apis/compute_alpha/classes.rb', line 78411

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


78416
78417
78418
# File 'lib/google/apis/compute_alpha/classes.rb', line 78416

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


78426
78427
78428
# File 'lib/google/apis/compute_alpha/classes.rb', line 78426

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


78431
78432
78433
# File 'lib/google/apis/compute_alpha/classes.rb', line 78431

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::TargetTcpProxyList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



78436
78437
78438
# File 'lib/google/apis/compute_alpha/classes.rb', line 78436

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



78443
78444
78445
78446
78447
78448
78449
78450
# File 'lib/google/apis/compute_alpha/classes.rb', line 78443

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end