Class: Google::Apis::ComputeAlpha::TargetTcpProxyList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of TargetTcpProxy resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetTcpProxyList

Returns a new instance of TargetTcpProxyList.



77224
77225
77226
# File 'lib/google/apis/compute_alpha/classes.rb', line 77224

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


77192
77193
77194
# File 'lib/google/apis/compute_alpha/classes.rb', line 77192

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::TargetTcpProxy>

A list of TargetTcpProxy resources. Corresponds to the JSON property items



77197
77198
77199
# File 'lib/google/apis/compute_alpha/classes.rb', line 77197

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


77202
77203
77204
# File 'lib/google/apis/compute_alpha/classes.rb', line 77202

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


77212
77213
77214
# File 'lib/google/apis/compute_alpha/classes.rb', line 77212

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


77217
77218
77219
# File 'lib/google/apis/compute_alpha/classes.rb', line 77217

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::TargetTcpProxyList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



77222
77223
77224
# File 'lib/google/apis/compute_alpha/classes.rb', line 77222

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



77229
77230
77231
77232
77233
77234
77235
77236
# File 'lib/google/apis/compute_alpha/classes.rb', line 77229

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end