Class: Google::Apis::ComputeAlpha::TargetVpnGateway

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Represents a Target VPN Gateway resource. The target VPN gateway resource represents a Classic Cloud VPN gateway. For more information, read thethe Cloud VPN Overview.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetVpnGateway

Returns a new instance of TargetVpnGateway.



79240
79241
79242
# File 'lib/google/apis/compute_alpha/classes.rb', line 79240

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


79143
79144
79145
# File 'lib/google/apis/compute_alpha/classes.rb', line 79143

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


79149
79150
79151
# File 'lib/google/apis/compute_alpha/classes.rb', line 79149

def description
  @description
end

#forwarding_rulesArray<String>

[Output Only] A list of URLs to the ForwardingRule resources. ForwardingRules are created usingcompute.forwardingRules.insert and associated with a VPN gateway. Corresponds to the JSON property forwardingRules

Returns:

  • (Array<String>)


79157
79158
79159
# File 'lib/google/apis/compute_alpha/classes.rb', line 79157

def forwarding_rules
  @forwarding_rules
end

#idFixnum

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


79163
79164
79165
# File 'lib/google/apis/compute_alpha/classes.rb', line 79163

def id
  @id
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute#targetVpnGateway for target VPN gateways. Corresponds to the JSON property kind

Returns:

  • (String)


79169
79170
79171
# File 'lib/google/apis/compute_alpha/classes.rb', line 79169

def kind
  @kind
end

#label_fingerprintString

A fingerprint for the labels being applied to this TargetVpnGateway, which is essentially a hash of the labels set used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update labels. You must always provide an up-to-date fingerprint hash in order to update or change labels, otherwise the request will fail with error412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve a TargetVpnGateway. Corresponds to the JSON property labelFingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


79182
79183
79184
# File 'lib/google/apis/compute_alpha/classes.rb', line 79182

def label_fingerprint
  @label_fingerprint
end

#labelsHash<String,String>

Labels for this resource. These can only be added or modified by thesetLabels method. Each label key/value pair must comply withRFC1035. Label values may be empty. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


79189
79190
79191
# File 'lib/google/apis/compute_alpha/classes.rb', line 79189

def labels
  @labels
end

#nameString

Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


79200
79201
79202
# File 'lib/google/apis/compute_alpha/classes.rb', line 79200

def name
  @name
end

#networkString

URL of the network to which this VPN gateway is attached. Provided by the client when the VPN gateway is created. Corresponds to the JSON property network

Returns:

  • (String)


79206
79207
79208
# File 'lib/google/apis/compute_alpha/classes.rb', line 79206

def network
  @network
end

#paramsGoogle::Apis::ComputeAlpha::TargetVpnGatewayParams

Input only. [Input Only] Additional params passed with the request, but not persisted as part of resource payload. Corresponds to the JSON property params



79213
79214
79215
# File 'lib/google/apis/compute_alpha/classes.rb', line 79213

def params
  @params
end

#regionString

[Output Only] URL of the region where the target VPN gateway resides. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body. Corresponds to the JSON property region

Returns:

  • (String)


79220
79221
79222
# File 'lib/google/apis/compute_alpha/classes.rb', line 79220

def region
  @region
end

[Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


79225
79226
79227
# File 'lib/google/apis/compute_alpha/classes.rb', line 79225

def self_link
  @self_link
end

#statusString

[Output Only] The status of the VPN gateway, which can be one of the following: CREATING, READY, FAILED, or DELETING. Corresponds to the JSON property status

Returns:

  • (String)


79231
79232
79233
# File 'lib/google/apis/compute_alpha/classes.rb', line 79231

def status
  @status
end

#tunnelsArray<String>

[Output Only] A list of URLs to VpnTunnel resources. VpnTunnels are created using the compute.vpntunnels.insert method and associated with a VPN gateway. Corresponds to the JSON property tunnels

Returns:

  • (Array<String>)


79238
79239
79240
# File 'lib/google/apis/compute_alpha/classes.rb', line 79238

def tunnels
  @tunnels
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



79245
79246
79247
79248
79249
79250
79251
79252
79253
79254
79255
79256
79257
79258
79259
79260
# File 'lib/google/apis/compute_alpha/classes.rb', line 79245

def update!(**args)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @forwarding_rules = args[:forwarding_rules] if args.key?(:forwarding_rules)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @label_fingerprint = args[:label_fingerprint] if args.key?(:label_fingerprint)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @network = args[:network] if args.key?(:network)
  @params = args[:params] if args.key?(:params)
  @region = args[:region] if args.key?(:region)
  @self_link = args[:self_link] if args.key?(:self_link)
  @status = args[:status] if args.key?(:status)
  @tunnels = args[:tunnels] if args.key?(:tunnels)
end