Class: Google::Apis::ComputeAlpha::TargetVpnGatewayAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetVpnGatewayAggregatedList

Returns a new instance of TargetVpnGatewayAggregatedList.



79365
79366
79367
# File 'lib/google/apis/compute_alpha/classes.rb', line 79365

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


79327
79328
79329
# File 'lib/google/apis/compute_alpha/classes.rb', line 79327

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::TargetVpnGatewaysScopedList>

A list of TargetVpnGateway resources. Corresponds to the JSON property items



79332
79333
79334
# File 'lib/google/apis/compute_alpha/classes.rb', line 79332

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute#targetVpnGateway for target VPN gateways. Corresponds to the JSON property kind

Returns:

  • (String)


79338
79339
79340
# File 'lib/google/apis/compute_alpha/classes.rb', line 79338

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


79348
79349
79350
# File 'lib/google/apis/compute_alpha/classes.rb', line 79348

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


79353
79354
79355
# File 'lib/google/apis/compute_alpha/classes.rb', line 79353

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


79358
79359
79360
# File 'lib/google/apis/compute_alpha/classes.rb', line 79358

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::TargetVpnGatewayAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



79363
79364
79365
# File 'lib/google/apis/compute_alpha/classes.rb', line 79363

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



79370
79371
79372
79373
79374
79375
79376
79377
79378
# File 'lib/google/apis/compute_alpha/classes.rb', line 79370

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end