Class: Google::Apis::ComputeAlpha::TargetVpnGatewayAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetVpnGatewayAggregatedList

Returns a new instance of TargetVpnGatewayAggregatedList.



78699
78700
78701
# File 'lib/google/apis/compute_alpha/classes.rb', line 78699

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


78661
78662
78663
# File 'lib/google/apis/compute_alpha/classes.rb', line 78661

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::TargetVpnGatewaysScopedList>

A list of TargetVpnGateway resources. Corresponds to the JSON property items



78666
78667
78668
# File 'lib/google/apis/compute_alpha/classes.rb', line 78666

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute#targetVpnGateway for target VPN gateways. Corresponds to the JSON property kind

Returns:

  • (String)


78672
78673
78674
# File 'lib/google/apis/compute_alpha/classes.rb', line 78672

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


78682
78683
78684
# File 'lib/google/apis/compute_alpha/classes.rb', line 78682

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


78687
78688
78689
# File 'lib/google/apis/compute_alpha/classes.rb', line 78687

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


78692
78693
78694
# File 'lib/google/apis/compute_alpha/classes.rb', line 78692

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::TargetVpnGatewayAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



78697
78698
78699
# File 'lib/google/apis/compute_alpha/classes.rb', line 78697

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



78704
78705
78706
78707
78708
78709
78710
78711
78712
# File 'lib/google/apis/compute_alpha/classes.rb', line 78704

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end