Class: Google::Apis::ComputeAlpha::TargetVpnGatewayAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetVpnGatewayAggregatedList

Returns a new instance of TargetVpnGatewayAggregatedList.



78433
78434
78435
# File 'lib/google/apis/compute_alpha/classes.rb', line 78433

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


78395
78396
78397
# File 'lib/google/apis/compute_alpha/classes.rb', line 78395

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::TargetVpnGatewaysScopedList>

A list of TargetVpnGateway resources. Corresponds to the JSON property items



78400
78401
78402
# File 'lib/google/apis/compute_alpha/classes.rb', line 78400

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute#targetVpnGateway for target VPN gateways. Corresponds to the JSON property kind

Returns:

  • (String)


78406
78407
78408
# File 'lib/google/apis/compute_alpha/classes.rb', line 78406

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


78416
78417
78418
# File 'lib/google/apis/compute_alpha/classes.rb', line 78416

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


78421
78422
78423
# File 'lib/google/apis/compute_alpha/classes.rb', line 78421

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


78426
78427
78428
# File 'lib/google/apis/compute_alpha/classes.rb', line 78426

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::TargetVpnGatewayAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



78431
78432
78433
# File 'lib/google/apis/compute_alpha/classes.rb', line 78431

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



78438
78439
78440
78441
78442
78443
78444
78445
78446
# File 'lib/google/apis/compute_alpha/classes.rb', line 78438

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end