Class: Google::Apis::ComputeAlpha::TargetVpnGatewayList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::TargetVpnGatewayList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Contains a list of TargetVpnGateway resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::TargetVpnGateway>
A list of TargetVpnGateway resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::TargetVpnGatewayList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TargetVpnGatewayList
constructor
A new instance of TargetVpnGatewayList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TargetVpnGatewayList
Returns a new instance of TargetVpnGatewayList.
81442 81443 81444 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 81442 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
81409 81410 81411 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 81409 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::TargetVpnGateway>
A list of TargetVpnGateway resources.
Corresponds to the JSON property items
81414 81415 81416 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 81414 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#targetVpnGateway
for target VPN gateways.
Corresponds to the JSON property kind
81420 81421 81422 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 81420 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
81430 81431 81432 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 81430 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
81435 81436 81437 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 81435 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::TargetVpnGatewayList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
81440 81441 81442 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 81440 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
81447 81448 81449 81450 81451 81452 81453 81454 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 81447 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |