Class: Google::Apis::ComputeAlpha::TargetVpnGatewayList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::TargetVpnGatewayList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Contains a list of TargetVpnGateway resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::TargetVpnGateway>
A list of TargetVpnGateway resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::TargetVpnGatewayList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TargetVpnGatewayList
constructor
A new instance of TargetVpnGatewayList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TargetVpnGatewayList
Returns a new instance of TargetVpnGatewayList.
79434 79435 79436 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 79434 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
79401 79402 79403 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 79401 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::TargetVpnGateway>
A list of TargetVpnGateway resources.
Corresponds to the JSON property items
79406 79407 79408 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 79406 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#targetVpnGateway
for target VPN gateways.
Corresponds to the JSON property kind
79412 79413 79414 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 79412 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
79422 79423 79424 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 79422 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
79427 79428 79429 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 79427 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::TargetVpnGatewayList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
79432 79433 79434 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 79432 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
79439 79440 79441 79442 79443 79444 79445 79446 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 79439 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |