Class: Google::Apis::ComputeAlpha::TargetVpnGatewayList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of TargetVpnGateway resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetVpnGatewayList

Returns a new instance of TargetVpnGatewayList.



78827
78828
78829
# File 'lib/google/apis/compute_alpha/classes.rb', line 78827

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


78794
78795
78796
# File 'lib/google/apis/compute_alpha/classes.rb', line 78794

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::TargetVpnGateway>

A list of TargetVpnGateway resources. Corresponds to the JSON property items



78799
78800
78801
# File 'lib/google/apis/compute_alpha/classes.rb', line 78799

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute#targetVpnGateway for target VPN gateways. Corresponds to the JSON property kind

Returns:

  • (String)


78805
78806
78807
# File 'lib/google/apis/compute_alpha/classes.rb', line 78805

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


78815
78816
78817
# File 'lib/google/apis/compute_alpha/classes.rb', line 78815

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


78820
78821
78822
# File 'lib/google/apis/compute_alpha/classes.rb', line 78820

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::TargetVpnGatewayList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



78825
78826
78827
# File 'lib/google/apis/compute_alpha/classes.rb', line 78825

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



78832
78833
78834
78835
78836
78837
78838
78839
# File 'lib/google/apis/compute_alpha/classes.rb', line 78832

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end