Class: Google::Apis::ComputeAlpha::TestFailure

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TestFailure

Returns a new instance of TestFailure.



81434
81435
81436
# File 'lib/google/apis/compute_alpha/classes.rb', line 81434

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#actual_output_urlString

The actual output URL evaluated by a load balancer containing the scheme, host, path and query parameters. Corresponds to the JSON property actualOutputUrl

Returns:

  • (String)


81387
81388
81389
# File 'lib/google/apis/compute_alpha/classes.rb', line 81387

def actual_output_url
  @actual_output_url
end

#actual_redirect_response_codeFixnum

Actual HTTP status code for rule with urlRedirect calculated by load balancer Corresponds to the JSON property actualRedirectResponseCode

Returns:

  • (Fixnum)


81393
81394
81395
# File 'lib/google/apis/compute_alpha/classes.rb', line 81393

def actual_redirect_response_code
  @actual_redirect_response_code
end

#actual_serviceString

BackendService or BackendBucket returned by load balancer. Corresponds to the JSON property actualService

Returns:

  • (String)


81399
81400
81401
# File 'lib/google/apis/compute_alpha/classes.rb', line 81399

def actual_service
  @actual_service
end

#expected_output_urlString

The expected output URL evaluated by a load balancer containing the scheme, host, path and query parameters. Corresponds to the JSON property expectedOutputUrl

Returns:

  • (String)


81405
81406
81407
# File 'lib/google/apis/compute_alpha/classes.rb', line 81405

def expected_output_url
  @expected_output_url
end

#expected_redirect_response_codeFixnum

Expected HTTP status code for rule with urlRedirect calculated by load balancer Corresponds to the JSON property expectedRedirectResponseCode

Returns:

  • (Fixnum)


81411
81412
81413
# File 'lib/google/apis/compute_alpha/classes.rb', line 81411

def expected_redirect_response_code
  @expected_redirect_response_code
end

#expected_serviceString

Expected BackendService or BackendBucket resource the given URL should be mapped to. Corresponds to the JSON property expectedService

Returns:

  • (String)


81417
81418
81419
# File 'lib/google/apis/compute_alpha/classes.rb', line 81417

def expected_service
  @expected_service
end

#headersArray<Google::Apis::ComputeAlpha::UrlMapTestHeader>

HTTP headers of the request. Corresponds to the JSON property headers



81422
81423
81424
# File 'lib/google/apis/compute_alpha/classes.rb', line 81422

def headers
  @headers
end

#hostString

Host portion of the URL. Corresponds to the JSON property host

Returns:

  • (String)


81427
81428
81429
# File 'lib/google/apis/compute_alpha/classes.rb', line 81427

def host
  @host
end

#pathString

Path portion including query parameters in the URL. Corresponds to the JSON property path

Returns:

  • (String)


81432
81433
81434
# File 'lib/google/apis/compute_alpha/classes.rb', line 81432

def path
  @path
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



81439
81440
81441
81442
81443
81444
81445
81446
81447
81448
81449
# File 'lib/google/apis/compute_alpha/classes.rb', line 81439

def update!(**args)
  @actual_output_url = args[:actual_output_url] if args.key?(:actual_output_url)
  @actual_redirect_response_code = args[:actual_redirect_response_code] if args.key?(:actual_redirect_response_code)
  @actual_service = args[:actual_service] if args.key?(:actual_service)
  @expected_output_url = args[:expected_output_url] if args.key?(:expected_output_url)
  @expected_redirect_response_code = args[:expected_redirect_response_code] if args.key?(:expected_redirect_response_code)
  @expected_service = args[:expected_service] if args.key?(:expected_service)
  @headers = args[:headers] if args.key?(:headers)
  @host = args[:host] if args.key?(:host)
  @path = args[:path] if args.key?(:path)
end