Class: Google::Apis::ComputeAlpha::TestFailure

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TestFailure

Returns a new instance of TestFailure.



81128
81129
81130
# File 'lib/google/apis/compute_alpha/classes.rb', line 81128

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#actual_output_urlString

The actual output URL evaluated by a load balancer containing the scheme, host, path and query parameters. Corresponds to the JSON property actualOutputUrl

Returns:

  • (String)


81081
81082
81083
# File 'lib/google/apis/compute_alpha/classes.rb', line 81081

def actual_output_url
  @actual_output_url
end

#actual_redirect_response_codeFixnum

Actual HTTP status code for rule with urlRedirect calculated by load balancer Corresponds to the JSON property actualRedirectResponseCode

Returns:

  • (Fixnum)


81087
81088
81089
# File 'lib/google/apis/compute_alpha/classes.rb', line 81087

def actual_redirect_response_code
  @actual_redirect_response_code
end

#actual_serviceString

BackendService or BackendBucket returned by load balancer. Corresponds to the JSON property actualService

Returns:

  • (String)


81093
81094
81095
# File 'lib/google/apis/compute_alpha/classes.rb', line 81093

def actual_service
  @actual_service
end

#expected_output_urlString

The expected output URL evaluated by a load balancer containing the scheme, host, path and query parameters. Corresponds to the JSON property expectedOutputUrl

Returns:

  • (String)


81099
81100
81101
# File 'lib/google/apis/compute_alpha/classes.rb', line 81099

def expected_output_url
  @expected_output_url
end

#expected_redirect_response_codeFixnum

Expected HTTP status code for rule with urlRedirect calculated by load balancer Corresponds to the JSON property expectedRedirectResponseCode

Returns:

  • (Fixnum)


81105
81106
81107
# File 'lib/google/apis/compute_alpha/classes.rb', line 81105

def expected_redirect_response_code
  @expected_redirect_response_code
end

#expected_serviceString

Expected BackendService or BackendBucket resource the given URL should be mapped to. Corresponds to the JSON property expectedService

Returns:

  • (String)


81111
81112
81113
# File 'lib/google/apis/compute_alpha/classes.rb', line 81111

def expected_service
  @expected_service
end

#headersArray<Google::Apis::ComputeAlpha::UrlMapTestHeader>

HTTP headers of the request. Corresponds to the JSON property headers



81116
81117
81118
# File 'lib/google/apis/compute_alpha/classes.rb', line 81116

def headers
  @headers
end

#hostString

Host portion of the URL. Corresponds to the JSON property host

Returns:

  • (String)


81121
81122
81123
# File 'lib/google/apis/compute_alpha/classes.rb', line 81121

def host
  @host
end

#pathString

Path portion including query parameters in the URL. Corresponds to the JSON property path

Returns:

  • (String)


81126
81127
81128
# File 'lib/google/apis/compute_alpha/classes.rb', line 81126

def path
  @path
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



81133
81134
81135
81136
81137
81138
81139
81140
81141
81142
81143
# File 'lib/google/apis/compute_alpha/classes.rb', line 81133

def update!(**args)
  @actual_output_url = args[:actual_output_url] if args.key?(:actual_output_url)
  @actual_redirect_response_code = args[:actual_redirect_response_code] if args.key?(:actual_redirect_response_code)
  @actual_service = args[:actual_service] if args.key?(:actual_service)
  @expected_output_url = args[:expected_output_url] if args.key?(:expected_output_url)
  @expected_redirect_response_code = args[:expected_redirect_response_code] if args.key?(:expected_redirect_response_code)
  @expected_service = args[:expected_service] if args.key?(:expected_service)
  @headers = args[:headers] if args.key?(:headers)
  @host = args[:host] if args.key?(:host)
  @path = args[:path] if args.key?(:path)
end