Class: Google::Apis::ComputeAlpha::TestFailure
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::TestFailure
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#actual_output_url ⇒ String
The actual output URL evaluated by a load balancer containing the scheme, host, path and query parameters.
-
#actual_redirect_response_code ⇒ Fixnum
Actual HTTP status code for rule with
urlRedirectcalculated by load balancer Corresponds to the JSON propertyactualRedirectResponseCode. -
#actual_service ⇒ String
BackendService or BackendBucket returned by load balancer.
-
#expected_output_url ⇒ String
The expected output URL evaluated by a load balancer containing the scheme, host, path and query parameters.
-
#expected_redirect_response_code ⇒ Fixnum
Expected HTTP status code for rule with
urlRedirectcalculated by load balancer Corresponds to the JSON propertyexpectedRedirectResponseCode. -
#expected_service ⇒ String
Expected BackendService or BackendBucket resource the given URL should be mapped to.
-
#headers ⇒ Array<Google::Apis::ComputeAlpha::UrlMapTestHeader>
HTTP headers of the request.
-
#host ⇒ String
Host portion of the URL.
-
#path ⇒ String
Path portion including query parameters in the URL.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TestFailure
constructor
A new instance of TestFailure.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TestFailure
Returns a new instance of TestFailure.
79760 79761 79762 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 79760 def initialize(**args) update!(**args) end |
Instance Attribute Details
#actual_output_url ⇒ String
The actual output URL evaluated by a load balancer containing the scheme,
host, path and query parameters.
Corresponds to the JSON property actualOutputUrl
79713 79714 79715 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 79713 def actual_output_url @actual_output_url end |
#actual_redirect_response_code ⇒ Fixnum
Actual HTTP status code for rule with urlRedirect
calculated by load balancer
Corresponds to the JSON property actualRedirectResponseCode
79719 79720 79721 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 79719 def actual_redirect_response_code @actual_redirect_response_code end |
#actual_service ⇒ String
BackendService or BackendBucket returned by load
balancer.
Corresponds to the JSON property actualService
79725 79726 79727 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 79725 def actual_service @actual_service end |
#expected_output_url ⇒ String
The expected output URL evaluated by a load balancer containing the scheme,
host, path and query parameters.
Corresponds to the JSON property expectedOutputUrl
79731 79732 79733 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 79731 def expected_output_url @expected_output_url end |
#expected_redirect_response_code ⇒ Fixnum
Expected HTTP status code for rule with urlRedirect
calculated by load balancer
Corresponds to the JSON property expectedRedirectResponseCode
79737 79738 79739 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 79737 def expected_redirect_response_code @expected_redirect_response_code end |
#expected_service ⇒ String
Expected BackendService or BackendBucket resource
the given URL should be mapped to.
Corresponds to the JSON property expectedService
79743 79744 79745 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 79743 def expected_service @expected_service end |
#headers ⇒ Array<Google::Apis::ComputeAlpha::UrlMapTestHeader>
HTTP headers of the request.
Corresponds to the JSON property headers
79748 79749 79750 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 79748 def headers @headers end |
#host ⇒ String
Host portion of the URL.
Corresponds to the JSON property host
79753 79754 79755 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 79753 def host @host end |
#path ⇒ String
Path portion including query parameters in the URL.
Corresponds to the JSON property path
79758 79759 79760 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 79758 def path @path end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
79765 79766 79767 79768 79769 79770 79771 79772 79773 79774 79775 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 79765 def update!(**args) @actual_output_url = args[:actual_output_url] if args.key?(:actual_output_url) @actual_redirect_response_code = args[:actual_redirect_response_code] if args.key?(:actual_redirect_response_code) @actual_service = args[:actual_service] if args.key?(:actual_service) @expected_output_url = args[:expected_output_url] if args.key?(:expected_output_url) @expected_redirect_response_code = args[:expected_redirect_response_code] if args.key?(:expected_redirect_response_code) @expected_service = args[:expected_service] if args.key?(:expected_service) @headers = args[:headers] if args.key?(:headers) @host = args[:host] if args.key?(:host) @path = args[:path] if args.key?(:path) end |