Class: Google::Apis::ComputeAlpha::TestFailure

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TestFailure

Returns a new instance of TestFailure.



79096
79097
79098
# File 'lib/google/apis/compute_alpha/classes.rb', line 79096

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#actual_output_urlString

The actual output URL evaluated by a load balancer containing the scheme, host, path and query parameters. Corresponds to the JSON property actualOutputUrl

Returns:

  • (String)


79049
79050
79051
# File 'lib/google/apis/compute_alpha/classes.rb', line 79049

def actual_output_url
  @actual_output_url
end

#actual_redirect_response_codeFixnum

Actual HTTP status code for rule with urlRedirect calculated by load balancer Corresponds to the JSON property actualRedirectResponseCode

Returns:

  • (Fixnum)


79055
79056
79057
# File 'lib/google/apis/compute_alpha/classes.rb', line 79055

def actual_redirect_response_code
  @actual_redirect_response_code
end

#actual_serviceString

BackendService or BackendBucket returned by load balancer. Corresponds to the JSON property actualService

Returns:

  • (String)


79061
79062
79063
# File 'lib/google/apis/compute_alpha/classes.rb', line 79061

def actual_service
  @actual_service
end

#expected_output_urlString

The expected output URL evaluated by a load balancer containing the scheme, host, path and query parameters. Corresponds to the JSON property expectedOutputUrl

Returns:

  • (String)


79067
79068
79069
# File 'lib/google/apis/compute_alpha/classes.rb', line 79067

def expected_output_url
  @expected_output_url
end

#expected_redirect_response_codeFixnum

Expected HTTP status code for rule with urlRedirect calculated by load balancer Corresponds to the JSON property expectedRedirectResponseCode

Returns:

  • (Fixnum)


79073
79074
79075
# File 'lib/google/apis/compute_alpha/classes.rb', line 79073

def expected_redirect_response_code
  @expected_redirect_response_code
end

#expected_serviceString

Expected BackendService or BackendBucket resource the given URL should be mapped to. Corresponds to the JSON property expectedService

Returns:

  • (String)


79079
79080
79081
# File 'lib/google/apis/compute_alpha/classes.rb', line 79079

def expected_service
  @expected_service
end

#headersArray<Google::Apis::ComputeAlpha::UrlMapTestHeader>

HTTP headers of the request. Corresponds to the JSON property headers



79084
79085
79086
# File 'lib/google/apis/compute_alpha/classes.rb', line 79084

def headers
  @headers
end

#hostString

Host portion of the URL. Corresponds to the JSON property host

Returns:

  • (String)


79089
79090
79091
# File 'lib/google/apis/compute_alpha/classes.rb', line 79089

def host
  @host
end

#pathString

Path portion including query parameters in the URL. Corresponds to the JSON property path

Returns:

  • (String)


79094
79095
79096
# File 'lib/google/apis/compute_alpha/classes.rb', line 79094

def path
  @path
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



79101
79102
79103
79104
79105
79106
79107
79108
79109
79110
79111
# File 'lib/google/apis/compute_alpha/classes.rb', line 79101

def update!(**args)
  @actual_output_url = args[:actual_output_url] if args.key?(:actual_output_url)
  @actual_redirect_response_code = args[:actual_redirect_response_code] if args.key?(:actual_redirect_response_code)
  @actual_service = args[:actual_service] if args.key?(:actual_service)
  @expected_output_url = args[:expected_output_url] if args.key?(:expected_output_url)
  @expected_redirect_response_code = args[:expected_redirect_response_code] if args.key?(:expected_redirect_response_code)
  @expected_service = args[:expected_service] if args.key?(:expected_service)
  @headers = args[:headers] if args.key?(:headers)
  @host = args[:host] if args.key?(:host)
  @path = args[:path] if args.key?(:path)
end