Class: Google::Apis::ComputeAlpha::TestFailure
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::TestFailure
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#actual_output_url ⇒ String
The actual output URL evaluated by a load balancer containing the scheme, host, path and query parameters.
-
#actual_redirect_response_code ⇒ Fixnum
Actual HTTP status code for rule with
urlRedirectcalculated by load balancer Corresponds to the JSON propertyactualRedirectResponseCode. -
#actual_service ⇒ String
BackendService or BackendBucket returned by load balancer.
-
#expected_output_url ⇒ String
The expected output URL evaluated by a load balancer containing the scheme, host, path and query parameters.
-
#expected_redirect_response_code ⇒ Fixnum
Expected HTTP status code for rule with
urlRedirectcalculated by load balancer Corresponds to the JSON propertyexpectedRedirectResponseCode. -
#expected_service ⇒ String
Expected BackendService or BackendBucket resource the given URL should be mapped to.
-
#headers ⇒ Array<Google::Apis::ComputeAlpha::UrlMapTestHeader>
HTTP headers of the request.
-
#host ⇒ String
Host portion of the URL.
-
#path ⇒ String
Path portion including query parameters in the URL.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TestFailure
constructor
A new instance of TestFailure.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TestFailure
Returns a new instance of TestFailure.
78828 78829 78830 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 78828 def initialize(**args) update!(**args) end |
Instance Attribute Details
#actual_output_url ⇒ String
The actual output URL evaluated by a load balancer containing the scheme,
host, path and query parameters.
Corresponds to the JSON property actualOutputUrl
78781 78782 78783 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 78781 def actual_output_url @actual_output_url end |
#actual_redirect_response_code ⇒ Fixnum
Actual HTTP status code for rule with urlRedirect
calculated by load balancer
Corresponds to the JSON property actualRedirectResponseCode
78787 78788 78789 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 78787 def actual_redirect_response_code @actual_redirect_response_code end |
#actual_service ⇒ String
BackendService or BackendBucket returned by load
balancer.
Corresponds to the JSON property actualService
78793 78794 78795 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 78793 def actual_service @actual_service end |
#expected_output_url ⇒ String
The expected output URL evaluated by a load balancer containing the scheme,
host, path and query parameters.
Corresponds to the JSON property expectedOutputUrl
78799 78800 78801 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 78799 def expected_output_url @expected_output_url end |
#expected_redirect_response_code ⇒ Fixnum
Expected HTTP status code for rule with urlRedirect
calculated by load balancer
Corresponds to the JSON property expectedRedirectResponseCode
78805 78806 78807 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 78805 def expected_redirect_response_code @expected_redirect_response_code end |
#expected_service ⇒ String
Expected BackendService or BackendBucket resource
the given URL should be mapped to.
Corresponds to the JSON property expectedService
78811 78812 78813 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 78811 def expected_service @expected_service end |
#headers ⇒ Array<Google::Apis::ComputeAlpha::UrlMapTestHeader>
HTTP headers of the request.
Corresponds to the JSON property headers
78816 78817 78818 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 78816 def headers @headers end |
#host ⇒ String
Host portion of the URL.
Corresponds to the JSON property host
78821 78822 78823 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 78821 def host @host end |
#path ⇒ String
Path portion including query parameters in the URL.
Corresponds to the JSON property path
78826 78827 78828 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 78826 def path @path end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
78833 78834 78835 78836 78837 78838 78839 78840 78841 78842 78843 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 78833 def update!(**args) @actual_output_url = args[:actual_output_url] if args.key?(:actual_output_url) @actual_redirect_response_code = args[:actual_redirect_response_code] if args.key?(:actual_redirect_response_code) @actual_service = args[:actual_service] if args.key?(:actual_service) @expected_output_url = args[:expected_output_url] if args.key?(:expected_output_url) @expected_redirect_response_code = args[:expected_redirect_response_code] if args.key?(:expected_redirect_response_code) @expected_service = args[:expected_service] if args.key?(:expected_service) @headers = args[:headers] if args.key?(:headers) @host = args[:host] if args.key?(:host) @path = args[:path] if args.key?(:path) end |