Class: Google::Apis::ComputeAlpha::TlsValidationContext
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::TlsValidationContext
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
[Deprecated] Defines the mechanism to obtain the Certificate Authority certificate to validate the client/server certificate. validate the client/server certificate.
Instance Attribute Summary collapse
-
#certificate_path ⇒ String
The path to the file holding the CA certificate to validate the client or server certificate.
-
#sds_config ⇒ Google::Apis::ComputeAlpha::SdsConfig
[Deprecated] The configuration to access the SDS server.
-
#validation_source ⇒ String
Defines how TLS certificates are obtained.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TlsValidationContext
constructor
A new instance of TlsValidationContext.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TlsValidationContext
Returns a new instance of TlsValidationContext.
78078 78079 78080 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 78078 def initialize(**args) update!(**args) end |
Instance Attribute Details
#certificate_path ⇒ String
The path to the file holding the CA certificate to validate the
client or server certificate.
Corresponds to the JSON property certificatePath
78065 78066 78067 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 78065 def certificate_path @certificate_path end |
#sds_config ⇒ Google::Apis::ComputeAlpha::SdsConfig
[Deprecated] The configuration to access the SDS server.
The configuration to access the SDS server.
Corresponds to the JSON property sdsConfig
78071 78072 78073 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 78071 def sds_config @sds_config end |
#validation_source ⇒ String
Defines how TLS certificates are obtained.
Corresponds to the JSON property validationSource
78076 78077 78078 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 78076 def validation_source @validation_source end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
78083 78084 78085 78086 78087 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 78083 def update!(**args) @certificate_path = args[:certificate_path] if args.key?(:certificate_path) @sds_config = args[:sds_config] if args.key?(:sds_config) @validation_source = args[:validation_source] if args.key?(:validation_source) end |