Class: Google::Apis::ComputeAlpha::UdpHealthCheck

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UdpHealthCheck

Returns a new instance of UdpHealthCheck.



81365
81366
81367
# File 'lib/google/apis/compute_alpha/classes.rb', line 81365

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#portFixnum

The UDP port number to which the health check prober sends packets. Valid values are 1 through 65535. Corresponds to the JSON property port

Returns:

  • (Fixnum)


81346
81347
81348
# File 'lib/google/apis/compute_alpha/classes.rb', line 81346

def port
  @port
end

#port_nameString

Not supported. Corresponds to the JSON property portName

Returns:

  • (String)


81351
81352
81353
# File 'lib/google/apis/compute_alpha/classes.rb', line 81351

def port_name
  @port_name
end

#requestString

Raw data of request to send in payload of UDP packet. It is an error if this is empty. The request data can only be ASCII. Corresponds to the JSON property request

Returns:

  • (String)


81357
81358
81359
# File 'lib/google/apis/compute_alpha/classes.rb', line 81357

def request
  @request
end

#responseString

The bytes to match against the beginning of the response data. It is an error if this is empty. The response data can only be ASCII. Corresponds to the JSON property response

Returns:

  • (String)


81363
81364
81365
# File 'lib/google/apis/compute_alpha/classes.rb', line 81363

def response
  @response
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



81370
81371
81372
81373
81374
81375
# File 'lib/google/apis/compute_alpha/classes.rb', line 81370

def update!(**args)
  @port = args[:port] if args.key?(:port)
  @port_name = args[:port_name] if args.key?(:port_name)
  @request = args[:request] if args.key?(:request)
  @response = args[:response] if args.key?(:response)
end