Class: Google::Apis::ComputeAlpha::UdpHealthCheck
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::UdpHealthCheck
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#port ⇒ Fixnum
The UDP port number to which the health check prober sends packets.
-
#port_name ⇒ String
Not supported.
-
#request ⇒ String
Raw data of request to send in payload of UDP packet.
-
#response ⇒ String
The bytes to match against the beginning of the response data.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UdpHealthCheck
constructor
A new instance of UdpHealthCheck.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UdpHealthCheck
Returns a new instance of UdpHealthCheck.
79065 79066 79067 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 79065 def initialize(**args) update!(**args) end |
Instance Attribute Details
#port ⇒ Fixnum
The UDP port number to which the health check prober sends packets. Valid
values are 1 through 65535.
Corresponds to the JSON property port
79046 79047 79048 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 79046 def port @port end |
#port_name ⇒ String
Not supported.
Corresponds to the JSON property portName
79051 79052 79053 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 79051 def port_name @port_name end |
#request ⇒ String
Raw data of request to send in payload of UDP packet. It is an error if
this is empty. The request data can only be ASCII.
Corresponds to the JSON property request
79057 79058 79059 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 79057 def request @request end |
#response ⇒ String
The bytes to match against the beginning of the response data.
It is an error if this is empty. The response data can only be ASCII.
Corresponds to the JSON property response
79063 79064 79065 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 79063 def response @response end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
79070 79071 79072 79073 79074 79075 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 79070 def update!(**args) @port = args[:port] if args.key?(:port) @port_name = args[:port_name] if args.key?(:port_name) @request = args[:request] if args.key?(:request) @response = args[:response] if args.key?(:response) end |