Class: Google::Apis::ComputeAlpha::UdpHealthCheck

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UdpHealthCheck

Returns a new instance of UdpHealthCheck.



78117
78118
78119
# File 'lib/google/apis/compute_alpha/classes.rb', line 78117

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#portFixnum

The UDP port number to which the health check prober sends packets. Valid values are 1 through 65535. Corresponds to the JSON property port

Returns:

  • (Fixnum)


78098
78099
78100
# File 'lib/google/apis/compute_alpha/classes.rb', line 78098

def port
  @port
end

#port_nameString

Not supported. Corresponds to the JSON property portName

Returns:

  • (String)


78103
78104
78105
# File 'lib/google/apis/compute_alpha/classes.rb', line 78103

def port_name
  @port_name
end

#requestString

Raw data of request to send in payload of UDP packet. It is an error if this is empty. The request data can only be ASCII. Corresponds to the JSON property request

Returns:

  • (String)


78109
78110
78111
# File 'lib/google/apis/compute_alpha/classes.rb', line 78109

def request
  @request
end

#responseString

The bytes to match against the beginning of the response data. It is an error if this is empty. The response data can only be ASCII. Corresponds to the JSON property response

Returns:

  • (String)


78115
78116
78117
# File 'lib/google/apis/compute_alpha/classes.rb', line 78115

def response
  @response
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



78122
78123
78124
78125
78126
78127
# File 'lib/google/apis/compute_alpha/classes.rb', line 78122

def update!(**args)
  @port = args[:port] if args.key?(:port)
  @port_name = args[:port_name] if args.key?(:port_name)
  @request = args[:request] if args.key?(:request)
  @response = args[:response] if args.key?(:response)
end