Class: Google::Apis::ComputeAlpha::UpcomingMaintenance

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Upcoming Maintenance notification information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UpcomingMaintenance

Returns a new instance of UpcomingMaintenance.



81784
81785
81786
# File 'lib/google/apis/compute_alpha/classes.rb', line 81784

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#can_rescheduleBoolean Also known as: can_reschedule?

Indicates if the maintenance can be customer triggered. Corresponds to the JSON property canReschedule

Returns:

  • (Boolean)


81716
81717
81718
# File 'lib/google/apis/compute_alpha/classes.rb', line 81716

def can_reschedule
  @can_reschedule
end

#dateString

[Output Only] The date when the maintenance will take place. This value is inRFC3339 text format. DEPRECATED: Use window_start_time instead. Corresponds to the JSON property date

Returns:

  • (String)


81725
81726
81727
# File 'lib/google/apis/compute_alpha/classes.rb', line 81725

def date
  @date
end

#latest_window_start_timeString

The latest time for the planned maintenance window to start. This timestamp value is in RFC3339 text format. Corresponds to the JSON property latestWindowStartTime

Returns:

  • (String)


81731
81732
81733
# File 'lib/google/apis/compute_alpha/classes.rb', line 81731

def latest_window_start_time
  @latest_window_start_time
end

#maintenance_methodString

Output only. Maintenance method for the upcoming maintenance. Corresponds to the JSON property maintenanceMethod

Returns:

  • (String)


81736
81737
81738
# File 'lib/google/apis/compute_alpha/classes.rb', line 81736

def maintenance_method
  @maintenance_method
end

#maintenance_on_shutdownBoolean Also known as: maintenance_on_shutdown?

Indicates whether the UpcomingMaintenance will be triggered on VM shutdown. Corresponds to the JSON property maintenanceOnShutdown

Returns:

  • (Boolean)


81741
81742
81743
# File 'lib/google/apis/compute_alpha/classes.rb', line 81741

def maintenance_on_shutdown
  @maintenance_on_shutdown
end

#maintenance_reasonsArray<String>

The reasons for the maintenance. Only valid for vms. Corresponds to the JSON property maintenanceReasons

Returns:

  • (Array<String>)


81747
81748
81749
# File 'lib/google/apis/compute_alpha/classes.rb', line 81747

def maintenance_reasons
  @maintenance_reasons
end

#maintenance_statusString

Corresponds to the JSON property maintenanceStatus

Returns:

  • (String)


81752
81753
81754
# File 'lib/google/apis/compute_alpha/classes.rb', line 81752

def maintenance_status
  @maintenance_status
end

#start_time_windowGoogle::Apis::ComputeAlpha::UpcomingMaintenanceTimeWindow

Represents a window of time using two timestamps: earliest and latest. Corresponds to the JSON property startTimeWindow



81757
81758
81759
# File 'lib/google/apis/compute_alpha/classes.rb', line 81757

def start_time_window
  @start_time_window
end

#timeString

[Output Only] The time when the maintenance will take place. This value is inRFC3339 text format. DEPRECATED: Use window_start_time instead. Corresponds to the JSON property time

Returns:

  • (String)


81765
81766
81767
# File 'lib/google/apis/compute_alpha/classes.rb', line 81765

def time
  @time
end

#typeString

Defines the type of maintenance. Corresponds to the JSON property type

Returns:

  • (String)


81770
81771
81772
# File 'lib/google/apis/compute_alpha/classes.rb', line 81770

def type
  @type
end

#window_end_timeString

The time by which the maintenance disruption will be completed. This timestamp value is in RFC3339 text format. Corresponds to the JSON property windowEndTime

Returns:

  • (String)


81776
81777
81778
# File 'lib/google/apis/compute_alpha/classes.rb', line 81776

def window_end_time
  @window_end_time
end

#window_start_timeString

The current start time of the maintenance window. This timestamp value is in RFC3339 text format. Corresponds to the JSON property windowStartTime

Returns:

  • (String)


81782
81783
81784
# File 'lib/google/apis/compute_alpha/classes.rb', line 81782

def window_start_time
  @window_start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



81789
81790
81791
81792
81793
81794
81795
81796
81797
81798
81799
81800
81801
81802
# File 'lib/google/apis/compute_alpha/classes.rb', line 81789

def update!(**args)
  @can_reschedule = args[:can_reschedule] if args.key?(:can_reschedule)
  @date = args[:date] if args.key?(:date)
  @latest_window_start_time = args[:latest_window_start_time] if args.key?(:latest_window_start_time)
  @maintenance_method = args[:maintenance_method] if args.key?(:maintenance_method)
  @maintenance_on_shutdown = args[:maintenance_on_shutdown] if args.key?(:maintenance_on_shutdown)
  @maintenance_reasons = args[:maintenance_reasons] if args.key?(:maintenance_reasons)
  @maintenance_status = args[:maintenance_status] if args.key?(:maintenance_status)
  @start_time_window = args[:start_time_window] if args.key?(:start_time_window)
  @time = args[:time] if args.key?(:time)
  @type = args[:type] if args.key?(:type)
  @window_end_time = args[:window_end_time] if args.key?(:window_end_time)
  @window_start_time = args[:window_start_time] if args.key?(:window_start_time)
end