Class: Google::Apis::ComputeAlpha::UpcomingMaintenance
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::UpcomingMaintenance
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Upcoming Maintenance notification information.
Instance Attribute Summary collapse
-
#can_reschedule ⇒ Boolean
(also: #can_reschedule?)
Indicates if the maintenance can be customer triggered.
-
#date ⇒ String
[Output Only] The date when the maintenance will take place.
-
#latest_window_start_time ⇒ String
The latest time for the planned maintenance window to start.
-
#maintenance_method ⇒ String
Output only.
-
#maintenance_on_shutdown ⇒ Boolean
(also: #maintenance_on_shutdown?)
Indicates whether the UpcomingMaintenance will be triggered on VM shutdown.
-
#maintenance_reasons ⇒ Array<String>
The reasons for the maintenance.
-
#maintenance_status ⇒ String
Corresponds to the JSON property
maintenanceStatus. -
#start_time_window ⇒ Google::Apis::ComputeAlpha::UpcomingMaintenanceTimeWindow
Represents a window of time using two timestamps:
earliestandlatest. -
#time ⇒ String
[Output Only] The time when the maintenance will take place.
-
#type ⇒ String
Defines the type of maintenance.
-
#window_end_time ⇒ String
The time by which the maintenance disruption will be completed.
-
#window_start_time ⇒ String
The current start time of the maintenance window.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UpcomingMaintenance
constructor
A new instance of UpcomingMaintenance.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UpcomingMaintenance
Returns a new instance of UpcomingMaintenance.
80053 80054 80055 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 80053 def initialize(**args) update!(**args) end |
Instance Attribute Details
#can_reschedule ⇒ Boolean Also known as: can_reschedule?
Indicates if the maintenance can be customer triggered.
Corresponds to the JSON property canReschedule
79985 79986 79987 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 79985 def can_reschedule @can_reschedule end |
#date ⇒ String
[Output Only] The date when the maintenance will take place.
This value is inRFC3339
text format.
DEPRECATED: Use window_start_time instead.
Corresponds to the JSON property date
79994 79995 79996 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 79994 def date @date end |
#latest_window_start_time ⇒ String
The latest time for the planned maintenance window to start.
This timestamp value is in RFC3339 text format.
Corresponds to the JSON property latestWindowStartTime
80000 80001 80002 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 80000 def latest_window_start_time @latest_window_start_time end |
#maintenance_method ⇒ String
Output only. Maintenance method for the upcoming maintenance.
Corresponds to the JSON property maintenanceMethod
80005 80006 80007 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 80005 def maintenance_method @maintenance_method end |
#maintenance_on_shutdown ⇒ Boolean Also known as: maintenance_on_shutdown?
Indicates whether the UpcomingMaintenance will be triggered on VM shutdown.
Corresponds to the JSON property maintenanceOnShutdown
80010 80011 80012 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 80010 def maintenance_on_shutdown @maintenance_on_shutdown end |
#maintenance_reasons ⇒ Array<String>
The reasons for the maintenance. Only valid for vms.
Corresponds to the JSON property maintenanceReasons
80016 80017 80018 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 80016 def maintenance_reasons @maintenance_reasons end |
#maintenance_status ⇒ String
Corresponds to the JSON property maintenanceStatus
80021 80022 80023 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 80021 def maintenance_status @maintenance_status end |
#start_time_window ⇒ Google::Apis::ComputeAlpha::UpcomingMaintenanceTimeWindow
Represents a window of time using two timestamps: earliest and latest.
Corresponds to the JSON property startTimeWindow
80026 80027 80028 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 80026 def start_time_window @start_time_window end |
#time ⇒ String
[Output Only] The time when the maintenance will take place.
This value is inRFC3339
text format.
DEPRECATED: Use window_start_time instead.
Corresponds to the JSON property time
80034 80035 80036 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 80034 def time @time end |
#type ⇒ String
Defines the type of maintenance.
Corresponds to the JSON property type
80039 80040 80041 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 80039 def type @type end |
#window_end_time ⇒ String
The time by which the maintenance disruption will be completed.
This timestamp value is in RFC3339 text format.
Corresponds to the JSON property windowEndTime
80045 80046 80047 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 80045 def window_end_time @window_end_time end |
#window_start_time ⇒ String
The current start time of the maintenance window.
This timestamp value is in RFC3339 text format.
Corresponds to the JSON property windowStartTime
80051 80052 80053 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 80051 def window_start_time @window_start_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
80058 80059 80060 80061 80062 80063 80064 80065 80066 80067 80068 80069 80070 80071 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 80058 def update!(**args) @can_reschedule = args[:can_reschedule] if args.key?(:can_reschedule) @date = args[:date] if args.key?(:date) @latest_window_start_time = args[:latest_window_start_time] if args.key?(:latest_window_start_time) @maintenance_method = args[:maintenance_method] if args.key?(:maintenance_method) @maintenance_on_shutdown = args[:maintenance_on_shutdown] if args.key?(:maintenance_on_shutdown) @maintenance_reasons = args[:maintenance_reasons] if args.key?(:maintenance_reasons) @maintenance_status = args[:maintenance_status] if args.key?(:maintenance_status) @start_time_window = args[:start_time_window] if args.key?(:start_time_window) @time = args[:time] if args.key?(:time) @type = args[:type] if args.key?(:type) @window_end_time = args[:window_end_time] if args.key?(:window_end_time) @window_start_time = args[:window_start_time] if args.key?(:window_start_time) end |