Class: Google::Apis::ComputeAlpha::UpcomingMaintenance
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::UpcomingMaintenance
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Upcoming Maintenance notification information.
Instance Attribute Summary collapse
-
#can_reschedule ⇒ Boolean
(also: #can_reschedule?)
Indicates if the maintenance can be customer triggered.
-
#date ⇒ String
[Output Only] The date when the maintenance will take place.
-
#latest_window_start_time ⇒ String
The latest time for the planned maintenance window to start.
-
#maintenance_method ⇒ String
Output only.
-
#maintenance_on_shutdown ⇒ Boolean
(also: #maintenance_on_shutdown?)
Indicates whether the UpcomingMaintenance will be triggered on VM shutdown.
-
#maintenance_reasons ⇒ Array<String>
The reasons for the maintenance.
-
#maintenance_status ⇒ String
Corresponds to the JSON property
maintenanceStatus. -
#start_time_window ⇒ Google::Apis::ComputeAlpha::UpcomingMaintenanceTimeWindow
Represents a window of time using two timestamps:
earliestandlatest. -
#time ⇒ String
[Output Only] The time when the maintenance will take place.
-
#type ⇒ String
Defines the type of maintenance.
-
#window_end_time ⇒ String
The time by which the maintenance disruption will be completed.
-
#window_start_time ⇒ String
The current start time of the maintenance window.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UpcomingMaintenance
constructor
A new instance of UpcomingMaintenance.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UpcomingMaintenance
Returns a new instance of UpcomingMaintenance.
79178 79179 79180 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 79178 def initialize(**args) update!(**args) end |
Instance Attribute Details
#can_reschedule ⇒ Boolean Also known as: can_reschedule?
Indicates if the maintenance can be customer triggered.
Corresponds to the JSON property canReschedule
79110 79111 79112 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 79110 def can_reschedule @can_reschedule end |
#date ⇒ String
[Output Only] The date when the maintenance will take place.
This value is inRFC3339
text format.
DEPRECATED: Use window_start_time instead.
Corresponds to the JSON property date
79119 79120 79121 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 79119 def date @date end |
#latest_window_start_time ⇒ String
The latest time for the planned maintenance window to start.
This timestamp value is in RFC3339 text format.
Corresponds to the JSON property latestWindowStartTime
79125 79126 79127 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 79125 def latest_window_start_time @latest_window_start_time end |
#maintenance_method ⇒ String
Output only. Maintenance method for the upcoming maintenance.
Corresponds to the JSON property maintenanceMethod
79130 79131 79132 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 79130 def maintenance_method @maintenance_method end |
#maintenance_on_shutdown ⇒ Boolean Also known as: maintenance_on_shutdown?
Indicates whether the UpcomingMaintenance will be triggered on VM shutdown.
Corresponds to the JSON property maintenanceOnShutdown
79135 79136 79137 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 79135 def maintenance_on_shutdown @maintenance_on_shutdown end |
#maintenance_reasons ⇒ Array<String>
The reasons for the maintenance. Only valid for vms.
Corresponds to the JSON property maintenanceReasons
79141 79142 79143 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 79141 def maintenance_reasons @maintenance_reasons end |
#maintenance_status ⇒ String
Corresponds to the JSON property maintenanceStatus
79146 79147 79148 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 79146 def maintenance_status @maintenance_status end |
#start_time_window ⇒ Google::Apis::ComputeAlpha::UpcomingMaintenanceTimeWindow
Represents a window of time using two timestamps: earliest and latest.
Corresponds to the JSON property startTimeWindow
79151 79152 79153 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 79151 def start_time_window @start_time_window end |
#time ⇒ String
[Output Only] The time when the maintenance will take place.
This value is inRFC3339
text format.
DEPRECATED: Use window_start_time instead.
Corresponds to the JSON property time
79159 79160 79161 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 79159 def time @time end |
#type ⇒ String
Defines the type of maintenance.
Corresponds to the JSON property type
79164 79165 79166 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 79164 def type @type end |
#window_end_time ⇒ String
The time by which the maintenance disruption will be completed.
This timestamp value is in RFC3339 text format.
Corresponds to the JSON property windowEndTime
79170 79171 79172 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 79170 def window_end_time @window_end_time end |
#window_start_time ⇒ String
The current start time of the maintenance window.
This timestamp value is in RFC3339 text format.
Corresponds to the JSON property windowStartTime
79176 79177 79178 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 79176 def window_start_time @window_start_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
79183 79184 79185 79186 79187 79188 79189 79190 79191 79192 79193 79194 79195 79196 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 79183 def update!(**args) @can_reschedule = args[:can_reschedule] if args.key?(:can_reschedule) @date = args[:date] if args.key?(:date) @latest_window_start_time = args[:latest_window_start_time] if args.key?(:latest_window_start_time) @maintenance_method = args[:maintenance_method] if args.key?(:maintenance_method) @maintenance_on_shutdown = args[:maintenance_on_shutdown] if args.key?(:maintenance_on_shutdown) @maintenance_reasons = args[:maintenance_reasons] if args.key?(:maintenance_reasons) @maintenance_status = args[:maintenance_status] if args.key?(:maintenance_status) @start_time_window = args[:start_time_window] if args.key?(:start_time_window) @time = args[:time] if args.key?(:time) @type = args[:type] if args.key?(:type) @window_end_time = args[:window_end_time] if args.key?(:window_end_time) @window_start_time = args[:window_start_time] if args.key?(:window_start_time) end |