Class: Google::Apis::ComputeAlpha::UrlMap

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Represents a URL Map resource. Compute Engine has two URL Map resources:

  • Global
  • Regional A URL map resource is a component of certain types of cloud load balancers and Traffic Director:
  • urlMaps are used by global external Application Load Balancers, classic Application Load Balancers, and cross-region internal Application Load Balancers.
  • regionUrlMaps are used by internal Application Load Balancers, regional external Application Load Balancers and regional internal Application Load Balancers. For a list of supported URL map features by the load balancer type, see the Load balancing features: Routing and traffic management table. For a list of supported URL map features for Traffic Director, see the Traffic Director features: Routing and traffic management table. This resource defines mappings from hostnames and URL paths to either a backend service or a backend bucket. To use the global urlMaps resource, the backend service must have a loadBalancingScheme of either EXTERNAL,EXTERNAL_MANAGED, or INTERNAL_SELF_MANAGED. To use the regionUrlMaps resource, the backend service must have aloadBalancingScheme of INTERNAL_MANAGED. For more information, read URL Map Concepts.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UrlMap

Returns a new instance of UrlMap.



81989
81990
81991
# File 'lib/google/apis/compute_alpha/classes.rb', line 81989

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


81862
81863
81864
# File 'lib/google/apis/compute_alpha/classes.rb', line 81862

def creation_timestamp
  @creation_timestamp
end

#default_custom_error_response_policyGoogle::Apis::ComputeAlpha::CustomErrorResponsePolicy

Specifies the custom error response policy that must be applied when the backend service or backend bucket responds with an error. Corresponds to the JSON property defaultCustomErrorResponsePolicy



81868
81869
81870
# File 'lib/google/apis/compute_alpha/classes.rb', line 81868

def default_custom_error_response_policy
  @default_custom_error_response_policy
end

#default_route_actionGoogle::Apis::ComputeAlpha::HttpRouteAction

defaultRouteAction takes effect when none of the hostRules match. The load balancer performs advanced routing actions, such as URL rewrites and header transformations, before forwarding the request to the selected backend. Only one of defaultUrlRedirect, defaultService or defaultRouteAction.weightedBackendService can be set. URL maps for classic Application Load Balancers only support the urlRewrite action within defaultRouteAction. defaultRouteAction has no effect when the URL map is bound to a target gRPC proxy that has the validateForProxyless field set to true. Corresponds to the JSON property defaultRouteAction



81883
81884
81885
# File 'lib/google/apis/compute_alpha/classes.rb', line 81883

def default_route_action
  @default_route_action
end

#default_serviceString

The full or partial URL of the defaultService resource to which traffic is directed if none of the hostRules match. If defaultRouteAction is also specified, advanced routing actions, such as URL rewrites, take effect before sending the request to the backend. Only one of defaultUrlRedirect, defaultService or defaultRouteAction.weightedBackendService can be set. defaultService has no effect when the URL map is bound to a target gRPC proxy that has the validateForProxyless field set to true. Corresponds to the JSON property defaultService

Returns:

  • (String)


81897
81898
81899
# File 'lib/google/apis/compute_alpha/classes.rb', line 81897

def default_service
  @default_service
end

#default_url_redirectGoogle::Apis::ComputeAlpha::HttpRedirectAction

Specifies settings for an HTTP redirect. Corresponds to the JSON property defaultUrlRedirect



81902
81903
81904
# File 'lib/google/apis/compute_alpha/classes.rb', line 81902

def default_url_redirect
  @default_url_redirect
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


81908
81909
81910
# File 'lib/google/apis/compute_alpha/classes.rb', line 81908

def description
  @description
end

#fingerprintString

Fingerprint of this resource. A hash of the contents stored in this object. This field is used in optimistic locking. This field is ignored when inserting a UrlMap. An up-to-date fingerprint must be provided in order to update the UrlMap, otherwise the request will fail with error 412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve a UrlMap. Corresponds to the JSON property fingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


81920
81921
81922
# File 'lib/google/apis/compute_alpha/classes.rb', line 81920

def fingerprint
  @fingerprint
end

#header_actionGoogle::Apis::ComputeAlpha::HttpHeaderAction

The request and response header transformations that take effect before the request is passed along to the selected backendService. Corresponds to the JSON property headerAction



81926
81927
81928
# File 'lib/google/apis/compute_alpha/classes.rb', line 81926

def header_action
  @header_action
end

#host_rulesArray<Google::Apis::ComputeAlpha::HostRule>

The list of host rules to use against the URL. Corresponds to the JSON property hostRules



81931
81932
81933
# File 'lib/google/apis/compute_alpha/classes.rb', line 81931

def host_rules
  @host_rules
end

#idFixnum

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


81937
81938
81939
# File 'lib/google/apis/compute_alpha/classes.rb', line 81937

def id
  @id
end

#kindString

Output only. [Output Only] Type of the resource. Always compute#urlMaps for url maps. Corresponds to the JSON property kind

Returns:

  • (String)


81943
81944
81945
# File 'lib/google/apis/compute_alpha/classes.rb', line 81943

def kind
  @kind
end

#nameString

Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


81954
81955
81956
# File 'lib/google/apis/compute_alpha/classes.rb', line 81954

def name
  @name
end

#path_matchersArray<Google::Apis::ComputeAlpha::PathMatcher>

The list of named PathMatchers to use against the URL. Corresponds to the JSON property pathMatchers



81959
81960
81961
# File 'lib/google/apis/compute_alpha/classes.rb', line 81959

def path_matchers
  @path_matchers
end

#regionString

Output only. [Output Only] URL of the region where the regional URL map resides. This field is not applicable to global URL maps. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body. Corresponds to the JSON property region

Returns:

  • (String)


81968
81969
81970
# File 'lib/google/apis/compute_alpha/classes.rb', line 81968

def region
  @region
end

[Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


81973
81974
81975
# File 'lib/google/apis/compute_alpha/classes.rb', line 81973

def self_link
  @self_link
end

#statusGoogle::Apis::ComputeAlpha::UrlMapStatus

[Output Only] The status of the URL map. Corresponds to the JSON property status



81978
81979
81980
# File 'lib/google/apis/compute_alpha/classes.rb', line 81978

def status
  @status
end

#testsArray<Google::Apis::ComputeAlpha::UrlMapTest>

The list of expected URL mapping tests. Request to update theUrlMap succeeds only if all test cases pass. You can specify a maximum of 100 tests per UrlMap. Not supported when the URL map is bound to a target gRPC proxy that has validateForProxyless field set to true. Corresponds to the JSON property tests



81987
81988
81989
# File 'lib/google/apis/compute_alpha/classes.rb', line 81987

def tests
  @tests
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



81994
81995
81996
81997
81998
81999
82000
82001
82002
82003
82004
82005
82006
82007
82008
82009
82010
82011
82012
# File 'lib/google/apis/compute_alpha/classes.rb', line 81994

def update!(**args)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @default_custom_error_response_policy = args[:default_custom_error_response_policy] if args.key?(:default_custom_error_response_policy)
  @default_route_action = args[:default_route_action] if args.key?(:default_route_action)
  @default_service = args[:default_service] if args.key?(:default_service)
  @default_url_redirect = args[:default_url_redirect] if args.key?(:default_url_redirect)
  @description = args[:description] if args.key?(:description)
  @fingerprint = args[:fingerprint] if args.key?(:fingerprint)
  @header_action = args[:header_action] if args.key?(:header_action)
  @host_rules = args[:host_rules] if args.key?(:host_rules)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @path_matchers = args[:path_matchers] if args.key?(:path_matchers)
  @region = args[:region] if args.key?(:region)
  @self_link = args[:self_link] if args.key?(:self_link)
  @status = args[:status] if args.key?(:status)
  @tests = args[:tests] if args.key?(:tests)
end