Class: Google::Apis::ComputeAlpha::UrlMap

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Represents a URL Map resource. Compute Engine has two URL Map resources:

  • Global
  • Regional A URL map resource is a component of certain types of cloud load balancers and Traffic Director:
  • urlMaps are used by global external Application Load Balancers, classic Application Load Balancers, and cross-region internal Application Load Balancers.
  • regionUrlMaps are used by internal Application Load Balancers, regional external Application Load Balancers and regional internal Application Load Balancers. For a list of supported URL map features by the load balancer type, see the Load balancing features: Routing and traffic management table. For a list of supported URL map features for Traffic Director, see the Traffic Director features: Routing and traffic management table. This resource defines mappings from hostnames and URL paths to either a backend service or a backend bucket. To use the global urlMaps resource, the backend service must have a loadBalancingScheme of either EXTERNAL,EXTERNAL_MANAGED, or INTERNAL_SELF_MANAGED. To use the regionUrlMaps resource, the backend service must have aloadBalancingScheme of INTERNAL_MANAGED. For more information, read URL Map Concepts.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UrlMap

Returns a new instance of UrlMap.



79651
79652
79653
# File 'lib/google/apis/compute_alpha/classes.rb', line 79651

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


79524
79525
79526
# File 'lib/google/apis/compute_alpha/classes.rb', line 79524

def creation_timestamp
  @creation_timestamp
end

#default_custom_error_response_policyGoogle::Apis::ComputeAlpha::CustomErrorResponsePolicy

Specifies the custom error response policy that must be applied when the backend service or backend bucket responds with an error. Corresponds to the JSON property defaultCustomErrorResponsePolicy



79530
79531
79532
# File 'lib/google/apis/compute_alpha/classes.rb', line 79530

def default_custom_error_response_policy
  @default_custom_error_response_policy
end

#default_route_actionGoogle::Apis::ComputeAlpha::HttpRouteAction

defaultRouteAction takes effect when none of the hostRules match. The load balancer performs advanced routing actions, such as URL rewrites and header transformations, before forwarding the request to the selected backend. Only one of defaultUrlRedirect, defaultService or defaultRouteAction.weightedBackendService can be set. URL maps for classic Application Load Balancers only support the urlRewrite action within defaultRouteAction. defaultRouteAction has no effect when the URL map is bound to a target gRPC proxy that has the validateForProxyless field set to true. Corresponds to the JSON property defaultRouteAction



79545
79546
79547
# File 'lib/google/apis/compute_alpha/classes.rb', line 79545

def default_route_action
  @default_route_action
end

#default_serviceString

The full or partial URL of the defaultService resource to which traffic is directed if none of the hostRules match. If defaultRouteAction is also specified, advanced routing actions, such as URL rewrites, take effect before sending the request to the backend. Only one of defaultUrlRedirect, defaultService or defaultRouteAction.weightedBackendService can be set. defaultService has no effect when the URL map is bound to a target gRPC proxy that has the validateForProxyless field set to true. Corresponds to the JSON property defaultService

Returns:

  • (String)


79559
79560
79561
# File 'lib/google/apis/compute_alpha/classes.rb', line 79559

def default_service
  @default_service
end

#default_url_redirectGoogle::Apis::ComputeAlpha::HttpRedirectAction

Specifies settings for an HTTP redirect. Corresponds to the JSON property defaultUrlRedirect



79564
79565
79566
# File 'lib/google/apis/compute_alpha/classes.rb', line 79564

def default_url_redirect
  @default_url_redirect
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


79570
79571
79572
# File 'lib/google/apis/compute_alpha/classes.rb', line 79570

def description
  @description
end

#fingerprintString

Fingerprint of this resource. A hash of the contents stored in this object. This field is used in optimistic locking. This field is ignored when inserting a UrlMap. An up-to-date fingerprint must be provided in order to update the UrlMap, otherwise the request will fail with error 412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve a UrlMap. Corresponds to the JSON property fingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


79582
79583
79584
# File 'lib/google/apis/compute_alpha/classes.rb', line 79582

def fingerprint
  @fingerprint
end

#header_actionGoogle::Apis::ComputeAlpha::HttpHeaderAction

The request and response header transformations that take effect before the request is passed along to the selected backendService. Corresponds to the JSON property headerAction



79588
79589
79590
# File 'lib/google/apis/compute_alpha/classes.rb', line 79588

def header_action
  @header_action
end

#host_rulesArray<Google::Apis::ComputeAlpha::HostRule>

The list of host rules to use against the URL. Corresponds to the JSON property hostRules



79593
79594
79595
# File 'lib/google/apis/compute_alpha/classes.rb', line 79593

def host_rules
  @host_rules
end

#idFixnum

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


79599
79600
79601
# File 'lib/google/apis/compute_alpha/classes.rb', line 79599

def id
  @id
end

#kindString

Output only. [Output Only] Type of the resource. Always compute#urlMaps for url maps. Corresponds to the JSON property kind

Returns:

  • (String)


79605
79606
79607
# File 'lib/google/apis/compute_alpha/classes.rb', line 79605

def kind
  @kind
end

#nameString

Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


79616
79617
79618
# File 'lib/google/apis/compute_alpha/classes.rb', line 79616

def name
  @name
end

#path_matchersArray<Google::Apis::ComputeAlpha::PathMatcher>

The list of named PathMatchers to use against the URL. Corresponds to the JSON property pathMatchers



79621
79622
79623
# File 'lib/google/apis/compute_alpha/classes.rb', line 79621

def path_matchers
  @path_matchers
end

#regionString

Output only. [Output Only] URL of the region where the regional URL map resides. This field is not applicable to global URL maps. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body. Corresponds to the JSON property region

Returns:

  • (String)


79630
79631
79632
# File 'lib/google/apis/compute_alpha/classes.rb', line 79630

def region
  @region
end

[Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


79635
79636
79637
# File 'lib/google/apis/compute_alpha/classes.rb', line 79635

def self_link
  @self_link
end

#statusGoogle::Apis::ComputeAlpha::UrlMapStatus

[Output Only] The status of the URL map. Corresponds to the JSON property status



79640
79641
79642
# File 'lib/google/apis/compute_alpha/classes.rb', line 79640

def status
  @status
end

#testsArray<Google::Apis::ComputeAlpha::UrlMapTest>

The list of expected URL mapping tests. Request to update theUrlMap succeeds only if all test cases pass. You can specify a maximum of 100 tests per UrlMap. Not supported when the URL map is bound to a target gRPC proxy that has validateForProxyless field set to true. Corresponds to the JSON property tests



79649
79650
79651
# File 'lib/google/apis/compute_alpha/classes.rb', line 79649

def tests
  @tests
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



79656
79657
79658
79659
79660
79661
79662
79663
79664
79665
79666
79667
79668
79669
79670
79671
79672
79673
79674
# File 'lib/google/apis/compute_alpha/classes.rb', line 79656

def update!(**args)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @default_custom_error_response_policy = args[:default_custom_error_response_policy] if args.key?(:default_custom_error_response_policy)
  @default_route_action = args[:default_route_action] if args.key?(:default_route_action)
  @default_service = args[:default_service] if args.key?(:default_service)
  @default_url_redirect = args[:default_url_redirect] if args.key?(:default_url_redirect)
  @description = args[:description] if args.key?(:description)
  @fingerprint = args[:fingerprint] if args.key?(:fingerprint)
  @header_action = args[:header_action] if args.key?(:header_action)
  @host_rules = args[:host_rules] if args.key?(:host_rules)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @path_matchers = args[:path_matchers] if args.key?(:path_matchers)
  @region = args[:region] if args.key?(:region)
  @self_link = args[:self_link] if args.key?(:self_link)
  @status = args[:status] if args.key?(:status)
  @tests = args[:tests] if args.key?(:tests)
end