Class: Google::Apis::ComputeAlpha::UrlMapList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::UrlMapList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Contains a list of UrlMap resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::UrlMap>
A list of UrlMap resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::UrlMapList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UrlMapList
constructor
A new instance of UrlMapList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UrlMapList
Returns a new instance of UrlMapList.
82331 82332 82333 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 82331 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
82299 82300 82301 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 82299 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::UrlMap>
A list of UrlMap resources.
Corresponds to the JSON property items
82304 82305 82306 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 82304 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
82309 82310 82311 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 82309 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
82319 82320 82321 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 82319 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
82324 82325 82326 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 82324 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::UrlMapList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
82329 82330 82331 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 82329 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
82336 82337 82338 82339 82340 82341 82342 82343 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 82336 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |