Class: Google::Apis::ComputeAlpha::UrlMapList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of UrlMap resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UrlMapList

Returns a new instance of UrlMapList.



81748
81749
81750
# File 'lib/google/apis/compute_alpha/classes.rb', line 81748

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


81716
81717
81718
# File 'lib/google/apis/compute_alpha/classes.rb', line 81716

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::UrlMap>

A list of UrlMap resources. Corresponds to the JSON property items



81721
81722
81723
# File 'lib/google/apis/compute_alpha/classes.rb', line 81721

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


81726
81727
81728
# File 'lib/google/apis/compute_alpha/classes.rb', line 81726

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


81736
81737
81738
# File 'lib/google/apis/compute_alpha/classes.rb', line 81736

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


81741
81742
81743
# File 'lib/google/apis/compute_alpha/classes.rb', line 81741

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::UrlMapList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



81746
81747
81748
# File 'lib/google/apis/compute_alpha/classes.rb', line 81746

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



81753
81754
81755
81756
81757
81758
81759
81760
# File 'lib/google/apis/compute_alpha/classes.rb', line 81753

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end