Class: Google::Apis::ComputeAlpha::UrlMapList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of UrlMap resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UrlMapList

Returns a new instance of UrlMapList.



80380
80381
80382
# File 'lib/google/apis/compute_alpha/classes.rb', line 80380

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


80348
80349
80350
# File 'lib/google/apis/compute_alpha/classes.rb', line 80348

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::UrlMap>

A list of UrlMap resources. Corresponds to the JSON property items



80353
80354
80355
# File 'lib/google/apis/compute_alpha/classes.rb', line 80353

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


80358
80359
80360
# File 'lib/google/apis/compute_alpha/classes.rb', line 80358

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


80368
80369
80370
# File 'lib/google/apis/compute_alpha/classes.rb', line 80368

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


80373
80374
80375
# File 'lib/google/apis/compute_alpha/classes.rb', line 80373

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::UrlMapList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



80378
80379
80380
# File 'lib/google/apis/compute_alpha/classes.rb', line 80378

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



80385
80386
80387
80388
80389
80390
80391
80392
# File 'lib/google/apis/compute_alpha/classes.rb', line 80385

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end