Class: Google::Apis::ComputeAlpha::UrlMapList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::UrlMapList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Contains a list of UrlMap resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::UrlMap>
A list of UrlMap resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::UrlMapList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UrlMapList
constructor
A new instance of UrlMapList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UrlMapList
Returns a new instance of UrlMapList.
80323 80324 80325 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 80323 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
80291 80292 80293 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 80291 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::UrlMap>
A list of UrlMap resources.
Corresponds to the JSON property items
80296 80297 80298 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 80296 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
80301 80302 80303 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 80301 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
80311 80312 80313 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 80311 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
80316 80317 80318 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 80316 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::UrlMapList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
80321 80322 80323 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 80321 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
80328 80329 80330 80331 80332 80333 80334 80335 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 80328 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |