Class: Google::Apis::ComputeAlpha::UrlMapList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of UrlMap resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UrlMapList

Returns a new instance of UrlMapList.



79714
79715
79716
# File 'lib/google/apis/compute_alpha/classes.rb', line 79714

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


79682
79683
79684
# File 'lib/google/apis/compute_alpha/classes.rb', line 79682

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::UrlMap>

A list of UrlMap resources. Corresponds to the JSON property items



79687
79688
79689
# File 'lib/google/apis/compute_alpha/classes.rb', line 79687

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


79692
79693
79694
# File 'lib/google/apis/compute_alpha/classes.rb', line 79692

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


79702
79703
79704
# File 'lib/google/apis/compute_alpha/classes.rb', line 79702

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


79707
79708
79709
# File 'lib/google/apis/compute_alpha/classes.rb', line 79707

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::UrlMapList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



79712
79713
79714
# File 'lib/google/apis/compute_alpha/classes.rb', line 79712

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



79719
79720
79721
79722
79723
79724
79725
79726
# File 'lib/google/apis/compute_alpha/classes.rb', line 79719

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end