Class: Google::Apis::ComputeAlpha::UrlMapQuotaUsage

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Message representing the quota usage for a UrlMap.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UrlMapQuotaUsage

Returns a new instance of UrlMapQuotaUsage.



79813
79814
79815
# File 'lib/google/apis/compute_alpha/classes.rb', line 79813

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#forwarding_rulesFixnum

Output only. The number of forwarding rules that uses this UrlMap. Corresponds to the JSON property forwardingRules

Returns:

  • (Fixnum)


79806
79807
79808
# File 'lib/google/apis/compute_alpha/classes.rb', line 79806

def forwarding_rules
  @forwarding_rules
end

#unitsFixnum

Output only. The number of quota units calculated for this UrlMap. Corresponds to the JSON property units

Returns:

  • (Fixnum)


79811
79812
79813
# File 'lib/google/apis/compute_alpha/classes.rb', line 79811

def units
  @units
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



79818
79819
79820
79821
# File 'lib/google/apis/compute_alpha/classes.rb', line 79818

def update!(**args)
  @forwarding_rules = args[:forwarding_rules] if args.key?(:forwarding_rules)
  @units = args[:units] if args.key?(:units)
end