Class: Google::Apis::ComputeAlpha::UrlMapQuotaUsage
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::UrlMapQuotaUsage
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Message representing the quota usage for a UrlMap.
Instance Attribute Summary collapse
-
#forwarding_rules ⇒ Fixnum
Output only.
-
#units ⇒ Fixnum
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UrlMapQuotaUsage
constructor
A new instance of UrlMapQuotaUsage.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UrlMapQuotaUsage
Returns a new instance of UrlMapQuotaUsage.
79547 79548 79549 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 79547 def initialize(**args) update!(**args) end |
Instance Attribute Details
#forwarding_rules ⇒ Fixnum
Output only. The number of forwarding rules that uses this UrlMap.
Corresponds to the JSON property forwardingRules
79540 79541 79542 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 79540 def forwarding_rules @forwarding_rules end |
#units ⇒ Fixnum
Output only. The number of quota units calculated for this UrlMap.
Corresponds to the JSON property units
79545 79546 79547 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 79545 def units @units end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
79552 79553 79554 79555 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 79552 def update!(**args) @forwarding_rules = args[:forwarding_rules] if args.key?(:forwarding_rules) @units = args[:units] if args.key?(:units) end |