Class: Google::Apis::ComputeAlpha::UrlMapTest
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::UrlMapTest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Message for the expected URL mappings.
Instance Attribute Summary collapse
-
#backend_service_weight ⇒ Fixnum
The weight to use for the supplied host and path when using advanced routing rules that involve traffic splitting.
-
#description ⇒ String
Description of this test case.
-
#expected_output_url ⇒ String
The expected output URL evaluated by the load balancer containing the scheme, host, path and query parameters.
-
#expected_redirect_response_code ⇒ Fixnum
For rules with urlRedirect, the test passes only ifexpectedRedirectResponseCode matches the HTTP status code in load balancer's redirect response.
-
#expected_url_redirect ⇒ String
The expected URL that should be redirected to for the host and path being tested.
-
#headers ⇒ Array<Google::Apis::ComputeAlpha::UrlMapTestHeader>
HTTP headers for this request.
-
#host ⇒ String
Host portion of the URL.
-
#path ⇒ String
Path portion of the URL.
-
#service ⇒ String
Expected BackendService or BackendBucket resource the given URL should be mapped to.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UrlMapTest
constructor
A new instance of UrlMapTest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UrlMapTest
Returns a new instance of UrlMapTest.
82555 82556 82557 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 82555 def initialize(**args) update!(**args) end |
Instance Attribute Details
#backend_service_weight ⇒ Fixnum
The weight to use for the supplied host and path when using advanced
routing rules that involve traffic splitting.
Corresponds to the JSON property backendServiceWeight
82487 82488 82489 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 82487 def backend_service_weight @backend_service_weight end |
#description ⇒ String
Description of this test case.
Corresponds to the JSON property description
82492 82493 82494 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 82492 def description @description end |
#expected_output_url ⇒ String
The expected output URL evaluated by the load balancer
containing the scheme, host, path and query parameters.
For rules that forward requests to backends, the test passes only
whenexpectedOutputUrl matches the request forwarded by
the load balancer to backends. For rules with urlRewrite,
the test verifies that the forwarded request matcheshostRewrite and
pathPrefixRewrite in theurlRewrite action. When service is specified,
expectedOutputUrls scheme is ignored.
For rules with urlRedirect, the test passes only ifexpectedOutputUrl matches
the URL in the load balancer's
redirect response. If urlRedirect specifieshttps_redirect, the test passes
only if the scheme inexpectedOutputUrl is also set to HTTPS.
If urlRedirect specifies strip_query, the test
passes only if expectedOutputUrl does not contain any query
parameters.
expectedOutputUrl is optional whenservice is specified.
Corresponds to the JSON propertyexpectedOutputUrl`
82512 82513 82514 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 82512 def expected_output_url @expected_output_url end |
#expected_redirect_response_code ⇒ Fixnum
For rules with urlRedirect, the test passes only
ifexpectedRedirectResponseCode matches the HTTP status code in
load balancer's redirect response.
expectedRedirectResponseCode cannot be set whenservice is set.
Corresponds to the JSON property expectedRedirectResponseCode
82520 82521 82522 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 82520 def expected_redirect_response_code @expected_redirect_response_code end |
#expected_url_redirect ⇒ String
The expected URL that should be redirected to for the host and path
being tested.
[Deprecated] This field is deprecated.
Use expected_output_url instead.
Corresponds to the JSON property expectedUrlRedirect
82528 82529 82530 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 82528 def expected_url_redirect @expected_url_redirect end |
#headers ⇒ Array<Google::Apis::ComputeAlpha::UrlMapTestHeader>
HTTP headers for this request. If headers contains
a host header, then host must also match the header value.
Corresponds to the JSON property headers
82534 82535 82536 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 82534 def headers @headers end |
#host ⇒ String
Host portion of the URL. If headers contains a host header,
then host must also match the header value.
Corresponds to the JSON property host
82540 82541 82542 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 82540 def host @host end |
#path ⇒ String
Path portion of the URL.
Corresponds to the JSON property path
82545 82546 82547 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 82545 def path @path end |
#service ⇒ String
Expected BackendService or BackendBucket resource
the given URL should be mapped to.
The service field cannot
be set if expectedRedirectResponseCode is set.
Corresponds to the JSON property service
82553 82554 82555 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 82553 def service @service end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
82560 82561 82562 82563 82564 82565 82566 82567 82568 82569 82570 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 82560 def update!(**args) @backend_service_weight = args[:backend_service_weight] if args.key?(:backend_service_weight) @description = args[:description] if args.key?(:description) @expected_output_url = args[:expected_output_url] if args.key?(:expected_output_url) @expected_redirect_response_code = args[:expected_redirect_response_code] if args.key?(:expected_redirect_response_code) @expected_url_redirect = args[:expected_url_redirect] if args.key?(:expected_url_redirect) @headers = args[:headers] if args.key?(:headers) @host = args[:host] if args.key?(:host) @path = args[:path] if args.key?(:path) @service = args[:service] if args.key?(:service) end |