Class: Google::Apis::ComputeAlpha::UrlMapTest
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::UrlMapTest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Message for the expected URL mappings.
Instance Attribute Summary collapse
-
#backend_service_weight ⇒ Fixnum
The weight to use for the supplied host and path when using advanced routing rules that involve traffic splitting.
-
#description ⇒ String
Description of this test case.
-
#expected_output_url ⇒ String
The expected output URL evaluated by the load balancer containing the scheme, host, path and query parameters.
-
#expected_redirect_response_code ⇒ Fixnum
For rules with urlRedirect, the test passes only ifexpectedRedirectResponseCode matches the HTTP status code in load balancer's redirect response.
-
#expected_url_redirect ⇒ String
The expected URL that should be redirected to for the host and path being tested.
-
#headers ⇒ Array<Google::Apis::ComputeAlpha::UrlMapTestHeader>
HTTP headers for this request.
-
#host ⇒ String
Host portion of the URL.
-
#path ⇒ String
Path portion of the URL.
-
#service ⇒ String
Expected BackendService or BackendBucket resource the given URL should be mapped to.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UrlMapTest
constructor
A new instance of UrlMapTest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UrlMapTest
Returns a new instance of UrlMapTest.
79938 79939 79940 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 79938 def initialize(**args) update!(**args) end |
Instance Attribute Details
#backend_service_weight ⇒ Fixnum
The weight to use for the supplied host and path when using advanced
routing rules that involve traffic splitting.
Corresponds to the JSON property backendServiceWeight
79870 79871 79872 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 79870 def backend_service_weight @backend_service_weight end |
#description ⇒ String
Description of this test case.
Corresponds to the JSON property description
79875 79876 79877 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 79875 def description @description end |
#expected_output_url ⇒ String
The expected output URL evaluated by the load balancer
containing the scheme, host, path and query parameters.
For rules that forward requests to backends, the test passes only
whenexpectedOutputUrl matches the request forwarded by
the load balancer to backends. For rules with urlRewrite,
the test verifies that the forwarded request matcheshostRewrite and
pathPrefixRewrite in theurlRewrite action. When service is specified,
expectedOutputUrls scheme is ignored.
For rules with urlRedirect, the test passes only ifexpectedOutputUrl matches
the URL in the load balancer's
redirect response. If urlRedirect specifieshttps_redirect, the test passes
only if the scheme inexpectedOutputUrl is also set to HTTPS.
If urlRedirect specifies strip_query, the test
passes only if expectedOutputUrl does not contain any query
parameters.
expectedOutputUrl is optional whenservice is specified.
Corresponds to the JSON propertyexpectedOutputUrl`
79895 79896 79897 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 79895 def expected_output_url @expected_output_url end |
#expected_redirect_response_code ⇒ Fixnum
For rules with urlRedirect, the test passes only
ifexpectedRedirectResponseCode matches the HTTP status code in
load balancer's redirect response.
expectedRedirectResponseCode cannot be set whenservice is set.
Corresponds to the JSON property expectedRedirectResponseCode
79903 79904 79905 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 79903 def expected_redirect_response_code @expected_redirect_response_code end |
#expected_url_redirect ⇒ String
The expected URL that should be redirected to for the host and path
being tested.
[Deprecated] This field is deprecated.
Use expected_output_url instead.
Corresponds to the JSON property expectedUrlRedirect
79911 79912 79913 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 79911 def expected_url_redirect @expected_url_redirect end |
#headers ⇒ Array<Google::Apis::ComputeAlpha::UrlMapTestHeader>
HTTP headers for this request. If headers contains
a host header, then host must also match the header value.
Corresponds to the JSON property headers
79917 79918 79919 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 79917 def headers @headers end |
#host ⇒ String
Host portion of the URL. If headers contains a host header,
then host must also match the header value.
Corresponds to the JSON property host
79923 79924 79925 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 79923 def host @host end |
#path ⇒ String
Path portion of the URL.
Corresponds to the JSON property path
79928 79929 79930 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 79928 def path @path end |
#service ⇒ String
Expected BackendService or BackendBucket resource
the given URL should be mapped to.
The service field cannot
be set if expectedRedirectResponseCode is set.
Corresponds to the JSON property service
79936 79937 79938 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 79936 def service @service end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
79943 79944 79945 79946 79947 79948 79949 79950 79951 79952 79953 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 79943 def update!(**args) @backend_service_weight = args[:backend_service_weight] if args.key?(:backend_service_weight) @description = args[:description] if args.key?(:description) @expected_output_url = args[:expected_output_url] if args.key?(:expected_output_url) @expected_redirect_response_code = args[:expected_redirect_response_code] if args.key?(:expected_redirect_response_code) @expected_url_redirect = args[:expected_url_redirect] if args.key?(:expected_url_redirect) @headers = args[:headers] if args.key?(:headers) @host = args[:host] if args.key?(:host) @path = args[:path] if args.key?(:path) @service = args[:service] if args.key?(:service) end |