Class: Google::Apis::ComputeAlpha::UrlMapsAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::UrlMapsAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::UrlMapsScopedList>
A list of UrlMapsScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::UrlMapsAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UrlMapsAggregatedList
constructor
A new instance of UrlMapsAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UrlMapsAggregatedList
Returns a new instance of UrlMapsAggregatedList.
82689 82690 82691 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 82689 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
82652 82653 82654 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 82652 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::UrlMapsScopedList>
A list of UrlMapsScopedList resources.
Corresponds to the JSON property items
82657 82658 82659 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 82657 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
82662 82663 82664 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 82662 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
82672 82673 82674 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 82672 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
82677 82678 82679 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 82677 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
82682 82683 82684 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 82682 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::UrlMapsAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
82687 82688 82689 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 82687 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
82694 82695 82696 82697 82698 82699 82700 82701 82702 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 82694 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |