Class: Google::Apis::ComputeAlpha::UrlMapsAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UrlMapsAggregatedList

Returns a new instance of UrlMapsAggregatedList.



82412
82413
82414
# File 'lib/google/apis/compute_alpha/classes.rb', line 82412

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


82375
82376
82377
# File 'lib/google/apis/compute_alpha/classes.rb', line 82375

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::UrlMapsScopedList>

A list of UrlMapsScopedList resources. Corresponds to the JSON property items



82380
82381
82382
# File 'lib/google/apis/compute_alpha/classes.rb', line 82380

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


82385
82386
82387
# File 'lib/google/apis/compute_alpha/classes.rb', line 82385

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


82395
82396
82397
# File 'lib/google/apis/compute_alpha/classes.rb', line 82395

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


82400
82401
82402
# File 'lib/google/apis/compute_alpha/classes.rb', line 82400

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


82405
82406
82407
# File 'lib/google/apis/compute_alpha/classes.rb', line 82405

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::UrlMapsAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



82410
82411
82412
# File 'lib/google/apis/compute_alpha/classes.rb', line 82410

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



82417
82418
82419
82420
82421
82422
82423
82424
82425
# File 'lib/google/apis/compute_alpha/classes.rb', line 82417

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end