Class: Google::Apis::ComputeAlpha::UrlMapsAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UrlMapsAggregatedList

Returns a new instance of UrlMapsAggregatedList.



82106
82107
82108
# File 'lib/google/apis/compute_alpha/classes.rb', line 82106

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


82069
82070
82071
# File 'lib/google/apis/compute_alpha/classes.rb', line 82069

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::UrlMapsScopedList>

A list of UrlMapsScopedList resources. Corresponds to the JSON property items



82074
82075
82076
# File 'lib/google/apis/compute_alpha/classes.rb', line 82074

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


82079
82080
82081
# File 'lib/google/apis/compute_alpha/classes.rb', line 82079

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


82089
82090
82091
# File 'lib/google/apis/compute_alpha/classes.rb', line 82089

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


82094
82095
82096
# File 'lib/google/apis/compute_alpha/classes.rb', line 82094

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


82099
82100
82101
# File 'lib/google/apis/compute_alpha/classes.rb', line 82099

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::UrlMapsAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



82104
82105
82106
# File 'lib/google/apis/compute_alpha/classes.rb', line 82104

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



82111
82112
82113
82114
82115
82116
82117
82118
82119
# File 'lib/google/apis/compute_alpha/classes.rb', line 82111

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end