Class: Google::Apis::ComputeAlpha::UrlMapsAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::UrlMapsAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::UrlMapsScopedList>
A list of UrlMapsScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::UrlMapsAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UrlMapsAggregatedList
constructor
A new instance of UrlMapsAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UrlMapsAggregatedList
Returns a new instance of UrlMapsAggregatedList.
79806 79807 79808 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 79806 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
79769 79770 79771 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 79769 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::UrlMapsScopedList>
A list of UrlMapsScopedList resources.
Corresponds to the JSON property items
79774 79775 79776 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 79774 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
79779 79780 79781 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 79779 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
79789 79790 79791 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 79789 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
79794 79795 79796 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 79794 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
79799 79800 79801 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 79799 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::UrlMapsAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
79804 79805 79806 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 79804 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
79811 79812 79813 79814 79815 79816 79817 79818 79819 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 79811 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |