Class: Google::Apis::ComputeAlpha::UrlMapsAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::UrlMapsAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::UrlMapsScopedList>
A list of UrlMapsScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::UrlMapsAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UrlMapsAggregatedList
constructor
A new instance of UrlMapsAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UrlMapsAggregatedList
Returns a new instance of UrlMapsAggregatedList.
78796 78797 78798 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 78796 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
78759 78760 78761 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 78759 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::UrlMapsScopedList>
A list of UrlMapsScopedList resources.
Corresponds to the JSON property items
78764 78765 78766 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 78764 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
78769 78770 78771 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 78769 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
78779 78780 78781 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 78779 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
78784 78785 78786 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 78784 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
78789 78790 78791 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 78789 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::UrlMapsAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
78794 78795 78796 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 78794 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
78801 78802 78803 78804 78805 78806 78807 78808 78809 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 78801 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |