Class: Google::Apis::ComputeAlpha::UsableSubnetworksAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::UsableSubnetworksAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] The unique identifier for the resource.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::UsableSubnetwork>
[Output] A list of usable subnetwork URLs.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#scoped_warnings ⇒ Array<Google::Apis::ComputeAlpha::SubnetworksScopedWarning>
Output only.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::UsableSubnetworksAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UsableSubnetworksAggregatedList
constructor
A new instance of UsableSubnetworksAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UsableSubnetworksAggregatedList
Returns a new instance of UsableSubnetworksAggregatedList.
82914 82915 82916 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 82914 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
82865 82866 82867 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 82865 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::UsableSubnetwork>
[Output] A list of usable subnetwork URLs.
Corresponds to the JSON property items
82870 82871 82872 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 82870 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
usableSubnetworksAggregatedList for aggregated lists
of usable subnetworks.
Corresponds to the JSON property kind
82877 82878 82879 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 82877 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
In special cases listUsable may return 0 subnetworks andnextPageToken which
still should be used to get the
next page of results.
Corresponds to the JSON property nextPageToken
82890 82891 82892 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 82890 def next_page_token @next_page_token end |
#scoped_warnings ⇒ Array<Google::Apis::ComputeAlpha::SubnetworksScopedWarning>
Output only. [Output Only] Informational warning messages for failures
encountered from
scopes.
Corresponds to the JSON property scopedWarnings
82897 82898 82899 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 82897 def scoped_warnings @scoped_warnings end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
82902 82903 82904 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 82902 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
82907 82908 82909 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 82907 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::UsableSubnetworksAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
82912 82913 82914 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 82912 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
82919 82920 82921 82922 82923 82924 82925 82926 82927 82928 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 82919 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @scoped_warnings = args[:scoped_warnings] if args.key?(:scoped_warnings) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |