Class: Google::Apis::ComputeAlpha::UsableSubnetworksAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::UsableSubnetworksAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] The unique identifier for the resource.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::UsableSubnetwork>
[Output] A list of usable subnetwork URLs.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#scoped_warnings ⇒ Array<Google::Apis::ComputeAlpha::SubnetworksScopedWarning>
Output only.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::UsableSubnetworksAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UsableSubnetworksAggregatedList
constructor
A new instance of UsableSubnetworksAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UsableSubnetworksAggregatedList
Returns a new instance of UsableSubnetworksAggregatedList.
80570 80571 80572 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 80570 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
80521 80522 80523 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 80521 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::UsableSubnetwork>
[Output] A list of usable subnetwork URLs.
Corresponds to the JSON property items
80526 80527 80528 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 80526 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
usableSubnetworksAggregatedList for aggregated lists
of usable subnetworks.
Corresponds to the JSON property kind
80533 80534 80535 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 80533 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
In special cases listUsable may return 0 subnetworks andnextPageToken which
still should be used to get the
next page of results.
Corresponds to the JSON property nextPageToken
80546 80547 80548 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 80546 def next_page_token @next_page_token end |
#scoped_warnings ⇒ Array<Google::Apis::ComputeAlpha::SubnetworksScopedWarning>
Output only. [Output Only] Informational warning messages for failures
encountered from
scopes.
Corresponds to the JSON property scopedWarnings
80553 80554 80555 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 80553 def scoped_warnings @scoped_warnings end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
80558 80559 80560 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 80558 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
80563 80564 80565 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 80563 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::UsableSubnetworksAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
80568 80569 80570 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 80568 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
80575 80576 80577 80578 80579 80580 80581 80582 80583 80584 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 80575 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @scoped_warnings = args[:scoped_warnings] if args.key?(:scoped_warnings) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |