Class: Google::Apis::ComputeAlpha::UsableSubnetworksAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UsableSubnetworksAggregatedList

Returns a new instance of UsableSubnetworksAggregatedList.



79292
79293
79294
# File 'lib/google/apis/compute_alpha/classes.rb', line 79292

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


79243
79244
79245
# File 'lib/google/apis/compute_alpha/classes.rb', line 79243

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::UsableSubnetwork>

[Output] A list of usable subnetwork URLs. Corresponds to the JSON property items



79248
79249
79250
# File 'lib/google/apis/compute_alpha/classes.rb', line 79248

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# usableSubnetworksAggregatedList for aggregated lists of usable subnetworks. Corresponds to the JSON property kind

Returns:

  • (String)


79255
79256
79257
# File 'lib/google/apis/compute_alpha/classes.rb', line 79255

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. In special cases listUsable may return 0 subnetworks andnextPageToken which still should be used to get the next page of results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


79268
79269
79270
# File 'lib/google/apis/compute_alpha/classes.rb', line 79268

def next_page_token
  @next_page_token
end

#scoped_warningsArray<Google::Apis::ComputeAlpha::SubnetworksScopedWarning>

Output only. [Output Only] Informational warning messages for failures encountered from scopes. Corresponds to the JSON property scopedWarnings



79275
79276
79277
# File 'lib/google/apis/compute_alpha/classes.rb', line 79275

def scoped_warnings
  @scoped_warnings
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


79280
79281
79282
# File 'lib/google/apis/compute_alpha/classes.rb', line 79280

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


79285
79286
79287
# File 'lib/google/apis/compute_alpha/classes.rb', line 79285

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::UsableSubnetworksAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



79290
79291
79292
# File 'lib/google/apis/compute_alpha/classes.rb', line 79290

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



79297
79298
79299
79300
79301
79302
79303
79304
79305
79306
# File 'lib/google/apis/compute_alpha/classes.rb', line 79297

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @scoped_warnings = args[:scoped_warnings] if args.key?(:scoped_warnings)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end