Class: Google::Apis::ComputeAlpha::VmEndpointNatMappingsInterfaceNatMappings
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::VmEndpointNatMappingsInterfaceNatMappings
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Contain information of Nat mapping for an interface of this endpoint.
Instance Attribute Summary collapse
-
#drain_nat_ip_port_ranges ⇒ Array<String>
Output only.
-
#nat_ip_port_ranges ⇒ Array<String>
Output only.
-
#num_total_drain_nat_ports ⇒ Fixnum
Output only.
-
#num_total_nat_ports ⇒ Fixnum
Output only.
-
#rule_mappings ⇒ Array<Google::Apis::ComputeAlpha::VmEndpointNatMappingsInterfaceNatMappingsNatRuleMappings>
Output only.
-
#source_alias_ip_range ⇒ String
Output only.
-
#source_virtual_ip ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VmEndpointNatMappingsInterfaceNatMappings
constructor
A new instance of VmEndpointNatMappingsInterfaceNatMappings.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VmEndpointNatMappingsInterfaceNatMappings
Returns a new instance of VmEndpointNatMappingsInterfaceNatMappings.
80502 80503 80504 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 80502 def initialize(**args) update!(**args) end |
Instance Attribute Details
#drain_nat_ip_port_ranges ⇒ Array<String>
Output only. List of all drain IP:port-range mappings assigned to this
interface.
These ranges are inclusive, that is, both the first and the last
ports can be used for NAT. Example: ["2.2.2.2:12345-12355",
"1.1.1.1:2234-2234"].
Corresponds to the JSON property drainNatIpPortRanges
80461 80462 80463 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 80461 def drain_nat_ip_port_ranges @drain_nat_ip_port_ranges end |
#nat_ip_port_ranges ⇒ Array<String>
Output only. A list of all IP:port-range mappings assigned to this interface.
These ranges are inclusive, that is, both the first and the last
ports can be used for NAT. Example: ["2.2.2.2:12345-12355",
"1.1.1.1:2234-2234"].
Corresponds to the JSON property natIpPortRanges
80469 80470 80471 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 80469 def nat_ip_port_ranges @nat_ip_port_ranges end |
#num_total_drain_nat_ports ⇒ Fixnum
Output only. Total number of drain ports across all NAT IPs allocated to this
interface. It equals to the aggregated port number in the field
drain_nat_ip_port_ranges.
Corresponds to the JSON property numTotalDrainNatPorts
80476 80477 80478 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 80476 def num_total_drain_nat_ports @num_total_drain_nat_ports end |
#num_total_nat_ports ⇒ Fixnum
Output only. Total number of ports across all NAT IPs allocated to this
interface.
It equals to the aggregated port number in the field nat_ip_port_ranges.
Corresponds to the JSON property numTotalNatPorts
80483 80484 80485 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 80483 def num_total_nat_ports @num_total_nat_ports end |
#rule_mappings ⇒ Array<Google::Apis::ComputeAlpha::VmEndpointNatMappingsInterfaceNatMappingsNatRuleMappings>
Output only. Information about mappings provided by rules in this NAT.
Corresponds to the JSON property ruleMappings
80488 80489 80490 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 80488 def rule_mappings @rule_mappings end |
#source_alias_ip_range ⇒ String
Output only. Alias IP range for this interface endpoint.
It will be a private (RFC 1918) IP range.
Examples: "10.33.4.55/32", or "192.168.5.0/24".
Corresponds to the JSON property sourceAliasIpRange
80495 80496 80497 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 80495 def source_alias_ip_range @source_alias_ip_range end |
#source_virtual_ip ⇒ String
Output only. Primary IP of the VM for this NIC.
Corresponds to the JSON property sourceVirtualIp
80500 80501 80502 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 80500 def source_virtual_ip @source_virtual_ip end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
80507 80508 80509 80510 80511 80512 80513 80514 80515 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 80507 def update!(**args) @drain_nat_ip_port_ranges = args[:drain_nat_ip_port_ranges] if args.key?(:drain_nat_ip_port_ranges) @nat_ip_port_ranges = args[:nat_ip_port_ranges] if args.key?(:nat_ip_port_ranges) @num_total_drain_nat_ports = args[:num_total_drain_nat_ports] if args.key?(:num_total_drain_nat_ports) @num_total_nat_ports = args[:num_total_nat_ports] if args.key?(:num_total_nat_ports) @rule_mappings = args[:rule_mappings] if args.key?(:rule_mappings) @source_alias_ip_range = args[:source_alias_ip_range] if args.key?(:source_alias_ip_range) @source_virtual_ip = args[:source_virtual_ip] if args.key?(:source_virtual_ip) end |