Class: Google::Apis::ComputeAlpha::VmEndpointNatMappingsInterfaceNatMappings

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contain information of Nat mapping for an interface of this endpoint.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VmEndpointNatMappingsInterfaceNatMappings

Returns a new instance of VmEndpointNatMappingsInterfaceNatMappings.



79492
79493
79494
# File 'lib/google/apis/compute_alpha/classes.rb', line 79492

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#drain_nat_ip_port_rangesArray<String>

Output only. List of all drain IP:port-range mappings assigned to this interface. These ranges are inclusive, that is, both the first and the last ports can be used for NAT. Example: ["2.2.2.2:12345-12355", "1.1.1.1:2234-2234"]. Corresponds to the JSON property drainNatIpPortRanges

Returns:

  • (Array<String>)


79451
79452
79453
# File 'lib/google/apis/compute_alpha/classes.rb', line 79451

def drain_nat_ip_port_ranges
  @drain_nat_ip_port_ranges
end

#nat_ip_port_rangesArray<String>

Output only. A list of all IP:port-range mappings assigned to this interface. These ranges are inclusive, that is, both the first and the last ports can be used for NAT. Example: ["2.2.2.2:12345-12355", "1.1.1.1:2234-2234"]. Corresponds to the JSON property natIpPortRanges

Returns:

  • (Array<String>)


79459
79460
79461
# File 'lib/google/apis/compute_alpha/classes.rb', line 79459

def nat_ip_port_ranges
  @nat_ip_port_ranges
end

#num_total_drain_nat_portsFixnum

Output only. Total number of drain ports across all NAT IPs allocated to this interface. It equals to the aggregated port number in the field drain_nat_ip_port_ranges. Corresponds to the JSON property numTotalDrainNatPorts

Returns:

  • (Fixnum)


79466
79467
79468
# File 'lib/google/apis/compute_alpha/classes.rb', line 79466

def num_total_drain_nat_ports
  @num_total_drain_nat_ports
end

#num_total_nat_portsFixnum

Output only. Total number of ports across all NAT IPs allocated to this interface. It equals to the aggregated port number in the field nat_ip_port_ranges. Corresponds to the JSON property numTotalNatPorts

Returns:

  • (Fixnum)


79473
79474
79475
# File 'lib/google/apis/compute_alpha/classes.rb', line 79473

def num_total_nat_ports
  @num_total_nat_ports
end

#rule_mappingsArray<Google::Apis::ComputeAlpha::VmEndpointNatMappingsInterfaceNatMappingsNatRuleMappings>

Output only. Information about mappings provided by rules in this NAT. Corresponds to the JSON property ruleMappings



79478
79479
79480
# File 'lib/google/apis/compute_alpha/classes.rb', line 79478

def rule_mappings
  @rule_mappings
end

#source_alias_ip_rangeString

Output only. Alias IP range for this interface endpoint. It will be a private (RFC 1918) IP range. Examples: "10.33.4.55/32", or "192.168.5.0/24". Corresponds to the JSON property sourceAliasIpRange

Returns:

  • (String)


79485
79486
79487
# File 'lib/google/apis/compute_alpha/classes.rb', line 79485

def source_alias_ip_range
  @source_alias_ip_range
end

#source_virtual_ipString

Output only. Primary IP of the VM for this NIC. Corresponds to the JSON property sourceVirtualIp

Returns:

  • (String)


79490
79491
79492
# File 'lib/google/apis/compute_alpha/classes.rb', line 79490

def source_virtual_ip
  @source_virtual_ip
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



79497
79498
79499
79500
79501
79502
79503
79504
79505
# File 'lib/google/apis/compute_alpha/classes.rb', line 79497

def update!(**args)
  @drain_nat_ip_port_ranges = args[:drain_nat_ip_port_ranges] if args.key?(:drain_nat_ip_port_ranges)
  @nat_ip_port_ranges = args[:nat_ip_port_ranges] if args.key?(:nat_ip_port_ranges)
  @num_total_drain_nat_ports = args[:num_total_drain_nat_ports] if args.key?(:num_total_drain_nat_ports)
  @num_total_nat_ports = args[:num_total_nat_ports] if args.key?(:num_total_nat_ports)
  @rule_mappings = args[:rule_mappings] if args.key?(:rule_mappings)
  @source_alias_ip_range = args[:source_alias_ip_range] if args.key?(:source_alias_ip_range)
  @source_virtual_ip = args[:source_virtual_ip] if args.key?(:source_virtual_ip)
end