Class: Google::Apis::ComputeAlpha::VmEndpointNatMappingsInterfaceNatMappingsNatRuleMappings

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains information of NAT Mappings provided by a NAT Rule.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VmEndpointNatMappingsInterfaceNatMappingsNatRuleMappings

Returns a new instance of VmEndpointNatMappingsInterfaceNatMappingsNatRuleMappings.



80831
80832
80833
# File 'lib/google/apis/compute_alpha/classes.rb', line 80831

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#drain_nat_ip_port_rangesArray<String>

Output only. List of all drain IP:port-range mappings assigned to this interface by this rule. These ranges are inclusive, that is, both the first and the last ports can be used for NAT. Example: ["2.2.2.2:12345-12355", "1.1.1.1:2234-2234"]. Corresponds to the JSON property drainNatIpPortRanges

Returns:

  • (Array<String>)


80798
80799
80800
# File 'lib/google/apis/compute_alpha/classes.rb', line 80798

def drain_nat_ip_port_ranges
  @drain_nat_ip_port_ranges
end

#nat_ip_port_rangesArray<String>

Output only. A list of all IP:port-range mappings assigned to this interface by this rule. These ranges are inclusive, that is, both the first and the last ports can be used for NAT. Example: ["2.2.2.2:12345-12355", "1.1.1.1:2234-2234"]. Corresponds to the JSON property natIpPortRanges

Returns:

  • (Array<String>)


80808
80809
80810
# File 'lib/google/apis/compute_alpha/classes.rb', line 80808

def nat_ip_port_ranges
  @nat_ip_port_ranges
end

#num_total_drain_nat_portsFixnum

Output only. Total number of drain ports across all NAT IPs allocated to this interface by this rule. It equals the aggregated port number in the field drain_nat_ip_port_ranges. Corresponds to the JSON property numTotalDrainNatPorts

Returns:

  • (Fixnum)


80816
80817
80818
# File 'lib/google/apis/compute_alpha/classes.rb', line 80816

def num_total_drain_nat_ports
  @num_total_drain_nat_ports
end

#num_total_nat_portsFixnum

Output only. Total number of ports across all NAT IPs allocated to this interface by this rule. It equals the aggregated port number in the field nat_ip_port_ranges. Corresponds to the JSON property numTotalNatPorts

Returns:

  • (Fixnum)


80824
80825
80826
# File 'lib/google/apis/compute_alpha/classes.rb', line 80824

def num_total_nat_ports
  @num_total_nat_ports
end

#rule_numberFixnum

Output only. Rule number of the NAT Rule. Corresponds to the JSON property ruleNumber

Returns:

  • (Fixnum)


80829
80830
80831
# File 'lib/google/apis/compute_alpha/classes.rb', line 80829

def rule_number
  @rule_number
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



80836
80837
80838
80839
80840
80841
80842
# File 'lib/google/apis/compute_alpha/classes.rb', line 80836

def update!(**args)
  @drain_nat_ip_port_ranges = args[:drain_nat_ip_port_ranges] if args.key?(:drain_nat_ip_port_ranges)
  @nat_ip_port_ranges = args[:nat_ip_port_ranges] if args.key?(:nat_ip_port_ranges)
  @num_total_drain_nat_ports = args[:num_total_drain_nat_ports] if args.key?(:num_total_drain_nat_ports)
  @num_total_nat_ports = args[:num_total_nat_ports] if args.key?(:num_total_nat_ports)
  @rule_number = args[:rule_number] if args.key?(:rule_number)
end