Class: Google::Apis::ComputeAlpha::VmEndpointNatMappingsInterfaceNatMappingsNatRuleMappings
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::VmEndpointNatMappingsInterfaceNatMappingsNatRuleMappings
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Contains information of NAT Mappings provided by a NAT Rule.
Instance Attribute Summary collapse
-
#drain_nat_ip_port_ranges ⇒ Array<String>
Output only.
-
#nat_ip_port_ranges ⇒ Array<String>
Output only.
-
#num_total_drain_nat_ports ⇒ Fixnum
Output only.
-
#num_total_nat_ports ⇒ Fixnum
Output only.
-
#rule_number ⇒ Fixnum
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VmEndpointNatMappingsInterfaceNatMappingsNatRuleMappings
constructor
A new instance of VmEndpointNatMappingsInterfaceNatMappingsNatRuleMappings.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VmEndpointNatMappingsInterfaceNatMappingsNatRuleMappings
Returns a new instance of VmEndpointNatMappingsInterfaceNatMappingsNatRuleMappings.
80563 80564 80565 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 80563 def initialize(**args) update!(**args) end |
Instance Attribute Details
#drain_nat_ip_port_ranges ⇒ Array<String>
Output only. List of all drain IP:port-range mappings assigned to this
interface
by this rule.
These ranges are inclusive, that is, both the first and the last
ports can be used for NAT. Example: ["2.2.2.2:12345-12355",
"1.1.1.1:2234-2234"].
Corresponds to the JSON property drainNatIpPortRanges
80530 80531 80532 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 80530 def drain_nat_ip_port_ranges @drain_nat_ip_port_ranges end |
#nat_ip_port_ranges ⇒ Array<String>
Output only. A list of all IP:port-range mappings assigned to this interface
by this
rule.
These ranges are inclusive, that is, both the first and the last
ports can be used for NAT. Example: ["2.2.2.2:12345-12355",
"1.1.1.1:2234-2234"].
Corresponds to the JSON property natIpPortRanges
80540 80541 80542 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 80540 def nat_ip_port_ranges @nat_ip_port_ranges end |
#num_total_drain_nat_ports ⇒ Fixnum
Output only. Total number of drain ports across all NAT IPs allocated to this
interface by this rule.
It equals the aggregated port number in the field
drain_nat_ip_port_ranges.
Corresponds to the JSON property numTotalDrainNatPorts
80548 80549 80550 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 80548 def num_total_drain_nat_ports @num_total_drain_nat_ports end |
#num_total_nat_ports ⇒ Fixnum
Output only. Total number of ports across all NAT IPs allocated to this
interface
by this rule.
It equals the aggregated port number in the field nat_ip_port_ranges.
Corresponds to the JSON property numTotalNatPorts
80556 80557 80558 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 80556 def num_total_nat_ports @num_total_nat_ports end |
#rule_number ⇒ Fixnum
Output only. Rule number of the NAT Rule.
Corresponds to the JSON property ruleNumber
80561 80562 80563 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 80561 def rule_number @rule_number end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
80568 80569 80570 80571 80572 80573 80574 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 80568 def update!(**args) @drain_nat_ip_port_ranges = args[:drain_nat_ip_port_ranges] if args.key?(:drain_nat_ip_port_ranges) @nat_ip_port_ranges = args[:nat_ip_port_ranges] if args.key?(:nat_ip_port_ranges) @num_total_drain_nat_ports = args[:num_total_drain_nat_ports] if args.key?(:num_total_drain_nat_ports) @num_total_nat_ports = args[:num_total_nat_ports] if args.key?(:num_total_nat_ports) @rule_number = args[:rule_number] if args.key?(:rule_number) end |