Class: Google::Apis::ComputeAlpha::VmEndpointNatMappingsList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::VmEndpointNatMappingsList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Contains a list of VmEndpointNatMappings.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] The unique identifier for the resource.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#result ⇒ Array<Google::Apis::ComputeAlpha::VmEndpointNatMappings>
[Output Only] A list of Nat mapping information of VM endpoints.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::VmEndpointNatMappingsList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VmEndpointNatMappingsList
constructor
A new instance of VmEndpointNatMappingsList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VmEndpointNatMappingsList
Returns a new instance of VmEndpointNatMappingsList.
81557 81558 81559 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 81557 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
81523 81524 81525 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 81523 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
vmEndpointNatMappingsList for lists of Nat mappings of
VM endpoints.
Corresponds to the JSON property kind
81530 81531 81532 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 81530 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
81540 81541 81542 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 81540 def next_page_token @next_page_token end |
#result ⇒ Array<Google::Apis::ComputeAlpha::VmEndpointNatMappings>
[Output Only] A list of Nat mapping information of VM endpoints.
Corresponds to the JSON property result
81545 81546 81547 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 81545 def result @result end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
81550 81551 81552 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 81550 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::VmEndpointNatMappingsList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
81555 81556 81557 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 81555 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
81562 81563 81564 81565 81566 81567 81568 81569 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 81562 def update!(**args) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @result = args[:result] if args.key?(:result) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |