Class: Google::Apis::ComputeAlpha::VmEndpointNatMappingsList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::VmEndpointNatMappingsList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Contains a list of VmEndpointNatMappings.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] The unique identifier for the resource.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#result ⇒ Array<Google::Apis::ComputeAlpha::VmEndpointNatMappings>
[Output Only] A list of Nat mapping information of VM endpoints.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::VmEndpointNatMappingsList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VmEndpointNatMappingsList
constructor
A new instance of VmEndpointNatMappingsList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VmEndpointNatMappingsList
Returns a new instance of VmEndpointNatMappingsList.
80887 80888 80889 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 80887 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
80853 80854 80855 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 80853 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
vmEndpointNatMappingsList for lists of Nat mappings of
VM endpoints.
Corresponds to the JSON property kind
80860 80861 80862 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 80860 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
80870 80871 80872 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 80870 def next_page_token @next_page_token end |
#result ⇒ Array<Google::Apis::ComputeAlpha::VmEndpointNatMappings>
[Output Only] A list of Nat mapping information of VM endpoints.
Corresponds to the JSON property result
80875 80876 80877 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 80875 def result @result end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
80880 80881 80882 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 80880 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::VmEndpointNatMappingsList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
80885 80886 80887 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 80885 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
80892 80893 80894 80895 80896 80897 80898 80899 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 80892 def update!(**args) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @result = args[:result] if args.key?(:result) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |