Class: Google::Apis::ComputeAlpha::VmEndpointNatMappingsList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of VmEndpointNatMappings.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VmEndpointNatMappingsList

Returns a new instance of VmEndpointNatMappingsList.



80885
80886
80887
# File 'lib/google/apis/compute_alpha/classes.rb', line 80885

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


80851
80852
80853
# File 'lib/google/apis/compute_alpha/classes.rb', line 80851

def id
  @id
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# vmEndpointNatMappingsList for lists of Nat mappings of VM endpoints. Corresponds to the JSON property kind

Returns:

  • (String)


80858
80859
80860
# File 'lib/google/apis/compute_alpha/classes.rb', line 80858

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


80868
80869
80870
# File 'lib/google/apis/compute_alpha/classes.rb', line 80868

def next_page_token
  @next_page_token
end

#resultArray<Google::Apis::ComputeAlpha::VmEndpointNatMappings>

[Output Only] A list of Nat mapping information of VM endpoints. Corresponds to the JSON property result



80873
80874
80875
# File 'lib/google/apis/compute_alpha/classes.rb', line 80873

def result
  @result
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


80878
80879
80880
# File 'lib/google/apis/compute_alpha/classes.rb', line 80878

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::VmEndpointNatMappingsList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



80883
80884
80885
# File 'lib/google/apis/compute_alpha/classes.rb', line 80883

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



80890
80891
80892
80893
80894
80895
80896
80897
# File 'lib/google/apis/compute_alpha/classes.rb', line 80890

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @result = args[:result] if args.key?(:result)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end