Class: Google::Apis::ComputeAlpha::VmEndpointNatMappingsList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of VmEndpointNatMappings.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VmEndpointNatMappingsList

Returns a new instance of VmEndpointNatMappingsList.



79609
79610
79611
# File 'lib/google/apis/compute_alpha/classes.rb', line 79609

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


79575
79576
79577
# File 'lib/google/apis/compute_alpha/classes.rb', line 79575

def id
  @id
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# vmEndpointNatMappingsList for lists of Nat mappings of VM endpoints. Corresponds to the JSON property kind

Returns:

  • (String)


79582
79583
79584
# File 'lib/google/apis/compute_alpha/classes.rb', line 79582

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


79592
79593
79594
# File 'lib/google/apis/compute_alpha/classes.rb', line 79592

def next_page_token
  @next_page_token
end

#resultArray<Google::Apis::ComputeAlpha::VmEndpointNatMappings>

[Output Only] A list of Nat mapping information of VM endpoints. Corresponds to the JSON property result



79597
79598
79599
# File 'lib/google/apis/compute_alpha/classes.rb', line 79597

def result
  @result
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


79602
79603
79604
# File 'lib/google/apis/compute_alpha/classes.rb', line 79602

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::VmEndpointNatMappingsList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



79607
79608
79609
# File 'lib/google/apis/compute_alpha/classes.rb', line 79607

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



79614
79615
79616
79617
79618
79619
79620
79621
# File 'lib/google/apis/compute_alpha/classes.rb', line 79614

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @result = args[:result] if args.key?(:result)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end