Class: Google::Apis::ComputeAlpha::VmExtensionPolicyAggregatedListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Response for the aggregated list of VM extension policies.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VmExtensionPolicyAggregatedListResponse

Returns a new instance of VmExtensionPolicyAggregatedListResponse.



81270
81271
81272
# File 'lib/google/apis/compute_alpha/classes.rb', line 81270

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


81226
81227
81228
# File 'lib/google/apis/compute_alpha/classes.rb', line 81226

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


81231
81232
81233
# File 'lib/google/apis/compute_alpha/classes.rb', line 81231

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::VmExtensionPoliciesScopedList>

A list of VmExtensionPoliciesScopedList resources. Corresponds to the JSON property items



81236
81237
81238
# File 'lib/google/apis/compute_alpha/classes.rb', line 81236

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# VmExtensionPolicyAggregatedList for lists of VmExtensionPolicies. Corresponds to the JSON property kind

Returns:

  • (String)


81243
81244
81245
# File 'lib/google/apis/compute_alpha/classes.rb', line 81243

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


81253
81254
81255
# File 'lib/google/apis/compute_alpha/classes.rb', line 81253

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


81258
81259
81260
# File 'lib/google/apis/compute_alpha/classes.rb', line 81258

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


81263
81264
81265
# File 'lib/google/apis/compute_alpha/classes.rb', line 81263

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::VmExtensionPolicyAggregatedListResponse::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



81268
81269
81270
# File 'lib/google/apis/compute_alpha/classes.rb', line 81268

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



81275
81276
81277
81278
81279
81280
81281
81282
81283
81284
# File 'lib/google/apis/compute_alpha/classes.rb', line 81275

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end