Class: Google::Apis::ComputeAlpha::VmExtensionPolicyAggregatedListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Response for the aggregated list of VM extension policies.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VmExtensionPolicyAggregatedListResponse

Returns a new instance of VmExtensionPolicyAggregatedListResponse.



81002
81003
81004
# File 'lib/google/apis/compute_alpha/classes.rb', line 81002

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


80958
80959
80960
# File 'lib/google/apis/compute_alpha/classes.rb', line 80958

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


80963
80964
80965
# File 'lib/google/apis/compute_alpha/classes.rb', line 80963

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::VmExtensionPoliciesScopedList>

A list of VmExtensionPoliciesScopedList resources. Corresponds to the JSON property items



80968
80969
80970
# File 'lib/google/apis/compute_alpha/classes.rb', line 80968

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# VmExtensionPolicyAggregatedList for lists of VmExtensionPolicies. Corresponds to the JSON property kind

Returns:

  • (String)


80975
80976
80977
# File 'lib/google/apis/compute_alpha/classes.rb', line 80975

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


80985
80986
80987
# File 'lib/google/apis/compute_alpha/classes.rb', line 80985

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


80990
80991
80992
# File 'lib/google/apis/compute_alpha/classes.rb', line 80990

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


80995
80996
80997
# File 'lib/google/apis/compute_alpha/classes.rb', line 80995

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::VmExtensionPolicyAggregatedListResponse::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



81000
81001
81002
# File 'lib/google/apis/compute_alpha/classes.rb', line 81000

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



81007
81008
81009
81010
81011
81012
81013
81014
81015
81016
# File 'lib/google/apis/compute_alpha/classes.rb', line 81007

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end