Class: Google::Apis::ComputeAlpha::VmExtensionPolicyAggregatedListResponse
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::VmExtensionPolicyAggregatedListResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Response for the aggregated list of VM extension policies.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::VmExtensionPoliciesScopedList>
A list of VmExtensionPoliciesScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::VmExtensionPolicyAggregatedListResponse::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VmExtensionPolicyAggregatedListResponse
constructor
A new instance of VmExtensionPolicyAggregatedListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VmExtensionPolicyAggregatedListResponse
Returns a new instance of VmExtensionPolicyAggregatedListResponse.
79992 79993 79994 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 79992 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
79948 79949 79950 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 79948 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
79953 79954 79955 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 79953 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::VmExtensionPoliciesScopedList>
A list of VmExtensionPoliciesScopedList resources.
Corresponds to the JSON property items
79958 79959 79960 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 79958 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
VmExtensionPolicyAggregatedList for lists of
VmExtensionPolicies.
Corresponds to the JSON property kind
79965 79966 79967 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 79965 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
79975 79976 79977 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 79975 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
79980 79981 79982 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 79980 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
79985 79986 79987 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 79985 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::VmExtensionPolicyAggregatedListResponse::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
79990 79991 79992 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 79990 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
79997 79998 79999 80000 80001 80002 80003 80004 80005 80006 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 79997 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |