Class: Google::Apis::ComputeAlpha::VmExtensionPolicyLabelSelector
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::VmExtensionPolicyLabelSelector
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
A LabelSelector is applied to a VM only if it matches all the specified labels.
Instance Attribute Summary collapse
-
#inclusion_labels ⇒ Hash<String,String>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VmExtensionPolicyLabelSelector
constructor
A new instance of VmExtensionPolicyLabelSelector.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VmExtensionPolicyLabelSelector
Returns a new instance of VmExtensionPolicyLabelSelector.
84089 84090 84091 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 84089 def initialize(**args) update!(**args) end |
Instance Attribute Details
#inclusion_labels ⇒ Hash<String,String>
Optional. A map of key-value pairs representing VM labels.
VMs must have all of the labels specified in this map to be selected
(logical AND).
e.g. If the inclusion_labels are ("key1", "value1"), ("key2",
"value2"), the VM labels must contain both ("key1", "value1") and
("key2", "value2") to be selected. If the VM labels are ("key1",
"value1") and ("something", "else"), it will not be selected.
If the map is empty, it's considered a match.
Corresponds to the JSON property inclusionLabels
84087 84088 84089 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 84087 def inclusion_labels @inclusion_labels end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
84094 84095 84096 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 84094 def update!(**args) @inclusion_labels = args[:inclusion_labels] if args.key?(:inclusion_labels) end |