Class: Google::Apis::ComputeAlpha::VmExtensionPolicyList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VmExtensionPolicyList

Returns a new instance of VmExtensionPolicyList.



83879
83880
83881
# File 'lib/google/apis/compute_alpha/classes.rb', line 83879

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Output only. [Output Only] Fingerprint of this resource. A hash of the contents stored in this object. This field is used in optimistic locking. This field will be ignored when inserting a VmExtensionPolicy. An up-to-date fingerprint must be provided in order to update the VmExtensionPolicy. To see the latest value of the fingerprint, make a get() request to retrieve a VmExtensionPolicy. Corresponds to the JSON property etag

Returns:

  • (String)


83835
83836
83837
# File 'lib/google/apis/compute_alpha/classes.rb', line 83835

def etag
  @etag
end

#idString

Output only. [Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


83841
83842
83843
# File 'lib/google/apis/compute_alpha/classes.rb', line 83841

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::VmExtensionPolicy>

Output only. [Output Only] A list of VM extension policy resources. Corresponds to the JSON property items



83846
83847
83848
# File 'lib/google/apis/compute_alpha/classes.rb', line 83846

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


83851
83852
83853
# File 'lib/google/apis/compute_alpha/classes.rb', line 83851

def kind
  @kind
end

#next_page_tokenString

Output only. [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


83862
83863
83864
# File 'lib/google/apis/compute_alpha/classes.rb', line 83862

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


83867
83868
83869
# File 'lib/google/apis/compute_alpha/classes.rb', line 83867

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


83872
83873
83874
# File 'lib/google/apis/compute_alpha/classes.rb', line 83872

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::VmExtensionPolicyList::Warning

Output only. [Output Only] Informational warning message. Corresponds to the JSON property warning



83877
83878
83879
# File 'lib/google/apis/compute_alpha/classes.rb', line 83877

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



83884
83885
83886
83887
83888
83889
83890
83891
83892
83893
# File 'lib/google/apis/compute_alpha/classes.rb', line 83884

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end