Class: Google::Apis::ComputeAlpha::VmExtensionPolicyList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::VmExtensionPolicyList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Output only.
-
#id ⇒ String
Output only.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::VmExtensionPolicy>
Output only.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
Output only.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::VmExtensionPolicyList::Warning
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VmExtensionPolicyList
constructor
A new instance of VmExtensionPolicyList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VmExtensionPolicyList
Returns a new instance of VmExtensionPolicyList.
83526 83527 83528 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 83526 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Output only. [Output Only] Fingerprint of this resource. A hash of the
contents stored
in this object. This field is used in optimistic locking. This field will
be ignored when inserting a VmExtensionPolicy. An up-to-date
fingerprint must be provided in order to update the VmExtensionPolicy.
To see the latest value of the fingerprint, make a get() request to
retrieve a VmExtensionPolicy.
Corresponds to the JSON property etag
83482 83483 83484 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 83482 def etag @etag end |
#id ⇒ String
Output only. [Output Only] Unique identifier for the resource; defined by the
server.
Corresponds to the JSON property id
83488 83489 83490 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 83488 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::VmExtensionPolicy>
Output only. [Output Only] A list of VM extension policy resources.
Corresponds to the JSON property items
83493 83494 83495 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 83493 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
83498 83499 83500 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 83498 def kind @kind end |
#next_page_token ⇒ String
Output only. [Output Only] This token allows you to get the next page of
results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
83509 83510 83511 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 83509 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
83514 83515 83516 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 83514 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
83519 83520 83521 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 83519 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::VmExtensionPolicyList::Warning
Output only. [Output Only] Informational warning message.
Corresponds to the JSON property warning
83524 83525 83526 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 83524 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
83531 83532 83533 83534 83535 83536 83537 83538 83539 83540 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 83531 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |