Class: Google::Apis::ComputeAlpha::VmExtensionPolicyList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VmExtensionPolicyList

Returns a new instance of VmExtensionPolicyList.



82101
82102
82103
# File 'lib/google/apis/compute_alpha/classes.rb', line 82101

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Output only. [Output Only] Fingerprint of this resource. A hash of the contents stored in this object. This field is used in optimistic locking. This field will be ignored when inserting a VmExtensionPolicy. An up-to-date fingerprint must be provided in order to update the VmExtensionPolicy. To see the latest value of the fingerprint, make a get() request to retrieve a VmExtensionPolicy. Corresponds to the JSON property etag

Returns:

  • (String)


82057
82058
82059
# File 'lib/google/apis/compute_alpha/classes.rb', line 82057

def etag
  @etag
end

#idString

Output only. [Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


82063
82064
82065
# File 'lib/google/apis/compute_alpha/classes.rb', line 82063

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::VmExtensionPolicy>

Output only. [Output Only] A list of VM extension policy resources. Corresponds to the JSON property items



82068
82069
82070
# File 'lib/google/apis/compute_alpha/classes.rb', line 82068

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


82073
82074
82075
# File 'lib/google/apis/compute_alpha/classes.rb', line 82073

def kind
  @kind
end

#next_page_tokenString

Output only. [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


82084
82085
82086
# File 'lib/google/apis/compute_alpha/classes.rb', line 82084

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


82089
82090
82091
# File 'lib/google/apis/compute_alpha/classes.rb', line 82089

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


82094
82095
82096
# File 'lib/google/apis/compute_alpha/classes.rb', line 82094

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::VmExtensionPolicyList::Warning

Output only. [Output Only] Informational warning message. Corresponds to the JSON property warning



82099
82100
82101
# File 'lib/google/apis/compute_alpha/classes.rb', line 82099

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



82106
82107
82108
82109
82110
82111
82112
82113
82114
82115
# File 'lib/google/apis/compute_alpha/classes.rb', line 82106

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end