Class: Google::Apis::ComputeAlpha::VmExtensionPolicyList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::VmExtensionPolicyList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Output only.
-
#id ⇒ String
Output only.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::VmExtensionPolicy>
Output only.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
Output only.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::VmExtensionPolicyList::Warning
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VmExtensionPolicyList
constructor
A new instance of VmExtensionPolicyList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VmExtensionPolicyList
Returns a new instance of VmExtensionPolicyList.
80210 80211 80212 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 80210 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Output only. [Output Only] Fingerprint of this resource. A hash of the
contents stored
in this object. This field is used in optimistic locking. This field will
be ignored when inserting a VmExtensionPolicy. An up-to-date
fingerprint must be provided in order to update the VmExtensionPolicy.
To see the latest value of the fingerprint, make a get() request to
retrieve a VmExtensionPolicy.
Corresponds to the JSON property etag
80166 80167 80168 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 80166 def etag @etag end |
#id ⇒ String
Output only. [Output Only] Unique identifier for the resource; defined by the
server.
Corresponds to the JSON property id
80172 80173 80174 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 80172 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::VmExtensionPolicy>
Output only. [Output Only] A list of VM extension policy resources.
Corresponds to the JSON property items
80177 80178 80179 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 80177 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
80182 80183 80184 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 80182 def kind @kind end |
#next_page_token ⇒ String
Output only. [Output Only] This token allows you to get the next page of
results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
80193 80194 80195 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 80193 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
80198 80199 80200 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 80198 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
80203 80204 80205 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 80203 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::VmExtensionPolicyList::Warning
Output only. [Output Only] Informational warning message.
Corresponds to the JSON property warning
80208 80209 80210 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 80208 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
80215 80216 80217 80218 80219 80220 80221 80222 80223 80224 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 80215 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |