Class: Google::Apis::ComputeAlpha::VmExtensionState

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

State of an extension on an instance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VmExtensionState

Returns a new instance of VmExtensionState.



84007
84008
84009
# File 'lib/google/apis/compute_alpha/classes.rb', line 84007

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enforcement_msgString

The status message of the extension if the extension fails to enforce. Corresponds to the JSON property enforcementMsg

Returns:

  • (String)


83973
83974
83975
# File 'lib/google/apis/compute_alpha/classes.rb', line 83973

def enforcement_msg
  @enforcement_msg
end

#enforcement_stateString

The enforcement state of the extension. If the extension is not enforced yet, then the health status will not be specified. Corresponds to the JSON property enforcementState

Returns:

  • (String)


83980
83981
83982
# File 'lib/google/apis/compute_alpha/classes.rb', line 83980

def enforcement_state
  @enforcement_state
end

#health_msgString

The health status message of the extension. Corresponds to the JSON property healthMsg

Returns:

  • (String)


83985
83986
83987
# File 'lib/google/apis/compute_alpha/classes.rb', line 83985

def health_msg
  @health_msg
end

#health_statusString

The health status of the extension. Corresponds to the JSON property healthStatus

Returns:

  • (String)


83990
83991
83992
# File 'lib/google/apis/compute_alpha/classes.rb', line 83990

def health_status
  @health_status
end

#nameString

The name of the extension. Corresponds to the JSON property name

Returns:

  • (String)


83995
83996
83997
# File 'lib/google/apis/compute_alpha/classes.rb', line 83995

def name
  @name
end

#policy_idString

The id of the policy that is enforced on the extension. Corresponds to the JSON property policyId

Returns:

  • (String)


84000
84001
84002
# File 'lib/google/apis/compute_alpha/classes.rb', line 84000

def policy_id
  @policy_id
end

#versionString

The version of the extension. Corresponds to the JSON property version

Returns:

  • (String)


84005
84006
84007
# File 'lib/google/apis/compute_alpha/classes.rb', line 84005

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



84012
84013
84014
84015
84016
84017
84018
84019
84020
# File 'lib/google/apis/compute_alpha/classes.rb', line 84012

def update!(**args)
  @enforcement_msg = args[:enforcement_msg] if args.key?(:enforcement_msg)
  @enforcement_state = args[:enforcement_state] if args.key?(:enforcement_state)
  @health_msg = args[:health_msg] if args.key?(:health_msg)
  @health_status = args[:health_status] if args.key?(:health_status)
  @name = args[:name] if args.key?(:name)
  @policy_id = args[:policy_id] if args.key?(:policy_id)
  @version = args[:version] if args.key?(:version)
end