Class: Google::Apis::ComputeAlpha::VmExtensionState
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::VmExtensionState
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
State of an extension on an instance.
Instance Attribute Summary collapse
-
#enforcement_msg ⇒ String
The status message of the extension if the extension fails to enforce.
-
#enforcement_state ⇒ String
The enforcement state of the extension.
-
#health_msg ⇒ String
The health status message of the extension.
-
#health_status ⇒ String
The health status of the extension.
-
#name ⇒ String
The name of the extension.
-
#policy_id ⇒ String
The id of the policy that is enforced on the extension.
-
#version ⇒ String
The version of the extension.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VmExtensionState
constructor
A new instance of VmExtensionState.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VmExtensionState
Returns a new instance of VmExtensionState.
82229 82230 82231 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 82229 def initialize(**args) update!(**args) end |
Instance Attribute Details
#enforcement_msg ⇒ String
The status message of the extension if the extension fails to enforce.
Corresponds to the JSON property enforcementMsg
82195 82196 82197 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 82195 def enforcement_msg @enforcement_msg end |
#enforcement_state ⇒ String
The enforcement state of the extension.
If the extension is not enforced yet, then the health status will not be
specified.
Corresponds to the JSON property enforcementState
82202 82203 82204 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 82202 def enforcement_state @enforcement_state end |
#health_msg ⇒ String
The health status message of the extension.
Corresponds to the JSON property healthMsg
82207 82208 82209 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 82207 def health_msg @health_msg end |
#health_status ⇒ String
The health status of the extension.
Corresponds to the JSON property healthStatus
82212 82213 82214 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 82212 def health_status @health_status end |
#name ⇒ String
The name of the extension.
Corresponds to the JSON property name
82217 82218 82219 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 82217 def name @name end |
#policy_id ⇒ String
The id of the policy that is enforced on the extension.
Corresponds to the JSON property policyId
82222 82223 82224 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 82222 def policy_id @policy_id end |
#version ⇒ String
The version of the extension.
Corresponds to the JSON property version
82227 82228 82229 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 82227 def version @version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
82234 82235 82236 82237 82238 82239 82240 82241 82242 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 82234 def update!(**args) @enforcement_msg = args[:enforcement_msg] if args.key?(:enforcement_msg) @enforcement_state = args[:enforcement_state] if args.key?(:enforcement_state) @health_msg = args[:health_msg] if args.key?(:health_msg) @health_status = args[:health_status] if args.key?(:health_status) @name = args[:name] if args.key?(:name) @policy_id = args[:policy_id] if args.key?(:policy_id) @version = args[:version] if args.key?(:version) end |