Class: Google::Apis::ComputeAlpha::VmExtensionState

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

State of an extension on an instance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VmExtensionState

Returns a new instance of VmExtensionState.



81614
81615
81616
# File 'lib/google/apis/compute_alpha/classes.rb', line 81614

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enforcement_msgString

The status message of the extension if the extension fails to enforce. Corresponds to the JSON property enforcementMsg

Returns:

  • (String)


81580
81581
81582
# File 'lib/google/apis/compute_alpha/classes.rb', line 81580

def enforcement_msg
  @enforcement_msg
end

#enforcement_stateString

The enforcement state of the extension. If the extension is not enforced yet, then the health status will not be specified. Corresponds to the JSON property enforcementState

Returns:

  • (String)


81587
81588
81589
# File 'lib/google/apis/compute_alpha/classes.rb', line 81587

def enforcement_state
  @enforcement_state
end

#health_msgString

The health status message of the extension. Corresponds to the JSON property healthMsg

Returns:

  • (String)


81592
81593
81594
# File 'lib/google/apis/compute_alpha/classes.rb', line 81592

def health_msg
  @health_msg
end

#health_statusString

The health status of the extension. Corresponds to the JSON property healthStatus

Returns:

  • (String)


81597
81598
81599
# File 'lib/google/apis/compute_alpha/classes.rb', line 81597

def health_status
  @health_status
end

#nameString

The name of the extension. Corresponds to the JSON property name

Returns:

  • (String)


81602
81603
81604
# File 'lib/google/apis/compute_alpha/classes.rb', line 81602

def name
  @name
end

#policy_idString

The id of the policy that is enforced on the extension. Corresponds to the JSON property policyId

Returns:

  • (String)


81607
81608
81609
# File 'lib/google/apis/compute_alpha/classes.rb', line 81607

def policy_id
  @policy_id
end

#versionString

The version of the extension. Corresponds to the JSON property version

Returns:

  • (String)


81612
81613
81614
# File 'lib/google/apis/compute_alpha/classes.rb', line 81612

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



81619
81620
81621
81622
81623
81624
81625
81626
81627
# File 'lib/google/apis/compute_alpha/classes.rb', line 81619

def update!(**args)
  @enforcement_msg = args[:enforcement_msg] if args.key?(:enforcement_msg)
  @enforcement_state = args[:enforcement_state] if args.key?(:enforcement_state)
  @health_msg = args[:health_msg] if args.key?(:health_msg)
  @health_status = args[:health_status] if args.key?(:health_status)
  @name = args[:name] if args.key?(:name)
  @policy_id = args[:policy_id] if args.key?(:policy_id)
  @version = args[:version] if args.key?(:version)
end