Class: Google::Apis::ComputeAlpha::VmExtensionState

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

State of an extension on an instance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VmExtensionState

Returns a new instance of VmExtensionState.



80338
80339
80340
# File 'lib/google/apis/compute_alpha/classes.rb', line 80338

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enforcement_msgString

The status message of the extension if the extension fails to enforce. Corresponds to the JSON property enforcementMsg

Returns:

  • (String)


80304
80305
80306
# File 'lib/google/apis/compute_alpha/classes.rb', line 80304

def enforcement_msg
  @enforcement_msg
end

#enforcement_stateString

The enforcement state of the extension. If the extension is not enforced yet, then the health status will not be specified. Corresponds to the JSON property enforcementState

Returns:

  • (String)


80311
80312
80313
# File 'lib/google/apis/compute_alpha/classes.rb', line 80311

def enforcement_state
  @enforcement_state
end

#health_msgString

The health status message of the extension. Corresponds to the JSON property healthMsg

Returns:

  • (String)


80316
80317
80318
# File 'lib/google/apis/compute_alpha/classes.rb', line 80316

def health_msg
  @health_msg
end

#health_statusString

The health status of the extension. Corresponds to the JSON property healthStatus

Returns:

  • (String)


80321
80322
80323
# File 'lib/google/apis/compute_alpha/classes.rb', line 80321

def health_status
  @health_status
end

#nameString

The name of the extension. Corresponds to the JSON property name

Returns:

  • (String)


80326
80327
80328
# File 'lib/google/apis/compute_alpha/classes.rb', line 80326

def name
  @name
end

#policy_idString

The id of the policy that is enforced on the extension. Corresponds to the JSON property policyId

Returns:

  • (String)


80331
80332
80333
# File 'lib/google/apis/compute_alpha/classes.rb', line 80331

def policy_id
  @policy_id
end

#versionString

The version of the extension. Corresponds to the JSON property version

Returns:

  • (String)


80336
80337
80338
# File 'lib/google/apis/compute_alpha/classes.rb', line 80336

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



80343
80344
80345
80346
80347
80348
80349
80350
80351
# File 'lib/google/apis/compute_alpha/classes.rb', line 80343

def update!(**args)
  @enforcement_msg = args[:enforcement_msg] if args.key?(:enforcement_msg)
  @enforcement_state = args[:enforcement_state] if args.key?(:enforcement_state)
  @health_msg = args[:health_msg] if args.key?(:health_msg)
  @health_status = args[:health_status] if args.key?(:health_status)
  @name = args[:name] if args.key?(:name)
  @policy_id = args[:policy_id] if args.key?(:policy_id)
  @version = args[:version] if args.key?(:version)
end