Class: Google::Apis::ComputeAlpha::VpnGatewayAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VpnGatewayAggregatedList

Returns a new instance of VpnGatewayAggregatedList.



84198
84199
84200
# File 'lib/google/apis/compute_alpha/classes.rb', line 84198

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


84160
84161
84162
# File 'lib/google/apis/compute_alpha/classes.rb', line 84160

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::VpnGatewaysScopedList>

A list of VpnGateway resources. Corresponds to the JSON property items



84165
84166
84167
# File 'lib/google/apis/compute_alpha/classes.rb', line 84165

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#vpnGateway for VPN gateways. Corresponds to the JSON property kind

Returns:

  • (String)


84171
84172
84173
# File 'lib/google/apis/compute_alpha/classes.rb', line 84171

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


84181
84182
84183
# File 'lib/google/apis/compute_alpha/classes.rb', line 84181

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


84186
84187
84188
# File 'lib/google/apis/compute_alpha/classes.rb', line 84186

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


84191
84192
84193
# File 'lib/google/apis/compute_alpha/classes.rb', line 84191

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::VpnGatewayAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



84196
84197
84198
# File 'lib/google/apis/compute_alpha/classes.rb', line 84196

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



84203
84204
84205
84206
84207
84208
84209
84210
84211
# File 'lib/google/apis/compute_alpha/classes.rb', line 84203

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end