Class: Google::Apis::ComputeAlpha::VpnGatewayAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VpnGatewayAggregatedList

Returns a new instance of VpnGatewayAggregatedList.



82420
82421
82422
# File 'lib/google/apis/compute_alpha/classes.rb', line 82420

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


82382
82383
82384
# File 'lib/google/apis/compute_alpha/classes.rb', line 82382

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::VpnGatewaysScopedList>

A list of VpnGateway resources. Corresponds to the JSON property items



82387
82388
82389
# File 'lib/google/apis/compute_alpha/classes.rb', line 82387

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#vpnGateway for VPN gateways. Corresponds to the JSON property kind

Returns:

  • (String)


82393
82394
82395
# File 'lib/google/apis/compute_alpha/classes.rb', line 82393

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


82403
82404
82405
# File 'lib/google/apis/compute_alpha/classes.rb', line 82403

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


82408
82409
82410
# File 'lib/google/apis/compute_alpha/classes.rb', line 82408

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


82413
82414
82415
# File 'lib/google/apis/compute_alpha/classes.rb', line 82413

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::VpnGatewayAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



82418
82419
82420
# File 'lib/google/apis/compute_alpha/classes.rb', line 82418

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



82425
82426
82427
82428
82429
82430
82431
82432
82433
# File 'lib/google/apis/compute_alpha/classes.rb', line 82425

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end