Class: Google::Apis::ComputeAlpha::VpnGatewayAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VpnGatewayAggregatedList

Returns a new instance of VpnGatewayAggregatedList.



81807
81808
81809
# File 'lib/google/apis/compute_alpha/classes.rb', line 81807

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


81769
81770
81771
# File 'lib/google/apis/compute_alpha/classes.rb', line 81769

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::VpnGatewaysScopedList>

A list of VpnGateway resources. Corresponds to the JSON property items



81774
81775
81776
# File 'lib/google/apis/compute_alpha/classes.rb', line 81774

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#vpnGateway for VPN gateways. Corresponds to the JSON property kind

Returns:

  • (String)


81780
81781
81782
# File 'lib/google/apis/compute_alpha/classes.rb', line 81780

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


81790
81791
81792
# File 'lib/google/apis/compute_alpha/classes.rb', line 81790

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


81795
81796
81797
# File 'lib/google/apis/compute_alpha/classes.rb', line 81795

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


81800
81801
81802
# File 'lib/google/apis/compute_alpha/classes.rb', line 81800

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::VpnGatewayAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



81805
81806
81807
# File 'lib/google/apis/compute_alpha/classes.rb', line 81805

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



81812
81813
81814
81815
81816
81817
81818
81819
81820
# File 'lib/google/apis/compute_alpha/classes.rb', line 81812

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end