Class: Google::Apis::ComputeAlpha::VpnGatewayAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::VpnGatewayAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::VpnGatewaysScopedList>
A list of VpnGateway resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::VpnGatewayAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VpnGatewayAggregatedList
constructor
A new instance of VpnGatewayAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VpnGatewayAggregatedList
Returns a new instance of VpnGatewayAggregatedList.
81805 81806 81807 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 81805 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
81767 81768 81769 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 81767 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::VpnGatewaysScopedList>
A list of VpnGateway resources.
Corresponds to the JSON property items
81772 81773 81774 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 81772 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#vpnGateway for
VPN gateways.
Corresponds to the JSON property kind
81778 81779 81780 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 81778 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
81788 81789 81790 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 81788 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
81793 81794 81795 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 81793 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
81798 81799 81800 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 81798 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::VpnGatewayAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
81803 81804 81805 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 81803 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
81810 81811 81812 81813 81814 81815 81816 81817 81818 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 81810 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |