Class: Google::Apis::ComputeAlpha::VpnGatewayAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::VpnGatewayAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::VpnGatewaysScopedList>
A list of VpnGateway resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::VpnGatewayAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VpnGatewayAggregatedList
constructor
A new instance of VpnGatewayAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VpnGatewayAggregatedList
Returns a new instance of VpnGatewayAggregatedList.
80529 80530 80531 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 80529 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
80491 80492 80493 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 80491 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::VpnGatewaysScopedList>
A list of VpnGateway resources.
Corresponds to the JSON property items
80496 80497 80498 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 80496 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#vpnGateway for
VPN gateways.
Corresponds to the JSON property kind
80502 80503 80504 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 80502 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
80512 80513 80514 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 80512 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
80517 80518 80519 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 80517 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
80522 80523 80524 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 80522 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::VpnGatewayAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
80527 80528 80529 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 80527 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
80534 80535 80536 80537 80538 80539 80540 80541 80542 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 80534 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |