Class: Google::Apis::ComputeAlpha::VpnGatewayList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of VpnGateway resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VpnGatewayList

Returns a new instance of VpnGatewayList.



84324
84325
84326
# File 'lib/google/apis/compute_alpha/classes.rb', line 84324

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


84291
84292
84293
# File 'lib/google/apis/compute_alpha/classes.rb', line 84291

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::VpnGateway>

A list of VpnGateway resources. Corresponds to the JSON property items



84296
84297
84298
# File 'lib/google/apis/compute_alpha/classes.rb', line 84296

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#vpnGateway for VPN gateways. Corresponds to the JSON property kind

Returns:

  • (String)


84302
84303
84304
# File 'lib/google/apis/compute_alpha/classes.rb', line 84302

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


84312
84313
84314
# File 'lib/google/apis/compute_alpha/classes.rb', line 84312

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


84317
84318
84319
# File 'lib/google/apis/compute_alpha/classes.rb', line 84317

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::VpnGatewayList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



84322
84323
84324
# File 'lib/google/apis/compute_alpha/classes.rb', line 84322

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



84329
84330
84331
84332
84333
84334
84335
84336
# File 'lib/google/apis/compute_alpha/classes.rb', line 84329

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end