Class: Google::Apis::ComputeAlpha::VpnGatewayList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::VpnGatewayList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Contains a list of VpnGateway resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::VpnGateway>
A list of VpnGateway resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::VpnGatewayList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VpnGatewayList
constructor
A new instance of VpnGatewayList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VpnGatewayList
Returns a new instance of VpnGatewayList.
83971 83972 83973 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 83971 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
83938 83939 83940 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 83938 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::VpnGateway>
A list of VpnGateway resources.
Corresponds to the JSON property items
83943 83944 83945 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 83943 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#vpnGateway for
VPN gateways.
Corresponds to the JSON property kind
83949 83950 83951 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 83949 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
83959 83960 83961 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 83959 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
83964 83965 83966 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 83964 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::VpnGatewayList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
83969 83970 83971 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 83969 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
83976 83977 83978 83979 83980 83981 83982 83983 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 83976 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |