Class: Google::Apis::ComputeAlpha::VpnGatewayList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of VpnGateway resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VpnGatewayList

Returns a new instance of VpnGatewayList.



81931
81932
81933
# File 'lib/google/apis/compute_alpha/classes.rb', line 81931

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


81898
81899
81900
# File 'lib/google/apis/compute_alpha/classes.rb', line 81898

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::VpnGateway>

A list of VpnGateway resources. Corresponds to the JSON property items



81903
81904
81905
# File 'lib/google/apis/compute_alpha/classes.rb', line 81903

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#vpnGateway for VPN gateways. Corresponds to the JSON property kind

Returns:

  • (String)


81909
81910
81911
# File 'lib/google/apis/compute_alpha/classes.rb', line 81909

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


81919
81920
81921
# File 'lib/google/apis/compute_alpha/classes.rb', line 81919

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


81924
81925
81926
# File 'lib/google/apis/compute_alpha/classes.rb', line 81924

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::VpnGatewayList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



81929
81930
81931
# File 'lib/google/apis/compute_alpha/classes.rb', line 81929

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



81936
81937
81938
81939
81940
81941
81942
81943
# File 'lib/google/apis/compute_alpha/classes.rb', line 81936

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end