Class: Google::Apis::ComputeAlpha::VpnGatewayStatusHighAvailabilityRequirementState

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Describes the high availability requirement state for the VPN connection between this Cloud VPN gateway and a peer gateway.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VpnGatewayStatusHighAvailabilityRequirementState

Returns a new instance of VpnGatewayStatusHighAvailabilityRequirementState.



82757
82758
82759
# File 'lib/google/apis/compute_alpha/classes.rb', line 82757

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#stateString

Indicates the high availability requirement state for the VPN connection. Valid values are CONNECTION_REDUNDANCY_MET,CONNECTION_REDUNDANCY_NOT_MET. Corresponds to the JSON property state

Returns:

  • (String)


82748
82749
82750
# File 'lib/google/apis/compute_alpha/classes.rb', line 82748

def state
  @state
end

#unsatisfied_reasonString

Indicates the reason why the VPN connection does not meet the high availability redundancy criteria/requirement. Valid values is INCOMPLETE_TUNNELS_COVERAGE. Corresponds to the JSON property unsatisfiedReason

Returns:

  • (String)


82755
82756
82757
# File 'lib/google/apis/compute_alpha/classes.rb', line 82755

def unsatisfied_reason
  @unsatisfied_reason
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



82762
82763
82764
82765
# File 'lib/google/apis/compute_alpha/classes.rb', line 82762

def update!(**args)
  @state = args[:state] if args.key?(:state)
  @unsatisfied_reason = args[:unsatisfied_reason] if args.key?(:unsatisfied_reason)
end