Class: Google::Apis::ComputeAlpha::VpnTunnel
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::VpnTunnel
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Represents a Cloud VPN Tunnel resource. For more information about VPN, read the the Cloud VPN Overview.
Instance Attribute Summary collapse
-
#capacity_tier ⇒ String
Capacity tier of the VPN tunnel.
-
#cipher_suite ⇒ Google::Apis::ComputeAlpha::VpnTunnelCipherSuite
User specified list of ciphers to use for the phase 1 and phase 2 of the IKE protocol.
-
#creation_timestamp ⇒ String
Output only.
-
#description ⇒ String
An optional description of this resource.
-
#detailed_status ⇒ String
[Output Only] Detailed status message for the VPN tunnel.
-
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource.
-
#ike_version ⇒ Fixnum
IKE protocol version to use when establishing the VPN tunnel with the peer VPN gateway.
-
#kind ⇒ String
Output only.
-
#label_fingerprint ⇒ String
A fingerprint for the labels being applied to this VpnTunnel, which is essentially a hash of the labels set used for optimistic locking.
-
#labels ⇒ Hash<String,String>
Labels for this resource.
-
#local_traffic_selector ⇒ Array<String>
Local traffic selector to use when establishing the VPN tunnel with the peer VPN gateway.
-
#name ⇒ String
Name of the resource.
-
#params ⇒ Google::Apis::ComputeAlpha::VpnTunnelParams
Input only.
-
#peer_external_gateway ⇒ String
URL of the peer side external VPN gateway to which this VPN tunnel is connected.
-
#peer_external_gateway_interface ⇒ Fixnum
The interface ID of the external VPN gateway to which this VPN tunnel is connected.
-
#peer_gcp_gateway ⇒ String
URL of the peer side HA VPN gateway to which this VPN tunnel is connected.
-
#peer_ip ⇒ String
IP address of the peer VPN gateway.
-
#region ⇒ String
[Output Only] URL of the region where the VPN tunnel resides.
-
#remote_traffic_selector ⇒ Array<String>
Remote traffic selectors to use when establishing the VPN tunnel with the peer VPN gateway.
-
#router ⇒ String
URL of the router resource to be used for dynamic routing.
-
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
-
#shared_secret ⇒ String
Shared secret used to set the secure session between the Cloud VPN gateway and the peer VPN gateway.
-
#shared_secret_hash ⇒ String
Hash of the shared secret.
-
#status ⇒ String
[Output Only] The status of the VPN tunnel, which can be one of the following:.
-
#target_vpn_gateway ⇒ String
URL of the Target VPN gateway with which this VPN tunnel is associated.
-
#vpn_gateway ⇒ String
URL of the VPN gateway with which this VPN tunnel is associated.
-
#vpn_gateway_interface ⇒ Fixnum
The interface ID of the VPN gateway with which this VPN tunnel is associated.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VpnTunnel
constructor
A new instance of VpnTunnel.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VpnTunnel
Returns a new instance of VpnTunnel.
81302 81303 81304 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 81302 def initialize(**args) update!(**args) end |
Instance Attribute Details
#capacity_tier ⇒ String
Capacity tier of the VPN tunnel. This is used for IPsec over Interconnect
tunnels to indicate different bandwidth limits.
Corresponds to the JSON property capacityTier
81084 81085 81086 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 81084 def capacity_tier @capacity_tier end |
#cipher_suite ⇒ Google::Apis::ComputeAlpha::VpnTunnelCipherSuite
User specified list of ciphers to use for the phase 1 and phase 2 of the
IKE protocol.
Corresponds to the JSON property cipherSuite
81090 81091 81092 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 81090 def cipher_suite @cipher_suite end |
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
81096 81097 81098 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 81096 def @creation_timestamp end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
81102 81103 81104 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 81102 def description @description end |
#detailed_status ⇒ String
[Output Only] Detailed status message for the VPN tunnel.
Corresponds to the JSON property detailedStatus
81107 81108 81109 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 81107 def detailed_status @detailed_status end |
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
81113 81114 81115 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 81113 def id @id end |
#ike_version ⇒ Fixnum
IKE protocol version to use when establishing the VPN tunnel with the peer
VPN gateway. Acceptable IKE versions are 1 or 2.
The default version is 2.
Corresponds to the JSON property ikeVersion
81120 81121 81122 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 81120 def ike_version @ike_version end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#vpnTunnel for
VPN tunnels.
Corresponds to the JSON property kind
81126 81127 81128 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 81126 def kind @kind end |
#label_fingerprint ⇒ String
A fingerprint for the labels being applied to this VpnTunnel, which is
essentially a hash of the labels set used for optimistic locking. The
fingerprint is initially generated by Compute Engine and changes after
every request to modify or update labels. You must always provide an
up-to-date fingerprint hash in order to update or change labels,
otherwise the request will fail with error412 conditionNotMet.
To see the latest fingerprint, make a get() request to
retrieve a VpnTunnel.
Corresponds to the JSON property labelFingerprint
NOTE: Values are automatically base64 encoded/decoded in the client library.
81139 81140 81141 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 81139 def label_fingerprint @label_fingerprint end |
#labels ⇒ Hash<String,String>
Labels for this resource. These can only be added or modified by thesetLabels
method. Each label key/value pair must comply withRFC1035.
Label values may be empty.
Corresponds to the JSON property labels
81146 81147 81148 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 81146 def labels @labels end |
#local_traffic_selector ⇒ Array<String>
Local traffic selector to use when establishing the VPN tunnel with the
peer VPN gateway. The value should be a CIDR formatted string, for
example: 192.168.0.0/16. The ranges must be disjoint.
Only IPv4 is supported for Classic VPN tunnels. This field is output only
for HA VPN tunnels.
Corresponds to the JSON property localTrafficSelector
81155 81156 81157 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 81155 def local_traffic_selector @local_traffic_selector end |
#name ⇒ String
Name of the resource. Provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must
be a dash, lowercase letter, or digit, except the last character, which
cannot be a dash.
Corresponds to the JSON property name
81166 81167 81168 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 81166 def name @name end |
#params ⇒ Google::Apis::ComputeAlpha::VpnTunnelParams
Input only. [Input Only] Additional params passed with the request, but not
persisted
as part of resource payload.
Corresponds to the JSON property params
81173 81174 81175 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 81173 def params @params end |
#peer_external_gateway ⇒ String
URL of the peer side external VPN gateway to which this VPN tunnel is
connected.
Provided by the client when the VPN tunnel is created.
This field is exclusive with the field peerGcpGateway.
Corresponds to the JSON property peerExternalGateway
81181 81182 81183 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 81181 def peer_external_gateway @peer_external_gateway end |
#peer_external_gateway_interface ⇒ Fixnum
The interface ID of the external VPN gateway to which this VPN tunnel is
connected. Provided by the client when the VPN tunnel is created.
Possible values are: 0, 1, 2, 3. The number of IDs in use
depends on the external VPN gateway redundancy type.
Corresponds to the JSON property peerExternalGatewayInterface
81189 81190 81191 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 81189 def peer_external_gateway_interface @peer_external_gateway_interface end |
#peer_gcp_gateway ⇒ String
URL of the peer side HA VPN gateway to which this VPN tunnel
is connected. Provided by the client when the VPN tunnel is created.
This field can be used when creating highly available VPN from VPC network
to VPC network, the field is exclusive with the field peerExternalGateway.
If provided, the VPN tunnel will automatically use the same
vpnGatewayInterface ID in the peer Google Cloud VPN gateway.
Corresponds to the JSON property peerGcpGateway
81199 81200 81201 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 81199 def peer_gcp_gateway @peer_gcp_gateway end |
#peer_ip ⇒ String
IP address of the peer VPN gateway. Only IPv4 is supported. This field can
be set only for Classic VPN tunnels.
Corresponds to the JSON property peerIp
81205 81206 81207 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 81205 def peer_ip @peer_ip end |
#region ⇒ String
[Output Only] URL of the region where the VPN tunnel resides.
You must specify this field as part of the HTTP request URL. It is
not settable as a field in the request body.
Corresponds to the JSON property region
81212 81213 81214 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 81212 def region @region end |
#remote_traffic_selector ⇒ Array<String>
Remote traffic selectors to use when establishing the VPN tunnel with
the peer VPN gateway. The value should be a CIDR formatted string,
for example: 192.168.0.0/16. The ranges should be disjoint. Only IPv4 is
supported for Classic VPN tunnels. This field is output only for HA VPN
tunnels.
Corresponds to the JSON property remoteTrafficSelector
81221 81222 81223 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 81221 def remote_traffic_selector @remote_traffic_selector end |
#router ⇒ String
URL of the router resource to be used for dynamic routing.
Corresponds to the JSON property router
81226 81227 81228 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 81226 def router @router end |
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
81231 81232 81233 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 81231 def self_link @self_link end |
#shared_secret ⇒ String
Shared secret used to set the secure session between the Cloud VPN gateway
and the peer VPN gateway.
Corresponds to the JSON property sharedSecret
81237 81238 81239 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 81237 def shared_secret @shared_secret end |
#shared_secret_hash ⇒ String
Hash of the shared secret.
Corresponds to the JSON property sharedSecretHash
81242 81243 81244 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 81242 def shared_secret_hash @shared_secret_hash end |
#status ⇒ String
[Output Only] The status of the VPN tunnel, which can be one of the following:
- PROVISIONING: Resource is being allocated for the VPN tunnel.
- WAITING_FOR_FULL_CONFIG: Waiting to receive all VPN-related configs from the user. Network, TargetVpnGateway, VpnTunnel, ForwardingRule, and Route resources are needed to setup the VPN tunnel.
- FIRST_HANDSHAKE: Successful first handshake with the peer VPN.
- ESTABLISHED: Secure session is successfully established with the peer VPN.
- NETWORK_ERROR: Deprecated, replaced by NO_INCOMING_PACKETS
- AUTHORIZATION_ERROR: Auth error (for example, bad shared secret).
- NEGOTIATION_FAILURE: Handshake failed.
- DEPROVISIONING: Resources are being deallocated for the VPN tunnel.
- FAILED: Tunnel creation has failed and the tunnel is not ready to be used.
- NO_INCOMING_PACKETS: No incoming packets from peer.
- REJECTED: Tunnel configuration was rejected, can be result of being denied access.
- ALLOCATING_RESOURCES: Cloud VPN is in the process of allocating all required resources.
- STOPPED: Tunnel is stopped due to its Forwarding Rules being deleted for Classic VPN tunnels or the project is in frozen state.
- PEER_IDENTITY_MISMATCH: Peer identity does not match peer IP, probably behind NAT.
- TS_NARROWING_NOT_ALLOWED: Traffic selector
narrowing not allowed for an HA-VPN tunnel.
Corresponds to the JSON property
status
81278 81279 81280 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 81278 def status @status end |
#target_vpn_gateway ⇒ String
URL of the Target VPN gateway with which this VPN tunnel is associated.
Provided by the client when the VPN tunnel is created.
This field can be set only for Classic VPN tunnels.
Corresponds to the JSON property targetVpnGateway
81285 81286 81287 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 81285 def target_vpn_gateway @target_vpn_gateway end |
#vpn_gateway ⇒ String
URL of the VPN gateway with which this VPN tunnel is associated.
Provided by the client when the VPN tunnel is created. This must be
used (instead of target_vpn_gateway) if a High Availability VPN gateway
resource is created.
Corresponds to the JSON property vpnGateway
81293 81294 81295 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 81293 def vpn_gateway @vpn_gateway end |
#vpn_gateway_interface ⇒ Fixnum
The interface ID of the VPN gateway with which this VPN tunnel is
associated.
Possible values are: 0, 1.
Corresponds to the JSON property vpnGatewayInterface
81300 81301 81302 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 81300 def vpn_gateway_interface @vpn_gateway_interface end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
81307 81308 81309 81310 81311 81312 81313 81314 81315 81316 81317 81318 81319 81320 81321 81322 81323 81324 81325 81326 81327 81328 81329 81330 81331 81332 81333 81334 81335 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 81307 def update!(**args) @capacity_tier = args[:capacity_tier] if args.key?(:capacity_tier) @cipher_suite = args[:cipher_suite] if args.key?(:cipher_suite) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @detailed_status = args[:detailed_status] if args.key?(:detailed_status) @id = args[:id] if args.key?(:id) @ike_version = args[:ike_version] if args.key?(:ike_version) @kind = args[:kind] if args.key?(:kind) @label_fingerprint = args[:label_fingerprint] if args.key?(:label_fingerprint) @labels = args[:labels] if args.key?(:labels) @local_traffic_selector = args[:local_traffic_selector] if args.key?(:local_traffic_selector) @name = args[:name] if args.key?(:name) @params = args[:params] if args.key?(:params) @peer_external_gateway = args[:peer_external_gateway] if args.key?(:peer_external_gateway) @peer_external_gateway_interface = args[:peer_external_gateway_interface] if args.key?(:peer_external_gateway_interface) @peer_gcp_gateway = args[:peer_gcp_gateway] if args.key?(:peer_gcp_gateway) @peer_ip = args[:peer_ip] if args.key?(:peer_ip) @region = args[:region] if args.key?(:region) @remote_traffic_selector = args[:remote_traffic_selector] if args.key?(:remote_traffic_selector) @router = args[:router] if args.key?(:router) @self_link = args[:self_link] if args.key?(:self_link) @shared_secret = args[:shared_secret] if args.key?(:shared_secret) @shared_secret_hash = args[:shared_secret_hash] if args.key?(:shared_secret_hash) @status = args[:status] if args.key?(:status) @target_vpn_gateway = args[:target_vpn_gateway] if args.key?(:target_vpn_gateway) @vpn_gateway = args[:vpn_gateway] if args.key?(:vpn_gateway) @vpn_gateway_interface = args[:vpn_gateway_interface] if args.key?(:vpn_gateway_interface) end |