Class: Google::Apis::ComputeAlpha::VpnTunnelAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VpnTunnelAggregatedList

Returns a new instance of VpnTunnelAggregatedList.



83331
83332
83333
# File 'lib/google/apis/compute_alpha/classes.rb', line 83331

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


83293
83294
83295
# File 'lib/google/apis/compute_alpha/classes.rb', line 83293

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::VpnTunnelsScopedList>

A list of VpnTunnelsScopedList resources. Corresponds to the JSON property items



83298
83299
83300
# File 'lib/google/apis/compute_alpha/classes.rb', line 83298

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#vpnTunnel for VPN tunnels. Corresponds to the JSON property kind

Returns:

  • (String)


83304
83305
83306
# File 'lib/google/apis/compute_alpha/classes.rb', line 83304

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


83314
83315
83316
# File 'lib/google/apis/compute_alpha/classes.rb', line 83314

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


83319
83320
83321
# File 'lib/google/apis/compute_alpha/classes.rb', line 83319

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


83324
83325
83326
# File 'lib/google/apis/compute_alpha/classes.rb', line 83324

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::VpnTunnelAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



83329
83330
83331
# File 'lib/google/apis/compute_alpha/classes.rb', line 83329

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



83336
83337
83338
83339
83340
83341
83342
83343
83344
# File 'lib/google/apis/compute_alpha/classes.rb', line 83336

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end