Class: Google::Apis::ComputeAlpha::VpnTunnelAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VpnTunnelAggregatedList

Returns a new instance of VpnTunnelAggregatedList.



83274
83275
83276
# File 'lib/google/apis/compute_alpha/classes.rb', line 83274

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


83236
83237
83238
# File 'lib/google/apis/compute_alpha/classes.rb', line 83236

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::VpnTunnelsScopedList>

A list of VpnTunnelsScopedList resources. Corresponds to the JSON property items



83241
83242
83243
# File 'lib/google/apis/compute_alpha/classes.rb', line 83241

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#vpnTunnel for VPN tunnels. Corresponds to the JSON property kind

Returns:

  • (String)


83247
83248
83249
# File 'lib/google/apis/compute_alpha/classes.rb', line 83247

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


83257
83258
83259
# File 'lib/google/apis/compute_alpha/classes.rb', line 83257

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


83262
83263
83264
# File 'lib/google/apis/compute_alpha/classes.rb', line 83262

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


83267
83268
83269
# File 'lib/google/apis/compute_alpha/classes.rb', line 83267

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::VpnTunnelAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



83272
83273
83274
# File 'lib/google/apis/compute_alpha/classes.rb', line 83272

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



83279
83280
83281
83282
83283
83284
83285
83286
83287
# File 'lib/google/apis/compute_alpha/classes.rb', line 83279

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end