Class: Google::Apis::ComputeAlpha::VpnTunnelAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VpnTunnelAggregatedList

Returns a new instance of VpnTunnelAggregatedList.



82659
82660
82661
# File 'lib/google/apis/compute_alpha/classes.rb', line 82659

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


82621
82622
82623
# File 'lib/google/apis/compute_alpha/classes.rb', line 82621

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::VpnTunnelsScopedList>

A list of VpnTunnelsScopedList resources. Corresponds to the JSON property items



82626
82627
82628
# File 'lib/google/apis/compute_alpha/classes.rb', line 82626

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#vpnTunnel for VPN tunnels. Corresponds to the JSON property kind

Returns:

  • (String)


82632
82633
82634
# File 'lib/google/apis/compute_alpha/classes.rb', line 82632

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


82642
82643
82644
# File 'lib/google/apis/compute_alpha/classes.rb', line 82642

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


82647
82648
82649
# File 'lib/google/apis/compute_alpha/classes.rb', line 82647

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


82652
82653
82654
# File 'lib/google/apis/compute_alpha/classes.rb', line 82652

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::VpnTunnelAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



82657
82658
82659
# File 'lib/google/apis/compute_alpha/classes.rb', line 82657

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



82664
82665
82666
82667
82668
82669
82670
82671
82672
# File 'lib/google/apis/compute_alpha/classes.rb', line 82664

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end