Class: Google::Apis::ComputeAlpha::VpnTunnelAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VpnTunnelAggregatedList

Returns a new instance of VpnTunnelAggregatedList.



82393
82394
82395
# File 'lib/google/apis/compute_alpha/classes.rb', line 82393

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


82355
82356
82357
# File 'lib/google/apis/compute_alpha/classes.rb', line 82355

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeAlpha::VpnTunnelsScopedList>

A list of VpnTunnelsScopedList resources. Corresponds to the JSON property items



82360
82361
82362
# File 'lib/google/apis/compute_alpha/classes.rb', line 82360

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#vpnTunnel for VPN tunnels. Corresponds to the JSON property kind

Returns:

  • (String)


82366
82367
82368
# File 'lib/google/apis/compute_alpha/classes.rb', line 82366

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


82376
82377
82378
# File 'lib/google/apis/compute_alpha/classes.rb', line 82376

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


82381
82382
82383
# File 'lib/google/apis/compute_alpha/classes.rb', line 82381

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


82386
82387
82388
# File 'lib/google/apis/compute_alpha/classes.rb', line 82386

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::VpnTunnelAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



82391
82392
82393
# File 'lib/google/apis/compute_alpha/classes.rb', line 82391

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



82398
82399
82400
82401
82402
82403
82404
82405
82406
# File 'lib/google/apis/compute_alpha/classes.rb', line 82398

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end