Class: Google::Apis::ComputeAlpha::VpnTunnelAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::VpnTunnelAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::VpnTunnelsScopedList>
A list of VpnTunnelsScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::VpnTunnelAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VpnTunnelAggregatedList
constructor
A new instance of VpnTunnelAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VpnTunnelAggregatedList
Returns a new instance of VpnTunnelAggregatedList.
81383 81384 81385 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 81383 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
81345 81346 81347 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 81345 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeAlpha::VpnTunnelsScopedList>
A list of VpnTunnelsScopedList resources.
Corresponds to the JSON property items
81350 81351 81352 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 81350 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#vpnTunnel for
VPN tunnels.
Corresponds to the JSON property kind
81356 81357 81358 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 81356 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
81366 81367 81368 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 81366 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
81371 81372 81373 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 81371 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
81376 81377 81378 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 81376 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::VpnTunnelAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
81381 81382 81383 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 81381 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
81388 81389 81390 81391 81392 81393 81394 81395 81396 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 81388 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |