Class: Google::Apis::ComputeAlpha::VpnTunnelList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of VpnTunnel resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VpnTunnelList

Returns a new instance of VpnTunnelList.



85203
85204
85205
# File 'lib/google/apis/compute_alpha/classes.rb', line 85203

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


85170
85171
85172
# File 'lib/google/apis/compute_alpha/classes.rb', line 85170

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::VpnTunnel>

A list of VpnTunnel resources. Corresponds to the JSON property items



85175
85176
85177
# File 'lib/google/apis/compute_alpha/classes.rb', line 85175

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#vpnTunnel for VPN tunnels. Corresponds to the JSON property kind

Returns:

  • (String)


85181
85182
85183
# File 'lib/google/apis/compute_alpha/classes.rb', line 85181

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


85191
85192
85193
# File 'lib/google/apis/compute_alpha/classes.rb', line 85191

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


85196
85197
85198
# File 'lib/google/apis/compute_alpha/classes.rb', line 85196

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::VpnTunnelList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



85201
85202
85203
# File 'lib/google/apis/compute_alpha/classes.rb', line 85201

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



85208
85209
85210
85211
85212
85213
85214
85215
# File 'lib/google/apis/compute_alpha/classes.rb', line 85208

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end