Class: Google::Apis::ComputeAlpha::VpnTunnelList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of VpnTunnel resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VpnTunnelList

Returns a new instance of VpnTunnelList.



83482
83483
83484
# File 'lib/google/apis/compute_alpha/classes.rb', line 83482

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


83449
83450
83451
# File 'lib/google/apis/compute_alpha/classes.rb', line 83449

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::VpnTunnel>

A list of VpnTunnel resources. Corresponds to the JSON property items



83454
83455
83456
# File 'lib/google/apis/compute_alpha/classes.rb', line 83454

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#vpnTunnel for VPN tunnels. Corresponds to the JSON property kind

Returns:

  • (String)


83460
83461
83462
# File 'lib/google/apis/compute_alpha/classes.rb', line 83460

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


83470
83471
83472
# File 'lib/google/apis/compute_alpha/classes.rb', line 83470

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


83475
83476
83477
# File 'lib/google/apis/compute_alpha/classes.rb', line 83475

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::VpnTunnelList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



83480
83481
83482
# File 'lib/google/apis/compute_alpha/classes.rb', line 83480

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



83487
83488
83489
83490
83491
83492
83493
83494
# File 'lib/google/apis/compute_alpha/classes.rb', line 83487

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end