Class: Google::Apis::ComputeAlpha::VpnTunnelList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::VpnTunnelList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Contains a list of VpnTunnel resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::VpnTunnel>
A list of VpnTunnel resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::VpnTunnelList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VpnTunnelList
constructor
A new instance of VpnTunnelList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VpnTunnelList
Returns a new instance of VpnTunnelList.
83425 83426 83427 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 83425 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
83392 83393 83394 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 83392 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::VpnTunnel>
A list of VpnTunnel resources.
Corresponds to the JSON property items
83397 83398 83399 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 83397 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#vpnTunnel for
VPN tunnels.
Corresponds to the JSON property kind
83403 83404 83405 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 83403 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
83413 83414 83415 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 83413 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
83418 83419 83420 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 83418 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::VpnTunnelList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
83423 83424 83425 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 83423 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
83430 83431 83432 83433 83434 83435 83436 83437 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 83430 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |