Class: Google::Apis::ComputeAlpha::VpnTunnelList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of VpnTunnel resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VpnTunnelList

Returns a new instance of VpnTunnelList.



82810
82811
82812
# File 'lib/google/apis/compute_alpha/classes.rb', line 82810

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


82777
82778
82779
# File 'lib/google/apis/compute_alpha/classes.rb', line 82777

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::VpnTunnel>

A list of VpnTunnel resources. Corresponds to the JSON property items



82782
82783
82784
# File 'lib/google/apis/compute_alpha/classes.rb', line 82782

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#vpnTunnel for VPN tunnels. Corresponds to the JSON property kind

Returns:

  • (String)


82788
82789
82790
# File 'lib/google/apis/compute_alpha/classes.rb', line 82788

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


82798
82799
82800
# File 'lib/google/apis/compute_alpha/classes.rb', line 82798

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


82803
82804
82805
# File 'lib/google/apis/compute_alpha/classes.rb', line 82803

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::VpnTunnelList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



82808
82809
82810
# File 'lib/google/apis/compute_alpha/classes.rb', line 82808

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



82815
82816
82817
82818
82819
82820
82821
82822
# File 'lib/google/apis/compute_alpha/classes.rb', line 82815

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end