Class: Google::Apis::ComputeAlpha::VpnTunnelList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::VpnTunnelList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Contains a list of VpnTunnel resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::VpnTunnel>
A list of VpnTunnel resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::VpnTunnelList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VpnTunnelList
constructor
A new instance of VpnTunnelList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VpnTunnelList
Returns a new instance of VpnTunnelList.
81534 81535 81536 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 81534 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
81501 81502 81503 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 81501 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::VpnTunnel>
A list of VpnTunnel resources.
Corresponds to the JSON property items
81506 81507 81508 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 81506 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#vpnTunnel for
VPN tunnels.
Corresponds to the JSON property kind
81512 81513 81514 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 81512 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
81522 81523 81524 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 81522 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
81527 81528 81529 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 81527 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::VpnTunnelList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
81532 81533 81534 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 81532 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
81539 81540 81541 81542 81543 81544 81545 81546 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 81539 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |