Class: Google::Apis::ComputeAlpha::WafExpressionSet

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WafExpressionSet

Returns a new instance of WafExpressionSet.



82852
82853
82854
# File 'lib/google/apis/compute_alpha/classes.rb', line 82852

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#aliasesArray<String>

A list of alternate IDs. The format should be:

  • E.g. XSS-stable Generic suffix like "stable" is particularly useful if a policy likes to avail newer set of expressions without having to change the policy. A given alias name can't be used for more than one entity set. Corresponds to the JSON property aliases

Returns:

  • (Array<String>)


82838
82839
82840
# File 'lib/google/apis/compute_alpha/classes.rb', line 82838

def aliases
  @aliases
end

#expressionsArray<Google::Apis::ComputeAlpha::WafExpressionSetExpression>

List of available expressions. Corresponds to the JSON property expressions



82843
82844
82845
# File 'lib/google/apis/compute_alpha/classes.rb', line 82843

def expressions
  @expressions
end

#idString

Google specified expression set ID. The format should be:

  • E.g. XSS-20170329 required Corresponds to the JSON property id

Returns:

  • (String)


82850
82851
82852
# File 'lib/google/apis/compute_alpha/classes.rb', line 82850

def id
  @id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



82857
82858
82859
82860
82861
# File 'lib/google/apis/compute_alpha/classes.rb', line 82857

def update!(**args)
  @aliases = args[:aliases] if args.key?(:aliases)
  @expressions = args[:expressions] if args.key?(:expressions)
  @id = args[:id] if args.key?(:id)
end