Class: Google::Apis::ComputeAlpha::WafExpressionSetExpression

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WafExpressionSetExpression

Returns a new instance of WafExpressionSetExpression.



85545
85546
85547
# File 'lib/google/apis/compute_alpha/classes.rb', line 85545

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Expression ID should uniquely identify the origin of the expression. E.g. owasp-crs-v020901-id973337 identifies Owasp core rule set version 2.9.1 rule id 973337. The ID could be used to determine the individual attack definition that has been detected. It could also be used to exclude it from the policy in case of false positive. required Corresponds to the JSON property id

Returns:

  • (String)


85536
85537
85538
# File 'lib/google/apis/compute_alpha/classes.rb', line 85536

def id
  @id
end

#sensitivityFixnum

The sensitivity value associated with the WAF rule ID. This corresponds to the ModSecurity paranoia level, ranging from 1 to 4. 0 is reserved for opt-in only rules. Corresponds to the JSON property sensitivity

Returns:

  • (Fixnum)


85543
85544
85545
# File 'lib/google/apis/compute_alpha/classes.rb', line 85543

def sensitivity
  @sensitivity
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



85550
85551
85552
85553
# File 'lib/google/apis/compute_alpha/classes.rb', line 85550

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @sensitivity = args[:sensitivity] if args.key?(:sensitivity)
end