Class: Google::Apis::ComputeAlpha::WireGroup

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

A resource that represents a group of redundant wires.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WireGroup

Returns a new instance of WireGroup.



85811
85812
85813
# File 'lib/google/apis/compute_alpha/classes.rb', line 85811

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#admin_enabledBoolean Also known as: admin_enabled?

Indicates whether the wires in the wire group are enabled. When false, the wires in the wire group are disabled. When true and when there is simultaneously no wire-specific override of adminEnabled to false, a given wire is enabled. Defaults to true. Corresponds to the JSON property adminEnabled

Returns:

  • (Boolean)


85711
85712
85713
# File 'lib/google/apis/compute_alpha/classes.rb', line 85711

def admin_enabled
  @admin_enabled
end

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


85718
85719
85720
# File 'lib/google/apis/compute_alpha/classes.rb', line 85718

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of the wire group. Corresponds to the JSON property description

Returns:

  • (String)


85723
85724
85725
# File 'lib/google/apis/compute_alpha/classes.rb', line 85723

def description
  @description
end

#endpointsHash<String,Google::Apis::ComputeAlpha::WireGroupEndpoint>

A map that contains the logical endpoints of the wire group. Specify key-value pairs for the map as follows:

  • Key: an RFC1035 user-specified label.
  • Value: an Endpoint object. Corresponds to the JSON property endpoints


85732
85733
85734
# File 'lib/google/apis/compute_alpha/classes.rb', line 85732

def endpoints
  @endpoints
end

#idFixnum

Output only. [Output Only] The unique identifier for the resource type. The server generates this identifier. Corresponds to the JSON property id

Returns:

  • (Fixnum)


85739
85740
85741
# File 'lib/google/apis/compute_alpha/classes.rb', line 85739

def id
  @id
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute#wireGroups for wire groups. Corresponds to the JSON property kind

Returns:

  • (String)


85745
85746
85747
# File 'lib/google/apis/compute_alpha/classes.rb', line 85745

def kind
  @kind
end

#nameString

Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


85756
85757
85758
# File 'lib/google/apis/compute_alpha/classes.rb', line 85756

def name
  @name
end

#reconcilingBoolean Also known as: reconciling?

Output only. [Output Only] Indicates whether there are wire changes yet to be processed. Corresponds to the JSON property reconciling

Returns:

  • (Boolean)


85762
85763
85764
# File 'lib/google/apis/compute_alpha/classes.rb', line 85762

def reconciling
  @reconciling
end

Output only. [Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


85768
85769
85770
# File 'lib/google/apis/compute_alpha/classes.rb', line 85768

def self_link
  @self_link
end

Corresponds to the JSON property selfLinkWithId

Returns:

  • (String)


85773
85774
85775
# File 'lib/google/apis/compute_alpha/classes.rb', line 85773

def self_link_with_id
  @self_link_with_id
end

#service_levelGoogle::Apis::ComputeAlpha::WireGroupServiceLevel

Service level details determined for the wire group configuration. Corresponds to the JSON property serviceLevel



85778
85779
85780
# File 'lib/google/apis/compute_alpha/classes.rb', line 85778

def service_level
  @service_level
end

#topologyGoogle::Apis::ComputeAlpha::WireGroupTopology

Topology details for the wire group. Corresponds to the JSON property topology



85783
85784
85785
# File 'lib/google/apis/compute_alpha/classes.rb', line 85783

def topology
  @topology
end

#wire_group_propertiesGoogle::Apis::ComputeAlpha::WireGroupProperties

The properties of a wire group. These properties determine how a group of redundant wires are created and managed. Corresponds to the JSON property wireGroupProperties



85789
85790
85791
# File 'lib/google/apis/compute_alpha/classes.rb', line 85789

def wire_group_properties
  @wire_group_properties
end

#wire_inputsHash<String,Google::Apis::ComputeAlpha::WireGroupWireInputs>

A map that contains optional settings for individual wires. Specify key-value pairs for the map as follows:

  • Key: the label of an existing wire. To view a wire label and its format, see the wires[].label field.
  • Value: a WireInputs object. Corresponds to the JSON property wireInputs


85799
85800
85801
# File 'lib/google/apis/compute_alpha/classes.rb', line 85799

def wire_inputs
  @wire_inputs
end

#wire_propertiesGoogle::Apis::ComputeAlpha::WireProperties

The properties of a wire. Corresponds to the JSON property wireProperties



85804
85805
85806
# File 'lib/google/apis/compute_alpha/classes.rb', line 85804

def wire_properties
  @wire_properties
end

#wiresArray<Google::Apis::ComputeAlpha::Wire>

Output only. The single/redundant wire(s) managed by the wire group. Corresponds to the JSON property wires



85809
85810
85811
# File 'lib/google/apis/compute_alpha/classes.rb', line 85809

def wires
  @wires
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



85816
85817
85818
85819
85820
85821
85822
85823
85824
85825
85826
85827
85828
85829
85830
85831
85832
85833
# File 'lib/google/apis/compute_alpha/classes.rb', line 85816

def update!(**args)
  @admin_enabled = args[:admin_enabled] if args.key?(:admin_enabled)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @endpoints = args[:endpoints] if args.key?(:endpoints)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @reconciling = args[:reconciling] if args.key?(:reconciling)
  @self_link = args[:self_link] if args.key?(:self_link)
  @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id)
  @service_level = args[:service_level] if args.key?(:service_level)
  @topology = args[:topology] if args.key?(:topology)
  @wire_group_properties = args[:wire_group_properties] if args.key?(:wire_group_properties)
  @wire_inputs = args[:wire_inputs] if args.key?(:wire_inputs)
  @wire_properties = args[:wire_properties] if args.key?(:wire_properties)
  @wires = args[:wires] if args.key?(:wires)
end