Class: Google::Apis::ComputeAlpha::WireGroup

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

A resource that represents a group of redundant wires.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WireGroup

Returns a new instance of WireGroup.



85458
85459
85460
# File 'lib/google/apis/compute_alpha/classes.rb', line 85458

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#admin_enabledBoolean Also known as: admin_enabled?

Indicates whether the wires in the wire group are enabled. When false, the wires in the wire group are disabled. When true and when there is simultaneously no wire-specific override of adminEnabled to false, a given wire is enabled. Defaults to true. Corresponds to the JSON property adminEnabled

Returns:

  • (Boolean)


85358
85359
85360
# File 'lib/google/apis/compute_alpha/classes.rb', line 85358

def admin_enabled
  @admin_enabled
end

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


85365
85366
85367
# File 'lib/google/apis/compute_alpha/classes.rb', line 85365

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of the wire group. Corresponds to the JSON property description

Returns:

  • (String)


85370
85371
85372
# File 'lib/google/apis/compute_alpha/classes.rb', line 85370

def description
  @description
end

#endpointsHash<String,Google::Apis::ComputeAlpha::WireGroupEndpoint>

A map that contains the logical endpoints of the wire group. Specify key-value pairs for the map as follows:

  • Key: an RFC1035 user-specified label.
  • Value: an Endpoint object. Corresponds to the JSON property endpoints


85379
85380
85381
# File 'lib/google/apis/compute_alpha/classes.rb', line 85379

def endpoints
  @endpoints
end

#idFixnum

Output only. [Output Only] The unique identifier for the resource type. The server generates this identifier. Corresponds to the JSON property id

Returns:

  • (Fixnum)


85386
85387
85388
# File 'lib/google/apis/compute_alpha/classes.rb', line 85386

def id
  @id
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute#wireGroups for wire groups. Corresponds to the JSON property kind

Returns:

  • (String)


85392
85393
85394
# File 'lib/google/apis/compute_alpha/classes.rb', line 85392

def kind
  @kind
end

#nameString

Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


85403
85404
85405
# File 'lib/google/apis/compute_alpha/classes.rb', line 85403

def name
  @name
end

#reconcilingBoolean Also known as: reconciling?

Output only. [Output Only] Indicates whether there are wire changes yet to be processed. Corresponds to the JSON property reconciling

Returns:

  • (Boolean)


85409
85410
85411
# File 'lib/google/apis/compute_alpha/classes.rb', line 85409

def reconciling
  @reconciling
end

Output only. [Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


85415
85416
85417
# File 'lib/google/apis/compute_alpha/classes.rb', line 85415

def self_link
  @self_link
end

Corresponds to the JSON property selfLinkWithId

Returns:

  • (String)


85420
85421
85422
# File 'lib/google/apis/compute_alpha/classes.rb', line 85420

def self_link_with_id
  @self_link_with_id
end

#service_levelGoogle::Apis::ComputeAlpha::WireGroupServiceLevel

Service level details determined for the wire group configuration. Corresponds to the JSON property serviceLevel



85425
85426
85427
# File 'lib/google/apis/compute_alpha/classes.rb', line 85425

def service_level
  @service_level
end

#topologyGoogle::Apis::ComputeAlpha::WireGroupTopology

Topology details for the wire group. Corresponds to the JSON property topology



85430
85431
85432
# File 'lib/google/apis/compute_alpha/classes.rb', line 85430

def topology
  @topology
end

#wire_group_propertiesGoogle::Apis::ComputeAlpha::WireGroupProperties

The properties of a wire group. These properties determine how a group of redundant wires are created and managed. Corresponds to the JSON property wireGroupProperties



85436
85437
85438
# File 'lib/google/apis/compute_alpha/classes.rb', line 85436

def wire_group_properties
  @wire_group_properties
end

#wire_inputsHash<String,Google::Apis::ComputeAlpha::WireGroupWireInputs>

A map that contains optional settings for individual wires. Specify key-value pairs for the map as follows:

  • Key: the label of an existing wire. To view a wire label and its format, see the wires[].label field.
  • Value: a WireInputs object. Corresponds to the JSON property wireInputs


85446
85447
85448
# File 'lib/google/apis/compute_alpha/classes.rb', line 85446

def wire_inputs
  @wire_inputs
end

#wire_propertiesGoogle::Apis::ComputeAlpha::WireProperties

The properties of a wire. Corresponds to the JSON property wireProperties



85451
85452
85453
# File 'lib/google/apis/compute_alpha/classes.rb', line 85451

def wire_properties
  @wire_properties
end

#wiresArray<Google::Apis::ComputeAlpha::Wire>

Output only. The single/redundant wire(s) managed by the wire group. Corresponds to the JSON property wires



85456
85457
85458
# File 'lib/google/apis/compute_alpha/classes.rb', line 85456

def wires
  @wires
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



85463
85464
85465
85466
85467
85468
85469
85470
85471
85472
85473
85474
85475
85476
85477
85478
85479
85480
# File 'lib/google/apis/compute_alpha/classes.rb', line 85463

def update!(**args)
  @admin_enabled = args[:admin_enabled] if args.key?(:admin_enabled)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @endpoints = args[:endpoints] if args.key?(:endpoints)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @reconciling = args[:reconciling] if args.key?(:reconciling)
  @self_link = args[:self_link] if args.key?(:self_link)
  @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id)
  @service_level = args[:service_level] if args.key?(:service_level)
  @topology = args[:topology] if args.key?(:topology)
  @wire_group_properties = args[:wire_group_properties] if args.key?(:wire_group_properties)
  @wire_inputs = args[:wire_inputs] if args.key?(:wire_inputs)
  @wire_properties = args[:wire_properties] if args.key?(:wire_properties)
  @wires = args[:wires] if args.key?(:wires)
end