Class: Google::Apis::ComputeAlpha::WireGroupList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::WireGroupList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Response for the list request.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::WireGroup>
A list of wire group resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::WireGroupList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ WireGroupList
constructor
A new instance of WireGroupList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ WireGroupList
Returns a new instance of WireGroupList.
85612 85613 85614 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 85612 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
85568 85569 85570 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 85568 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
85573 85574 85575 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 85573 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::WireGroup>
A list of wire group resources.
Corresponds to the JSON property items
85578 85579 85580 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 85578 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#wireGroups for
wire groups.
Corresponds to the JSON property kind
85584 85585 85586 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 85584 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
85594 85595 85596 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 85594 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
85599 85600 85601 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 85599 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
end_interface: MixerListResponseWithEtagBuilder
Corresponds to the JSON property unreachables
85605 85606 85607 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 85605 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::WireGroupList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
85610 85611 85612 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 85610 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
85617 85618 85619 85620 85621 85622 85623 85624 85625 85626 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 85617 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |