Class: Google::Apis::ComputeAlpha::WireGroupList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::WireGroupList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Response for the list request.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::WireGroup>
A list of wire group resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::WireGroupList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ WireGroupList
constructor
A new instance of WireGroupList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ WireGroupList
Returns a new instance of WireGroupList.
84187 84188 84189 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 84187 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
84143 84144 84145 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 84143 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
84148 84149 84150 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 84148 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::WireGroup>
A list of wire group resources.
Corresponds to the JSON property items
84153 84154 84155 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 84153 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#wireGroups for
wire groups.
Corresponds to the JSON property kind
84159 84160 84161 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 84159 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
84169 84170 84171 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 84169 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
84174 84175 84176 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 84174 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
end_interface: MixerListResponseWithEtagBuilder
Corresponds to the JSON property unreachables
84180 84181 84182 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 84180 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::WireGroupList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
84185 84186 84187 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 84185 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
84192 84193 84194 84195 84196 84197 84198 84199 84200 84201 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 84192 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |