Class: Google::Apis::ComputeAlpha::WireGroupList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Response for the list request.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WireGroupList

Returns a new instance of WireGroupList.



83574
83575
83576
# File 'lib/google/apis/compute_alpha/classes.rb', line 83574

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


83530
83531
83532
# File 'lib/google/apis/compute_alpha/classes.rb', line 83530

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


83535
83536
83537
# File 'lib/google/apis/compute_alpha/classes.rb', line 83535

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::WireGroup>

A list of wire group resources. Corresponds to the JSON property items



83540
83541
83542
# File 'lib/google/apis/compute_alpha/classes.rb', line 83540

def items
  @items
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute#wireGroups for wire groups. Corresponds to the JSON property kind

Returns:

  • (String)


83546
83547
83548
# File 'lib/google/apis/compute_alpha/classes.rb', line 83546

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


83556
83557
83558
# File 'lib/google/apis/compute_alpha/classes.rb', line 83556

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


83561
83562
83563
# File 'lib/google/apis/compute_alpha/classes.rb', line 83561

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


83567
83568
83569
# File 'lib/google/apis/compute_alpha/classes.rb', line 83567

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeAlpha::WireGroupList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



83572
83573
83574
# File 'lib/google/apis/compute_alpha/classes.rb', line 83572

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



83579
83580
83581
83582
83583
83584
83585
83586
83587
83588
# File 'lib/google/apis/compute_alpha/classes.rb', line 83579

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end