Class: Google::Apis::ComputeAlpha::WireGroupList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::WireGroupList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Response for the list request.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::WireGroup>
A list of wire group resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::WireGroupList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ WireGroupList
constructor
A new instance of WireGroupList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ WireGroupList
Returns a new instance of WireGroupList.
83306 83307 83308 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 83306 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
83262 83263 83264 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 83262 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
83267 83268 83269 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 83267 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::WireGroup>
A list of wire group resources.
Corresponds to the JSON property items
83272 83273 83274 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 83272 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#wireGroups for
wire groups.
Corresponds to the JSON property kind
83278 83279 83280 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 83278 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
83288 83289 83290 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 83288 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
83293 83294 83295 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 83293 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
end_interface: MixerListResponseWithEtagBuilder
Corresponds to the JSON property unreachables
83299 83300 83301 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 83299 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeAlpha::WireGroupList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
83304 83305 83306 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 83304 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
83311 83312 83313 83314 83315 83316 83317 83318 83319 83320 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 83311 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |