Class: Google::Apis::ComputeAlpha::WireGroupProperties

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

The properties of a wire group. These properties determine how a group of redundant wires are created and managed.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WireGroupProperties

Returns a new instance of WireGroupProperties.



82408
82409
82410
# File 'lib/google/apis/compute_alpha/classes.rb', line 82408

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#typeString

The type of the wire group, one of the following:

  • WIRE: a single pseudowire over two Interconnect connections with no redundancy.
  • REDUNDANT: two pseudowires over four Interconnect connections, with two connections in one metro and two connections in another metro. Each redundant pair of Interconnect connections spans both edge availability domains of the metro. Each pseudowire connects Interconnect connections in matching edge availability domains of the two metros.
  • BOX_AND_CROSS: four pseudowires over four Interconnect connections, with two connections in one metro and two connections in another metro. Each redundant pair of Interconnect connections spans both edge availability domains of the metro. Two pseudowires connect Interconnect connections in matching edge availability domains of the two metros. Two additional pseudowires connect the non-matching edge availability domains of the two metros. Corresponds to the JSON property type

Returns:

  • (String)


82406
82407
82408
# File 'lib/google/apis/compute_alpha/classes.rb', line 82406

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



82413
82414
82415
# File 'lib/google/apis/compute_alpha/classes.rb', line 82413

def update!(**args)
  @type = args[:type] if args.key?(:type)
end