Class: Google::Apis::ComputeAlpha::WireGroupWireInputs

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Optional settings for individual wires. Allows wire-level control that can be useful for migration purposes. If you use this field, you opt-out of the SLA for the wire group.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WireGroupWireInputs

Returns a new instance of WireGroupWireInputs.



84453
84454
84455
# File 'lib/google/apis/compute_alpha/classes.rb', line 84453

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#admin_enabledBoolean Also known as: admin_enabled?

Indicates whether the wire is enabled. When false, the wire is disabled. When true and when the wire group of the wire is also enabled, the wire is enabled. Defaults to true. Corresponds to the JSON property adminEnabled

Returns:

  • (Boolean)


84445
84446
84447
# File 'lib/google/apis/compute_alpha/classes.rb', line 84445

def admin_enabled
  @admin_enabled
end

#wire_property_overridesGoogle::Apis::ComputeAlpha::WireProperties

The properties of a wire. Corresponds to the JSON property wirePropertyOverrides



84451
84452
84453
# File 'lib/google/apis/compute_alpha/classes.rb', line 84451

def wire_property_overrides
  @wire_property_overrides
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



84458
84459
84460
84461
# File 'lib/google/apis/compute_alpha/classes.rb', line 84458

def update!(**args)
  @admin_enabled = args[:admin_enabled] if args.key?(:admin_enabled)
  @wire_property_overrides = args[:wire_property_overrides] if args.key?(:wire_property_overrides)
end