Class: Google::Apis::ComputeAlpha::WireGroupWireInputs
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::WireGroupWireInputs
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Optional settings for individual wires. Allows wire-level control that can be useful for migration purposes. If you use this field, you opt-out of the SLA for the wire group.
Instance Attribute Summary collapse
-
#admin_enabled ⇒ Boolean
(also: #admin_enabled?)
Indicates whether the wire is enabled.
-
#wire_property_overrides ⇒ Google::Apis::ComputeAlpha::WireProperties
The properties of a wire.
Instance Method Summary collapse
-
#initialize(**args) ⇒ WireGroupWireInputs
constructor
A new instance of WireGroupWireInputs.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ WireGroupWireInputs
Returns a new instance of WireGroupWireInputs.
84396 84397 84398 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 84396 def initialize(**args) update!(**args) end |
Instance Attribute Details
#admin_enabled ⇒ Boolean Also known as: admin_enabled?
Indicates whether the wire is enabled.
When false, the wire is disabled. When true and when the wire group of
the wire is also enabled, the wire is enabled. Defaults to true.
Corresponds to the JSON property adminEnabled
84388 84389 84390 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 84388 def admin_enabled @admin_enabled end |
#wire_property_overrides ⇒ Google::Apis::ComputeAlpha::WireProperties
The properties of a wire.
Corresponds to the JSON property wirePropertyOverrides
84394 84395 84396 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 84394 def wire_property_overrides @wire_property_overrides end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
84401 84402 84403 84404 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 84401 def update!(**args) @admin_enabled = args[:admin_enabled] if args.key?(:admin_enabled) @wire_property_overrides = args[:wire_property_overrides] if args.key?(:wire_property_overrides) end |