Class: Google::Apis::ComputeAlpha::WireProperties

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

The properties of a wire.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WireProperties

Returns a new instance of WireProperties.



86231
86232
86233
# File 'lib/google/apis/compute_alpha/classes.rb', line 86231

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bandwidth_allocationString

The configuration of the bandwidth allocation, one of the following:

  • ALLOCATE_PER_WIRE: configures a separate unmetered bandwidth allocation (and associated charges) for each wire in the group.
  • SHARED_WITH_WIRE_GROUP: this is the default behavior, which configures one unmetered bandwidth allocation for the wire group. The unmetered bandwidth is divided equally across each wire in the group, but dynamic throttling reallocates unused unmetered bandwidth from unused or underused wires to other wires in the group. Corresponds to the JSON property bandwidthAllocation

Returns:

  • (String)


86200
86201
86202
# File 'lib/google/apis/compute_alpha/classes.rb', line 86200

def bandwidth_allocation
  @bandwidth_allocation
end

#bandwidth_meteredFixnum

The metered bandwidth in Gigabits per second, using decimal units. 10 is 10 Gbps, 100 is 100 Gbps. The default value is 0. You can specify unlimited bandwidth by entering -1. However, actual data transfer is limited by the port speed. Corresponds to the JSON property bandwidthMetered

Returns:

  • (Fixnum)


86208
86209
86210
# File 'lib/google/apis/compute_alpha/classes.rb', line 86208

def bandwidth_metered
  @bandwidth_metered
end

#bandwidth_unmeteredFixnum

The unmetered bandwidth in Gigabits per second, using decimal units. 10 is 10 Gbps, 100 is 100 Gbps. The bandwidth must be greater than 0. Corresponds to the JSON property bandwidthUnmetered

Returns:

  • (Fixnum)


86214
86215
86216
# File 'lib/google/apis/compute_alpha/classes.rb', line 86214

def bandwidth_unmetered
  @bandwidth_unmetered
end

#fault_responseString

Response when a fault is detected in a pseudowire:

  • NONE: default.
  • DISABLE_PORT: set the port line protocol down when inline probes detect a fault. This setting is only permitted on port mode pseudowires. Corresponds to the JSON property faultResponse

Returns:

  • (String)


86224
86225
86226
# File 'lib/google/apis/compute_alpha/classes.rb', line 86224

def fault_response
  @fault_response
end

#network_service_classString

The network service class. Corresponds to the JSON property networkServiceClass

Returns:

  • (String)


86229
86230
86231
# File 'lib/google/apis/compute_alpha/classes.rb', line 86229

def network_service_class
  @network_service_class
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



86236
86237
86238
86239
86240
86241
86242
# File 'lib/google/apis/compute_alpha/classes.rb', line 86236

def update!(**args)
  @bandwidth_allocation = args[:bandwidth_allocation] if args.key?(:bandwidth_allocation)
  @bandwidth_metered = args[:bandwidth_metered] if args.key?(:bandwidth_metered)
  @bandwidth_unmetered = args[:bandwidth_unmetered] if args.key?(:bandwidth_unmetered)
  @fault_response = args[:fault_response] if args.key?(:fault_response)
  @network_service_class = args[:network_service_class] if args.key?(:network_service_class)
end