Class: Google::Apis::ComputeAlpha::WireProperties
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::WireProperties
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
The properties of a wire.
Instance Attribute Summary collapse
-
#bandwidth_allocation ⇒ String
The configuration of the bandwidth allocation, one of the following:.
-
#bandwidth_metered ⇒ Fixnum
The metered bandwidth in Gigabits per second, using decimal units.
-
#bandwidth_unmetered ⇒ Fixnum
The unmetered bandwidth in Gigabits per second, using decimal units.
-
#fault_response ⇒ String
Response when a fault is detected in a pseudowire:.
-
#network_service_class ⇒ String
The network service class.
Instance Method Summary collapse
-
#initialize(**args) ⇒ WireProperties
constructor
A new instance of WireProperties.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ WireProperties
Returns a new instance of WireProperties.
85878 85879 85880 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 85878 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bandwidth_allocation ⇒ String
The configuration of the bandwidth allocation, one of the following:
- ALLOCATE_PER_WIRE: configures a separate unmetered bandwidth allocation (and associated charges) for each wire in the group.
- SHARED_WITH_WIRE_GROUP: this is the default behavior, which configures
one unmetered bandwidth allocation for the wire group. The unmetered
bandwidth is divided equally across each wire in the group, but dynamic
throttling reallocates unused unmetered bandwidth from unused or underused
wires to other wires in the group.
Corresponds to the JSON property
bandwidthAllocation
85847 85848 85849 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 85847 def bandwidth_allocation @bandwidth_allocation end |
#bandwidth_metered ⇒ Fixnum
The metered bandwidth in Gigabits per second, using decimal units. 10 is
10 Gbps, 100 is 100 Gbps. The default value is 0. You can specify
unlimited bandwidth by entering -1. However, actual data transfer is
limited by the port speed.
Corresponds to the JSON property bandwidthMetered
85855 85856 85857 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 85855 def bandwidth_metered @bandwidth_metered end |
#bandwidth_unmetered ⇒ Fixnum
The unmetered bandwidth in Gigabits per second, using decimal units. 10
is 10 Gbps, 100 is 100 Gbps. The bandwidth must be greater than 0.
Corresponds to the JSON property bandwidthUnmetered
85861 85862 85863 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 85861 def bandwidth_unmetered @bandwidth_unmetered end |
#fault_response ⇒ String
Response when a fault is detected in a pseudowire:
- NONE: default.
- DISABLE_PORT: set the port line protocol down when inline probes
detect a fault. This setting is only permitted on port mode
pseudowires.
Corresponds to the JSON property
faultResponse
85871 85872 85873 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 85871 def fault_response @fault_response end |
#network_service_class ⇒ String
The network service class.
Corresponds to the JSON property networkServiceClass
85876 85877 85878 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 85876 def network_service_class @network_service_class end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
85883 85884 85885 85886 85887 85888 85889 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 85883 def update!(**args) @bandwidth_allocation = args[:bandwidth_allocation] if args.key?(:bandwidth_allocation) @bandwidth_metered = args[:bandwidth_metered] if args.key?(:bandwidth_metered) @bandwidth_unmetered = args[:bandwidth_unmetered] if args.key?(:bandwidth_unmetered) @fault_response = args[:fault_response] if args.key?(:fault_response) @network_service_class = args[:network_service_class] if args.key?(:network_service_class) end |