Class: Google::Apis::ComputeAlpha::WireProperties
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::WireProperties
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
The properties of a wire.
Instance Attribute Summary collapse
-
#bandwidth_allocation ⇒ String
The configuration of the bandwidth allocation, one of the following:.
-
#bandwidth_metered ⇒ Fixnum
The metered bandwidth in Gigabits per second, using decimal units.
-
#bandwidth_unmetered ⇒ Fixnum
The unmetered bandwidth in Gigabits per second, using decimal units.
-
#fault_response ⇒ String
Response when a fault is detected in a pseudowire:.
-
#network_service_class ⇒ String
The network service class.
Instance Method Summary collapse
-
#initialize(**args) ⇒ WireProperties
constructor
A new instance of WireProperties.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ WireProperties
Returns a new instance of WireProperties.
84510 84511 84512 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 84510 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bandwidth_allocation ⇒ String
The configuration of the bandwidth allocation, one of the following:
- ALLOCATE_PER_WIRE: configures a separate unmetered bandwidth allocation (and associated charges) for each wire in the group.
- SHARED_WITH_WIRE_GROUP: this is the default behavior, which configures
one unmetered bandwidth allocation for the wire group. The unmetered
bandwidth is divided equally across each wire in the group, but dynamic
throttling reallocates unused unmetered bandwidth from unused or underused
wires to other wires in the group.
Corresponds to the JSON property
bandwidthAllocation
84479 84480 84481 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 84479 def bandwidth_allocation @bandwidth_allocation end |
#bandwidth_metered ⇒ Fixnum
The metered bandwidth in Gigabits per second, using decimal units. 10 is
10 Gbps, 100 is 100 Gbps. The default value is 0. You can specify
unlimited bandwidth by entering -1. However, actual data transfer is
limited by the port speed.
Corresponds to the JSON property bandwidthMetered
84487 84488 84489 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 84487 def bandwidth_metered @bandwidth_metered end |
#bandwidth_unmetered ⇒ Fixnum
The unmetered bandwidth in Gigabits per second, using decimal units. 10
is 10 Gbps, 100 is 100 Gbps. The bandwidth must be greater than 0.
Corresponds to the JSON property bandwidthUnmetered
84493 84494 84495 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 84493 def bandwidth_unmetered @bandwidth_unmetered end |
#fault_response ⇒ String
Response when a fault is detected in a pseudowire:
- NONE: default.
- DISABLE_PORT: set the port line protocol down when inline probes
detect a fault. This setting is only permitted on port mode
pseudowires.
Corresponds to the JSON property
faultResponse
84503 84504 84505 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 84503 def fault_response @fault_response end |
#network_service_class ⇒ String
The network service class.
Corresponds to the JSON property networkServiceClass
84508 84509 84510 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 84508 def network_service_class @network_service_class end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
84515 84516 84517 84518 84519 84520 84521 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 84515 def update!(**args) @bandwidth_allocation = args[:bandwidth_allocation] if args.key?(:bandwidth_allocation) @bandwidth_metered = args[:bandwidth_metered] if args.key?(:bandwidth_metered) @bandwidth_unmetered = args[:bandwidth_unmetered] if args.key?(:bandwidth_unmetered) @fault_response = args[:fault_response] if args.key?(:fault_response) @network_service_class = args[:network_service_class] if args.key?(:network_service_class) end |