Class: Google::Apis::ComputeAlpha::WireProperties

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

The properties of a wire.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WireProperties

Returns a new instance of WireProperties.



84453
84454
84455
# File 'lib/google/apis/compute_alpha/classes.rb', line 84453

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bandwidth_allocationString

The configuration of the bandwidth allocation, one of the following:

  • ALLOCATE_PER_WIRE: configures a separate unmetered bandwidth allocation (and associated charges) for each wire in the group.
  • SHARED_WITH_WIRE_GROUP: this is the default behavior, which configures one unmetered bandwidth allocation for the wire group. The unmetered bandwidth is divided equally across each wire in the group, but dynamic throttling reallocates unused unmetered bandwidth from unused or underused wires to other wires in the group. Corresponds to the JSON property bandwidthAllocation

Returns:

  • (String)


84422
84423
84424
# File 'lib/google/apis/compute_alpha/classes.rb', line 84422

def bandwidth_allocation
  @bandwidth_allocation
end

#bandwidth_meteredFixnum

The metered bandwidth in Gigabits per second, using decimal units. 10 is 10 Gbps, 100 is 100 Gbps. The default value is 0. You can specify unlimited bandwidth by entering -1. However, actual data transfer is limited by the port speed. Corresponds to the JSON property bandwidthMetered

Returns:

  • (Fixnum)


84430
84431
84432
# File 'lib/google/apis/compute_alpha/classes.rb', line 84430

def bandwidth_metered
  @bandwidth_metered
end

#bandwidth_unmeteredFixnum

The unmetered bandwidth in Gigabits per second, using decimal units. 10 is 10 Gbps, 100 is 100 Gbps. The bandwidth must be greater than 0. Corresponds to the JSON property bandwidthUnmetered

Returns:

  • (Fixnum)


84436
84437
84438
# File 'lib/google/apis/compute_alpha/classes.rb', line 84436

def bandwidth_unmetered
  @bandwidth_unmetered
end

#fault_responseString

Response when a fault is detected in a pseudowire:

  • NONE: default.
  • DISABLE_PORT: set the port line protocol down when inline probes detect a fault. This setting is only permitted on port mode pseudowires. Corresponds to the JSON property faultResponse

Returns:

  • (String)


84446
84447
84448
# File 'lib/google/apis/compute_alpha/classes.rb', line 84446

def fault_response
  @fault_response
end

#network_service_classString

The network service class. Corresponds to the JSON property networkServiceClass

Returns:

  • (String)


84451
84452
84453
# File 'lib/google/apis/compute_alpha/classes.rb', line 84451

def network_service_class
  @network_service_class
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



84458
84459
84460
84461
84462
84463
84464
# File 'lib/google/apis/compute_alpha/classes.rb', line 84458

def update!(**args)
  @bandwidth_allocation = args[:bandwidth_allocation] if args.key?(:bandwidth_allocation)
  @bandwidth_metered = args[:bandwidth_metered] if args.key?(:bandwidth_metered)
  @bandwidth_unmetered = args[:bandwidth_unmetered] if args.key?(:bandwidth_unmetered)
  @fault_response = args[:fault_response] if args.key?(:fault_response)
  @network_service_class = args[:network_service_class] if args.key?(:network_service_class)
end