Class: Google::Apis::ComputeAlpha::XpnHostList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::XpnHostList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::Project>
[Output Only] A list of shared VPC host project URLs.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::XpnHostList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ XpnHostList
constructor
A new instance of XpnHostList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ XpnHostList
Returns a new instance of XpnHostList.
86317 86318 86319 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 86317 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
86284 86285 86286 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 86284 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::Project>
[Output Only] A list of shared VPC host project URLs.
Corresponds to the JSON property items
86289 86290 86291 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 86289 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#xpnHostList for
lists of shared VPC hosts.
Corresponds to the JSON property kind
86295 86296 86297 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 86295 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
86305 86306 86307 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 86305 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
86310 86311 86312 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 86310 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::XpnHostList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
86315 86316 86317 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 86315 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
86322 86323 86324 86325 86326 86327 86328 86329 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 86322 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |