Class: Google::Apis::ComputeAlpha::XpnHostList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::XpnHostList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::Project>
[Output Only] A list of shared VPC host project URLs.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::XpnHostList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ XpnHostList
constructor
A new instance of XpnHostList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ XpnHostList
Returns a new instance of XpnHostList.
84533 84534 84535 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 84533 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
84500 84501 84502 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 84500 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::Project>
[Output Only] A list of shared VPC host project URLs.
Corresponds to the JSON property items
84505 84506 84507 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 84505 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#xpnHostList for
lists of shared VPC hosts.
Corresponds to the JSON property kind
84511 84512 84513 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 84511 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
84521 84522 84523 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 84521 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
84526 84527 84528 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 84526 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::XpnHostList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
84531 84532 84533 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 84531 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
84538 84539 84540 84541 84542 84543 84544 84545 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 84538 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |