Class: Google::Apis::ComputeAlpha::XpnHostList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ XpnHostList

Returns a new instance of XpnHostList.



83920
83921
83922
# File 'lib/google/apis/compute_alpha/classes.rb', line 83920

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


83887
83888
83889
# File 'lib/google/apis/compute_alpha/classes.rb', line 83887

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::Project>

[Output Only] A list of shared VPC host project URLs. Corresponds to the JSON property items



83892
83893
83894
# File 'lib/google/apis/compute_alpha/classes.rb', line 83892

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#xpnHostList for lists of shared VPC hosts. Corresponds to the JSON property kind

Returns:

  • (String)


83898
83899
83900
# File 'lib/google/apis/compute_alpha/classes.rb', line 83898

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


83908
83909
83910
# File 'lib/google/apis/compute_alpha/classes.rb', line 83908

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


83913
83914
83915
# File 'lib/google/apis/compute_alpha/classes.rb', line 83913

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::XpnHostList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



83918
83919
83920
# File 'lib/google/apis/compute_alpha/classes.rb', line 83918

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



83925
83926
83927
83928
83929
83930
83931
83932
# File 'lib/google/apis/compute_alpha/classes.rb', line 83925

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end