Class: Google::Apis::ComputeAlpha::XpnHostList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::XpnHostList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::Project>
[Output Only] A list of shared VPC host project URLs.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::XpnHostList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ XpnHostList
constructor
A new instance of XpnHostList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ XpnHostList
Returns a new instance of XpnHostList.
83918 83919 83920 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 83918 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
83885 83886 83887 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 83885 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::Project>
[Output Only] A list of shared VPC host project URLs.
Corresponds to the JSON property items
83890 83891 83892 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 83890 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#xpnHostList for
lists of shared VPC hosts.
Corresponds to the JSON property kind
83896 83897 83898 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 83896 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
83906 83907 83908 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 83906 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
83911 83912 83913 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 83911 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::XpnHostList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
83916 83917 83918 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 83916 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
83923 83924 83925 83926 83927 83928 83929 83930 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 83923 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |