Class: Google::Apis::ComputeAlpha::XpnHostList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::XpnHostList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::Project>
[Output Only] A list of shared VPC host project URLs.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::XpnHostList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ XpnHostList
constructor
A new instance of XpnHostList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ XpnHostList
Returns a new instance of XpnHostList.
83652 83653 83654 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 83652 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
83619 83620 83621 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 83619 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::Project>
[Output Only] A list of shared VPC host project URLs.
Corresponds to the JSON property items
83624 83625 83626 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 83624 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#xpnHostList for
lists of shared VPC hosts.
Corresponds to the JSON property kind
83630 83631 83632 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 83630 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
83640 83641 83642 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 83640 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
83645 83646 83647 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 83645 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::XpnHostList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
83650 83651 83652 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 83650 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
83657 83658 83659 83660 83661 83662 83663 83664 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 83657 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |