Class: Google::Apis::ComputeAlpha::ZoneList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::ZoneList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Contains a list of zone resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::Zone>
A list of Zone resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::ZoneList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ZoneList
constructor
A new instance of ZoneList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ZoneList
Returns a new instance of ZoneList.
86561 86562 86563 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 86561 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
86529 86530 86531 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 86529 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::Zone>
A list of Zone resources.
Corresponds to the JSON property items
86534 86535 86536 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 86534 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
86539 86540 86541 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 86539 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
86549 86550 86551 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 86549 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
86554 86555 86556 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 86554 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::ZoneList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
86559 86560 86561 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 86559 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
86566 86567 86568 86569 86570 86571 86572 86573 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 86566 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |