Class: Google::Apis::ComputeAlpha::ZoneList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::ZoneList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Contains a list of zone resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::Zone>
A list of Zone resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::ZoneList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ZoneList
constructor
A new instance of ZoneList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ZoneList
Returns a new instance of ZoneList.
86208 86209 86210 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 86208 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
86176 86177 86178 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 86176 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::Zone>
A list of Zone resources.
Corresponds to the JSON property items
86181 86182 86183 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 86181 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
86186 86187 86188 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 86186 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
86196 86197 86198 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 86196 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
86201 86202 86203 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 86201 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::ZoneList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
86206 86207 86208 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 86206 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
86213 86214 86215 86216 86217 86218 86219 86220 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 86213 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |