Class: Google::Apis::ComputeAlpha::ZoneList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of zone resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ZoneList

Returns a new instance of ZoneList.



84834
84835
84836
# File 'lib/google/apis/compute_alpha/classes.rb', line 84834

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


84802
84803
84804
# File 'lib/google/apis/compute_alpha/classes.rb', line 84802

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::Zone>

A list of Zone resources. Corresponds to the JSON property items



84807
84808
84809
# File 'lib/google/apis/compute_alpha/classes.rb', line 84807

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


84812
84813
84814
# File 'lib/google/apis/compute_alpha/classes.rb', line 84812

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


84822
84823
84824
# File 'lib/google/apis/compute_alpha/classes.rb', line 84822

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


84827
84828
84829
# File 'lib/google/apis/compute_alpha/classes.rb', line 84827

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::ZoneList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



84832
84833
84834
# File 'lib/google/apis/compute_alpha/classes.rb', line 84832

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



84839
84840
84841
84842
84843
84844
84845
84846
# File 'lib/google/apis/compute_alpha/classes.rb', line 84839

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end