Class: Google::Apis::ComputeAlpha::ZoneList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::ZoneList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Overview
Contains a list of zone resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeAlpha::Zone>
A list of Zone resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeAlpha::ZoneList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ZoneList
constructor
A new instance of ZoneList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ZoneList
Returns a new instance of ZoneList.
84777 84778 84779 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 84777 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
84745 84746 84747 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 84745 def id @id end |
#items ⇒ Array<Google::Apis::ComputeAlpha::Zone>
A list of Zone resources.
Corresponds to the JSON property items
84750 84751 84752 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 84750 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
84755 84756 84757 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 84755 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
84765 84766 84767 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 84765 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
84770 84771 84772 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 84770 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeAlpha::ZoneList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
84775 84776 84777 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 84775 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
84782 84783 84784 84785 84786 84787 84788 84789 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 84782 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |