Class: Google::Apis::ComputeAlpha::ZoneList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb

Overview

Contains a list of zone resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ZoneList

Returns a new instance of ZoneList.



83896
83897
83898
# File 'lib/google/apis/compute_alpha/classes.rb', line 83896

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


83864
83865
83866
# File 'lib/google/apis/compute_alpha/classes.rb', line 83864

def id
  @id
end

#itemsArray<Google::Apis::ComputeAlpha::Zone>

A list of Zone resources. Corresponds to the JSON property items



83869
83870
83871
# File 'lib/google/apis/compute_alpha/classes.rb', line 83869

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


83874
83875
83876
# File 'lib/google/apis/compute_alpha/classes.rb', line 83874

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


83884
83885
83886
# File 'lib/google/apis/compute_alpha/classes.rb', line 83884

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


83889
83890
83891
# File 'lib/google/apis/compute_alpha/classes.rb', line 83889

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeAlpha::ZoneList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



83894
83895
83896
# File 'lib/google/apis/compute_alpha/classes.rb', line 83894

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



83901
83902
83903
83904
83905
83906
83907
83908
# File 'lib/google/apis/compute_alpha/classes.rb', line 83901

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end