Class: Google::Apis::ComputeAlpha::ZoneSetLabelsRequest
- Inherits:
-
Object
- Object
- Google::Apis::ComputeAlpha::ZoneSetLabelsRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_alpha/classes.rb,
lib/google/apis/compute_alpha/representations.rb,
lib/google/apis/compute_alpha/representations.rb
Instance Attribute Summary collapse
-
#label_fingerprint ⇒ String
The fingerprint of the previous set of labels for this resource, used to detect conflicts.
-
#labels ⇒ Hash<String,String>
The labels to set for this resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ZoneSetLabelsRequest
constructor
A new instance of ZoneSetLabelsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ZoneSetLabelsRequest
Returns a new instance of ZoneSetLabelsRequest.
84288 84289 84290 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 84288 def initialize(**args) update!(**args) end |
Instance Attribute Details
#label_fingerprint ⇒ String
The fingerprint of the previous set of labels for this resource,
used to detect conflicts. The fingerprint is initially generated by Compute
Engine and changes after every request to modify or update labels. You must
always provide an up-to-date fingerprint hash in order to update or change
labels. Make a get() request to the resource to get the latest
fingerprint.
Corresponds to the JSON property labelFingerprint
NOTE: Values are automatically base64 encoded/decoded in the client library.
84281 84282 84283 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 84281 def label_fingerprint @label_fingerprint end |
#labels ⇒ Hash<String,String>
The labels to set for this resource.
Corresponds to the JSON property labels
84286 84287 84288 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 84286 def labels @labels end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
84293 84294 84295 84296 |
# File 'lib/google/apis/compute_alpha/classes.rb', line 84293 def update!(**args) @label_fingerprint = args[:label_fingerprint] if args.key?(:label_fingerprint) @labels = args[:labels] if args.key?(:labels) end |